@@ -24,7 +24,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaRdio.c,v 1.4 2001
 #include <stdio.h>
 #include <sys/types.h>
 
-#include "misc/magic.h"
+#include <netinet/in.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
@@ -32,17 +34,21 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaRdio.c,v 1.4 2001
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "utils/malloc.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
 #include "cif/CIFread.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "calma/calmaInt.h"
 
+/* Forward declarations */
+bool calmaReadR8();
+bool calmaSkipBytes();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -325,7 +331,7 @@ bool
 calmaReadR8(pd)
     double *pd;		/* Store result in *pd */
 {
-    register int i, exponent;
+    int i, exponent;
     unsigned char dchars[8];
     double mantissa, d;
     bool isneg;
@@ -390,7 +396,7 @@ calmaReadR8(pd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 calmaSkipSet(skipwhat)
     int *skipwhat;
 {
@@ -516,8 +522,9 @@ calmaSkipTo(what)
  * ----------------------------------------------------------------------------
  */
 
+bool
 calmaSkipBytes(nbytes)
-    register nbytes;	/* Skip this many bytes */
+    int nbytes;	/* Skip this many bytes */
 {
     while (nbytes-- > 0)
 	if (getc(calmaInputFile) < 0)
