@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/calma/CalmaRead.c,v 1.5 20
 
 #include <netinet/in.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
@@ -34,17 +34,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/calma/CalmaRead.c,v 1.5 20
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "utils/malloc.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
 #include "cif/CIFread.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "calma/calmaInt.h"
-#include "undo/undo.h"
+#include "commands/commands.h"		/* for CmdGetRootPoint */
+#include "utils/undo.h"
 
 /* Globals for Calma reading */
 FILE *calmaInputFile = NULL;		/* Read from this stream */
@@ -55,11 +56,22 @@ bool CalmaSubcellPolygons = FALSE;	/* Put non-Manhattan polygons
 					 */
 int CalmaPolygonCount;
 #endif
-
+bool CalmaFlattenUses = FALSE;		/* If TRUE, small cells in the input
+					 * stream are flattened when encountered
+					 * as uses.  This improves magic's
+					 * performance when handling contacts
+					 * saved as subcell arrays.
+					 */
 bool CalmaReadOnly = FALSE;		/* Set files to read-only and
 					 * retain file position information
 					 * so cells can be written verbatim.
 					 */
+bool CalmaPostOrder = FALSE;		/* If TRUE, forces the GDS parser to
+					 * read cells in post-order.  It is
+					 * necessary, e.g., when we need to
+					 * flatten cells that are contact cuts.
+					 * Added by Nishit 8/16/2004
+					 */
 extern void calmaUnexpected();
 
 bool calmaParseUnits();
@@ -123,6 +135,7 @@ CalmaReadFile(file, filename)
 {
     int version;
     char *libname = NULL;
+    MagWindow *mw;
     static int hdrSkip[] = { CALMA_FORMAT, CALMA_MASK, CALMA_ENDMASKS,
 			     CALMA_REFLIBS, CALMA_FONTS, CALMA_ATTRTABLE,
 			     CALMA_STYPTABLE, CALMA_GENERATIONS, -1 };
@@ -169,12 +182,9 @@ CalmaReadFile(file, filename)
     if (!calmaSkipExact(CALMA_BGNLIB)) goto done;
     calmaSkipSet(skipBeforeLib);
     if (!calmaReadStringRecord(CALMA_LIBNAME, &libname)) goto done;
-    if (libname[0])
+    if ((libname != NULL) && (libname[0] != '\0'))
 	TxPrintf("Library name: %s\n", libname);
 
-    /* done with libname */
-    if (libname != NULL) freeMagic(libname);
-
     /* Skip the reflibs, fonts, etc. cruft */
     calmaSkipSet(hdrSkip);
 
@@ -188,13 +198,35 @@ CalmaReadFile(file, filename)
     (void) calmaSkipExact(CALMA_ENDLIB);
 
 done:
+
+    /* Added by Nishit, Sept. 2004---Load cell read from GDS    */
+    /* stream file to the magic layout window.  If this fails   */
+    /* then we do the original action and don't do a load into  */
+    /* the window.  Note that this follows the Magic GDS output	*/
+    /* convention of giving the library the name of the		*/
+    /* top-level cell, so magic-produced GDS can be read back	*/
+    /* with the expected cell appearing in the layout window.	*/
+
+    if (libname != NULL)
+    {
+	mw = CmdGetRootPoint((Point *)NULL, (Rect *)NULL);
+	if (mw == NULL)
+	    windCheckOnlyWindow(&mw, DBWclientID);
+	if (mw != NULL)
+	{
+	    if (calmaFindCell(libname, NULL) != (CellDef *)NULL)
+		DBWloadWindow(mw, libname, FALSE);
+	}
+	freeMagic(libname);
+    }
+
     CIFReadCellCleanup();
     HashKill(&calmaDefInitHash);
     UndoEnable();
 
     if (calmaErrorFile != NULL) fclose(calmaErrorFile);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
