@@ -29,33 +29,38 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaWrite.c,v 1.4 200
 #else
 #include <sys/time.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "calma/calmaInt.h"
 
     /* Exports */
-bool CalmaDoLabels = TRUE;	/* If FALSE, don't output labels with GDS-II */
-bool CalmaDoLower = TRUE;	/* If TRUE, allow lowercase labels. */
-bool CalmaFlattenArrays = FALSE;/* If TRUE, output arrays as individual uses */
+bool CalmaDoLabels = TRUE;	 /* If FALSE, don't output labels with GDS-II */
+bool CalmaDoLower = TRUE;	 /* If TRUE, allow lowercase labels. */
+bool CalmaFlattenArrays = FALSE; /* If TRUE, output arrays as individual uses */
+bool CalmaContactArrays = FALSE; /* If TRUE, output contacts as subcell arrays */
 
     /* Forward declarations */
 extern int calmaWriteInitFunc();
 extern int calmaWriteMarkFunc();
 extern int calmaWritePaintFunc();
 extern int calmaWriteUseFunc();
+extern void calmaWriteContacts();
+extern void calmaDelContacts();
 extern void calmaOutFunc();
 extern void calmaOutStructName();
 extern void calmaWriteLabelFunc();
@@ -65,6 +70,13 @@ extern void calmaOutStringRecord();
 extern void calmaOut8();
 extern void calmaOutR8();
 
+/* Structure used by calmaWritePaintFunc() */
+
+typedef struct {
+   FILE *f;		/* File stream for output		*/
+   Rect *area;		/* Clipping area, in GDS coordinates	*/
+} calmaOutputStruct;
+
 /* Number assigned to each cell */
 int calmaCellNum;
 
@@ -83,6 +95,7 @@ int calmaPaintLayerType;
 
 /* Imports */
 extern time_t time();
+
 
 /* -------------------------------------------------------------------- */
 
@@ -252,6 +265,11 @@ CalmaWrite(rootDef, f)
     /* Output the header, identifying this file */
     calmaOutHeader(rootDef, f);
 
+    /*
+     * Write all contact cell definitions first
+     */
+    if (CalmaContactArrays) calmaWriteContacts(f);
+
     /*
      * We perform a post-order traversal of the tree rooted at 'rootDef',
      * to insure that each child cell is output before it is used.  The
@@ -268,6 +286,11 @@ CalmaWrite(rootDef, f)
     if (problems = (DBWFeedbackCount - oldCount))
 	TxPrintf("%d problems occurred.  See feedback entries.\n", problems);
 
+    /*
+     * Destroy all contact cell definitions 
+     */
+    if (CalmaContactArrays) calmaDelContacts();
+
     return (good);
 }
 
@@ -295,7 +318,7 @@ calmaWriteInitFunc(def)
     def->cd_client = (ClientData) 0;
     return (0);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -415,7 +438,7 @@ calmaProcessDef(def, outf)
 
     /* Output this cell */
     if (!isReadOnly)
-	calmaOutFunc(def, outf);
+	calmaOutFunc(def, outf, &TiPlaneRect);
 
     return (0);
 }
@@ -440,14 +463,21 @@ calmaProcessDef(def, outf)
  */
 
 void
-calmaOutFunc(def, f)
+calmaOutFunc(def, f, cliprect)
     CellDef *def;	/* Pointer to cell def to be written */
     FILE *f;		/* Open output file */
+    Rect *cliprect;	/* Area to clip to (used for contact cells),
+			 * in CIF/GDS coordinates.
+			 */
 {
     Label *lab;
     CIFLayer *layer;
     Rect bigArea;
     int type;
+    calmaOutputStruct cos;
+
+    cos.f = f;
+    cos.area = (cliprect == &TiPlaneRect) ? NULL : cliprect;
 
     /* Output structure begin */
     calmaOutRH(28, CALMA_BGNSTR, CALMA_I2, f);
@@ -487,7 +517,7 @@ calmaOutFunc(def, f)
     /* Output all the tiles associated with this cell; skip temporary layers */
     GEO_EXPAND(&def->cd_bbox, CIFCurStyle->cs_radius, &bigArea);
     CIFErrorDef = def;
-    CIFGen(def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE);
+    CIFGen(def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE, (ClientData) f);
     CIFGenSubcells(def, &bigArea, CIFPlanes);
     CIFGenArrays(def, &bigArea, CIFPlanes);
 
@@ -499,9 +529,10 @@ calmaOutFunc(def, f)
 	calmaPaintLayerNumber = layer->cl_calmanum;
 	calmaPaintLayerType = layer->cl_calmatype;
 
+
 	(void) DBSrPaintArea((Tile *) NULL, CIFPlanes[type],
-	    &TiPlaneRect, &CIFSolidBits, calmaWritePaintFunc,
-	    (ClientData) f);
+	    cliprect, &CIFSolidBits, calmaWritePaintFunc,
+	    (ClientData) &cos);
     }
 
     /* Output labels */
@@ -513,7 +544,48 @@ calmaOutFunc(def, f)
     /* End of structure */
     calmaOutRH(4, CALMA_ENDSTR, CALMA_NODATA, f);
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaIsUseNameDefault --
+ *
+ * Determine if this use name is not default; that is, it is not the name
+ * of the cell def followed by an underscore and a use index number.  If
+ * it is not default, then we want to write out the use name as a property
+ * in the GDS stream file so that we can recover the name when the file is
+ * read back into magic.
+ *
+ * Results:
+ *	TRUE if the cell use ID is a default name; FALSE if not.
+ *
+ * Side Effects:
+ *	None.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+calmaIsUseNameDefault(defName, useName)
+    char *defName;
+    char *useName;
+{
+    int idx, slen;
+    char *sptr;
+
+    if (useName == NULL) return TRUE;
+    slen = strlen(defName);
+    if (!strncmp(defName, useName, slen))
+    {
+	sptr = useName + slen;
+	if (*sptr != '_') return FALSE;
+	else sptr++;
+	if (sscanf(sptr, "%d", &idx) != 1) return FALSE;
+	else return TRUE;
+    }
+    return FALSE;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -701,6 +773,30 @@ calmaWriteUseFunc(use, f)
 	    calmaOutI4(p2.p_y, f);
 	}
 
+	/* By NP */
+	/* Property attributes/value pairs. */
+	/* Add a CellUse ID property, if the CellUse has a non-default name */
+
+	if (!calmaIsUseNameDefault(use->cu_def->cd_name, use->cu_id))
+	{
+	    calmaOutRH(6, CALMA_PROPATTR, CALMA_I2, f);
+	    calmaOutI2(CALMA_PROP_USENAME, f);
+	    calmaOutStringRecord(CALMA_PROPVALUE, use->cu_id, f);
+	}
+
+	/* Add an array limits property, if the CellUse is an array and */
+	/* limits of the array (xlo, ylo) are not zero (the default).	*/
+
+	if ((use->cu_xlo != 0) || (use->cu_ylo != 0))
+	{
+	    char arraystr[128];
+	    sprintf(arraystr, "%d_%d_%d_%d", use->cu_xlo, use->cu_xhi,
+			use->cu_ylo, use->cu_yhi);
+	    calmaOutRH(6, CALMA_PROPATTR, CALMA_I2, f);
+	    calmaOutI2(CALMA_PROP_ARRAY_LIMITS, f);
+	    calmaOutStringRecord(CALMA_PROPVALUE, arraystr, f);
+	}
+
 	/* End of element */
 	calmaOutRH(4, CALMA_ENDEL, CALMA_NODATA, f);
     }
@@ -765,7 +861,249 @@ bad:
 
     calmaOutStringRecord(type, defname, f);
 }
-
+
+/* Added by NP 8/21/2004 */
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaGetContactCell --
+ *
+ *   This routine creates [if it hasn't been created yet] a cell definition
+ *   containing the given TileType.  Cellname is "$$" + layer1_name + "_" +
+ *   layer2_name... + "$$". Cellname contains the short name of all the
+ *   residues of the layer "type".
+ *
+ * Results:
+ *   Returns new celldef it doesn't exist else created one.
+ *
+ * Side effects:
+ *	 New celldef created specially for contact type if it does not exist.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+CellDef *
+calmaGetContactCell(type, lookOnly)
+    TileType type;		/* magic contact tile type */
+    bool lookOnly;		/* if true, don't generate any new cells */
+{
+    TileType j;
+    char contactCellName[100];
+    TileTypeBitMask *rMask = DBResidueMask(type);
+    CellDef *def;
+    bool first = TRUE;
+
+    strcpy(contactCellName, "$$");
+    for (j = TT_SPACE + 1; j < DBNumUserLayers; j++)
+	if (TTMaskHasType(rMask, j))
+	{
+            /* Cellname starts with "$$" to make it diffrent from
+             * other database cells, and to be compatible with a
+	     * number of other EDA tools.
+             */
+	    if (!first)
+		strcat(contactCellName, "_");
+	    else
+		first = FALSE;
+            strcat(contactCellName, DBTypeShortName(j));
+        }
+    strcat(contactCellName, "$$");
+
+    def = DBCellLookDef(contactCellName);
+    if ((def == (CellDef *) NULL) && (lookOnly == FALSE))
+    {
+	def = DBCellNewDef(contactCellName, (char *) NULL);
+       	def->cd_flags &= ~(CDMODIFIED|CDGETNEWSTAMP);
+        def->cd_flags |= CDAVAILABLE;
+    }
+    return def;
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * CalmaGenerateArray --
+ *
+ *	This routine
+ *
+ * Results:
+ *	TRUE on success, FALSE if no contact cell could be found.
+ *
+ * Side effects:
+ *	Writes an AREF record to the GDS stream output.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+CalmaGenerateArray(f, type, llx, lly, pitch, cols, rows)
+    FILE *f;		/* GDS output file */
+    TileType type;	/* Magic tile type of contact */
+    int llx, lly;	/* Lower-left hand coordinate of the array
+			 * (centered on contact cut)
+			 */
+    int pitch;		/* Pitch of the array elements */
+    int cols, rows;	/* Number of array elements in X and Y */
+{
+    CellDef *child;	/* Cell definition of the contact cell */
+    int xxlate, yxlate;
+
+    child = calmaGetContactCell(type, TRUE);
+    if (child == NULL) return FALSE;
+
+    /* Structure reference */
+    calmaOutRH(4, CALMA_AREF, CALMA_NODATA, f);
+    calmaOutStructName(CALMA_SNAME, child, f);
+
+    /* Transformation flags */
+    calmaOutRH(6, CALMA_STRANS, CALMA_BITARRAY, f);
+    calmaOutI2(0, f);
+
+    /* Number of columns and rows in the array */
+    calmaOutRH(8, CALMA_COLROW, CALMA_I2, f);
+    calmaOutI2(cols, f);
+    calmaOutI2(rows, f);
+
+    /* Translation */
+    xxlate = llx * calmaPaintScale;
+    yxlate = lly * calmaPaintScale;
+    calmaOutRH(28, CALMA_XY, CALMA_I4, f);
+    calmaOutI4(xxlate, f);
+    calmaOutI4(yxlate, f);
+
+    /* Column reference point */
+    calmaOutI4(xxlate + pitch * cols * calmaPaintScale, f);
+    calmaOutI4(yxlate, f);
+
+    /* Row reference point */
+    calmaOutI4(xxlate, f);
+    calmaOutI4(yxlate + pitch * rows * calmaPaintScale, f);
+
+    /* End of AREF element */
+    calmaOutRH(4, CALMA_ENDEL, CALMA_NODATA, f);
+
+    return TRUE;
+}
+
+/* Added by NP 8/22/2004 */
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaWriteContacts --
+ *
+ *  This routine creates a new cellDef for each contact type and writes to
+ *  the GDS output stream file. It is called before processing all cell
+ *  definitions while writing GDS output.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Writes contact cell definition to the open Calma output file.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+calmaWriteContacts(f)
+    FILE *f;
+{
+    TileType type;
+    TileTypeBitMask tMask;
+    CellDef *def, *cellDef;
+    Rect area, cliprect;
+    int halfwidth, halfsize;
+    CIFOp *op;
+    HashSearch hs;
+    HashEntry *entry;
+
+    /* Turn off generation of contact arrays for the duration of this	*/
+    /* subroutine, so that the contact definitions themselves will get	*/
+    /* the proper contact cut drawn.  It is turned on again at the end	*/
+    /* of the routine.  Note that this routine is not called unless	*/
+    /* CalmaContactArrays is TRUE.					*/
+    
+    CalmaContactArrays = FALSE;
+
+    DBEnumerateTypes(&tMask);
+
+    /* Decompose stacking types */
+    for (type = DBNumUserLayers; type < DBNumTypes; type++)
+	if (TTMaskHasType(&tMask, type))
+	    TTMaskSetMask(&tMask, DBResidueMask(type));
+
+    for (type = TT_SPACE + 1; type < DBNumUserLayers; type++)
+    {
+	/* We need to create cell array only for contact types */
+	if (DBIsContact(type) && TTMaskHasType(&tMask, type))
+	{
+            /* Write definition of cell to GDS stream.	*/
+	    /* Get cell definition for Tiletype type */
+            def = calmaGetContactCell(type, FALSE);
+
+            /* Get clip bounds, so that residue surround is	*/
+	    /* minimum.  Note that these values are in CIF/GDS	*/
+	    /* units, and the clipping rectangle passed to	*/
+	    /* calmaOutFunc is also in CIF/GDS units.		*/
+
+	    halfsize = CIFGetContactSize(type) >> 1;
+
+            /* Get minimum width for layer by rounding halfsize	*/
+	    /* to the nearest lambda value.			*/
+            halfwidth = halfsize / CIFCurStyle->cs_scaleFactor;
+	    if ((halfsize % CIFCurStyle->cs_scaleFactor) != 0)
+		halfwidth++;
+
+            area.r_xbot = area.r_ybot = -halfwidth;
+            area.r_xtop = area.r_ytop = halfwidth;
+       	    UndoDisable();
+       	    DBPaint(def, &area, type);
+       	    DBReComputeBbox(def);
+    	    TTMaskSetType(&def->cd_types, type);
+
+	    /* Clip output to the bounds of "cliprect"	*/
+	    cliprect.r_xbot = cliprect.r_ybot = -halfsize;
+	    cliprect.r_xtop = cliprect.r_ytop = halfsize;
+
+            calmaOutFunc(def, f, &cliprect);
+            UndoEnable();
+	}
+    }
+    CalmaContactArrays = TRUE;
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaDelContacts --
+ *
+ *  This routine removes all cell definitions generated by
+ *  calmaWriteContacts().
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Removes contact cell defs from the database.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+calmaDelContacts()
+{
+    TileType type;
+    CellDef *def;
+
+    for (type = TT_SPACE + 1; type < DBNumUserLayers; type++)
+	if (DBIsContact(type))
+	{
+            def = calmaGetContactCell(type, TRUE);
+	    if (def != (CellDef *)NULL)
+		 DBCellDeleteDef(def);
+	}
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -788,13 +1126,18 @@ bad:
  */
 
 int
-calmaWritePaintFunc(tile, f)
-    Tile *tile;		/* Tile to be written out. */
-    FILE *f;				/* File in which to write. */
+calmaWritePaintFunc(tile, cos)
+    Tile *tile;			/* Tile to be written out. */
+    calmaOutputStruct *cos;	/* File for output and clipping area */
 {
-    Rect r;
+    FILE *f = cos->f;
+    Rect *clipArea = cos->area;
+    Rect r, r2;
 
     TiToRect(tile, &r);
+    if (clipArea != NULL)
+	GeoClip(&r, clipArea);
+
     r.r_xbot *= calmaPaintScale;
     r.r_ybot *= calmaPaintScale;
     r.r_xtop *= calmaPaintScale;
