@@ -22,18 +22,22 @@
 #ifndef _CALMA_H
 #define _CALMA_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* Externally visible variables */
 extern bool CalmaSubcellPolygons;
 extern bool CalmaDoLabels;
 extern bool CalmaDoLower;
 extern bool CalmaFlattenArrays;
+extern bool CalmaFlattenUses;
 extern bool CalmaReadOnly;
+extern bool CalmaContactArrays;
+extern bool CalmaPostOrder;
 
 /* Externally-visible procedures: */
 extern bool CalmaWrite();
 extern void CalmaReadFile();
 extern void CalmaTechInit();
+extern bool CalmaGenerateArray();
 
 #endif /* _CALMA_H */
