@@ -26,7 +26,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFhier.c,v 1.3 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -35,9 +36,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFhier.c,v 1.3 2001/0
 #include "cif/cif.h"
 #include "drc/drc.h"
 #include "textio/textio.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* To compute CIF where there are interaction areas we do two things:
  * 1. Compute the CIF by combining all the material in all the interacting
