@@ -19,14 +19,10 @@
  * rcsid "$Header: /ufs/repository/magic/cif/CIFint.h,v 1.6 2001/07/23 17:49:50 tim Exp $"
  */
 
-#define _CIFINT
+#ifndef _CIFINT_H
+#define _CIFINT_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	_MAGIC
-#ifndef	_DATABASE
-int err1 = Need_to_include_database/database_header;
-#endif	_DATABASE
+#include "database/database.h"
 
 /* The main data structure used in the cif module is a description
  * of how to generate CIF layers from the Magic tiles.  There may
@@ -47,6 +43,23 @@ int err1 = Need_to_include_database/database_header;
  * or to grow by a certain amount.
  */
 
+typedef struct bloat_data
+{
+    int bl_plane;		/* Plane on which a bloat or squares
+				 * operation is valid.
+				 */
+    int bl_distance[TT_MAXTYPES];
+} BloatData;
+
+typedef struct squares_data
+{
+   int sq_border;
+   int sq_size;
+   int sq_sep;
+   int sq_gridx;		/* Only used for "squares-grid" */
+   int sq_gridy;		/* Only used for "squares-grid" */
+} SquaresData;
+
 typedef struct cifop
 {
     TileTypeBitMask co_paintMask;/* Zero or more paint layers to consider. */
@@ -55,13 +68,8 @@ typedef struct cifop
 				 * below for the legal ones.
 				 */
     int co_distance;		/* Grow or shrink distance (if needed). */
-    int *co_bloats;		/* For CIFOP_BLOAT, CIFOP_BLOATMAX, and
-				 * CIFOP_BLOATMIN: distance to grow per layer.
-				 * Exception: For CIFOP_SQUARES,
-				 * [0] is the border around squares, [1]
-				 * is the size of each square, and [2] is
-				 * the distance between squares.  For other
-				 * operations, co_bloats is NULL (not used).
+    ClientData co_client;	/* Pointer to a BloatData, SquaresData, or
+				 * SquaresGData structure, or NULL.
 				 */
     struct cifop *co_next;	/* Next in list of operations to perform. */
 } CIFOp;
@@ -77,7 +85,7 @@ typedef struct cifop
  * CIFOP_GROW -		Grow the current results uniformly by co_distance.
  * CIFOP_SHRINK -	Shrink the current results uniformly by co_distance.
  * CIFOP_BLOAT -	Find layers in paintMask, then bloat selectively
- *			according to co_bloats, and OR the results into
+ *			according to bl_distance, and OR the results into
  *			the current plane.
  * CIFOP_SQUARES -	Generates a pattern of squares (used for making
  *			contact vias.  Each square is co_distance large,
@@ -102,6 +110,20 @@ typedef struct cifop
 #define CIFOP_ANDNOT	9
 #define CIFOP_SQUARES_G	10
 
+/* Added by Tim 10/21/2004 */
+/* The following structure is used to pass information on how to draw
+ * contact subcell arrays for a specific magic contact tile type.  For
+ * the GDS write routine, the GDS file (FILE *) is passed as the client
+ * data.
+ */
+
+typedef struct cifsquaresinfo
+{
+    SquaresData	*csi_squares;	/* Information on how to generate squares */
+    TileType	 csi_type;	/* Magic contact tile type */
+    ClientData	 csi_client;	/* Used to pass output file info.	*/
+} CIFSquaresInfo;
+
 /* The following data structure contains all the information about
  * a particular CIF layer.
  */
@@ -132,6 +154,12 @@ typedef struct
 				 * for the layer. This is used by Grow Sliver
 				 * to generate drc correct parent slivers	
 				 */
+#ifdef THREE_D
+    int	   cl_renderStyle;	/* Style to render CIF layer with */
+    float  cl_height;		/* (rendered) height of CIF layer above substrate */
+    float  cl_thick;		/* (rendered) thickness of CIF layer */
+#endif
+
 } CIFLayer;
 
 /* The CIFLayer flags are:
@@ -231,6 +259,11 @@ extern CellUse *CIFDummyUse;		/* Used to dummy up a CellUse for a
 					 * def.
 					 */
 
+/* Valid values of CIFWarningLevel (see cif.h) */
+
+typedef enum {CIF_WARN_DEFAULT, CIF_WARN_NONE, CIF_WARN_ALIGN,
+	CIF_WARN_LIMIT, CIF_WARN_REDIRECT, CIF_WARN_END} CIFWarningTypes;
+
 /* Statistics counters: */
 
 extern int CIFTileOps;
@@ -254,3 +287,5 @@ extern void CIFError();
 
 #define CIF_SOLIDTYPE 1
 extern TileTypeBitMask CIFSolidBits;
+
+#endif /* _CIFINT_H */
