@@ -28,14 +28,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFrdpt.c,v 1.5 2001/0
 #include <math.h>		/* for wire path-to-poly path conversion */
 #endif
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "cif/CIFint.h"
 #include "cif/CIFread.h"
 
@@ -244,15 +244,16 @@ CIFParseFlash()
  *	a path can be halfway between two coordinates of the layout grid
  *	and still describe a polygon whose endpoints are all on the grid.
  *
- *	Endcap handling?
+ *	Also:  Needs to implement endcap handling!
  *
  * ----------------------------------------------------------------------------
  */
 
 void
-CIFPaintWirePath(pathheadp, width, plane, ptable, ui)
+CIFPaintWirePath(pathheadp, width, endcap, plane, ptable, ui)
     CIFPath *pathheadp;
     int width;
+    bool endcap;
     Plane *plane;
     PaintResultType *ptable;
     PaintUndoInfo *ui;
@@ -290,8 +291,11 @@ CIFPaintWirePath(pathheadp, width, plane, ptable, ui)
 	    /* Back first point up by endcap amount (width,	*/
 	    /* which is half the width of the route segment.)	*/
 
-	    xmin -= (double)width * cos(theta);
-	    ymin -= (double)width * sin(theta);
+	    if (endcap)
+	    {
+		xmin -= (double)width * cos(theta);
+		ymin -= (double)width * sin(theta);
+	    }
 	    xminoff = (double)width * cos(theta - 1.5708); /* 90 degrees */
 	    yminoff = (double)width * sin(theta - 1.5708);
 	    firstpoint = FALSE;
@@ -314,8 +318,11 @@ CIFPaintWirePath(pathheadp, width, plane, ptable, ui)
 	{
 	    /* Endpoint:  create 1/2 width endcap */
 	    phi = theta;
-	    xmax += (double)width * cos(theta);
-	    ymax += (double)width * sin(theta);
+	    if (endcap)
+	    {
+		xmax += (double)width * cos(theta);
+		ymax += (double)width * sin(theta);
+	    }
 	}
 
 	alpha = 0.5 * (phi - theta);
@@ -426,10 +433,11 @@ CIFPaintWirePath(pathheadp, width, plane, ptable, ui)
  */
 
 void
-PaintWireList(pointlist, number, width, plane, ptable, ui)
+PaintWireList(pointlist, number, width, endcap, plane, ptable, ui)
     Point *pointlist;		/* Array of Point structures */
     int number;			/* total number of points */
     int width;			/* Route width of path */
+    bool endcap;		/* Whether or not to add 1/2 width endcaps */
     Plane *plane;		/* Plane structure to paint into */
     PaintResultType *ptable;	/* Paint result table */
     PaintUndoInfo *ui;		/* Undo record */
@@ -439,13 +447,13 @@ PaintWireList(pointlist, number, width, plane, ptable, ui)
    
     for (i = 0; i < number; i++)
     {
-	MALLOC(CIFPath *, newpath, sizeof (CIFPath));
+	newpath = (CIFPath *) mallocMagic((unsigned) sizeof (CIFPath));
 	newpath->cifp_x = pointlist[i].p_x;
 	newpath->cifp_y = pointlist[i].p_y;
 	newpath->cifp_next = cifpath;
 	cifpath = newpath;
     }
-    CIFPaintWirePath(cifpath, width, plane, ptable, ui);
+    CIFPaintWirePath(cifpath, width, endcap, plane, ptable, ui);
 }
 
 
@@ -504,7 +512,7 @@ CIFParseWire()
     if (savescale != cifReadScale1)
 	width *= (cifReadScale1 / savescale);
 
-    CIFPaintWirePath(pathheadp, width, cifReadPlane, CIFPaintTable,
+    CIFPaintWirePath(pathheadp, width, TRUE, cifReadPlane, CIFPaintTable,
 		(PaintUndoInfo *)NULL);
     return TRUE;
 }
