@@ -29,12 +29,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFrdtech.c,v 1.5 2001
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
 #include "cif/CIFint.h"
@@ -226,6 +226,18 @@ CIFParseReadLayers(string, mask)
 	i = CIFReadNameToType(string, TRUE);
 	if (i >= 0)
 	    TTMaskSetType(mask, i);
+	else
+	{
+	    HashEntry *he;
+	    TileTypeBitMask *amask;
+
+	    he = HashLookOnly(&DBTypeAliasTable, string);
+	    if (he != NULL)
+	    {
+		amask = (TileTypeBitMask *)HashGetValue(he);
+		TTMaskSetMask(mask, amask);
+	    }
+	}
 
 	if (p == NULL) break;
 	*p = ',';
@@ -655,7 +667,7 @@ CIFReadTechLine(sectionName, argc, argv)
 	{
 	    cifCurReadOp = (CIFOp *) mallocMagic(sizeof(CIFOp));
 	    cifCurReadOp->co_opcode = CIFOP_OR;
-	    cifCurReadOp->co_bloats = (int *)NULL;
+	    cifCurReadOp->co_client = (ClientData)NULL;
 	    CIFParseReadLayers(argv[2], &cifCurReadOp->co_cifMask);
 	    TTMaskZero(&cifCurReadOp->co_paintMask);
 	    cifCurReadOp->co_next = NULL;
@@ -779,7 +791,7 @@ CIFReadTechLine(sectionName, argc, argv)
     newOp->co_opcode = 0;
     newOp->co_distance = 0;
     newOp->co_next = NULL;
-    newOp->co_bloats = (int *)NULL;
+    newOp->co_client = (ClientData)NULL;
 
     if (strcmp(argv[0], "and") == 0)
 	newOp->co_opcode = CIFOP_AND;
@@ -875,7 +887,7 @@ CIFReadTechFinal()
 	 cifCurReadStyle->crs_scaleFactor = 1;
     }
 
-    CIFTechInputScale(1, 1);
+    CIFTechInputScale(1, 1, TRUE);
 
     /* debug info --- Tim, 1/3/02 */
     TxPrintf("Input style %s: scaleFactor=%d, multiplier=%d\n",
@@ -914,7 +926,7 @@ CIFReadLoadStyle(stylename)
     TechLoad(NULL, invcifr);
 
     CIFReadTechFinal();
-    CIFTechInputScale(DBLambda[0], DBLambda[1]);
+    CIFTechInputScale(DBLambda[0], DBLambda[1], TRUE);
 }
     
 /*
@@ -1154,12 +1166,19 @@ cifParseCalmaNums(str, numArray, numNums)
  *   Scale all CIF input scale factors to make them equivalent
  *   to reducing the magic internal unit spacing by a factor of n/d.
  *
+ *   After scaling, we attempt to reduce the ratio scaleFactor : multiplier
+ *   if there is a common factor.  If "opt" is TRUE, we reduce both values
+ *   by this factor.  If FALSE, we do not reduce multiplier below its
+ *   original value.  This is important if we are still in the process of
+ *   reading CIF or GDS input.
+ *
  * ----------------------------------------------------------------------------
  */
 
 int
-CIFTechInputScale(n, d)
+CIFTechInputScale(n, d, opt)
     int n, d;
+    bool opt;
 {
     CIFReadStyle *istyle = cifCurReadStyle;
     CIFReadLayer *cl;
@@ -1196,16 +1215,27 @@ CIFTechInputScale(n, d)
     /* fprintf(stderr, "Multiplier goes from %d to %d\n", istyle->crs_multiplier,
 		istyle->crs_multiplier / lmult); */
 
-    istyle->crs_scaleFactor /= lmult;
-    istyle->crs_multiplier /= lmult;
-
-    for (i = 0; i < istyle->crs_nLayers; i++)
+    if (!opt)
     {
-	cl = istyle->crs_layers[i];
-	for (op = cl->crl_ops; op != NULL; op = op->co_next)
-	    if (op->co_distance)
-		op->co_distance /= lmult;
+	if ((lmult % d) == 0)
+	    lmult = d;
+	else
+	    lmult = 1;
     }
-    /* fflush(stderr); */
+
+    if (lmult > 1)
+    {
+	istyle->crs_scaleFactor /= lmult;
+	istyle->crs_multiplier /= lmult;
+
+	for (i = 0; i < istyle->crs_nLayers; i++)
+	{
+	    cl = istyle->crs_layers[i];
+	    for (op = cl->crl_ops; op != NULL; op = op->co_next)
+		if (op->co_distance)
+		    op->co_distance /= lmult;
+	}
+    }
+    return lmult;
 }
 
