@@ -28,12 +28,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFtech.c,v 1.4 2001/0
 #endif
 #include <stdlib.h>	/* for atof() */
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/utils.h"
 #include "cif/CIFint.h"
 #include "calma/calmaInt.h"
@@ -105,8 +105,11 @@ cifTechNewStyle()
 	    {
 		for (op = layer->cl_ops; op != NULL; op = op->co_next)
 		{
-		    if (op->co_bloats != NULL)
-			freeMagic((char *)op->co_bloats);
+		    if (op->co_client != (ClientData)NULL)
+		    {
+			if (op->co_opcode != CIFOP_OR)
+			    freeMagic((char *)op->co_client);
+		    }
 		    freeMagic((char *)op);
 		}
 		freeMagic((char *)layer);
@@ -216,7 +219,7 @@ cifParseLayers(string, style, paintMask, cifMask,spaceOK)
 
 	if (paintMask != NULL)
 	{
-	    paintType = DBTechNameTypes(curLayer,&curPaintMask);
+	    paintType = DBTechNameTypes(curLayer, &curPaintMask);
 	    if (paintType >= 0) goto okpaint;
 	}
 	else paintType = -2;
@@ -273,7 +276,20 @@ okpaint:
 	{
 	    TTMaskSetMask(cifMask, &curCifMask);
 	}
-	else TechError("Unrecognized layer (type) \"%s\".\n", curLayer);
+	else
+	{
+	    HashEntry *he;
+	    TileTypeBitMask *amask;
+
+	    he = HashLookOnly(&DBTypeAliasTable, curLayer);
+	    if (he != NULL)
+	    {
+		amask = (TileTypeBitMask *)HashGetValue(he);
+		TTMaskSetMask(paintMask, amask);
+	    }
+	    else
+		TechError("Unrecognized layer (type) \"%s\".\n", curLayer);
+	}
     }
 }
 
@@ -425,7 +441,8 @@ CIFTechLine(sectionName, argc, argv)
     CIFOp *newOp = NULL;
     CIFKeep *newStyle, *p;
     char **bloatArg;
-    int local_bloats[TT_MAXTYPES];
+    BloatData *bloats;
+    SquaresData *squares;
 
     if (argc <= 0) return TRUE;
     else if (argc >= 2) l = strlen(argv[1]);
@@ -708,7 +725,7 @@ CIFTechLine(sectionName, argc, argv)
 		&cifCurOp->co_cifMask,FALSE);
 	    cifCurOp->co_distance = 0;
 	    cifCurOp->co_next = NULL;
-	    cifCurOp->co_bloats = (int *)NULL;
+	    cifCurOp->co_client = (ClientData)NULL;
 	    cifCurLayer->cl_ops = cifCurOp;
 	}
 	return TRUE;
@@ -842,10 +859,7 @@ CIFTechLine(sectionName, argc, argv)
     newOp->co_opcode = 0;
     newOp->co_distance = 0;
     newOp->co_next = NULL;
-    newOp->co_bloats = (int *)NULL;
-
-    for (i = 0; i < TT_MAXTYPES; i++)
-	local_bloats[i] = 0;
+    newOp->co_client = (ClientData)NULL;
 
     if (strcmp(argv[0], "and") == 0)
 	newOp->co_opcode = CIFOP_AND;
@@ -903,6 +917,11 @@ CIFTechLine(sectionName, argc, argv)
 	    argc -= 2;
 	    bloatArg = argv + 2;
 	    bloatLayers = newOp->co_paintMask;
+	    bloats = (BloatData *)mallocMagic(sizeof(BloatData));
+	    for (i = 0; i < TT_MAXTYPES; i++)
+		bloats->bl_distance[i] = 0;
+	    newOp->co_client = (ClientData)bloats;
+
 	    while (argc > 0)
 	    {
 		if (argc == 1) goto wrongNumArgs;
@@ -926,7 +945,7 @@ CIFTechLine(sectionName, argc, argv)
 		}
 		for (i = 0; i < TT_MAXTYPES;  i++)
 		    if (TTMaskHasType(&mask, i))
-			local_bloats[i] = distance;
+			bloats->bl_distance[i] = distance;
 
 		argc -= 2;
 		bloatArg += 2;
@@ -938,7 +957,7 @@ CIFTechLine(sectionName, argc, argv)
 	     */
 	    for (i = 0; i < TT_MAXTYPES; i++)
 		if (TTMaskHasType(&newOp->co_paintMask, i))
-		    local_bloats[i] = 0;
+		    bloats->bl_distance[i] = 0;
 
 	    /* Make sure that all the layers specified in the statement
 	     * fall in a single plane.
@@ -948,68 +967,78 @@ CIFTechLine(sectionName, argc, argv)
 	    {
 		tempMask = bloatLayers;
 		TTMaskAndMask(&tempMask, &DBPlaneTypes[i]);
-		if (TTMaskEqual(&tempMask, &bloatLayers))
+		if (TTMaskEqual(&tempMask, &bloatLayers)) {
+		    bloats->bl_plane = i;
 		    goto bloatDone;
+		}
 	    }
 	    TechError("Not all bloat layers fall in the same plane.\n");
 	    bloatDone: break;
 	
 	case CIFOP_SQUARES_G:
-	    local_bloats[3] = 1; /* set default grid and fall through */
-	    local_bloats[4] = 1;
 	case CIFOP_SQUARES:
+	
+	    squares = (SquaresData *)mallocMagic(sizeof(SquaresData));
+	    newOp->co_client = (ClientData)squares;
+
 	    if (argc == 2)
 	    {
 		i = atoi(argv[1]);
-		local_bloats[0] = atoi(argv[1]);
+		squares->sq_border = atoi(argv[1]);
 		if ((i <= 0) || (i & 1))
 		{
 		    TechError("Squares must have positive even sizes.\n");
 		    goto errorReturn;
 		}
-		local_bloats[0] = i/2;
-		local_bloats[1] = i;
-		local_bloats[2] = i;
-		local_bloats[3] = 0;	/* placeholder; not used by SQUARES */
+		squares->sq_border = i/2;
+		squares->sq_size = i;
+		squares->sq_sep = i;
+		squares->sq_gridx = 1; /* set default grid */
+		squares->sq_gridy = 1; /* set default grid */
 	    }
 	    else if (argc == 4 || ((argc == 5 || argc == 6)
 			&& newOp->co_opcode==CIFOP_SQUARES_G))
 	    {
-		local_bloats[0] = atoi(argv[1]);
-		if (local_bloats[0] < 0)
+		squares->sq_border = atoi(argv[1]);
+		if (squares->sq_border < 0)
 		{
 		    TechError("Square border must not be negative.\n");
 		    goto errorReturn;
 		}
-		local_bloats[1] = atoi(argv[2]);
-		if (local_bloats[1] <= 0)
+		squares->sq_size = atoi(argv[2]);
+		if (squares->sq_size <= 0)
 		{
 		    TechError("Squares must have positive sizes.\n");
 		    goto errorReturn;
 		}
-		local_bloats[2] = atoi(argv[3]);
-		if (local_bloats[2] <= 0)
+		squares->sq_sep = atoi(argv[3]);
+		if (squares->sq_sep <= 0)
 		{
 		    TechError("Square separation must be positive.\n");
 		    goto errorReturn;
 		}
 		if (argc >= 5)
 		{
-		    local_bloats[3] = local_bloats[4] = atoi(argv[4]);
-		    if (local_bloats[3] <= 0)
+		    squares->sq_gridx = squares->sq_gridy = atoi(argv[4]);
+		    if (squares->sq_gridx <= 0)
 		    {
 		        TechError("Square grid must be strictly positive.\n");
-			local_bloats[3] = 1;
+			squares->sq_gridx = squares->sq_gridy = 1;
 		        goto errorReturn;
 		    }
 		}
+		else
+		{
+		    squares->sq_gridx = 1; /* set default grid */
+		    squares->sq_gridy = 1; /* set default grid */
+		}
 		if (argc == 6)
 		{
-		    local_bloats[4] = atoi(argv[5]);
-		    if (local_bloats[4] <= 0)
+		    squares->sq_gridy = atoi(argv[5]);
+		    if (squares->sq_gridy <= 0)
 		    {
 		        TechError("Square y-grid must be strictly positive.\n");
-			local_bloats[4] = 1;
+			squares->sq_gridy = 1;
 		        goto errorReturn;
 		    }
 		}
@@ -1018,31 +1047,6 @@ CIFTechLine(sectionName, argc, argv)
 	    break;
     }
 
-    /* Generate bloat rules list in newOp.				*/
-    /* There are so few bloat rules per CIF op, this is more efficient	*/
-    /* than an array of TT_MAXTYPES integers.				*/
-
-    switch (newOp->co_opcode)
-    {
-	case CIFOP_SQUARES:
-	    newOp->co_bloats = (int *) mallocMagic(4 * sizeof(int));
-	    for (i = 0; i < 4; i++)
-		newOp->co_bloats[i] = local_bloats[i];
-	    break;
-	case CIFOP_SQUARES_G:
-	    newOp->co_bloats = (int *) mallocMagic(5 * sizeof(int));
-	    for (i = 0; i < 5; i++)
-		newOp->co_bloats[i] = local_bloats[i];
-	    break;
-	case CIFOP_BLOAT:
-	case CIFOP_BLOATMAX:
-	case CIFOP_BLOATMIN:
-	    newOp->co_bloats = (int *) mallocMagic(TT_MAXTYPES * sizeof(int));
-	    for (i = 0; i < TT_MAXTYPES; i++)
-		newOp->co_bloats[i] = local_bloats[i];
-	    break;
-    }
-
     /* Link the new CIFOp into the list. */
 
     if (cifCurOp == NULL)
@@ -1053,7 +1057,7 @@ CIFTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1117,6 +1121,7 @@ cifComputeRadii(layer, des)
 {
     int i, grow, shrink, curGrow, curShrink;
     CIFOp *op;
+    BloatData *bloats;
 
     grow = shrink = 0;
 
@@ -1164,12 +1169,13 @@ cifComputeRadii(layer, des)
 
 	    case CIFOP_BLOAT:
 		curGrow = curShrink = 0;
+		bloats = (BloatData *)op->co_client;
 		for (i = 0; i < TT_MAXTYPES; i++)
 		{
-		    if (op->co_bloats[i] > curGrow)
-			curGrow = op->co_bloats[i];
-		    else if ((-op->co_bloats[i]) > curShrink)
-			curShrink = -op->co_bloats[i];
+		    if (bloats->bl_distance[i] > curGrow)
+			curGrow = bloats->bl_distance[i];
+		    else if ((-bloats->bl_distance[i]) > curShrink)
+			curShrink = -bloats->bl_distance[i];
 		}
 		grow += curGrow;
 		shrink += curShrink;
@@ -1266,12 +1272,31 @@ CIFTechFinal()
 	return;
     }
 
+    /*
+     * Make sure that all contact layers include stacked contact types
+     */
+    for (i = 0; i < style->cs_nLayers; i++)
+	for (op = style->cs_layers[i]->cl_ops; op != NULL; op = op->co_next)
+	{
+	    TileType d, s;
+	    TileTypeBitMask *rMask;
+
+	    for (d = TT_TECHDEPBASE; d < DBNumUserLayers; d++)
+		if (TTMaskHasType(&op->co_paintMask, d) && DBIsContact(d))
+		    for (s = DBNumUserLayers; s < DBNumTypes; s++)
+		    {
+			rMask = DBResidueMask(s);
+			if (TTMaskHasType(rMask, d))
+			    TTMaskSetType(&op->co_paintMask, s);
+		    }
+	}
+
     /*
      * Find the largest reducer value which divides into all of the CIF values.
      */
 
     minReduce = style->cs_scaleFactor;
-    for (i=0; i<style->cs_nLayers; i++)
+    for (i = 0; i < style->cs_nLayers; i++)
     {
 	for (op = style->cs_layers[i]->cl_ops; op != NULL; op = op->co_next)
 	{
@@ -1281,13 +1306,21 @@ CIFTechFinal()
 		c = FindGCF(style->cs_scaleFactor, op->co_distance);
 		if (c < minReduce) minReduce = c;
 	    }
-	    if (op->co_bloats)
+	    if (op->co_client)
 	    {
+		BloatData *bloats;
+		SquaresData *squares;
 		if (op->co_opcode == CIFOP_SQUARES)
 		{
-		    for (j = 0; j < 4; j++)
+		    squares = (SquaresData *)op->co_client;
+
+		    for (j = 0; j < 3; j++)
 		    {
-			bvalue = op->co_bloats[j];
+			switch (j) {
+			   case 0: bvalue = squares->sq_border; break;
+			   case 1: bvalue = squares->sq_size; break;
+			   case 2: bvalue = squares->sq_sep; break;
+			}
 			if (bvalue != 0)
 			{
 			    if ((j == 1) || (j == 2))
@@ -1302,14 +1335,35 @@ CIFTechFinal()
 			}
 		    }
 		}
-		else
+		else if (op->co_opcode == CIFOP_SQUARES_G)
 		{
-		    for (j = 0; j < ((op->co_opcode == CIFOP_SQUARES_G)
-				? 5 : TT_MAXTYPES); j++)
+		    squares = (SquaresData *)op->co_client;
+		    for (j = 0; j < TT_MAXTYPES; j++)
 		    {
-			if (op->co_bloats[j] != 0)
+			switch (j) {
+			   case 0: bvalue = squares->sq_border; break;
+			   case 1: bvalue = squares->sq_size; break;
+			   case 2: bvalue = squares->sq_sep; break;
+			   case 3: bvalue = squares->sq_gridx; break;
+			   case 4: bvalue = squares->sq_gridy; break;
+			}
+			if (bvalue != 0)
 			{
-			    c = FindGCF(style->cs_scaleFactor, op->co_bloats[j]);
+			    c = FindGCF(style->cs_scaleFactor, bvalue);
+			    if (c < minReduce) minReduce = c;
+			}
+		    }
+		}
+		/* Presence of op->co_opcode in CIFOP_OR indicates a copy */
+		/* of the SquaresData pointer from a following operator	  */
+		else if (op->co_opcode != CIFOP_OR)
+		{
+		    bloats = (BloatData *)op->co_client;
+		    for (j = 0; j < TT_MAXTYPES; j++)
+		    {
+			if (bloats->bl_distance[j] != 0)
+			{
+			    c = FindGCF(style->cs_scaleFactor, bloats->bl_distance[j]);
 			    if (c < minReduce) minReduce = c;
 			}
 		    }
@@ -1329,7 +1383,7 @@ CIFTechFinal()
      * and remember the largest.
      */
     maxGrow = maxShrink = 0;
-    for (i=0; i<style->cs_nLayers; i++)
+    for (i = 0; i < style->cs_nLayers; i++)
     {
 	cifComputeRadii(style->cs_layers[i], style);
 	if (style->cs_layers[i]->cl_growDist > maxGrow)
@@ -1374,6 +1428,8 @@ CIFTechFinal()
 	for (op = style->cs_layers[i]->cl_ops; op != NULL;
 		    op = op->co_next)
 	{
+	    BloatData *bloats;
+
 	    TTMaskSetMask(&ourDepend, &op->co_cifMask);
 	    TTMaskSetMask(&ourYank, &op->co_paintMask);
 	    switch (op->co_opcode)
@@ -1381,28 +1437,11 @@ CIFTechFinal()
 		case CIFOP_BLOAT:
 		case CIFOP_BLOATMAX:
 		case CIFOP_BLOATMIN:
+		    bloats = (BloatData *)op->co_client;
 		    for (j = 0; j < TT_MAXTYPES; j++)
 		    {
-			if (op->co_bloats[j] != op->co_bloats[TT_SPACE])
-			{
-			    /* Careful!  For contact images, must yank
-			     * the MASTER image.
-			     */
-				
-			    if (j < DBNumUserLayers)
-				TTMaskSetType(&ourYank, j);
-			    else
-			    {
-				int k;
-				for (k = TT_SELECTBASE;
-					k < DBNumUserLayers; k += 1)
-				{
-				    if (TTMaskHasType(
-					    &DBLayerTypeMaskTbl[k], j))
-					    TTMaskSetType(&ourYank, k);
-				}
-			    }
-			}
+			if (bloats->bl_distance[j] != bloats->bl_distance[TT_SPACE])
+			    TTMaskSetType(&ourYank, j);
 		    }
 		    needThisLayer = TRUE;
 		    break;
@@ -1422,20 +1461,33 @@ CIFTechFinal()
 	    TTMaskSetMask(&style->cs_hierLayers, &ourDepend);
 	}
     }
-    /* make sure that all the yanklayers that are images have their
-     * base types set -dcs 4/6/90
-     */
-    for (i = DBNumUserLayers; i < DBNumTypes;i++)
+
+    /* Added by Tim, 10/18/04					*/
+
+    /* Go through the layer operators looking for those that	*/
+    /* contain only OR operators followed by a single SQUARES	*/
+    /* operator.  If found, set the clientdata record of the OR	*/
+    /* operator to be a copy of that for the SQUARES operator.	*/
+    /* This is used by the GDS generator when the "gds contact	*/
+    /* on" option is enabled (CalmaContactArrays is TRUE) to	*/
+    /* translate contact areas into contact subcell arrays.	*/
+
+    for (i = 0; i < style->cs_nLayers; i++)
     {
-	if (TTMaskHasType(&style->cs_yankLayers,i))
+	ClientData clientdata;
+	for (op = style->cs_layers[i]->cl_ops; (op != NULL) &&
+			(op->co_opcode == CIFOP_OR) &&
+			(TTMaskIsZero(&op->co_cifMask)); op = op->co_next);
+	if (op && (op->co_opcode == CIFOP_SQUARES) && (op->co_next == NULL))
 	{
-	    int k;
-	    for (k = TT_SELECTBASE; k <DBNumUserLayers; k++)
+	    clientdata = op->co_client;
+	    for (op = style->cs_layers[i]->cl_ops; op->co_opcode == CIFOP_OR;
+			op = op->co_next)
 	    {
-		if (TTMaskHasType(DBLayerTypeMaskTbl+k,i))
-		{
-		    TTMaskSetType(&style->cs_yankLayers,k);
-		}
+		/* Copy the client record from the CIFOP_SQUARES operator
+		 * into the CIFOP_OR operator.
+		 */
+		op->co_client = clientdata;
 	    }
 	}
     }
@@ -1494,6 +1546,54 @@ CIFLoadStyle(stylename)
     CIFTechOutputScale(DBLambda[0], DBLambda[1]);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * CIFGetContactSize --
+ *
+ *   Return the smallest allowable contact size in lambda units corresponding
+ *   to the "squares" function operating on the indicated type.  This value
+ *   is computed as the (cut size) + 2 * (cut border).
+ *
+ * Results:
+ *	Contact minimum dimension, in CIF/GDS units
+ *
+ * Side effects:
+ *	None.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+int
+CIFGetContactSize(type)
+    TileType type;
+{
+    CIFStyle *style = CIFCurStyle;
+    CIFOp *op;
+    int i;
+    bool hasType;
+    SquaresData *squares;
+
+    for (i = 0; i < style->cs_nLayers; i++)
+    {
+	hasType = FALSE;
+	for (op = style->cs_layers[i]->cl_ops; (op != NULL) &&
+			(op->co_opcode == CIFOP_OR) &&
+			(TTMaskIsZero(&op->co_cifMask)); op = op->co_next)
+	    if (TTMaskHasType(&op->co_paintMask, type))
+		hasType = TRUE;
+
+	if (hasType && op && (op->co_opcode == CIFOP_SQUARES)
+		&& (op->co_next == NULL))
+	{
+	    squares = (SquaresData *)op->co_client;
+	    return (squares->sq_size + (squares->sq_border << 1));
+	}
+    }
+    return 0;
+}
+
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1530,6 +1630,8 @@ CIFTechOutputScale(n, d)
     CIFStyle *ostyle = CIFCurStyle;
     CIFLayer *cl;
     CIFOp *op;
+    SquaresData *squares;
+    BloatData *bloats;
 
     /* For contact half-grid centering, check for odd numbers. . . */
     if (d & 0x1)
@@ -1540,11 +1642,14 @@ CIFTechOutputScale(n, d)
 	    cl = ostyle->cs_layers[i];
 	    for (op = cl->cl_ops; op != NULL; op = op->co_next)
 		if (op->co_opcode == CIFOP_SQUARES)
-		    if ((op->co_bloats[1] & 0x01) || (op->co_bloats[2] & 0x01))
+		{
+		    squares = (SquaresData *)op->co_client;
+		    if ((squares->sq_size & 0x01) || (squares->sq_sep & 0x01))
 		    {
 			has_odd_space = TRUE;
 			break;
 		    }
+		}
 
 	    if (has_odd_space)
 	    {
@@ -1574,32 +1679,61 @@ CIFTechOutputScale(n, d)
 		lgcf = FindGCF(abs(op->co_distance), ostyle->cs_expander);
 		lexpand = FindGCF(lexpand, lgcf);
 	    }
-	    if (op->co_bloats)
+	    if (op->co_client)
 	    {
-		int bvalue;
+		int bvalue, *bptr;
 		if (op->co_opcode == CIFOP_SQUARES)
 		{
-		    for (j = 0; j < 4; j++)
+		    squares = (SquaresData *)op->co_client;
+		    for (j = 0; j < 3; j++)
 		    {
-			if (op->co_bloats[j] != 0)
+			switch (j) {
+			    case 0: bptr = &squares->sq_border; break;
+			    case 1: bptr = &squares->sq_size; break;
+			    case 2: bptr = &squares->sq_sep; break;
+			}
+			if (*bptr != 0)
 			{
-			    op->co_bloats[j] *= d;
-			    bvalue = abs(op->co_bloats[j]);
+			    (*bptr) *= d;
+			    bvalue = abs(*bptr);
 			    if ((j == 1) || (j == 2)) bvalue >>= 1;	/* half-grid */
 		            lgcf = FindGCF(bvalue, ostyle->cs_expander);
 			    lexpand = FindGCF(lexpand, lgcf);
 			}
 		    }
 		}
-		else
+		else if (op->co_opcode == CIFOP_SQUARES_G)
 		{
-		    for (j = 0; j < ((op->co_opcode == CIFOP_SQUARES_G)
-				? 5 : TT_MAXTYPES); j++)
+		    squares = (SquaresData *)op->co_client;
+		    for (j = 0; j < 5; j++)
 		    {
-			if (op->co_bloats[j] != 0)
+			switch (j) {
+			    case 0: bptr = &squares->sq_border; break;
+			    case 1: bptr = &squares->sq_size; break;
+			    case 2: bptr = &squares->sq_sep; break;
+			    case 3: bptr = &squares->sq_gridx; break;
+			    case 4: bptr = &squares->sq_gridy; break;
+			}
+			if (*bptr != 0)
 			{
-			    op->co_bloats[j] *= d;
-		            lgcf = FindGCF(abs(op->co_bloats[j]), ostyle->cs_expander);
+			    (*bptr) *= d;
+		            lgcf = FindGCF(abs(*bptr), ostyle->cs_expander);
+			    lexpand = FindGCF(lexpand, lgcf);
+			}
+		    }
+		}
+		/* Presence of op->co_opcode in CIFOP_OR indicates a copy */
+		/* of the SquaresData pointer from a following operator	  */
+		else if (op->co_opcode != CIFOP_OR)
+		{
+		    bloats = (BloatData *)op->co_client;
+		    for (j = 0; j < TT_MAXTYPES; j++)
+		    {
+			if (bloats->bl_distance[j] != 0)
+			{
+			    bloats->bl_distance[j] *= d;
+		            lgcf = FindGCF(abs(bloats->bl_distance[j]),
+					ostyle->cs_expander);
 			    lexpand = FindGCF(lexpand, lgcf);
 			}
 		    }
@@ -1636,24 +1770,39 @@ CIFTechOutputScale(n, d)
 	    if (op->co_distance)
 		op->co_distance /= lexpand;
 
-	    if (op->co_bloats)
+	    if (op->co_client)
 	    {
 		int nlayers;
 		switch (op->co_opcode)
 		{
-		    case CIFOP_SQUARES:
-			nlayers = 4;
-			break;
 		    case CIFOP_SQUARES_G:
-			nlayers = 5;
+			squares = (SquaresData *)op->co_client;
+			if (squares->sq_gridx != 0)
+			    squares->sq_gridx /= lexpand;
+			if (squares->sq_gridy != 0)
+			    squares->sq_gridy /= lexpand;
+			/* (drop through) */
+		    case CIFOP_SQUARES:
+			squares = (SquaresData *)op->co_client;
+			if (squares->sq_border != 0)
+			    squares->sq_border /= lexpand;
+			if (squares->sq_size != 0)
+			    squares->sq_size /= lexpand;
+			if (squares->sq_sep != 0)
+			    squares->sq_sep /= lexpand;
+			break;
+		    case CIFOP_BLOAT:
+		    case CIFOP_BLOATMIN:
+		    case CIFOP_BLOATMAX:
+			bloats = (BloatData *)op->co_client;
+			for (j = 0; j < TT_MAXTYPES; j++)
+			    if (bloats->bl_distance[j] != 0)
+				bloats->bl_distance[j] /= lexpand;
 			break;
 		    default:
-			nlayers = TT_MAXTYPES;
+			/* op->co_opcode in CIFOP_OR is a pointer copy */
 			break;
 		}
-		for (j = 0; j < nlayers; j++)
-		    if (op->co_bloats[j] != 0)
-			op->co_bloats[j] /= lexpand;
 	    }
 	}
     }
