@@ -20,14 +20,10 @@
  * rcsid "$Header: /ufs/repository/magic/cif/cif.h,v 1.2 2001/01/12 22:12:15 jsolomon Exp $
  */
 
-#define _CIF
+#ifndef _CIF_H
+#define _CIF_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_DATABASE
-int err1 = Need_to_include_database/database_header;
-#endif	/* _DATABASE */
+#include "database/database.h"
 
 #define CIFMAXRESCALE 100	/* This value avoids integer overflow
 				 * in most cases.  However, that
@@ -51,6 +47,7 @@ extern void CIFTechStyleInit();
 extern void CIFTechInit();
 extern bool CIFTechLine();
 extern void CIFTechFinal();
+extern void CIFTechOutputScale();
 extern void CIFReadTechStyleInit();
 extern void CIFReadTechInit();
 extern bool CIFReadTechLine();
@@ -60,6 +57,7 @@ extern void CIFReadTechFinal();
 
 extern float CIFGetOutputScale();
 extern float CIFGetInputScale();
+extern int CIFGetDefaultContactSize();
 
 extern void CIFSeeLayer();
 extern void CIFSeeHierLayer();
@@ -75,3 +73,7 @@ extern void CIFPrintStyle();
 extern void CIFPrintReadStyle();
 
 extern int CIFOutputScaleFactor();
+
+extern void PaintWireList();
+
+#endif /* _CIF_H */
