@@ -21,22 +21,24 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cmwind/CMWcmmnds.c,v 1.2 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "cmwind/cmwind.h"
 #include "graphics/graphics.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/txcommands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 /* Forward declarations: */
 
@@ -87,6 +89,9 @@ CMWcommand(w, cmd)
 {
     switch (cmd->tx_button)
     {
+        case TX_NO_BUTTON:
+	    WindExecute(w, CMWclientID, cmd);
+	    break;
         case TX_LEFT_BUTTON:
         case TX_RIGHT_BUTTON:
         case TX_MIDDLE_BUTTON:
@@ -100,9 +105,6 @@ CMWcommand(w, cmd)
 		    break;
 	    }
 	    break;
-        case TX_NO_BUTTON:
-	    WindExecute(w, CMWclientID, cmd);
-	    break;
 	default:
 	    ASSERT(FALSE, "CMWcommand");
     }
@@ -110,7 +112,6 @@ CMWcommand(w, cmd)
     UndoNext();
 }
 
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -133,7 +134,6 @@ CMWcommand(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
 void
 cmwButtonDown(w, p, button)
@@ -141,7 +141,7 @@ cmwButtonDown(w, p, button)
     Point *p;
     int button;
 {
-    ColorBar *cb, *cbFind();
+    ColorBar *cb;
     ColorPump *cp;
     Point surfacePoint;
     int x;
@@ -181,6 +181,15 @@ cmwButtonDown(w, p, button)
 	}
     }
 
+    /* Note that the "color picker" function can't work as implemented
+     * because this function is registered only with the color window,
+     * so it cannot be called with a different window "w".  So, we can
+     * only disable the button functions when pushed over the "current
+     * color area" rectangle.
+     */
+
+#ifndef MAGIC_WRAPPER
+
     /* See if the cursor is over the current color area.  If so, remember
      * the fact and wait for the button to be released.
      */
@@ -193,8 +202,10 @@ cmwButtonDown(w, p, button)
 	    TxPrintf("Release button over new color to edit.\n");
 	else TxPrintf("Release button over color to copy.\n");
     }
+#endif
+
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -213,7 +224,7 @@ cmwButtonDown(w, p, button)
 
 void
 cmwButtonUp(w, p, button)
-    MagWindow *w;		/* Window where the button was released */
+    MagWindow *w;	/* Window where the button was released */
     Point *p;		/* Point where button was released, in window coords.*/
     int button;		/* Button that was released. */
 {
@@ -263,7 +274,64 @@ cmwButtonUp(w, p, button)
 		cmwRedisplayFunc, (ClientData) crec->cmw_color);
     }
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * cmwPushbutton --
+ *
+ * Usage:
+ *	pushbutton <button>
+ *
+ * where button is "left", "middle", or "right".
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Performs the default action associated with the button event.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+cmwPushbutton(w, cmd)
+    MagWindow *w;
+    TxCommand *cmd;
+{
+    int button;
+    static char *cmwButton[] = {"left", "middle", "right", NULL};
+
+    if (cmd->tx_argc != 2)
+    {
+	TxError("Usage: pushbutton <button>\n");
+	return;
+    }
+    button = Lookup(cmd->tx_argv[1], cmwButton);
+    if (button < 0)
+    {
+	TxError("Argument \"button\" must be one of "
+		"\"left\", \"middle\", or \"right\".\n");
+	return;
+    }
+    else switch(button)
+    {
+	case 0:
+	    cmd->tx_button = TX_LEFT_BUTTON;
+	    break;
+	case 1:
+	    cmd->tx_button = TX_MIDDLE_BUTTON;
+	    break;
+	case 2:
+	    cmd->tx_button = TX_RIGHT_BUTTON;
+	    break;
+    }
+
+    cmd->tx_buttonAction = TX_BUTTON_DOWN;
+    CMWcommand(w, cmd);
+    cmwWatchButtonUp = FALSE;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -272,7 +340,7 @@ cmwButtonUp(w, p, button)
  * Load a color map window with a particular color.
  *
  * Usage:
- *	color color-#
+ *	color color-#|next|last|get|rgb
  *
  * where color-# is the octal number of the color to be edited.
  *
@@ -292,28 +360,73 @@ cmwColor(w, cmd)
 {
     int color, r, g, b;
     CMWclientRec *crec;
-    extern int grBitPlaneMask;
 
     if (cmd->tx_argc == 1)
     {
 	crec = (CMWclientRec *) w->w_clientData;
-	(void) GrGetColor(crec->cmw_color, &r, &g, &b);
-	TxPrintf("Current color is %o octal (%d decimal) (red = %d, green = %d, blue = %d)\n",
+	GrGetColor(crec->cmw_color, &r, &g, &b);
+	TxPrintf("Current color is %o octal (%d decimal) "
+			"(red = %d, green = %d, blue = %d)\n",
 	    crec->cmw_color, crec->cmw_color, r, g, b);
     }
     else if (cmd->tx_argc == 2)
     {
-	sscanf(cmd->tx_argv[1], "%o", &color);
-	if (color != (color & grBitPlaneMask)) 
+	if (sscanf(cmd->tx_argv[1], "%i", &color) == 0)
 	{
-	    TxError("This colormap only has values from 0 to %o (octal)\n", 
-		grBitPlaneMask);
+	    /* Invalid color---allow keywords "next" and "last" */
+	    crec = (CMWclientRec *) w->w_clientData;
+	    if (!strncmp(cmd->tx_argv[1], "next", 4))
+	    {
+		color = crec->cmw_color + 1;
+		if (color >= GrNumColors)
+		    color = 0;
+	    }
+	    else if (!strncmp(cmd->tx_argv[1], "last", 4))
+	    {
+		color = crec->cmw_color - 1;
+		if (color < 0)
+		    color = GrNumColors - 1;
+	    }
+	    else if (!strncmp(cmd->tx_argv[1], "get", 3))
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewIntObj(crec->cmw_color));
+#else
+		TxPrintf("Color index %d\n", crec->cmw_color);
+#endif
+		return;
+	    }
+	    else if (!strncmp(cmd->tx_argv[1], "rgb", 3))
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_Obj *cobj = Tcl_NewListObj(0, NULL);
+		GrGetColor(crec->cmw_color, &r, &g, &b);
+		Tcl_ListObjAppendElement(magicinterp, cobj, Tcl_NewIntObj(r));
+		Tcl_ListObjAppendElement(magicinterp, cobj, Tcl_NewIntObj(g));
+		Tcl_ListObjAppendElement(magicinterp, cobj, Tcl_NewIntObj(b));
+		Tcl_SetObjResult(magicinterp, cobj);
+#else
+		GrGetColor(crec->cmw_color, &r, &g, &b);
+		TxPrintf("Color RGB=%d %d %d\n", r, g, b);
+#endif
+		return;
+	    }
+	    else
+	    {
+		TxError("Usage: color [#|next|last|get|rgb]\n");
+		return;
+	    }
+	}
+	if (color < 0 || color >= GrNumColors)
+	{
+	    TxError("The colormap only has values from 0 to %d (decimal).\n",
+			(GrNumColors - 1));
 	    return;
 	}
 	CMWloadWindow(w, color);
     }
     else 
-	TxError("Usage: color [#]\n");
+	TxError("Usage: color [#|next|last|get|rgb]\n");
 }
 
 /*
@@ -472,16 +585,19 @@ cbUpdate(w, code, x, replace)
     /* Mark all windows containing this color as modified */
     (void) WindSearch(CMWclientID, (ClientData) NULL, (Rect *) NULL,
 		cmwRedisplayFunc, (ClientData) cr->cmw_color);
+
+    /* Here. . . ought to mark the layout windows as modified? */
 }
 
 int
 cmwRedisplayFunc(w, color)
-    MagWindow *w;			/* Window that may have to be redisplayed. */
+    MagWindow *w;		/* Window that may have to be redisplayed. */
     int color;			/* If this color is in window, redisplay the
 				 * color bars in the window.
 				 */
 {
     ColorBar *cb;
+    ColorPump *cp;
     Rect screenR;
     CMWclientRec *cr = (CMWclientRec *) w->w_clientData;
 
@@ -492,10 +608,20 @@ cmwRedisplayFunc(w, color)
 	    WindSurfaceToScreen(w, &cb->cb_rect, &screenR);
             WindAreaChanged(w, &screenR);
 	}
+	for (cp = colorPumps; cp->cp_code >= 0; cp++)
+	{
+	    WindSurfaceToScreen(w, &cp->cp_rect, &screenR);
+            WindAreaChanged(w, &screenR);
+	}
     }
+
+    /* Also update the "color being edited" rectangle */
+    WindSurfaceToScreen(w, &cmwCurrentColorArea, &screenR);
+    WindAreaChanged(w, &screenR);
+
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -519,7 +645,7 @@ cmwRedisplayFunc(w, color)
 bool
 CMWCheckWritten()
 {
-    int indx;
+    bool indx;
     char *prompt;
     static char *(yesno[]) = {"no", "yes", NULL};
 
