@@ -22,29 +22,34 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cmwind/CMWmain.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "cmwind/cmwind.h"
 #include "graphics/graphicsInt.h"
 #include "graphics/graphics.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "graphics/glyphs.h"
 #include "utils/malloc.h"
 
 global WindClient CMWclientID;
 
-/* ---------------------------- Commands ------------------------------ */
-
-int cmwColor(), cmwSave(), cmwLoad();
+/* Forward and external declarations */
 
+extern void cmwColor();
+extern void cmwSave();
+extern void cmwLoad();
+extern void cmwPushbutton();
+extern void RGBxHSV();
+extern void CMWundoInit();
 
 /* -------------------------------------------------------------------- */
 
@@ -86,45 +91,45 @@ int cmwColor(), cmwSave(), cmwLoad();
 
 ColorBar colorBars[] =
 {
-    "Red",	CB_RED,		STYLE_RED,	2000,	8000,	10000,	9000,
-						2000,	9500,	10000,	10500,
-    "Green",	CB_GREEN,	STYLE_GREEN,	2000,	5000,	10000,	6000,
-						2000,	6500,	10000,	7500,
-    "Blue",	CB_BLUE,	STYLE_BLUE,	2000,	2000,	10000,	3000,
-						2000,	3500,	10000,	4500,
-    "Hue",	CB_HUE,		STYLE_YELLOW,	14000,	8000,	22000,	9000,
-						14000,	9500,	22000,	10500,
-    "Saturation",  CB_SAT,	STYLE_GRAY,	14000,	5000,	22000,	6000,
-						14000,	6500,	22000,	7500,
-    "Value",	CB_VALUE,	STYLE_BROWN1,	14000,	2000,	22000,	3000,
-						14000,	3500,	22000,	4500,
+    "Red",	CB_RED,		STYLE_RED,	{2000,	8000,	10000,	9000},
+						{2000,	9500,	10000,	10500},
+    "Green",	CB_GREEN,	STYLE_GREEN,	{2000,	5000,	10000,	6000},
+						{2000,	6500,	10000,	7500},
+    "Blue",	CB_BLUE,	STYLE_BLUE,	{2000,	2000,	10000,	3000},
+						{2000,	3500,	10000,	4500},
+    "Hue",	CB_HUE,		STYLE_YELLOW,	{14000,	8000,	22000,	9000},
+						{14000,	9500,	22000,	10500},
+    "Saturation",  CB_SAT,	STYLE_GRAY,	{14000,	5000,	22000,	6000},
+						{14000,	6500,	22000,	7500},
+    "Value",	CB_VALUE,	STYLE_BROWN1,	{14000,	2000,	22000,	3000},
+						{14000,	3500,	22000,	4500},
     0
 };
 
 ColorPump colorPumps[] =
 {
-    CB_RED,	-.0078,	  500,	8000,	 1500,	9000,
-    CB_RED,	 .0078,	10500,  8000,	11500,	9000,
-    CB_GREEN,	-.0078,	  500,	5000,	 1500,	6000,
-    CB_GREEN,	 .0078,	10500,	5000,	11500,	6000,
-    CB_BLUE,	-.0078,	  500,	2000,	 1500,	3000,
-    CB_BLUE,	 .0078,	10500,	2000,	11500,	3000,
-    CB_HUE,	-.01,	12500,	8000,	13500,	9000,
-    CB_HUE,	 .01,	22500,	8000,	23500,	9000,
-    CB_SAT,	-.01,	12500,	5000,	13500,	6000,
-    CB_SAT,	 .01,	22500,	5000,	23500,	6000,
-    CB_VALUE,	-.01,	12500,	2000,	13500,	3000,
-    CB_VALUE,	 .01,	22500,	2000,	23500,	3000,
+    CB_RED,	-.0078,	  {500,	8000,	 1500,	9000},
+    CB_RED,	 .0078,	{10500, 8000,	11500,	9000},
+    CB_GREEN,	-.0078,	  {500,	5000,	 1500,	6000},
+    CB_GREEN,	 .0078,	{10500,	5000,	11500,	6000},
+    CB_BLUE,	-.0078,	  {500,	2000,	 1500,	3000},
+    CB_BLUE,	 .0078,	{10500,	2000,	11500,	3000},
+    CB_HUE,	-.01,	{12500,	8000,	13500,	9000},
+    CB_HUE,	 .01,	{22500,	8000,	23500,	9000},
+    CB_SAT,	-.01,	{12500,	5000,	13500,	6000},
+    CB_SAT,	 .01,	{22500,	5000,	23500,	6000},
+    CB_VALUE,	-.01,	{12500,	2000,	13500,	3000},
+    CB_VALUE,	 .01,	{22500,	2000,	23500,	3000},
     -1
 };
 
-Rect cmwCurrentColorArea = {6000, 12000, 18000, 15000};
-Rect cmwCurrentColorTextBox = {6000, 15500, 18000, 16500};
+Rect cmwCurrentColorArea = {{6000, 12000}, {18000, 15000}};
+Rect cmwCurrentColorTextBox = {{6000, 15500}, {18000, 16500}};
 char *cmwCurrentColorText = "Color Being Edited";
 
 /* Bounding rectangle for entire window */
 
-Rect colorWindowRect = { 0, 1500, 24000, 17000 };
+Rect colorWindowRect = {{0, 1500}, {24000, 17000}};
 
 /*
  * ----------------------------------------------------------------------------
@@ -143,12 +148,13 @@ Rect colorWindowRect = { 0, 1500, 24000, 17000 };
  * ----------------------------------------------------------------------------
  */
 
+bool
 CMWcreate(window, argc, argv)
     MagWindow *window;
     int argc;
     char *argv[];
 {
-    register CMWclientRec *crec;
+    CMWclientRec *crec;
     int color;
 
     crec = (CMWclientRec *) mallocMagic(sizeof(CMWclientRec));
@@ -182,6 +188,7 @@ CMWcreate(window, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+bool
 CMWdelete(window)
     MagWindow *window;
 {
@@ -210,8 +217,7 @@ CMWdelete(window)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
-Void
+void
 CMWreposition(window, newScreenArea, final)
     MagWindow *window;
     Rect *newScreenArea;
@@ -237,13 +243,14 @@ CMWreposition(window, newScreenArea, final)
  * ----------------------------------------------------------------------------
  */
 
+void
 CMWredisplay(w, rootArea, clipArea)
     MagWindow *w;		/* The window containing the area. */
     Rect *rootArea;	/* Redisplay area in surface coordinates. */
     Rect *clipArea;	/* An area on the screen to clip to. */
 {
-    register CMWclientRec *cr;
-    register ColorBar *cb;
+    CMWclientRec *cr;
+    ColorBar *cb;
     ColorPump *cp;
     Rect rect, screenR;
     Point screenP;
@@ -366,10 +373,10 @@ CMWredisplay(w, rootArea, clipArea)
 
 void
 CMWloadWindow(w, color)
-    register MagWindow *w;	/* Identifies window to which color is to be bound */
+    MagWindow *w;	/* Identifies window to which color is to be bound */
     int color;		/* New color to be bound to this window. */
 {
-    register CMWclientRec *cr = (CMWclientRec *) w->w_clientData;
+    CMWclientRec *cr = (CMWclientRec *) w->w_clientData;
     char caption[40];
 
     cr->cmw_color = color;
@@ -399,11 +406,12 @@ CMWloadWindow(w, color)
  * ----------------------------------------------------------------------------
  */
 
+void
 CMWinit()
 {
     CMWclientID = WindAddClient("color", CMWcreate, CMWdelete,
 			CMWredisplay, CMWcommand,
-			( Void (*)()) NULL,
+			(void(*)()) NULL,
 			CMWCheckWritten,
 			CMWreposition,
 			(GrGlyph *) NULL);
@@ -411,6 +419,9 @@ CMWinit()
 
     /* Register commands with the client */
 
+    WindAddCommand(CMWclientID,
+	"cmbutton button	invoke a button press in the color window",
+	 cmwPushbutton, FALSE);
     WindAddCommand(CMWclientID,
        "color [color-#]	        specify color to edit, or print current intensities",
 	cmwColor, FALSE);
