@@ -23,7 +23,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cmwind/CMWrgbhsv.c,v 1.2 2
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 
 /* max of three numbers */
 #define	MAX3(a,b,c)	(a > b ? (a > c ? a : c) : ( b > c ?b : c))
