@@ -21,12 +21,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cmwind/CMWundo.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
 #include "cmwind/cmwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 /*
  * Identifiers for the color map window editing
