@@ -27,14 +27,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdCD.c,v 1.5 200
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
@@ -43,10 +43,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdCD.c,v 1.5 200
 #include "textio/txcommands.h"
 #include "cif/cif.h"
 #include "calma/calma.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "router/rtrDcmpose.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 #include "cif/CIFint.h"
 
@@ -93,16 +93,19 @@ bool cmdDumpParseArgs();
  */
 
 #define CALMA_HELP	0
-#define	CALMA_FLATTEN	1
-#define	CALMA_LABELS	2
-#define	CALMA_LOWER	3
-#define CALMA_READ	4
-#define CALMA_READONLY	5
-#define CALMA_RESCALE	6
-#define CALMA_WARNING	7
-#define CALMA_WRITE	8
+#define CALMA_ARRAYS	1
+#define CALMA_CONTACTS	2
+#define	CALMA_FLATTEN	3
+#define CALMA_ORDERING	4
+#define	CALMA_LABELS	5
+#define	CALMA_LOWER	6
+#define CALMA_READ	7
+#define CALMA_READONLY	8
+#define CALMA_RESCALE	9
+#define CALMA_WARNING	10
+#define CALMA_WRITE	11
 #ifdef NONMANHATTAN
-#define CALMA_POLYS	9
+#define CALMA_POLYS	12
 #endif
 
 #define CALMA_WARN_HELP CIF_WARN_END	/* undefined by CIF module */
@@ -124,7 +127,10 @@ CmdCalma(w, cmd)
     static char *cmdCalmaOption[] =
     {	
 	"help		print this help information",
-	"flatten [yes|no]	output arrays as individual subuses (like in CIF)",
+	"arrays [yes|no]	output arrays as individual subuses (like in CIF)",
+	"contacts [yes|no]	optimize output by arraying contacts as subcells",
+	"flatten [yes|no]	flatten simple cells (e.g., contacts) on input",
+	"ordering [on|off]	cause cells to be read in post-order",
 	"labels [yes|no]	cause labels to be output when writing GDS-II",
 	"lower [yes|no]		allow both upper and lower case in labels",
 	"read file		read Calma GDS-II format from \"file\"\n"
@@ -220,9 +226,76 @@ CmdCalma(w, cmd)
 	    CalmaDoLabels = (option < 3) ? FALSE : TRUE;
 	    return;
 
+	case CALMA_CONTACTS:
+	    if (cmd->tx_argc == 2)
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(CalmaContactArrays));
+#else
+		if (CalmaContactArrays)
+		    TxPrintf("Contact areas are arrayed as subcells.\n");
+		else
+		    TxPrintf("Contact areas are output as individual cuts.\n");
+#endif
+		return;
+	    }
+	    else if (cmd->tx_argc != 3)
+		goto wrongNumArgs;
+
+	    option = Lookup(cmd->tx_argv[2], cmdCalmaYesNo);
+	    if (option < 0)
+		goto wrongNumArgs;
+	    CalmaContactArrays = (option < 3) ? FALSE : TRUE;
+	    return;
+
 	case CALMA_FLATTEN:
 	    if (cmd->tx_argc == 2)
 	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(CalmaFlattenUses));
+#else
+		if (CalmaFlattenUses)
+		    TxPrintf("Small cells in input are flattened.\n");
+		else
+		    TxPrintf("Cells are never flattened on input.\n");
+#endif
+		return;
+	    }
+	    else if (cmd->tx_argc != 3)
+		goto wrongNumArgs;
+
+	    option = Lookup(cmd->tx_argv[2], cmdCalmaYesNo);
+	    if (option < 0)
+		goto wrongNumArgs;
+	    CalmaFlattenUses = (option < 3) ? FALSE : TRUE;
+	    return;
+
+	case CALMA_ORDERING:
+	    if (cmd->tx_argc == 2)
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(CalmaPostOrder));
+#else
+		if (CalmaPostOrder)
+		    TxPrintf("GDS parser reads cells in post-order.\n");
+		else
+		    TxPrintf("GDS parser reads cells in the order "
+				"encountered in the stream file.\n");
+		return;
+#endif
+	    }
+	    else if (cmd->tx_argc != 3)
+		goto wrongNumArgs;
+
+	    option = Lookup(cmd->tx_argv[2], cmdCalmaYesNo);
+	    if (option < 0)
+		goto wrongNumArgs;
+	    CalmaPostOrder = (option < 3) ? FALSE : TRUE;
+	    return;
+
+	case CALMA_ARRAYS:
+	    if (cmd->tx_argc == 2)
+	    {
 #ifdef MAGIC_WRAPPER
 		Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(CalmaFlattenArrays));
 #else
@@ -858,7 +931,7 @@ CmdCif(w, cmd)
     switch (option)
     {
 	case HELP: case ISTYLE: case OSTYLE: case PREFIX:
-	case AREALABELS: case WARNING:
+	case AREALABELS: case WARNING: case CIF_LIMIT:
 #ifdef NONMANHATTAN
 	case POLYGONS:
 #endif
@@ -1199,8 +1272,8 @@ CmdCif(w, cmd)
  * box clockwise around the point.
  *
  * Usage:
- *	clockwise [degrees]	or
- *	rotate [degrees]
+ *	clockwise [degrees] [-origin]	or
+ *	rotate [degrees] [-origin]
  *
  * Results:
  *	None.
@@ -1215,6 +1288,9 @@ CmdCif(w, cmd)
  *	compatibility but the command must contain at least "clockw" for
  *	the interpreter to uniquely identify it.
  *
+ *	The "-origin" option has been added to allow rotating stuff
+ *	relative to the origin, insteadd of the lower-left corner.
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1224,13 +1300,21 @@ CmdClockwise(w, cmd)
     TxCommand *cmd;
 {
     Transform trans, t2;
-    int degrees;
+    int degrees, locargc;
     Rect rootBox,  bbox;
     CellDef *rootDef;
+    bool noAdjust = FALSE;
 
-    if (cmd->tx_argc == 1)
+    locargc = cmd->tx_argc;
+    if (!strncmp(cmd->tx_argv[locargc - 1], "-orig", 5))
+    {
+	noAdjust = TRUE;
+	locargc--;
+    }
+
+    if (locargc == 1)
 	degrees = 90;
-    else if (cmd->tx_argc == 2)
+    else if (locargc == 2)
     {
 	if (!StrIsInt(cmd->tx_argv[1])) goto badusage;
 	degrees = atoi(cmd->tx_argv[1]);
@@ -1261,9 +1345,17 @@ CmdClockwise(w, cmd)
      * that it used to be.
      */
     
-    GeoTransRect(&t2, &SelectDef->cd_bbox, &bbox);
-    GeoTranslateTrans(&t2, SelectDef->cd_bbox.r_xbot - bbox.r_xbot,
-	SelectDef->cd_bbox.r_ybot - bbox.r_ybot, &trans);
+    if (noAdjust)
+    {
+	GeoTransRect(&t2, &SelectDef->cd_bbox, &bbox);
+	trans = t2;
+    }
+    else
+    {
+	GeoTransRect(&t2, &SelectDef->cd_bbox, &bbox);
+	GeoTranslateTrans(&t2, SelectDef->cd_bbox.r_xbot - bbox.r_xbot,
+		SelectDef->cd_bbox.r_ybot - bbox.r_ybot, &trans);
+    }
 
     SelectTransform(&trans);
 
@@ -2550,14 +2642,14 @@ cmdDownEnumFunc(selUse, use, transform, area)
 #define COUNT		4
 #define EUCLIDEAN	5
 #define FIND		6
-#undef HELP
-#define HELP		7
-#define OFF		8
-#define ON		9
-#define PRINTRULES	10
-#define RULESTATS	11
-#define STATISTICS	12
-#define WHY		13
+#define DRC_HELP	7
+#define DRC_OFF		8
+#define DRC_ON		9
+#define DRC_STATUS	10
+#define PRINTRULES	11
+#define RULESTATS	12
+#define STATISTICS	13
+#define WHY		14
 
 void
 CmdDrc(w, cmd)
@@ -2586,6 +2678,7 @@ CmdDrc(w, cmd)
 	"help                   print this help information",
 	"off                    turn off background checker",
 	"on                     reenable background checker",
+	"status			report if the drc checker is on or off",
 	"printrules [file]      print out design rules in file or on tty",
 	"rulestats              print out stats about design rule database",
 	"statistics             print out statistics gathered by checker",
@@ -2596,7 +2689,7 @@ CmdDrc(w, cmd)
     if (cmd->tx_argc < 2)
     {
 	TxError("No option given in \":drc\" command.\n");
-	option = HELP;
+	option = DRC_HELP;
     }
     else
     {
@@ -2604,11 +2697,11 @@ CmdDrc(w, cmd)
 	if (option < 0)
 	{
 	    TxError("%s isn't a valid drc option.\n", cmd->tx_argv[1]);
-	    option = HELP;
+	    option = DRC_HELP;
 	    cmd->tx_argc = 2;
 	}
 	if ((cmd->tx_argc > 2) && (option != PRINTRULES) && (option != FIND)
-	    && (option != SHOWINT) && (option != HELP) && (option != EUCLIDEAN))
+	    && (option != SHOWINT) && (option != DRC_HELP) && (option != EUCLIDEAN))
 	{
 	    badusage:
 	    TxError("Wrong arguments in \"drc %s\" command:\n",
@@ -2705,7 +2798,7 @@ CmdDrc(w, cmd)
 	    }
 	    break;
 	
-	case HELP:
+	case DRC_HELP:
 	    if ((cmd->tx_argc == 3)
 		    && (strcmp(cmd->tx_argv[2], "wizard") == 0))
 		wizardHelp = TRUE;
@@ -2719,13 +2812,22 @@ CmdDrc(w, cmd)
 	    }
 	    break;
 	
-	case OFF:
+	case DRC_OFF:
 	    DRCBackGround = FALSE;
+	    TxSetPrompt('%');		/* Return prompt to "normal" */
 	    break;
 	
-	case ON:
+	case DRC_ON:
 	    DRCBackGround = TRUE;
 	    break;
+
+	case DRC_STATUS:
+#ifdef MAGIC_WRAPPER
+	    Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(DRCBackGround));
+#else
+	    TxPrintf("DRC checker is %s.\n", (DRCBackGround) ? "on" : "off");
+#endif
+	    break;
 	
 	case PRINTRULES:
 	    if (cmd->tx_argc > 3) goto badusage;
