@@ -25,8 +25,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdE.c,v 1.4 2001
 #include <string.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
-#include "misc/styles.h"
+#include "utils/magic.h"
+#include "utils/styles.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
@@ -35,10 +35,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdE.c,v 1.4 2001
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "drc/drc.h"
 #include "textio/txcommands.h"
 #include "extract/extract.h"
@@ -570,7 +570,7 @@ badusage:
  * EditCellUse->cu_def.
  *
  * Usage:
- *	erase [layers]
+ *	erase [layers | cursor]
  *
  * Results:
  *	None.
@@ -604,7 +604,7 @@ CmdErase(w, cmd)
 
     if (cmd->tx_argc > 2)
     {
-	TxError("Usage: %s [layers]\n", cmd->tx_argv[0]);
+	TxError("Usage: %s [<layers> | cursor]\n", cmd->tx_argv[0]);
 	return;
     }
 
@@ -618,6 +618,11 @@ CmdErase(w, cmd)
 
     if (cmd->tx_argc == 1)
 	(void) CmdParseLayers("*,label", &mask);
+    else if (!strncmp(cmd->tx_argv[1], "cursor", 6))
+    {
+	CmdPaintEraseButton(w, &cmd->tx_p, FALSE);
+	return;
+    }
     else if (!CmdParseLayers(cmd->tx_argv[1], &mask))
 	return;
 
@@ -719,8 +724,10 @@ CmdExpand(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    int windowMask, boxMask;
+    int windowMask, boxMask, d;
     Rect rootRect;
+    CellUse *rootBoxUse;
+    CellDef *rootBoxDef;
     int cmdExpandFunc();		/* Forward reference. */
 
     if (cmd->tx_argc > 2 || (cmd->tx_argc == 2 
@@ -737,20 +744,45 @@ CmdExpand(w, cmd)
 	return;
     }
     windowMask = ((DBWclientRec *) w->w_clientData)->dbw_bitmask;
+    d = DBLambda[1];
+    rootBoxUse = (CellUse *)w->w_surfaceID;
+    rootBoxDef = rootBoxUse->cu_def;
 
-    if (cmd->tx_argc == 2)
-	SelectExpand(windowMask);
-    else
+    /* Check for possible rescaling during the expansion, and adjust    */
+    /* the cursor box and window to restore the original view.          */
+
+    d = DBLambda[1];
+    do 
     {
-	(void) ToolGetBoxWindow(&rootRect, &boxMask);
-	if ((boxMask & windowMask) != windowMask)
+	if (d != DBLambda[1])
 	{
-	    TxError("The box isn't in the same window as the cursor.\n");
-	    return;
+            d = DBLambda[1] / d;
+            DBScalePoint(&rootRect.r_ll, d, 1);
+            DBScalePoint(&rootRect.r_ur, d, 1);
+            ToolMoveBox(TOOL_BL, &rootRect.r_ll, FALSE, rootBoxDef);
+            ToolMoveCorner(TOOL_TR, &rootRect.r_ur, FALSE, rootBoxDef);
+
+            /* Adjust all window viewing scales and positions and redraw */
+
+            WindScale(d, 1);
+	    TxPrintf("expand: rescaled by %d\n", d);
+	    d = DBLambda[1];
 	}
-	DBExpandAll(((CellUse *) w->w_surfaceID), &rootRect, windowMask,
-		TRUE, cmdExpandFunc, (ClientData) windowMask);
-    }
+
+	if (cmd->tx_argc == 2)
+	    SelectExpand(windowMask);
+	else
+	{
+	    (void) ToolGetBoxWindow(&rootRect, &boxMask);
+	    if ((boxMask & windowMask) != windowMask)
+	    {
+		TxError("The box isn't in the same window as the cursor.\n");
+		return;
+	    }
+	    DBExpandAll(rootBoxUse, &rootRect, windowMask,
+			TRUE, cmdExpandFunc, (ClientData) windowMask);
+	}
+    } while (d != DBLambda[1]);
 }
 
 /* This function is called for each cell whose expansion status changed.
