@@ -35,21 +35,22 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdFI.c,v 1.4 200
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
+#include "utils/undo.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "drc/drc.h"
 #include "textio/txcommands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "extract/extract.h"
 #include "utils/malloc.h"
 #include "select/select.h"
@@ -622,9 +623,10 @@ CmdFindLabel(w, cmd)
     }
     else
     {
-	/* Exact-match label search */
+	/* Exact-match label search (corrected by Nishit, 10/14/04) */
 
-	found = DBSrLabelLoc(EditCellUse, labname, cmdFindLabelFunc, (ClientData) 0);
+	found = DBSrLabelLoc(EditCellUse, labname, cmdFindLabelFunc,
+		(ClientData) &cmdFindLabelRect);
 	if (found) {
 	    if (cmdFindLabelRect.r_xbot == cmdFindLabelRect.r_xtop) 
 		cmdFindLabelRect.r_xtop++;
@@ -1007,11 +1009,63 @@ CmdGrid(w, cmd)
 	return;
     }
 
-    if ((cmd->tx_argc == 2) &&
-	    ((strcmp(cmd->tx_argv[1], "off") == 0)
-	    || (strcmp(cmd->tx_argv[1], "0") == 0)))
-	crec->dbw_flags &= ~DBW_GRID;
-    else if (cmd->tx_argc >= 2)
+    /* Parse various options with two arguments */
+
+    if (cmd->tx_argc == 2)
+    {
+	if (!strcmp(cmd->tx_argv[1], "box")
+		|| !strcmp(cmd->tx_argv[1], "what"))
+	{
+#ifdef MAGIC_WRAPPER
+	    char *boxvalues = (char *)Tcl_Alloc(50);
+	    sprintf(boxvalues, "%d %d %d %d",
+		crec->dbw_gridRect.r_xbot, crec->dbw_gridRect.r_ybot,
+		crec->dbw_gridRect.r_xtop, crec->dbw_gridRect.r_ytop);
+	    Tcl_SetResult(magicinterp, boxvalues, TCL_DYNAMIC);
+	
+#else
+	    TxPrintf("Grid unit box is (%d, %d) to (%d, %d)\n", 
+		crec->dbw_gridRect.r_xbot, crec->dbw_gridRect.r_ybot,
+		crec->dbw_gridRect.r_xtop, crec->dbw_gridRect.r_ytop);
+#endif
+	}
+	else if (!strcmp(cmd->tx_argv[1], "state"))
+	{
+#ifdef MAGIC_WRAPPER
+	    Tcl_SetObjResult(magicinterp,
+			Tcl_NewBooleanObj(crec->dbw_flags & DBW_GRID));
+#else
+	    TxPrintf("Grid is %s\n", 
+			(crec->dbw_flags & DBW_GRID) ? "on" : "off");
+#endif
+	}
+	else if (!strcmp(cmd->tx_argv[1], "help"))
+	{
+	    TxPrintf("Usage: grid [xSpacing [ySpacing [xOrig yOrig]]]]\n");
+	    TxPrintf("or     grid <option>\n");
+	    TxPrintf("where <option> is one of: on, off, state, box, or help.\n");
+	}
+	else if (!strcmp(cmd->tx_argv[1], "off")
+		|| !strcmp(cmd->tx_argv[1], "0"))
+	{
+	    if (crec->dbw_flags & DBW_GRID)
+	    {
+		crec->dbw_flags &= ~DBW_GRID;
+		WindAreaChanged(w, (Rect *) NULL);
+	    }
+	}
+	else if (!strcmp(cmd->tx_argv[1], "on"))
+	{
+	    if (!(crec->dbw_flags & DBW_GRID))
+	    {
+		crec->dbw_flags |= DBW_GRID;
+		WindAreaChanged(w, (Rect *) NULL);
+	    }
+	}
+	return;
+    }
+
+    if (cmd->tx_argc >= 2)
     {
 	xSpacing = cmdParseCoord(w, cmd->tx_argv[1], TRUE, TRUE);
 	if (xSpacing <= 0)
@@ -1191,7 +1245,6 @@ cmdIdFunc(selUse, use, transform, newId)
     return 1;
 }
 
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1434,7 +1487,71 @@ findTile(tile, rtype)
     return 1;			/* stop search */
 }
 
-
+/*
+ * The following are from DBcellcopy.c; slightly modified for present 
+ * purposes.
+ */
+
+#define FLATTERMSIZE	1024
+
+void
+FlatCopyAllLabels(scx, mask, xMask, targetUse)
+    SearchContext *scx;
+    TileTypeBitMask *mask;
+    int xMask;		
+    CellUse *targetUse;
+{
+    int flatCopyAllLabels();
+    char pathstring[FLATTERMSIZE];
+    TerminalPath	tpath;
+    
+    tpath.tp_first = tpath.tp_next = pathstring;
+    tpath.tp_last = pathstring + FLATTERMSIZE;
+
+    DBTreeSrLabels(scx, mask, xMask, &tpath, flatCopyAllLabels,
+			(ClientData) targetUse);
+}
+
+int
+flatCopyAllLabels(scx, lab, tpath, targetUse)
+    SearchContext *scx;
+    Label *lab;
+    TerminalPath *tpath;
+    CellUse	*targetUse;
+{
+    Rect labTargetRect;
+    int targetPos;
+    CellDef *def;
+    char	labelname[1024];
+
+    def = targetUse->cu_def;
+    if (!GEO_LABEL_IN_AREA(&lab->lab_rect, &(scx->scx_area))) return 0;
+    GeoTransRect(&scx->scx_trans, &lab->lab_rect, &labTargetRect);
+    targetPos = GeoTransPos(&scx->scx_trans, lab->lab_pos);
+
+    /* Eliminate duplicate labels.  Don't pay any attention to layers
+     * in deciding on duplicates:  if text and position match, it's a
+     * duplicate.
+     *
+     * (Added 9/10/04) Make sure that the target flattened label is
+     * not a port; possibly we should retain ports taken from the
+     * top level cell, but certainly not any others.
+     */
+
+    (void) DBEraseLabelsByContent(def, &labTargetRect, targetPos,
+        -1, lab->lab_text);
+    {
+    	 char *n = tpath->tp_next;
+    	 char *f = tpath->tp_first;
+	 char c = *n;
+	 strcpy(n,lab->lab_text);
+         (void) DBPutLabel(def, &labTargetRect, targetPos,
+			f, lab->lab_type, 0);
+	 *n = c;
+    }
+    return 0;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1494,60 +1611,4 @@ CmdFlatten(w, cmd)
     UndoEnable();
 }
 
-/* the following are from DBcellcopy.c; slightly modified for present 
-   purposes.
-*/
-FlatCopyAllLabels(scx, mask, xMask, targetUse)
-    SearchContext *scx;
-    TileTypeBitMask *mask;
-    int xMask;		
-    CellUse *targetUse;
-{
-#define FLATTERMSIZE	1024
-    int flatCopyAllLabels();
-    char pathstring[FLATTERMSIZE];
-    TerminalPath	tpath;
-    
-    tpath.tp_first = tpath.tp_next = pathstring;
-    tpath.tp_last = pathstring+FLATTERMSIZE;
 
-    (void) DBTreeSrLabels(scx, mask, xMask, &tpath,
-			flatCopyAllLabels, (ClientData) targetUse);
-}
-
-    /*ARGSUSED*/
-int
-flatCopyAllLabels(scx, lab, tpath, targetUse)
-    SearchContext *scx;
-    Label *lab;
-    TerminalPath *tpath;
-    CellUse	*targetUse;
-{
-    Rect labTargetRect;
-    int targetPos;
-    CellDef *def;
-    char	labelname[1024];
-
-    def = targetUse->cu_def;
-    if (!GEO_LABEL_IN_AREA(&lab->lab_rect, &(scx->scx_area))) return 0;
-    GeoTransRect(&scx->scx_trans, &lab->lab_rect, &labTargetRect);
-    targetPos = GeoTransPos(&scx->scx_trans, lab->lab_pos);
-
-    /* Eliminate duplicate labels.  Don't pay any attention to layers
-     * in deciding on duplicates:  if text and position match, it's a
-     * duplicate.
-     */
-
-    (void) DBEraseLabelsByContent(def, &labTargetRect, targetPos,
-        -1, lab->lab_text);
-    {
-    	 char *n = tpath->tp_next;
-    	 char *f = tpath->tp_first;
-	 char c = *n;
-	 strcpy(n,lab->lab_text);
-         (void) DBPutLabel(def, &labTargetRect, targetPos,
-			f, lab->lab_type, lab->lab_flags);
-	 *n = c;
-    }
-    return 0;
-}
