@@ -21,13 +21,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdLQ.c,v 1.11 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #ifdef SYSV
 #include <string.h>
 #endif
 #include <ctype.h>
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
@@ -35,15 +37,19 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdLQ.c,v 1.11 20
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "graphics/graphics.h"
 #include "drc/drc.h"
 #include "textio/txcommands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "select/select.h"
 
+/* Forward declarations */
+
+void CmdPaintEraseButton();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -140,9 +146,7 @@ CmdLabelProc(text, pos, type)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdLabel(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -199,7 +203,7 @@ CmdLabel(w, cmd)
  * Implement the "load" command.
  *
  * Usage:
- *	load [name [scaled n [d]]]
+ *	load [name [scaled n [d]]] [-force]
  *
  * If name is supplied, then the window containing the point tool is
  * remapped so as to edit the cell with the given name.
@@ -221,13 +225,16 @@ CmdLabel(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdLoad(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
     int n = 1;
     int d = 1;
+    int locargc = cmd->tx_argc;
+    bool ignoreTech = FALSE;
+    int keepGoing();			/* forward declaration */
 
     windCheckOnlyWindow(&w, DBWclientID);
     if (w == (MagWindow *) NULL)
@@ -236,15 +243,20 @@ CmdLoad(w, cmd)
 	return;
     }
 
-    if (cmd->tx_argc > 2)
+    if (locargc > 2)
     {
-	if (cmd->tx_argc >= 4 && !strncmp(cmd->tx_argv[2], "scale", 5) &&
+	if (!strncmp(cmd->tx_argv[locargc - 1], "-force", 6))
+	{
+	    locargc--;
+	    ignoreTech = TRUE;
+	}
+	if (locargc >= 4 && !strncmp(cmd->tx_argv[2], "scale", 5) &&
 		StrIsInt(cmd->tx_argv[3]))
 	{
 	    n = atoi(cmd->tx_argv[3]);
  	    if (cmd->tx_argc == 5 && StrIsInt(cmd->tx_argv[4]))
 	        d = atoi(cmd->tx_argv[4]);
-	    else
+	    else if (locargc != 4)
 	    {
 		TxError("Usage: %s name scaled n [d]\n", cmd->tx_argv[0]);
 		return;
@@ -253,21 +265,41 @@ CmdLoad(w, cmd)
 	    DBLambda[1] *= n;
 	    ReduceFraction(&DBLambda[0], &DBLambda[1]);
 	}
-	else
+	else if (!ignoreTech)
 	{
 	    TxError("Usage: %s [name [scaled n [d]]]\n", cmd->tx_argv[0]);
 	    return;
 	}
     }
 
-    if (cmd->tx_argc > 1)
+    if (locargc > 1)
     {
 	if (CmdIllegalChars(cmd->tx_argv[1], "[],", "Cell name"))
 	    return;
-	DBWloadWindow(w, cmd->tx_argv[1]);
+	DBWloadWindow(w, cmd->tx_argv[1], ignoreTech, FALSE);
 
 	if ((n > 1) || (d > 1))
 	{
+            CellUse *topuse = (CellUse *)w->w_surfaceID;
+
+	    /* To ensure that all subcells are also scaled, we need to	*/
+	    /* expand the entire cell hierarchy to force a load of the	*/
+	    /* cell.  After this, we return all the expansion flags	*/
+	    /* back to the way they were originally.			*/
+
+	    TxPrintf("Recursively reading all cells at new scale.\n");
+
+	    DBExpandAll(topuse, &(topuse->cu_bbox),
+			((DBWclientRec *)w->w_clientData)->dbw_bitmask,
+			TRUE, keepGoing, NULL);
+
+	    DBExpandAll(topuse, &(topuse->cu_bbox),
+			((DBWclientRec *)w->w_clientData)->dbw_bitmask,
+			FALSE, keepGoing, NULL);
+	    DBExpand(topuse,
+			((DBWclientRec *)w->w_clientData)->dbw_bitmask,
+			TRUE);
+
 	    /* We don't want to save and restore DBLambda, because      */
 	    /* loading the file may change their values.  Instead, we   */
 	    /* invert the scaling factor and reapply.                   */
@@ -277,9 +309,22 @@ CmdLoad(w, cmd)
 	    ReduceFraction(&DBLambda[0], &DBLambda[1]);
 	}
     }
-    else DBWloadWindow(w, (char *) NULL);
+    else DBWloadWindow(w, (char *) NULL, TRUE, FALSE);
 }
-
+
+/*
+ * Function callback which continues the search through all cells for
+ * expansion/unexpansion.
+ */
+
+int
+keepGoing(use, clientdata)
+    CellUse *use;
+    ClientData clientdata;
+{
+    return 0;	/* keep the search going */
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -300,9 +345,7 @@ CmdLoad(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdMove(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -322,15 +365,15 @@ CmdMove(w, cmd)
 
     if (cmd->tx_argc > 1)
     {
-	int indx, amount;
+	int indx, amountx, amounty;
 	int xdelta, ydelta;
 
 	if (strcmp(cmd->tx_argv[1], "to") == 0)
 	{
 	    if (cmd->tx_argc != 4)
 		goto badUsage;
-	    editPoint.p_x = cmdParseCoord(cmd->tx_argv[2]);
-	    editPoint.p_y = cmdParseCoord(cmd->tx_argv[3]);
+	    editPoint.p_x = cmdParseCoord(w, cmd->tx_argv[2], FALSE, TRUE);
+	    editPoint.p_y = cmdParseCoord(w, cmd->tx_argv[3], FALSE, FALSE);
 	    GeoTransPoint(&EditToRootTransform, &editPoint, &rootPoint);
 	    goto moveToPoint;
 	}
@@ -340,43 +383,64 @@ CmdMove(w, cmd)
 	    return;
 	if (cmd->tx_argc == 3)
 	{
-	    amount = cmdParseCoord(cmd->tx_argv[2]);
+	    if (DBWSnapToGrid != DBW_SNAP_USER)
+	    {
+		amountx = amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	    }
+	    else
+	    {
+		switch (indx)
+		{
+		    case GEO_EAST: case GEO_WEST:
+			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
+			amounty = amountx;
+			break;
+		    case GEO_NORTH: case GEO_SOUTH:
+			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+			amountx = amounty;
+			break;
+		    default:
+			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
+			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+			break;
+		}
+	    }
 	}
-	else amount = 1;
+	else amountx = amounty = 1;
 
 	switch (indx)
 	{
 	    case GEO_NORTH:
 		xdelta = 0;
-		ydelta = amount;
+		ydelta = amounty;
 		break;
 	    case GEO_SOUTH:
 		xdelta = 0;
-		ydelta = -amount;
+		ydelta = -amounty;
 		break;
 	    case GEO_EAST:
-		xdelta = amount;
+		xdelta = amountx;
 		ydelta = 0;
 		break;
 	    case GEO_WEST:
-		xdelta = -amount;
+		xdelta = -amountx;
 		ydelta = 0;
 		break;
 	    case GEO_NORTHEAST:
-		xdelta = amount;
-		ydelta = amount;
+		xdelta = amountx;
+		ydelta = amounty;
 		break;
 	    case GEO_NORTHWEST:
-		xdelta = -amount;
-		ydelta = amount;
+		xdelta = -amountx;
+		ydelta = amounty;
 		break;
 	    case GEO_SOUTHEAST:
-		xdelta = amount;
-		ydelta = -amount;
+		xdelta = amountx;
+		ydelta = -amounty;
 		break;
 	    case GEO_SOUTHWEST:
-		xdelta = -amount;
-		ydelta = -amount;
+		xdelta = -amountx;
+		ydelta = -amounty;
 		break;
 	    default:
 		ASSERT(FALSE, "Bad direction in CmdMove");
@@ -443,7 +507,7 @@ moveToPoint:
  * Paint the specified layers underneath the box in EditCellUse->cu_def.
  *
  * Usage:
- *	paint [layers]
+ *	paint <layers> | cursor
  *
  * Results:
  *	None.
@@ -454,9 +518,7 @@ moveToPoint:
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdPaint(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -473,13 +535,18 @@ CmdPaint(w, cmd)
 
     if (cmd->tx_argc != 2)
     {
-	TxError("Usage: %s layers\n", cmd->tx_argv[0]);
+	TxError("Usage: %s <layers> | cursor\n", cmd->tx_argv[0]);
 	return;
     }
 
     if (!ToolGetEditBox(&editRect)) return;
 
-    if (!CmdParseLayers(cmd->tx_argv[1], &mask))
+    if (!strncmp(cmd->tx_argv[1], "cursor", 6))
+    {
+	CmdPaintEraseButton(w, &cmd->tx_p, TRUE);
+	return;
+    }
+    else if (!CmdParseLayers(cmd->tx_argv[1], &mask))
 	return;
 
     if (TTMaskHasType(&mask, L_LABEL))
@@ -505,10 +572,10 @@ CmdPaint(w, cmd)
 /*
  * ----------------------------------------------------------------------------
  *
- * CmdPaintButton --
+ * CmdPaintEraseButton --
  *
- * This is a first crack at an implementation of the "paint" button.
  * Paint the specified layers underneath the box in EditCellUse->cu_def.
+ * Implements the traditional "box tool" Button2 function as a command.
  *
  * Results:
  *	None.
@@ -519,10 +586,11 @@ CmdPaint(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
-CmdPaintButton(w, butPoint)
+void
+CmdPaintEraseButton(w, butPoint, isPaint)
     MagWindow *w;
     Point *butPoint;	/* Screen location at which button was raised */
+    bool isPaint;	/* True for paint, False for erase.	*/
 {
     Rect rootRect, editRect;
     TileTypeBitMask mask;
@@ -561,9 +629,12 @@ CmdPaintButton(w, butPoint)
 	DBEraseMask(EditCellUse->cu_def, &editRect, &crec->dbw_visibleLayers);
 	(void) DBEraseLabel(EditCellUse->cu_def, &editRect, &mask);
     }
+    else if (isPaint)
+	DBPaintMask(EditCellUse->cu_def, &editRect, &mask);
     else
     {
-	DBPaintMask(EditCellUse->cu_def, &editRect, &mask);
+	DBEraseMask(EditCellUse->cu_def, &editRect, &mask);
+	DBEraseLabel(EditCellUse->cu_def, &editRect, &mask);
     }
     SelectClear();
     DBAdjustLabels(EditCellUse->cu_def, &editRect);
@@ -573,7 +644,6 @@ CmdPaintButton(w, butPoint)
     DBReComputeBbox(EditCellUse->cu_def);
     UndoNext();
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -597,15 +667,12 @@ CmdPaintButton(w, butPoint)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
 #define PATHSEARCH	0
 #define PATHCELL	1
 #define PATHSYSTEM	2
 #define PATHHELP	3
 
-
-int
+void
 CmdPath(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -630,7 +697,7 @@ CmdPath(w, cmd)
 	TxPrintf("Search path for cells is \"%s\"\n", Path);
 	TxPrintf("Cell library search path is \"%s\"\n", CellLibPath);
 	TxPrintf("System search path is \"%s\"\n", SysLibPath);
-	return 0;
+	return;
     }
     option = Lookup(cmd->tx_argv[1], cmdPathOption);
     if (option == -1)
@@ -652,7 +719,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("Search path for cells is \"%s\"\n", Path);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -666,7 +733,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("Cell library search path is \"%s\"\n", CellLibPath);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -680,7 +747,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("System search path is \"%s\"\n", SysLibPath);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -704,11 +771,10 @@ CmdPath(w, cmd)
     {
 	(void) StrDup(pathptr, srcptr);
     }
-    return 0;
+    return;
 	
 usage:
     TxError("Usage: %s [search|cell|sys] [[+]path]\n", cmd->tx_argv[0]);
-    return 0;
 }
 
 /*
@@ -760,20 +826,18 @@ usage:
 #define PORT_REMOVE	6
 #define PORT_HELP	7
 
-    /* ARGSUSED */
-
-Void
+void
 CmdPort(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
     char **msg;
-    int posmask, posstart;
+    int posstart;
     int i, idx, pos, type, option;
     unsigned short dirmask;
     bool found;
     Label *lab, *sl;
-    Rect r, editBox;
+    Rect editBox;
     CellDef *editDef = EditCellUse->cu_def;
 
     static char *cmdPortOption[] =
@@ -1199,25 +1263,36 @@ parsepositions:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdProperty(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    CellDef *editDef = EditCellUse->cu_def;
+    CellDef *def;
     int printPropertiesFunc();
     char *value;
     bool propfound;
 
+    /* Get the root definition of the window	*/
+    /* If window is NULL, pick up the edit def	*/
+
+    windCheckOnlyWindow(&w, DBWclientID);
+    if (w == (MagWindow *) NULL)
+    {
+	def = EditCellUse->cu_def;
+    }
+    else
+	def = ((CellUse *) w->w_surfaceID)->cu_def;
+
     if (cmd->tx_argc == 1)
     {
 	/* print all properties and their values */
-	DBPropEnum(editDef, printPropertiesFunc);
+	DBPropEnum(def, printPropertiesFunc);
     }
     else if (cmd->tx_argc == 2)
     {
 	/* print the value of the indicated property */
-	value = (char *)DBPropGet(editDef, cmd->tx_argv[1], &propfound);
+	value = (char *)DBPropGet(def, cmd->tx_argv[1], &propfound);
 	if (propfound)
 #ifdef MAGIC_WRAPPER
 	    Tcl_SetResult(magicinterp, value, NULL);
@@ -1230,13 +1305,13 @@ CmdProperty(w, cmd)
     else if (cmd->tx_argc == 3)
     {
 	if (strlen(cmd->tx_argv[2]) == 0)
-	    DBPropPut(editDef, cmd->tx_argv[1], NULL);
+	    DBPropPut(def, cmd->tx_argv[1], NULL);
 	else
 	{
 	    value = StrDup((char **)NULL, cmd->tx_argv[2]);
-	    DBPropPut(editDef, cmd->tx_argv[1], value);
+	    DBPropPut(def, cmd->tx_argv[1], value);
 	}
-	editDef->cd_flags |= (CDMODIFIED | CDGETNEWSTAMP);
+	def->cd_flags |= (CDMODIFIED | CDGETNEWSTAMP);
     }    
     else
     {
