@@ -28,7 +28,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/stack.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -37,18 +37,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "graphics/graphics.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "drc/drc.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "netmenu/netmenu.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "sim/sim.h"
 
 extern void DisplayWindow();
@@ -228,7 +228,7 @@ CmdScaleGrid(w, cmd)
 
 	/* Scale cifinput and cifoutput */
 
-	CIFTechInputScale(scalen, scaled);
+	CIFTechInputScale(scalen, scaled, TRUE);
 	CIFTechOutputScale(scalen, scaled);
 
 	/* Scale drc rules */
@@ -1664,7 +1664,7 @@ CmdSplit(w, cmd)
 {
     Rect editRect;
     TileTypeBitMask mask1, mask2, *cmask;
-    TileType t, dir, side;
+    TileType t, dir, side, diag;
     int pNum, direction;
     PaintUndoInfo ui;
 
@@ -1709,6 +1709,7 @@ CmdSplit(w, cmd)
 	for (cmask = &mask1; cmask != NULL; cmask = ((cmask == &mask1) ? &mask2 : NULL))
 	{
 	    if (cmask == &mask2) side = (side) ? 0 : TT_SIDE;
+	    diag = DBTransformDiagonal(TT_DIAGONAL | dir | side, &RootToEditTransform);
 
 	    if (TTMaskHasType(cmask, t))
 	    {
@@ -1719,8 +1720,7 @@ CmdSplit(w, cmd)
 		    {
 			ui.pu_pNum = pNum;
 			DBNMPaintPlane(EditCellUse->cu_def->cd_planes[pNum],
-				TT_DIAGONAL | dir | side,
-				&editRect, DBStdPaintTbl(t, pNum), &ui);
+				diag, &editRect, DBStdPaintTbl(t, pNum), &ui);
 		    }
 	    }
 	}
@@ -1756,7 +1756,7 @@ CmdSplitErase(w, cmd)
 {
     Rect editRect;
     TileTypeBitMask mask;
-    TileType t, dir, side;
+    TileType t, dir, side, diag;
     int pNum, direction;
     PaintUndoInfo ui;
 
@@ -1795,6 +1795,8 @@ CmdSplitErase(w, cmd)
     for (t = TT_SPACE + 1; t < DBNumTypes; t++)
     {
 	side = (direction & 0x2) ? 0 : TT_SIDE;
+	diag = DBTransformDiagonal(TT_DIAGONAL | dir | side, &RootToEditTransform);
+
 	if (TTMaskHasType(&mask, t))
 	{
 	    EditCellUse->cu_def->cd_flags |= CDMODIFIED|CDGETNEWSTAMP;
@@ -1804,8 +1806,7 @@ CmdSplitErase(w, cmd)
 		{
 		    ui.pu_pNum = pNum;
 		    DBNMPaintPlane(EditCellUse->cu_def->cd_planes[pNum],
-				TT_DIAGONAL | dir | side,
-				&editRect, DBStdEraseTbl(t, pNum), &ui);
+				diag, &editRect, DBStdEraseTbl(t, pNum), &ui);
 		}
 	}
     }
