@@ -23,8 +23,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdSubrs.c,v 1.5
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
@@ -32,17 +34,21 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdSubrs.c,v 1.5
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "cif/cif.h"
 #include "drc/drc.h"
 #include "textio/txcommands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
+#include "utils/macros.h"
+#include "sim/sim.h"
+#include "select/select.h"
 #ifdef SCHEME_INTERPRETER
 #include "lisp/lisp.h"
 #endif
-    /* Forward declarations */
+
+/* Forward declarations */
 
 extern char *cmdCheckNewName();
 extern int cmdSaveWindSet();
@@ -60,15 +66,24 @@ TileTypeBitMask CmdYMAllButSpace;
  * cmdParseCoord --
  *
  * Replaces the use of atoi() in command parsing of coordinates.  Allows
- * coordinates to be declared in internal units, lambda, or microns, and
- * translates to internal units accordingly.  It also allows coordinates
- * to be specified in floating-point.
+ * coordinates to be declared in internal units, lambda, user units, or
+ * microns, and translates to internal units accordingly.  It also allows
+ * coordinates to be specified in floating-point.
  *    A suffix of "i" indicates internal units, a suffix of "l" indicates
- * lambda, and a suffix in metric notation ("nm", "um", "mm", "cm")
- * indicates natural units.  Other valid units are "cu" or "centimicrons"
- * for centimicrons, or "microns" for um.
+ * lambda, a suffix of "g" indicates the user grid, and a suffix in metric
+ * notation ("nm", "um", "mm", "cm") indicates natural units.  Other valid
+ * units are "cu" or "centimicrons" for centimicrons, or "microns" for um.
  *    Units without any suffix are assumed to be in lambda if "snap"
- * (DBWSnapToGrid) is set to lambda, and internal units otherwise.
+ * (DBWSnapToGrid) is set to lambda, grid units if "snap" is set to the
+ * user grid, and internal units otherwise.
+ *
+ *    MagWindow argument w is used only with grid-based snapping, to find
+ * the value of the grid for the given window.  In this case, because the
+ * grid specifies an offset, "is_relative" specifies whether the given
+ * coordinate is a relative measurement (ignore offset) or an absolute
+ * position.  Because the grid can be different in X and Y, "is_x"
+ * specifies whether the given distance is in the X (TRUE) or Y (FALSE)
+ * direction.
  *
  * Results:
  *      Integer representing the given coordinate in internal units
@@ -80,12 +95,15 @@ TileTypeBitMask CmdYMAllButSpace;
  */
 
 int
-cmdParseCoord(arg)
+cmdParseCoord(w, arg, is_relative, is_x)
+    MagWindow *w;
     char *arg;
+    bool is_relative, is_x;
 {
     char *endptr;
     double dval = 0;
-    int ival, mscale;
+    int mscale;
+    DBWclientRec *crec;
 
     dval = strtod(arg, &endptr);
 
@@ -105,11 +123,38 @@ cmdParseCoord(arg)
 	return round(dval);
     }
     else if ((*endptr == 'i')
-		|| ((*endptr == '\0') && (DBWSnapToGrid != DBW_SNAP_LAMBDA)))
+		|| ((*endptr == '\0') && (DBWSnapToGrid == DBW_SNAP_INTERNAL)))
     {
 	/* internal units */
 	return round(dval);
     }
+    else if ((*endptr == 'g')
+		|| ((*endptr == '\0') && (DBWSnapToGrid == DBW_SNAP_USER)))
+    {
+	/* grid units */
+	if (w == (MagWindow *)NULL)
+	{
+	    windCheckOnlyWindow(&w, DBWclientID);
+	    if (w == (MagWindow *)NULL)
+		return round(dval);		/* Default, if window is unknown */
+	}
+	crec = (DBWclientRec *) w->w_clientData;
+	if (is_x)
+	{
+	    dval *= (double)(crec->dbw_gridRect.r_xtop
+			- crec->dbw_gridRect.r_xbot);
+	    if (!is_relative)
+		dval += (double)crec->dbw_gridRect.r_xbot;
+	}
+	else
+	{
+	    dval *= (double)(crec->dbw_gridRect.r_ytop
+			- crec->dbw_gridRect.r_ybot);
+	    if (!is_relative)
+		dval += (double)crec->dbw_gridRect.r_ybot;
+	}
+	return round(dval);
+    }
     else
     {
         /* natural units referred to the current cifoutput style */
@@ -169,6 +214,7 @@ cmdParseCoord(arg)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdInit()
 {
     TTMaskZero(&CmdYMLabel);
@@ -202,6 +248,7 @@ CmdInit()
  * ----------------------------------------------------------------------------
  */
 
+void
 cmdFlushCell(def)
     CellDef *def;
 {
@@ -277,7 +324,7 @@ CmdParseLayers(s, mask)
     TileTypeBitMask *mask;
 {
     TileTypeBitMask newmask, tempmask;
-    register char *dp, c;
+    char *dp, c;
     char name[50];
     TileType type;
     Rect rootRect;
@@ -475,6 +522,7 @@ cmdMaskToType(mask)
  * ----------------------------------------------------------------------------
  */
 
+void
 cmdSaveCell(cellDef, newName, noninteractive, tryRename)
     CellDef *cellDef;	/* Pointer to def of cell to be saved */
     char *newName;	/* Pointer to name of file in which cell is to be
@@ -631,13 +679,13 @@ again:
 		prompt = TxPrintString("File %s already exists.\n"
 			"  Overwrite it with %s? ", filename, def->cd_name);
 		code = TxDialog(prompt, yesno, 0);
-	    }
 
-	    if (code == 0)
-	    {
-		/* No -- don't overwrite */
-		newName = NULL;
-		goto again;
+		if (code == 0)
+		{
+		    /* No -- don't overwrite */
+		    newName = NULL;
+		    goto again;
+		}
 	    }
 	}
 
@@ -669,7 +717,7 @@ again:
  *	def [NOT BEING EDITED]
  *
  * Results:
- *	0.
+ *	Always 0 to keep the search going.
  *
  * Side effects:
  *	Modifies captions and clientData for the window
@@ -762,7 +810,7 @@ CmdSetWindCaption(newEditUse, rootDef)
  *	RootDef [NOT BEING EDITED]
  *
  * Results:
- *	0.
+ *	Always 0 to keep the function going.
  *
  * Side effects:
  *	Modifies captions and clientData for the window
@@ -881,8 +929,8 @@ CmdGetEditPoint(point, rect)
  * user whether he wants to stay in magic or lose all these cells.
  *
  * Results:
- *	1 if the user wishes to continue anyway without writing the
- *	modified cells out to disk, 0 if not.
+ *	TRUE if the user wishes to continue anyway without writing the
+ *	modified cells out to disk, FALSE if not.
  *
  * Side effects:
  *	None.
@@ -890,7 +938,7 @@ CmdGetEditPoint(point, rect)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 CmdWarnWrite()
 {
     int count, code;
@@ -902,17 +950,16 @@ CmdWarnWrite()
     (void) DBCellSrDefs(CDMODIFIED|CDBOXESCHANGED|CDSTAMPSCHANGED,
 	cmdWarnWriteFunc, (ClientData) &count);
     if (count == 0)
-	return (1);
+	return TRUE;
 
     prompt = TxPrintString("%d Magic cell%s been modified.\n  Do you"
 		" want to exit magic and lose %s? ", count,
 		count == 1 ? " has" : "s have",
 		count == 1 ? "it" : "them");		
     code = TxDialog(prompt, yesno, 0);
-    return (code);
+    return (code) ? TRUE : FALSE;
 }
 
-    /*ARGSUSED*/
 int
 cmdWarnWriteFunc(cellDef, pcount)
     CellDef *cellDef;
@@ -939,7 +986,7 @@ cmdWarnWriteFunc(cellDef, pcount)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 cmdExpandOneLevel(cu, bitmask, expand)
     CellUse *cu;
     int bitmask;
@@ -955,6 +1002,7 @@ cmdExpandOneLevel(cu, bitmask, expand)
 	(void) DBCellEnum(cu->cu_def, cmdExpand1func, (ClientData) bitmask);
 }
 
+int
 cmdExpand1func(cu, bitmask)
     CellUse *cu;
     ClientData bitmask;
@@ -1043,7 +1091,7 @@ CmdIllegalChars(string, illegal, msg)
 				 * printing error messages.
 				 */
 {
-    register char *p, *bad;
+    char *p, *bad;
 
     for (p = string; *p != 0; p++)
     {
@@ -1067,3 +1115,4 @@ CmdIllegalChars(string, illegal, msg)
     }
     return FALSE;
 }
+
