@@ -27,7 +27,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdTZ.c,v 1.7 200
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
@@ -35,18 +36,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdTZ.c,v 1.7 200
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
-#include "undo/undo.h"
+#include "utils/signals.h"
+#include "utils/undo.h"
 #include "select/select.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "wiring/wiring.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "netmenu/netmenu.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 
 #ifdef	LLNL
 #include "yacr.h"
@@ -331,7 +332,7 @@ CmdTech(w, cmd)
 		int d = DBLambda[0];
 		int n = DBLambda[1];
 
-		CIFTechInputScale(d, n);      
+		CIFTechInputScale(d, n, TRUE);
 		CIFTechOutputScale(d, n);
 		DRCTechScale(d, n);
 		ExtTechScale(d, n);
@@ -609,7 +610,7 @@ CmdUpsidedown(w, cmd)
  * 	Print out information about what's selected.
  *
  * Usage:
- *	what
+ *	what [-list]
  *
  * Results:
  *	None.
@@ -617,6 +618,8 @@ CmdUpsidedown(w, cmd)
  * Side effects:
  *	Information gets printed to identify the kinds of paint, plus
  *	labels and subcells, that are selected.
+ *	In the TCL version, the "-list" option puts the result in a
+ *	nested TCL list.
  *
  * ----------------------------------------------------------------------------
  */
@@ -635,17 +638,43 @@ CmdWhat(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;		/* Information about the command. */
 {
-    int i;
+    int i, locargc;
     bool foundAny;
+    bool doList = FALSE;
     TileTypeBitMask layers;
+
+#ifdef MAGIC_WRAPPER
+    Tcl_Obj *lobj, *paintobj, *labelobj, *cellobj;
+    extern int cmdWhatCellListFunc();
+#endif
+
     extern int cmdWhatPaintFunc(), cmdWhatLabelFunc(), cmdWhatCellFunc();
     extern int cmdWhatLabelPreFunc(), orderLabelFunc();
 
-    if (cmd->tx_argc > 1)
+    locargc = cmd->tx_argc;
+    
+#ifdef MAGIC_WRAPPER
+    if ((locargc == 2) && !strncmp(cmd->tx_argv[locargc - 1], "-list", 5))
+    {
+	doList = TRUE;
+	locargc--;
+	lobj = Tcl_NewListObj(0, NULL);
+	paintobj = Tcl_NewListObj(0, NULL);
+	labelobj = Tcl_NewListObj(0, NULL);
+	cellobj = Tcl_NewListObj(0, NULL);
+    }	
+    if (locargc > 1)
+    {
+	TxError("Usage: what [-list]\n");
+	return;
+    }
+#else
+    if (locargc > 1)
     {
 	TxError("Usage: what\n");
 	return;
     }
+#endif
 
     /* Find all the selected paint and print out the layer names. */
 
@@ -669,12 +698,26 @@ CmdWhat(w, cmd)
 
     if (!TTMaskIsZero(&layers))
     {
-	TxPrintf("Selected mask layers:\n");
-	for (i = TT_SELECTBASE; i < DBNumUserLayers; i++)
+#ifdef MAGIC_WRAPPER
+	if (doList)
 	{
-	    if (TTMaskHasType(&layers, i))
-		TxPrintf("    %s\n", DBTypeLongName(i));
+	    for (i = TT_SELECTBASE; i < DBNumUserLayers; i++)
+		if (TTMaskHasType(&layers, i))
+		    Tcl_ListObjAppendElement(magicinterp, paintobj,
+				Tcl_NewStringObj(DBTypeLongName(i), -1));
 	}
+	else
+	{
+#endif
+	    TxPrintf("Selected mask layers:\n");
+	    for (i = TT_SELECTBASE; i < DBNumUserLayers; i++)
+	    {
+		if (TTMaskHasType(&layers, i))
+		    TxPrintf("    %s\n", DBTypeLongName(i));
+	    }
+#ifdef MAGIC_WRAPPER
+	}
+#endif
     }
 
     /* Enumerate all of the selected labels. */
@@ -688,21 +731,60 @@ CmdWhat(w, cmd)
     if (labelBlockTop)
     {
 	qsort(labelBlockTop, labelEntryCount, sizeof(LabelStore), orderLabelFunc);
-    		/* now print them out */
-	for (labelEntry = labelBlockTop; labelEntryCount-- > 0; labelEntry++)
-            i = cmdWhatLabelFunc(labelEntry, &foundAny);
-	if (i > 1)
+
+#ifdef MAGIC_WRAPPER
+	if (doList)
+	{
+	    Tcl_Obj *newtriple;
+	    for (labelEntry = labelBlockTop; labelEntryCount-- > 0; labelEntry++)
+	    {
+		newtriple = Tcl_NewListObj(0, NULL);
+		Tcl_ListObjAppendElement(magicinterp, newtriple,
+			Tcl_NewStringObj(labelEntry->lab_text, -1));
+		Tcl_ListObjAppendElement(magicinterp, newtriple,
+			Tcl_NewStringObj(DBTypeLongName(labelEntry->lab_type), -1));
+		Tcl_ListObjAppendElement(magicinterp, newtriple,
+			Tcl_NewStringObj(labelEntry->cell_name, -1));
+		Tcl_ListObjAppendElement(magicinterp, labelobj, newtriple);
+	    }
+	}
+	else
+	{
+#endif
+    	    /* now print them out */
+	    for (labelEntry = labelBlockTop; labelEntryCount-- > 0; labelEntry++)
+        	i = cmdWhatLabelFunc(labelEntry, &foundAny);
+	    if (i > 1)
 		TxPrintf(" (%i instances)", i);
-        TxPrintf("\n");
+	    TxPrintf("\n");
+
+#ifdef MAGIC_WRAPPER
+	}
+#endif
 	freeMagic(labelBlockTop);
     }
-    
 
     /* Enumerate all of the selected subcells. */
 
     foundAny = FALSE;
-    (void) SelEnumCells(FALSE, (bool *) NULL, (SearchContext *) NULL,
-	    cmdWhatCellFunc, (ClientData) &foundAny);
+#ifdef MAGIC_WRAPPER
+    if (doList)
+	SelEnumCells(FALSE, (bool *) NULL, (SearchContext *) NULL,
+		cmdWhatCellListFunc, (ClientData) cellobj);
+    else
+#endif
+	SelEnumCells(FALSE, (bool *) NULL, (SearchContext *) NULL,
+		cmdWhatCellFunc, (ClientData) &foundAny);
+
+#ifdef MAGIC_WRAPPER
+    if (doList)
+    {
+	Tcl_ListObjAppendElement(magicinterp, lobj, paintobj);
+	Tcl_ListObjAppendElement(magicinterp, lobj, labelobj);
+	Tcl_ListObjAppendElement(magicinterp, lobj, cellobj);
+ 	Tcl_SetObjResult(magicinterp, lobj);
+    }
+#endif
 }
 
 /* Search function invoked for each paint tile in the selection:
@@ -845,7 +927,31 @@ cmdWhatCellFunc(selUse, realUse, transform, foundAny)
 	    realUse->cu_def->cd_name);
     return 0;
 }
-
+
+#ifdef MAGIC_WRAPPER
+
+/* Same search function as above, but appends use names to a Tcl list */
+
+int
+cmdWhatCellListFunc(selUse, realUse, transform, newobj)
+    CellUse *selUse;		/* Not used. */
+    CellUse *realUse;		/* Selected cell use. */
+    Transform *transform;	/* Not used. */
+    Tcl_Obj *newobj;		/* Tcl list object holding use names */
+{
+    Tcl_Obj *tuple;
+
+    tuple = Tcl_NewListObj(0, NULL);
+    Tcl_ListObjAppendElement(magicinterp, tuple,
+		Tcl_NewStringObj(realUse->cu_id, -1));
+    Tcl_ListObjAppendElement(magicinterp, tuple,
+		Tcl_NewStringObj(realUse->cu_def->cd_name, -1));
+    Tcl_ListObjAppendElement(magicinterp, newobj, tuple);
+    return 0;
+}
+
+#endif
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -879,8 +985,8 @@ CmdWire(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    int option;
-    char **msg;
+    int option, locargc;
+    char **msg, *lastargv;
     TileType type;
     int width;
 
@@ -892,15 +998,16 @@ CmdWire(w, cmd)
 	"switch [layer width]   place contact and switch layers",
 	"type [layer width]     select the type and size of wires",
 	"vertical               add a new vertical wire leg",
-	"segment layer width x1 y1 x2 y2...\n"
+	"segment layer width x1 y1 x2 y2... [-noendcap]\n"
 	"			paint one or more wire segments",
 	NULL
     };
 
-    if (cmd->tx_argc < 2)
+    locargc = cmd->tx_argc;
+    if (locargc < 2)
     {
 	option = HELP;
-	cmd->tx_argc = 2;
+	locargc = 2;
     }
     else
     {
@@ -909,7 +1016,7 @@ CmdWire(w, cmd)
 	{
 	    TxError("\"%s\" isn't a valid wire option.\n", cmd->tx_argv[1]);
 	    option = HELP;
-	    cmd->tx_argc = 2;
+	    locargc = 2;
 	}
     }
 
@@ -933,9 +1040,9 @@ CmdWire(w, cmd)
 	    return;
 
 	case SWITCH:
-	    if (cmd->tx_argc == 2)
+	    if (locargc == 2)
 		WireAddContact(-1, 0);
-	    else if (cmd->tx_argc != 4)
+	    else if (locargc != 4)
 		goto badargs;
 	    else
 	    {
@@ -959,9 +1066,9 @@ CmdWire(w, cmd)
 	    break;
 
 	case TYPE:
-	    if (cmd->tx_argc == 2)
+	    if (locargc == 2)
 		WirePickType(-1, 0);
-	    else if (cmd->tx_argc != 4)
+	    else if (locargc != 4)
 	    {
 		badargs:
 		TxError("Wrong arguments.  The correct syntax is\n");
@@ -1000,6 +1107,7 @@ CmdWire(w, cmd)
 		int pNum, i, j, points, wexpand;
 	 	CellDef *def = (CellDef *)NULL;
 		PaintUndoInfo ui;
+		bool endcap = TRUE;
 
 		if (EditCellUse != NULL)
 		    def = EditCellUse->cu_def;
@@ -1010,7 +1118,16 @@ CmdWire(w, cmd)
 		    return;
 		}
 
-		if ((cmd->tx_argc < 8) || (cmd->tx_argc & 0x1))
+		lastargv = cmd->tx_argv[locargc - 1];
+		if (lastargv[0] == '-')
+		{
+		    if (!strcmp(lastargv, "-noendcap"))
+		    {
+			endcap = FALSE;
+			locargc--;
+		    }
+		}
+		if ((locargc < 8) || (locargc & 0x1))
 		{
 		    TxError("Usage: wire segment layer width x1 x2 y1 y2\n");
 		    return;
@@ -1029,7 +1146,7 @@ CmdWire(w, cmd)
 		/* what is needed by routine PaintWireList.	*/
 
 		DBLambda[1] *= 2; 
-		points = (cmd->tx_argc - 4) / 2;
+		points = (locargc - 4) / 2;
 		plist = (Point *)mallocMagic(points * sizeof(Point));
 		for (i = 0, j = 4; i < points; i++)
 		{
@@ -1045,7 +1162,8 @@ CmdWire(w, cmd)
 		    if (DBPaintOnPlane(type, pNum))
 		    {
 			ui.pu_pNum = pNum;
-			PaintWireList(plist, points, width, def->cd_planes[pNum],
+			PaintWireList(plist, points, width, endcap,
+				def->cd_planes[pNum],
 				DBStdPaintTbl(type, pNum), &ui);
 		    }
 		}
@@ -1072,7 +1190,6 @@ CmdWire(w, cmd)
 		freeMagic(plist);
 	    }
 	    break;
-	    
     }
 }
 
