@@ -29,7 +29,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdWizard.c,v 1.2
 #include <sys/types.h>
 #include <sys/times.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/malloc.h"
 #include "tiles/tile.h"
@@ -37,12 +37,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdWizard.c,v 1.2
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "utils/runstats.h"
 #include "textio/textio.h"
 #include "graphics/graphics.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "textio/txcommands.h"
 
@@ -189,6 +189,7 @@ CmdExtractTest(w, cmd)
 /*
  * ----------------------------------------------------------------------------
  *
+ * showTech --
  * CmdShowtech --
  *
  * Usage:
@@ -207,48 +208,6 @@ CmdExtractTest(w, cmd)
  */
 
 void
-CmdShowtech(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    FILE *outf;
-    bool verbose;
-    char **av;
-    int ac;
-
-    if (cmd->tx_argc > 3)
-    {
-	TxError("Usage: showtech [-v] [file]\n");
-	return;
-    }
-
-    verbose = FALSE;
-    av = &cmd->tx_argv[1];
-    ac = cmd->tx_argc - 1;
-
-    outf = stdout;
-    if (ac > 0 && strcmp(av[0], "-v") == 0)
-    {
-	verbose = TRUE;
-	av++, ac--;
-    }
-
-    if (ac > 0)
-    {
-	outf = fopen(av[0], "w");
-	if (outf == (FILE *) NULL)
-	{
-	    perror(av[0]);
-	    TxError("Nothing written\n");
-	    return;
-	}
-    }
-
-    showTech(outf, verbose);
-    if (outf != stdout)
-	(void) fclose(outf);
-}
-
 showTech(outf, verbose)
     FILE *outf;		/* File to which information is to be output */
     bool verbose;	/* If TRUE, output detailed erase table */
@@ -390,6 +349,50 @@ showTech(outf, verbose)
 	}
     }
 }
+
+void
+CmdShowtech(w, cmd)
+    MagWindow *w;
+    TxCommand *cmd;
+{
+    FILE *outf;
+    bool verbose;
+    char **av;
+    int ac;
+
+    if (cmd->tx_argc > 3)
+    {
+	TxError("Usage: showtech [-v] [file]\n");
+	return;
+    }
+
+    verbose = FALSE;
+    av = &cmd->tx_argv[1];
+    ac = cmd->tx_argc - 1;
+
+    outf = stdout;
+    if (ac > 0 && strcmp(av[0], "-v") == 0)
+    {
+	verbose = TRUE;
+	av++, ac--;
+    }
+
+    if (ac > 0)
+    {
+	outf = fopen(av[0], "w");
+	if (outf == (FILE *) NULL)
+	{
+	    perror(av[0]);
+	    TxError("Nothing written\n");
+	    return;
+	}
+    }
+
+    showTech(outf, verbose);
+    if (outf != stdout)
+	(void) fclose(outf);
+}
+
 
 /*
  * ----------------------------------------------------------------------------
