@@ -20,15 +20,11 @@
  * rcsid $Header: /ufs/repository/magic/commands/commands.h,v 1.2 2001/01/12 22:12:18 jsolomon Exp $
  */
 
-#define	_COMMANDS
+#ifndef _COMMANDS_H
+#define	_COMMANDS_H
 
-#ifndef	_WINDOWS
-int err0 = Need_to_include_window_header;
-#endif	/* _WINDOWS */
-
-#ifndef	_DATABASE
-int err2 = Need_to_include_database/database_header;
-#endif	/* _DATABASE */
+#include "windows/windows.h"
+#include "database/database.h"
 
 /*
  * Name of default yank buffer
@@ -57,10 +53,13 @@ extern TileTypeBitMask CmdYMAllButSpace;
 extern MagWindow *CmdGetRootBox();
 extern MagWindow *CmdGetEditPoint();
 extern MagWindow *CmdGetRootPoint();
-extern int CmdWarnWrite();
+extern bool CmdWarnWrite();
 extern bool CmdParseLayers();
 extern void CmdAddSlop();
 extern void CmdLabelProc();
 extern void CmdSetWindCaption();
 extern CellUse *CmdGetSelectedCell();
 extern bool CmdIllegalChars();
+extern void CmdDoMacro();
+
+#endif /* _COMMANDS_H */
