@@ -21,7 +21,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBbound.c,v 1.2 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 
@@ -50,7 +50,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBbound.c,v 1.2 2
 bool
 DBBoundPlane(plane, rect)
     Plane *plane;
-    register Rect *rect;
+    Rect *rect;
 {
     Tile *left, *right, *top, *bottom, *tp;
 
@@ -131,7 +131,7 @@ DBBoundPlane(plane, rect)
 bool
 DBBoundPlaneVert(plane, rect)
     Plane *plane;
-    register Rect *rect;
+    Rect *rect;
 {
     Tile *left, *right, *top, *bottom, *tp;
 
