@@ -22,15 +22,16 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcell.c,v 1.2 20
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 
 int placeCellFunc();
 int deleteCellFunc();
@@ -237,7 +238,7 @@ placeCellFunc (tile, arg)
 
     tp = clipCellTile (tile, arg->plane, arg->rect);
 
-    MALLOC(CellTileBody *, body, sizeof (CellTileBody));
+    body = (CellTileBody *) mallocMagic((unsigned) (sizeof (CellTileBody)));
     body->ctb_use = arg->celluse;
 
     ctp = (CellTileBody *) tp->ti_body;
@@ -325,7 +326,7 @@ deleteCellFunc (tile, arg)
     else					/* beyond front of list */
 	ctplast->ctb_next = ctp->ctb_next;
 
-    FREE((char *) ctp);
+    freeMagic((char *) ctp);
 
 /* merge tiles back into the the plane */
 /* requires that TiSrArea visit tiles in NW to SE wavefront */
@@ -433,7 +434,7 @@ dupTileBody (oldtp, newtp)
     oldctb = (CellTileBody *) oldtp->ti_body;
     if (oldctb != (CellTileBody *) NULL)
     {
-	MALLOC(CellTileBody *, newctb, sizeof (CellTileBody));
+	newctb = (CellTileBody *) mallocMagic((unsigned) (sizeof (CellTileBody)));
 	TiSetBody(newtp, newctb);
 	newctb->ctb_use = oldctb->ctb_use;
 
@@ -442,7 +443,7 @@ dupTileBody (oldtp, newtp)
 
 	while (oldctb != (CellTileBody *) NULL)
 	{
-	    MALLOC(CellTileBody *, newctb, sizeof (CellTileBody));
+	    newctb = (CellTileBody *) mallocMagic((unsigned) (sizeof (CellTileBody)));
 	    newctblast->ctb_next = newctb;
 	    newctb->ctb_use = oldctb->ctb_use;
 
@@ -670,7 +671,7 @@ freeCTBList (tile)
     {
 	ctplast = ctp;
 	ctp = ctp->ctb_next;
-	FREE((char *) ctplast);
+	freeMagic((char *) ctplast);
     }
     TiSetBody(tile, NULL);
 }
