@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellbox.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -31,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellbox.c,v 1.2
 #include "database/databaseInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 
 /*
@@ -183,7 +184,7 @@ DBCellSetModified(cellDef, ismod)
 /*
  * ----------------------------------------------------------------------------
  *
- * dbComputeBbox --
+ * DBComputeUseBbox --
  *
  * Compute the bounding box for a CellUse in coordinates of its parent.
  *
@@ -198,7 +199,7 @@ DBCellSetModified(cellDef, ismod)
  */
 
 void
-dbComputeBbox(use)
+DBComputeUseBbox(use)
     CellUse *use;
 {
     Rect *box;
@@ -310,7 +311,7 @@ DBSetTrans(cellUse, trans)
     Transform *trans;
 {
     cellUse->cu_transform = *trans;
-    dbComputeBbox(cellUse);
+    DBComputeUseBbox(cellUse);
 }
 
 /*
@@ -369,7 +370,7 @@ DBMakeArray(cellUse, rootToCell, xlo, ylo, xhi, yhi, xsep, ysep)
     cellUse->cu_xhi = xhi;
     cellUse->cu_yhi = yhi;
 
-    dbComputeBbox(cellUse);
+    DBComputeUseBbox(cellUse);
 }
 
 /*
@@ -711,7 +712,7 @@ dbReComputeBboxFunc(cellDef, boundProc, recurseProc)
     for (use = cellDef->cd_parents; use != NULL; use = use->cu_nextuse)
     {
 	redisplayArea = use->cu_bbox;
-	dbComputeBbox(use);
+	DBComputeUseBbox(use);
 	if ((parent = use->cu_parent) != (CellDef *) NULL)
 	{
 	    parent->cd_flags |= CDBOXESCHANGED;
