@@ -21,7 +21,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellcopy.c,v 1.
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/malloc.h"
@@ -603,6 +603,7 @@ topbottom:
 
 splitdone:
 
+    /* Should this just be replaced with DBPaint()? */
     for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
 	if (DBPaintOnPlane(type, pNum))
 	{
@@ -781,7 +782,7 @@ dbCellCopyCellsFunc(scx, arg)
     newUse = DBCellNewUse(def, (char *) use->cu_id);
     if (!DBLinkCell(newUse, arg->caa_targetUse->cu_def))
     {
-	FREE((char *) newUse->cu_id);
+	freeMagic((char *) newUse->cu_id);
 	newUse->cu_id = NULL;
 	(void) DBLinkCell(newUse, arg->caa_targetUse->cu_def);
     }
