@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellname.c,v 1.
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
@@ -34,13 +34,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellname.c,v 1.
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "select/select.h"
-#include "signals/signals.h"
-#include "undo/undo.h"
+#include "utils/signals.h"
+#include "utils/undo.h"
 #include "utils/malloc.h"
 #include "windows/windows.h"
 #include "textio/textio.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
+#include "drc/drc.h"
 
 /*
  * Hash tables for CellDefs and CellUses
@@ -67,7 +68,6 @@ extern void DBUnLinkCell();
  * Routines from other database modules
  */
 
-extern void dbComputeBbox();
 extern void DBSetUseIdHash();
 
 /*
@@ -123,6 +123,45 @@ DBCellRename(cellname, newname)
     return result;
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBEnumerateTypes
+ *
+ *	Generate a mask of all known types in all known cells.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Returns the OR of the layer mask of each cell definition in
+ *	the pointer to rMask.
+ *
+ * Notes:
+ *	cd_types needs to be properly handled through paint/erase
+ *	operations, or else we should not rely on cd_types.
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBEnumerateTypes(rMask)
+    TileTypeBitMask *rMask;
+{
+    HashSearch hs;
+    HashEntry *entry;
+    CellDef *cellDef;
+    
+    TTMaskZero(rMask);
+    HashStartSearch(&hs);
+    while ((entry = HashNext(&dbCellDefTable, &hs)) != NULL)
+    {
+	cellDef = (CellDef *) HashGetValue(entry);
+	if (cellDef != (CellDef *)NULL)
+	    if ((cellDef->cd_flags & CDINTERNAL) != CDINTERNAL)
+		TTMaskSetMask(rMask, &cellDef->cd_types);
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -216,9 +255,9 @@ DBCellDelete(cellname)
 	if (celluse->cu_parent == (CellDef *) NULL)
 	{
 	    WindUnload(celluse);
-	    FREE(celluse->cu_id);
+	    freeMagic(celluse->cu_id);
 	}
-	FREE((char *)celluse);
+	freeMagic((char *)celluse);
     }
     celldef->cd_parents = (CellUse *)NULL;
 
@@ -357,7 +396,7 @@ dbCellPrintInfo(StartDef, who, dolist)
 	    {
 	        if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, "1", (char *)NULL);
+		    Tcl_AppendElement(magicinterp, "1");
 #else
 		    TxPrintf("TRUE\n");
 #endif
@@ -368,7 +407,7 @@ dbCellPrintInfo(StartDef, who, dolist)
 	    {
 		if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, StartDef->cd_name, (char *)NULL);
+		    Tcl_AppendElement(magicinterp, StartDef->cd_name);
 #else
 		    TxPrintf("%s\n", StartDef->cd_name);
 #endif
@@ -548,7 +587,7 @@ DBTopPrint(mw, dolist)
 	if (celldef == NULL) return;
 #ifdef MAGIC_WRAPPER
 	if (dolist)
-	    Tcl_AppendResult(magicinterp, celldef->cd_name, (char *)NULL);
+	    Tcl_AppendElement(magicinterp, celldef->cd_name);
 	else
 #endif
 	TxPrintf("Top-level cell in the window is: %s\n", celldef->cd_name);
@@ -707,7 +746,7 @@ DBCellPrint(CellName, who, dolist)
 		{
 		    if (dolist)
 #ifdef MAGIC_WRAPPER
-			Tcl_AppendResult(magicinterp, "0", (char *)NULL);
+			Tcl_AppendElement(magicinterp, "0");
 #else
 			TxPrintf("Not loaded\n");
 #endif
@@ -762,7 +801,7 @@ dbUsePrintInfo(StartUse, who, dolist)
 	    {
 	        if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, "1", (char *)NULL);
+		    Tcl_AppendElement(magicinterp, "1");
 #else
 		    TxPrintf("TRUE\n");
 #endif
@@ -774,7 +813,7 @@ dbUsePrintInfo(StartUse, who, dolist)
 		cu_name = dbGetUseName(StartUse);
 		if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, cu_name, (char *)NULL);
+		    Tcl_AppendElement(magicinterp, cu_name);
 #else
 		    TxPrintf("%s\n", cu_name);
 #endif
@@ -789,7 +828,7 @@ dbUsePrintInfo(StartUse, who, dolist)
 	    {
 	        if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, "0", (char *)NULL);
+		    Tcl_AppendElement(magicinterp, "0");
 #else
 		    TxPrintf("FALSE\n");
 #endif
@@ -800,8 +839,7 @@ dbUsePrintInfo(StartUse, who, dolist)
 	    {
 	        if (dolist)
 #ifdef MAGIC_WRAPPER
-		    Tcl_AppendResult(magicinterp, StartUse->cu_def->cd_name,
-				(char *)NULL);
+		    Tcl_AppendElement(magicinterp, StartUse->cu_def->cd_name);
 #else
 		    TxPrintf("%s\n", StartUse->cu_def->cd_name);
 #endif
@@ -941,7 +979,6 @@ DBUsePrint(CellName, who, dolist)
 			    {
 				dbUsePrintInfo(celluse, who, dolist);
 				found = 1;
-				break;
 			    }
 			}
 		    }
@@ -998,7 +1035,7 @@ dbCellUsePrintFunc(cellUse, dolist)
 	cu_name = dbGetUseName(cellUse);
 	if (*dolist)
 #ifdef MAGIC_WRAPPER
-            Tcl_AppendResult(magicinterp, cu_name, " ", (char *)NULL);
+            Tcl_AppendElement(magicinterp, cu_name);
 #else
 	    TxPrintf("%s ", cu_name);
 #endif
@@ -1118,7 +1155,7 @@ DBCellDefAlloc()
     CellDef *cellDef;
     int pNum;
 
-    MALLOC(CellDef *, cellDef, sizeof (CellDef));
+    cellDef = (CellDef *) mallocMagic((unsigned) (sizeof (CellDef)));
     cellDef->cd_flags = 0;
     cellDef->cd_bbox.r_xbot = 0;
     cellDef->cd_bbox.r_ybot = 0;
@@ -1172,7 +1209,7 @@ DBCellNewUse(cellDef, useName)
 {
     CellUse *cellUse;
 
-    MALLOC(CellUse *, cellUse, sizeof (CellUse));
+    cellUse = (CellUse *) mallocMagic((unsigned) (sizeof (CellUse)));
     cellUse->cu_id = StrDup((char **) NULL, useName);
     cellUse->cu_expandMask = 0;
     cellUse->cu_transform = GeoIdentityTransform;
@@ -1194,7 +1231,7 @@ DBCellNewUse(cellDef, useName)
     cellUse->cu_client = (ClientData) MINFINITY;
 
     cellDef->cd_parents = cellUse;
-    dbComputeBbox(cellUse);
+    DBComputeUseBbox(cellUse);
     return (cellUse);
 }
 
@@ -1277,6 +1314,11 @@ DBCellDeleteDef(cellDef)
     HashSetValue(entry, (ClientData) NULL);
     if (cellDef->cd_props)
 	DBPropClearAll(cellDef);
+
+    /* Need to check the DRC pending queue, and remove	*/
+    /* this cell if it's there.				*/
+    DRCRemovePending(cellDef);
+
     DBCellDefFree(cellDef);
     return TRUE;
 }
@@ -1310,9 +1352,9 @@ DBCellDefFree(cellDef)
     Label *lab;
 
     if (cellDef->cd_file != (char *) NULL)
-	FREE(cellDef->cd_file);
+	freeMagic(cellDef->cd_file);
     if (cellDef->cd_name != (char *) NULL)
-	FREE(cellDef->cd_name);
+	freeMagic(cellDef->cd_name);
 
     /*
      * We want the following searching to be non-interruptible
@@ -1331,11 +1373,11 @@ DBCellDefFree(cellDef)
     }
 
     for (lab = cellDef->cd_labels; lab; lab = lab->lab_next)
-	FREE((char *) lab);
+	freeMagic((char *) lab);
     SigEnableInterrupts();
     HashKill(&cellDef->cd_idHash);
 
-    FREE((char *) cellDef);
+    freeMagic((char *) cellDef);
 }
 
 /*
@@ -1373,7 +1415,7 @@ DBCellDeleteUse(cellUse)
 
     cellDef = cellUse->cu_def;
     if (cellUse->cu_id != (char *) NULL)
-	FREE(cellUse->cu_id);
+	freeMagic(cellUse->cu_id);
     cellUse->cu_id = (char *) NULL;
     cellUse->cu_def = (CellDef *) NULL;
 
@@ -1391,7 +1433,7 @@ DBCellDeleteUse(cellUse)
 	}
     }
 
-    FREE((char *) cellUse);
+    freeMagic((char *) cellUse);
     return (TRUE);
 }
 
@@ -1724,7 +1766,7 @@ dbFindNamesFunc(use, parentDef)
 	    TxError("Duplicate instance-id for cell %s (%s) will be renamed\n",
 			use->cu_def->cd_name, use->cu_id);
 	    DBUnLinkCell(use, parentDef);
-	    FREE(use->cu_id);
+	    freeMagic(use->cu_id);
 	    use->cu_id = (char *) NULL;
 	}
 	HashSetValue(he, use);
