@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsrch.c,v 1.
 
 #include <stdio.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -30,9 +31,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsrch.c,v 1.
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
+
+/* Quick hack for dbScalePlanes() access to the CIF/GDS paint table */
+
+#ifdef CIF_MODULE
+extern PaintResultType CIFPaintTable[];
+#endif
 
 /*
  * The following structure is used to accumulate information about
@@ -759,15 +766,13 @@ DBSeeTypesAll(rootUse, rootRect, xMask, mask)
 {
     int dbSeeTypesAllSrFunc();
     SearchContext scontext;
-    TileTypeBitMask visitMask;
 
     scontext.scx_use = rootUse;
     scontext.scx_trans = GeoIdentityTransform;
     scontext.scx_area = *rootRect;
 
     TTMaskZero(mask);
-    TTMaskSetMask3(&visitMask, &DBUserLayerBits, &DBBuiltinLayerBits);
-    (void) DBTreeSrTiles(&scontext, &visitMask, xMask,
+    (void) DBTreeSrTiles(&scontext, &DBAllTypeBits, xMask,
 		dbSeeTypesAllSrFunc, (ClientData) mask);
 }
 
@@ -799,72 +804,7 @@ dbSeeTypesAllSrFunc(tile, cxp)
     }
     return 0;
 }
-
-/*
- *-----------------------------------------------------------------------------
- *
- * DBSeeTypes --
- *
- * Set a TileTypeBitMask to all tiles beneath the given rectangle in the
- * definition of the given CellUse.  "Beneath" in this case means
- * "completely containing".
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Sets the TileTypeBitMask pointed to by 'mask' to all types beneath
- *	the rectangle.
- *
- *-----------------------------------------------------------------------------
- */
 
-void
-DBSeeTypes(rootUse, rootRect, mask)
-    CellUse *rootUse;	/* CellUse to search */
-    Rect *rootRect;	/* Clipping rectangle in coordinates of CellUse's def */
-    TileTypeBitMask *mask;	/* Mask to be set */
-{
-    int dbSeeTypesSrFunc();
-    TileTypeBitMask visitMask;
-    struct seeTypesArg arg;
-    CellDef *def;
-    int pNum;
-
-    TTMaskZero(mask);
-    arg.saa_mask = mask;
-    arg.saa_rect = rootRect;
-    def = rootUse->cu_def;
-    if ((def->cd_flags & CDAVAILABLE) == 0)
-	if (!DBCellRead(def, (char *) NULL, TRUE))
-	    return;
-
-    TTMaskSetMask3(&visitMask, &DBUserLayerBits, &DBBuiltinLayerBits);
-    for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
-	(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
-		    rootRect, &visitMask,
-		    dbSeeTypesSrFunc, (ClientData) &arg);
-}
-
-/*
- * dbSeeTypesSrFunc --
- *
- * Filter procedure applied to tiles by DBSeeTypes() above.
- */
-
-int
-dbSeeTypesSrFunc(tile, arg)
-    Tile *tile;			/* Tile found */
-    struct seeTypesArg *arg;
-{
-    Rect tileRect;
-
-    TiToRect(tile, &tileRect);
-    if (GEO_OVERLAP((&tileRect), (arg->saa_rect)))
-	TTMaskSetType(arg->saa_mask, TiGetType(tile));
-    return 0;
-}
-
 /*
  *-----------------------------------------------------------------------------
  *
@@ -1492,6 +1432,7 @@ struct scaleArg {
    int scaled;
    int pnum;
    Plane *ptarget;
+   bool doCIF;
 };
 
 /*
@@ -1506,18 +1447,20 @@ struct scaleArg {
  */
 
 void
-dbScalePlane(oldplane, newplane, pnum, scalen, scaled)
+dbScalePlane(oldplane, newplane, pnum, scalen, scaled, doCIF)
     Plane *oldplane, *newplane;
     int pnum;
     int scalen, scaled;
+    bool doCIF;
 {
-    int dbTileScaleFunc();
+    int dbTileScaleFunc();		/* forward declaration */
     struct scaleArg arg;
 
     arg.scalen = scalen;
     arg.scaled = scaled;
     arg.ptarget = newplane;
     arg.pnum = pnum;
+    arg.doCIF = doCIF;
     (void) DBSrPaintArea((Tile *) NULL, oldplane, &TiPlaneRect,
 		&DBAllButSpaceBits, dbTileScaleFunc, (ClientData) &arg);
 }
@@ -1565,10 +1508,14 @@ dbTileScaleFunc(tile, scvals)
     if (IsSplit(tile))
 	type = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
     DBNMPaintPlane(scvals->ptarget, exact, &targetRect,
-		DBStdPaintTbl(type, scvals->pnum), (PaintUndoInfo *)NULL);
+		((scvals->doCIF) ? CIFPaintTable :
+		DBStdPaintTbl(type, scvals->pnum)),
+		(PaintUndoInfo *)NULL);
 #else
     DBPaintPlane(scvals->ptarget, &targetRect,
-		DBStdPaintTbl(type, scvals->pnum), (PaintUndoInfo *)NULL);
+		((scvals->doCIF) ? CIFPaintTable :
+		DBStdPaintTbl(type, scvals->pnum)),
+		(PaintUndoInfo *)NULL);
 #endif
     return 0;
 }
@@ -1600,7 +1547,7 @@ dbScaleCell(cellDef, scalen, scaled)
     /* DBCellEnum() attempts to read unavailable celldefs.  We don't	*/
     /* want to do that here, so check CDAVAILABLE flag first.	  	*/
 
-    if ((cellDef->cd_flags & CDAVAILABLE) == 0) return 0;
+    if ((cellDef->cd_flags & CDAVAILABLE) == 0) goto donecell;
 
     /* Enumerate all unique cell uses, and scale their position,	*/
     /* transform, and array information.				*/
@@ -1677,7 +1624,8 @@ dbScaleCell(cellDef, scalen, scaled)
 	if (cellDef->cd_planes[pNum] == NULL) continue;
 	newplane = DBNewPlane((ClientData) TT_SPACE);
 	DBClearPaintPlane(newplane);
-	dbScalePlane(cellDef->cd_planes[pNum], newplane, pNum, scalen, scaled);
+	dbScalePlane(cellDef->cd_planes[pNum], newplane, pNum,
+		scalen, scaled, FALSE);
         DBFreePaintPlane(cellDef->cd_planes[pNum]);
 	TiFreePlane(cellDef->cd_planes[pNum]);
         cellDef->cd_planes[pNum] = newplane;
@@ -1694,11 +1642,14 @@ dbScaleCell(cellDef, scalen, scaled)
 	}
     }
 
+donecell:
+
     /* The cellDef bounding box gets expanded to match the new scale. */
 
     DBScalePoint(&cellDef->cd_bbox.r_ll, scalen, scaled);
     DBScalePoint(&cellDef->cd_bbox.r_ur, scalen, scaled);
 
+    /* Perhaps we should not do this if CD_AVAILABLE is not set? */
     cellDef->cd_flags &= ~(CDMODIFIED|CDBOXESCHANGED|CDSTAMPSCHANGED);
 
     return 0;
