@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsubr.c,v 1.
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -29,7 +30,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsubr.c,v 1.
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
     /* Forward declarations */
 extern void dbSetPlaneTile();
@@ -158,7 +159,7 @@ DBCellClearDef(cellDef)
     cellDef->cd_bbox.r_xbot = cellDef->cd_bbox.r_ybot = 0;
     cellDef->cd_bbox.r_xtop = cellDef->cd_bbox.r_ytop = 1;
     for (lab = cellDef->cd_labels; lab; lab = lab->lab_next)
-	FREE((char *) lab);
+	freeMagic((char *) lab);
     cellDef->cd_labels = (Label *) NULL;
     cellDef->cd_lastLabel = (Label *) NULL;
     SigEnableInterrupts();
