@@ -18,10 +18,10 @@
 
 #ifndef lint
 static char rcsid[] = "$Header: /ufs/repository/magic/database/DBexpand.c,v 1.2 2001/01/12 22:12:20 jsolomon Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -174,14 +174,15 @@ DBExpandAll(rootUse, rootRect, expandMask, expandFlag, func, cdarg)
 
 int
 dbExpandFunc(scx, arg)
-    register SearchContext *scx;	/* Pointer to search context containing
+    SearchContext *scx;	/* Pointer to search context containing
 					 * child use, search area in coor-
 					 * dinates of the child use, and
 					 * transform back to "root".
 					 */
-    register struct expandArg *arg;	/* Client data from caller */
+    struct expandArg *arg;	/* Client data from caller */
 {
     CellUse *childUse = scx->scx_use;
+    int n = DBLambda[1];
 
     /*
      * Change the expansion status of this cell if necessary.  Call the
@@ -221,12 +222,12 @@ dbExpandFunc(scx, arg)
 
 int
 dbUnexpandFunc(scx, arg)
-    register SearchContext *scx;	/* Pointer to search context containing
+    SearchContext *scx;	/* Pointer to search context containing
 					 * child use, search area in coor-
 					 * dinates of the child use, and
 					 * transform back to "root".
 					 */
-    register struct expandArg *arg;	/* Client data from caller */
+    struct expandArg *arg;	/* Client data from caller */
 {
     CellUse *childUse = scx->scx_use;
 
@@ -293,13 +294,13 @@ DBCellReadArea(rootUse, rootRect)
 
 int
 dbReadAreaFunc(scx)
-    register SearchContext *scx;	/* Pointer to context specifying
+    SearchContext *scx;	/* Pointer to context specifying
 					 * the cell use to be read in, and
 					 * an area to be recursively read in
 					 * coordinates of the cell use's def.
 					 */
 {
-    register CellDef *def = scx->scx_use->cu_def;
+    CellDef *def = scx->scx_use->cu_def;
 
     if ((def->cd_flags & CDAVAILABLE) == 0)
     {
