@@ -33,7 +33,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBio.c,v 1.5 2001
 #include <sys/stat.h>
 #include <time.h>
 #include <sys/time.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
@@ -42,12 +43,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBio.c,v 1.5 2001
 #include "database/databaseInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "drc/drc.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 extern char *Path;
 
@@ -364,7 +365,7 @@ DBCellRead(cellDef, name, ignoreTech)
     ReduceFraction(&n, &d);
     if (d > 1)
     {
-	CIFTechInputScale(1, d);
+	CIFTechInputScale(1, d, TRUE);
 	CIFTechOutputScale(1, d);
 	DRCTechScale(1, d);
 	ExtTechScale(1, d);
@@ -377,10 +378,12 @@ DBCellRead(cellDef, name, ignoreTech)
 #endif
 	DBScaleEverything(d, 1);
 	DBLambda[1] *= d;
-	TxPrintf("Scaled magic internal geometry by factor of %d\n", d);
+	TxPrintf("Input cell %s scales magic internal geometry by factor of %d\n",
+			cellDef->cd_name, d);
     }
     if (n > 1)
-	TxPrintf("Scaled magic input file geometry by factor of %d\n", n);
+	TxPrintf("Scaled magic input cell %s geometry by factor of %d\n", 
+		cellDef->cd_name, n);
 
     /*
      * Next, get the paint, subcells, and labels for this cell.
@@ -701,7 +704,7 @@ dbReadOpen(cellDef, name, setFileName)
 	else {
 	    TxError("Cell %s couldn't be found\n", cellDef->cd_name);
 #ifdef FILE_LOCKS
-	    MALLOC(char *, realname, strlen(cellDef->cd_name) + strlen(DBSuffix) + 1);
+	    realname = (char *) mallocMagic((unsigned) (strlen(cellDef->cd_name) + strlen(DBSuffix) + 1));
 	    (void) sprintf(realname, "%s%s", cellDef->cd_name, DBSuffix);
 	    cellDef->cd_file = StrDup(&cellDef->cd_file, realname);
 #endif
@@ -1356,7 +1359,19 @@ dbReadLabels(cellDef, line, len, f, scale)
 Warning: label \"%s\" attached to unknown type \"%s\"\n", text, layername);
 	    type = TT_SPACE;
 	}
+	else if (type >= DBNumUserLayers)
+	{
+	    TileTypeBitMask *rmask;
+	    TileType rtype;
 
+	    /* Don't stick labels on stacked types; choose the	*/
+	    /* topmost (last, usually) residue contact type.	*/
+
+	    rmask = DBResidueMask(type);
+	    for (rtype = TT_SPACE + 1; rtype < DBNumUserLayers; rtype++)
+		if (TTMaskHasType(rmask, rtype))
+		    type = rtype;
+	}
 	(void) DBPutLabel(cellDef, &r, orient, text, type, 0);
 
 nextlabel:
@@ -1752,7 +1767,7 @@ DBCellWriteFile(cellDef, f)
     {
 	FPRINTF(f, "<< elements >>\n");
 	FPRINTF(f, estring);
-	FREE(estring);
+	freeMagic(estring);
     }
 
     /* And any properties */
@@ -1879,7 +1894,7 @@ DBCellWrite(cellDef, fileName)
      */
     if (fileName)
     {
-	MALLOC(char *, realname, strlen(fileName)+strlen(DBSuffix)+1);
+	realname = (char *) mallocMagic((unsigned) (strlen(fileName)+strlen(DBSuffix)+1));
 	(void) sprintf(realname, "%s%s", fileName, DBSuffix);
 	/* Bug fix: 7/17/99, Michael D. Godfrey:  Forces		*/
 	/* cd_name and cd_file to ALWAYS be the same, otherwise ugly	*/
@@ -1893,7 +1908,7 @@ DBCellWrite(cellDef, fileName)
     }
     else if (cellDef->cd_name)
     {
-	MALLOC(char *, realname, strlen(cellDef->cd_name)+strlen(DBSuffix)+1);
+	realname = (char *) mallocMagic((unsigned) (strlen(cellDef->cd_name)+strlen(DBSuffix)+1));
 	(void) sprintf(realname, "%s%s", cellDef->cd_name, DBSuffix);
     }
     else return (FALSE);
@@ -1928,7 +1943,7 @@ DBCellWrite(cellDef, fileName)
     /*
      * Figure name of the temp file to write.
      */
-    MALLOC(char *, tmpname, strlen(expandname) + strlen(template) + 1);
+    tmpname = (char *) mallocMagic((unsigned) (strlen(expandname) + strlen(template) + 1));
     (void) sprintf(tmpname, "%s%s", expandname, template);
     tmpres = mkstemp(tmpname);
 
@@ -1974,15 +1989,23 @@ DBCellWrite(cellDef, fileName)
 	{
 	    result = FALSE;
 	    perror("rename");
-	    TxError(
-"\
-ATTENTION: Magic was unable to rename file %s to %s.\n\
-If the file %s exists, it is the old copy of the cell %s.\n\
-The new copy is in the file %s.  Please copy this file\n\
-to a safe place before executing any more Magic commands.\n",
-		tmpname, expandname, expandname, cellDef->cd_name, tmpname);
+	    TxError("ATTENTION: Magic was unable to rename file %s to %s.\n"
+		    "If the file %s exists, it is the old copy of the cell %s.\n"
+		    "The new copy is in the file %s.  Please copy this file\n"
+		    "to a safe place before executing any more Magic commands.\n",
+		    tmpname, expandname, expandname, cellDef->cd_name, tmpname);
 	    goto cleanup;
 	}
+	else
+	{
+	    /* mkstemp() generates a file with permissions 0600 */
+	    /* This is okay for the temporary file, but we want	*/
+	    /* to respect the user's umask value when renaming	*/
+	    /* the file to ".mag".				*/
+	    mode_t userumask = umask((mode_t)0);
+	    umask(userumask);
+	    chmod(expandname, (mode_t)0666 & ~userumask);
+	}
     }
     else
     {
@@ -2066,8 +2089,8 @@ to a safe place before executing any more Magic commands.\n",
 
 cleanup:
     SigEnableInterrupts();
-    FREE(realname);
-    FREE(tmpname);
+    freeMagic(realname);
+    freeMagic(tmpname);
     return result;
 }
 
