@@ -24,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBlabel.c,v 1.4 2
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -47,7 +47,7 @@ static TileType DBPickLabelLayer(/* CellDef *def, Label *lab, int noreconnect */
  * that the CellDef should be treated as a subcircuit.
  *
  * Results:
- *	True if CellDef contains ports, False otherwise.
+ *	TRUE if CellDef contains ports, FALSE otherwise.
  *
  * Side effects:
  *	None.
@@ -109,7 +109,7 @@ DBPutLabel(cellDef, rect, align, text, type, flags)
     int len, x1, x2, y1, y2, tmp, labx, laby;
 
     len = strlen(text) + sizeof (Label) - sizeof lab->lab_text + 1;
-    MALLOC(Label *, lab, (unsigned) len);
+    lab = (Label *) mallocMagic ((unsigned) len);
     strcpy(lab->lab_text, text);
 
     /* Pick a nice alignment if the caller didn't give one.  If the
@@ -242,7 +242,7 @@ DBEraseLabel(cellDef, area, mask)
 	    lab->lab_text, lab->lab_type, lab->lab_flags);
 	DBWLabelChanged(cellDef, lab->lab_text, &lab->lab_rect,
 	    lab->lab_pos, DBW_ALLWINDOWS);
-	FREE((char *) lab);
+	freeMagic((char *) lab);
 	lab = lab->lab_next;
 	erasedAny = TRUE;
 	continue;
@@ -316,7 +316,7 @@ DBEraseLabelsByContent(def, rect, pos, type, text)
 	else labPrev->lab_next = lab->lab_next;
 	if (def->cd_lastLabel == lab)
 	    def->cd_lastLabel = labPrev;
-	FREE((char *) lab);
+	freeMagic((char *) lab);
 
 	/* Don't iterate through loop, since this will skip a label:
 	 * just go back to top.  This is tricky!
@@ -379,7 +379,7 @@ DBEraseLabelsByFunction(def, func)
 	else labPrev->lab_next = lab->lab_next;
 	if (def->cd_lastLabel == lab)
 	    def->cd_lastLabel = labPrev;
-	FREE((char *) lab);
+	freeMagic((char *) lab);
 
 	/* Don't iterate through loop, since this will skip a label:
 	 * just go back to top.  This is tricky!
@@ -540,7 +540,7 @@ DBAdjustLabelsNew(def, area, noreconnect)
 				     lab->lab_text, lab->lab_type, lab->lab_flags);
 		    DBWLabelChanged(def, lab->lab_text, &lab->lab_rect,
 				    lab->lab_pos, DBW_ALLWINDOWS);
-		    FREE((char *) lab);
+		    freeMagic((char *) lab);
 		    lab = lab->lab_next;
 		    modified = TRUE;
 		    continue;
