@@ -24,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBlabel2.c,v 1.2
 #ifdef SYSV
 #include <string.h>
 #endif
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -509,7 +509,7 @@ DBNearestLabel(cellUse, area, point, xMask, labelArea, labelName, length)
     if (labelName == NULL) tp = NULL, name = NULL;
     else
     {
-	MALLOC(char *, name, length);
+	name = (char *) mallocMagic((unsigned) (length));
 	tPath.tp_first = name;
 	tPath.tp_next = name;
 	tPath.tp_last = name + length - 1;
@@ -527,7 +527,7 @@ DBNearestLabel(cellUse, area, point, xMask, labelArea, labelName, length)
     (void) DBTreeSrLabels(&scx, &DBAllTypeBits, xMask, tp, dbNearestLabelFunc,
 	(ClientData) &funcData);
 
-    if (name) FREE(name);
+    if (name) freeMagic(name);
     
     if (!funcData.nld_gotLabel) return FALSE;
     else return TRUE;
