@@ -24,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBprop.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
