@@ -30,7 +30,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtcontact.c,v 1.
 #include <string.h>
 #include <ctype.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "utils/malloc.h"
@@ -38,7 +38,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtcontact.c,v 1.
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 
 /* type-to-bitmask conversion (1 bit per entry) */
@@ -187,7 +187,7 @@ DBTechAddContact(sectionName, argc, argv)
 	}
 	else if (!strcmp(*argv, "stackable"))
 	{
-	    TileType stackType, newType;
+	    TileType stackType, newType = -1;
 	    LayerInfo *lim, *lin;
 
 	    if (argc == 1)
@@ -233,7 +233,11 @@ DBTechAddContact(sectionName, argc, argv)
 			else if (lastType >= TT_SPACE)
 			{
 			    /* (*argv) becomes an alias name for layer newType */
-			    DBTechAddNameToType(*argv, newType);
+			    if (newType < 0)
+				TechError("Contact type %s unknown or contact "
+					"missing in stackable statement\n", *argv);
+			    else
+				DBTechAddNameToType(*argv, newType);
 			    lastType = TT_SPACE;
 			}
 			else
@@ -803,11 +807,8 @@ DBTechFinalContact()
 	    {
 		lp = &dbLayerInfo[primaryType];
 
-		if (primaryType < DBNumUserLayers)
-		    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
-			if (PlaneMaskHasPlane(lp->l_pmask, pNum))
-			    DBTypePlaneMaskTbl[primaryType] |=
-					PlaneNumToMaskBit(pNum);
+		/* if (primaryType < DBNumUserLayers) */
+		    DBTypePlaneMaskTbl[primaryType] |= lp->l_pmask;
 
 		for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 		    if (PlaneMaskHasPlane(lp->l_pmask, pNum))
