@@ -24,15 +24,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtech.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
@@ -68,7 +71,7 @@ DBTechInit()
 {
     /* StrDup() takes care of reallocating DBTechName */
 
-    /* TECH_FORMAT_VERSION is defined in tech/tech.h,	*/
+    /* TECH_FORMAT_VERSION is defined in utils/tech.h,	*/
     /* and should be 27, the last version to be		*/
     /* included as part of the tech filename suffix.	*/
 
@@ -168,15 +171,37 @@ DBTechSetVersion(sectionName, argc, argv)
     int argc;
     char *argv[];
 {
-    if (argc != 2) goto usage;
-    if (strcmp(argv[0], "version") == 0) {
+    char *contline;
+    int n, slen;
+
+    if (argc < 2) goto usage;
+    if (strcmp(argv[0], "version") == 0)
+    {
 	(void) StrDup(&DBTechVersion, argv[1]);
+	for (n = 2; n < argc; n++)
+	{
+	    slen = strlen(DBTechVersion);
+	    contline = mallocMagic(strlen(argv[n]) + slen + 1);
+	    sprintf(contline, "%s\n%s", DBTechVersion, argv[n]);
+	    freeMagic(DBTechVersion);
+	    DBTechVersion = contline;
+	}
 	return TRUE;
     }
-    if (strcmp(argv[0], "description") == 0) {
+    if (strcmp(argv[0], "description") == 0)
+    {
 	(void) StrDup(&DBTechDescription, argv[1]);
+	for (n = 2; n < argc; n++)
+	{
+	    slen = strlen(DBTechDescription);
+	    contline = mallocMagic(strlen(argv[n]) + slen + 1);
+	    sprintf(contline, "%s\n%s", DBTechDescription, argv[n]);
+	    freeMagic(DBTechDescription);
+	    DBTechDescription = contline;
+	}
 	return TRUE;
     }
+
 usage:
     TechError("Badly formed version line\nUsage: {version text}|{description text}\n");
     return FALSE;
@@ -201,7 +226,7 @@ usage:
 void
 DBTechInitConnect()
 {
-    register int i;
+    int i;
 
     for (i = 0; i < TT_MAXTYPES; i++)
     {
@@ -237,7 +262,7 @@ DBTechAddConnect(sectionName, argc, argv)
     char *argv[];
 {
     TileTypeBitMask types1, types2;
-    register TileType t1, t2;
+    TileType t1, t2;
 
     if (argc != 2)
     {
@@ -295,9 +320,9 @@ DBTechAddConnect(sectionName, argc, argv)
 void
 DBTechFinalConnect()
 {
-    TileTypeBitMask saveConnect[TT_MAXTYPES], tmp, tmp2;
-    register TileType base, s;
-    register LayerInfo *lp;
+    /* TileTypeBitMask saveConnect[TT_MAXTYPES]; */
+    TileType base, s;
+    LayerInfo *lp;
     int n;
 
     for (s = 0; s < DBNumTypes; s++)
@@ -306,40 +331,27 @@ DBTechFinalConnect()
     /*
      * Each stacked contact type must necessarily connect to its
      * residual contact types, and the connecting types of those
-     * contacts.
+     * contacts.  Each stacked contact type also connects to
+     * other contact types that share (first) residues.
      */
     for (base = DBNumUserLayers; base < DBNumTypes; base++)
     {
-	TileTypeBitMask *rmask = DBResidueMask(base);
+	TileTypeBitMask *smask, *rmask = DBResidueMask(base), cmask;
 	TTMaskSetMask(&DBConnectTbl[base], rmask);
 	for (s = TT_TECHDEPBASE; s < DBNumUserLayers; s++)
 	    if (TTMaskHasType(rmask, s))
 		TTMaskSetMask(&DBConnectTbl[base], &DBConnectTbl[s]);
-    }
 
-    /*
-     * Each contact type should connect to everything that each of
-     * its connected images connects to, but only stuff that's on
-     * the same plane as each connected image or the original contact
-     * type (i.e, no transitive connections to contacts on other planes).
-     * To ensure that we don't generate the transitive closure of the
-     * connectivity table (we only want adjacency connectedness), we
-     * make a copy of the original connectivity table and use it as
-     * the source of image connectedness, instead of using DBConnectTbl[]
-     * as well as updating it.
-     */
-    bcopy((char *) DBConnectTbl, (char *) saveConnect, sizeof saveConnect);
-    for (n = 0; n < dbNumContacts; n++)
-    {
-	lp = dbContactInfo[n];
+	/* Only need to start above "base";  the mirror-image	*/
+	/* connection is ensured by the code below.		*/
 
-	/*
-	 * DBConnPlanes[] is nonzero only for contact images, for which
-	 * it shows the planes connected to an image, exclusive of the
-	 * image's plane itself.
-	 */
-	DBConnPlanes[lp->l_type] = lp->l_pmask;
-	DBConnPlanes[lp->l_type] &= ~(PlaneNumToMaskBit(DBPlane(lp->l_type)));
+	for (s = base + 1; s < DBNumTypes; s++)
+	{
+	    smask = DBResidueMask(s);
+	    TTMaskAndMask3(&cmask, smask, rmask);
+	    if (!TTMaskIsZero(&cmask))
+		TTMaskSetType(&DBConnectTbl[base], s);
+	}
     }
 
     /* Make the connectivity matrix symmetric */
@@ -352,6 +364,18 @@ DBTechFinalConnect()
     for (base = 0; base < TT_MAXTYPES; base++)
 	TTMaskCom2(&DBNotConnectTbl[base], &DBConnectTbl[base]);
 
+    /*
+     * DBConnPlanes[] is nonzero only for contact images, for which
+     * it shows the planes connected to an image.  It is the
+     * responsibility of the routine examining this value to exclude
+     * the plane being searched, if necessary.
+     */
+    for (n = 0; n < dbNumContacts; n++)
+    {
+	lp = dbContactInfo[n];
+	DBConnPlanes[lp->l_type] = lp->l_pmask;
+    }
+
     /*
      * Now finally construct DBAllConnPlanes, which will be non-zero
      * for those planes to which each type 'base' connects, exclusive
