@@ -29,15 +29,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtechname.c,v 1.
 #include <string.h>
 #endif
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
@@ -68,7 +68,7 @@ DBTechNameType(typename)
 {
     char *slash;
     TileType type;
-    int plane, i;
+    int plane;
     LayerInfo *lp;
 
     slash = index(typename, '/');
@@ -112,20 +112,20 @@ DBTechNameTypes(typename,bitmask)
 {
     char *slash;
     TileType type;
-    int plane, i;
+    int plane;
     LayerInfo *lp;
 
     TTMaskZero(bitmask);
     slash = index(typename, '/');
     if (slash != NULL) *slash = 0;
     type = (TileType) dbTechNameLookup(typename, &dbTypeNameLists);
+    if (type < 0) return type;
     if (slash == NULL)
     {
     	 TTMaskSetType(bitmask,type);
 	 return type;
     } 
     *slash = '/';
-    if (type < 0) return type;
 
     /* There's a plane qualification.  Locate the image. */
 
@@ -199,6 +199,7 @@ DBTechNoisyNameType(typename)
  * ----------------------------------------------------------------------------
  */
 
+int
 DBTechNamePlane(planename)
     char *planename;	/* The name of the plane */
 {
@@ -268,7 +269,7 @@ char *
 DBTypeShortName(type)
     TileType type;
 {
-    register NameList *tbl;
+    NameList *tbl;
 
     for (tbl = dbTypeNameLists.sn_next;
 	    tbl != &dbTypeNameLists;
@@ -288,7 +289,7 @@ char *
 DBPlaneShortName(pNum)
     int pNum;
 {
-    register NameList *tbl;
+    NameList *tbl;
 
     for (tbl = dbPlaneNameLists.sn_next;
 	    tbl != &dbPlaneNameLists;
@@ -323,6 +324,7 @@ DBPlaneShortName(pNum)
  * ----------------------------------------------------------------------------
  */
 
+int
 DBTechTypesToPlanes(mask)
     TileTypeBitMask *mask;
 {
@@ -367,7 +369,7 @@ DBTechPrintTypes(dolist)
 {
     TileType i;
     NameList *p;
-    bool first, found;
+    bool first;
     DefaultType *dtp;
     char *keepname;
 
@@ -512,13 +514,18 @@ DBTechPrintCanonicalType(layername)
  *	a parenthesized group.  For example, ~(x,y)/foo refers to
  *	all layers on plane "foo" except "x" and "y".
  *
- *	Finally, magic version 7.3 defines *x to mean "x and all
+ *	Magic version 7.3 defines *x to mean "x and all
  *	contact layers containing x as a residue".  Thus, for example,
  *	*metal1 expands to m1,pc,ndc,pdc,nsc,psc,m2c,...  Because many
  *	connect, cif, extract, and drc rules list all these layers,
  *	the asterisk notation makes the techfile shorter and more
  *	readable.
  *
+ *	Magic version 7.3 also defines a hash table "DBTypeAliasTable"
+ *	that allows macros to be embedded in the technology file.
+ *	Macros are expanded first, prior to applying the parsing
+ *	described above.
+ *
  * Results:
  *	Returns a plane mask of all the planes specified.
  *
@@ -534,14 +541,14 @@ DBTechNoisyNameMask(layers, mask)
     char *layers;			/* String to be parsed. */
     TileTypeBitMask *mask;		/* Where to store the layer mask. */
 {
-    register char *p, *p2, c;
+    char *p, *p2, c;
     TileTypeBitMask m2;        /* Each time around the loop, we will
 				* form the mask for one section of
 				* the layer string.
 				*/
     char save;
     bool allBut;
-    int planemask;
+    int planemask = 0;
 
     TTMaskZero(mask);
     p = layers;
@@ -589,7 +596,7 @@ DBTechNoisyNameMask(layers, mask)
 	    }
 	    save = *p2;
 	    *p2 = 0;
-	    DBTechNoisyNameMask(p, &m2);
+	    planemask |= DBTechNoisyNameMask(p, &m2);
 	    *p2 = save;
 	    if (save == ')') p = p2 + 1;
 	    else p = p2;
@@ -614,26 +621,39 @@ DBTechNoisyNameMask(layers, mask)
 	    }
 	    else if (strcmp(p, "0") != 0)
 	    {
-		save = *p2;
-		*p2 = 0;
+		HashEntry *he;
 
-		/* Check for asterisk notation, meaning to include	*/
-		/* all types which have this type as a residue.		*/
-		if (*p == '*')
+		/* Check the alias table for macro definitions */
+		he = HashLookOnly(&DBTypeAliasTable, p);
+		if (he)
 		{
-		    allResidues = TRUE;
-		    p++;
+		    TileTypeBitMask *amask;
+		    amask = (TileTypeBitMask *)HashGetValue(he);
+		    TTMaskSetMask(&m2, amask);
 		}
+		else
+		{
+		    save = *p2;
+		    *p2 = 0;
 
-		t = DBTechNoisyNameType(p);
-		if (t >= 0) m2 = DBLayerTypeMaskTbl[t];
-		*p2 = save;
+		    /* Check for asterisk notation, meaning to include	*/
+		    /* all types which have this type as a residue.	*/
+		    if (*p == '*')
+		    {
+			allResidues = TRUE;
+			p++;
+		    }
 
-		/* Include all types which have t as a residue */
-		if (allResidues)
-		    for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
-			if (TTMaskHasType(DBResidueMask(rtype), t))
-			    TTMaskSetType(&m2, rtype);
+		    t = DBTechNoisyNameType(p);
+		    if (t >= 0) m2 = DBLayerTypeMaskTbl[t];
+		    *p2 = save;
+
+		    /* Include all types which have t as a residue */
+		    if (allResidues)
+			for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
+			    if (TTMaskHasType(DBResidueMask(rtype), t))
+				TTMaskSetType(&m2, rtype);
+		}
 	    }
 	    p = p2;
 	}
@@ -717,7 +737,7 @@ DBTechMinSetPlanes(typeMask, newTypes)
     TTMaskZero(newTypes);
     for (i = TT_SELECTBASE; i < DBNumTypes; i++)
     {
-	if (!TTMaskHasType(&typeMask, i) || DBConnPlanes[i] != 0)
+	if (!TTMaskHasType(&typeMask, i) || DBIsContact(i))
 	    continue;
 	TTMaskSetType(newTypes, i);
 	planes |= PlaneNumToMaskBit(DBPlane(i));
@@ -725,12 +745,12 @@ DBTechMinSetPlanes(typeMask, newTypes)
 
     /*
      * Now go through each contact type.  If one of the contact's planes
-     * is already necessary, use it.  Otherwise, add the plane for
+     * is already necessary, use it.  Otherwise, add the home plane for
      * the contact.
      */
     for (i = TT_SELECTBASE; i < DBNumTypes; i++)
     {
-	if (!TTMaskHasType(&typeMask, i) || DBConnPlanes[i] == 0)
+	if (!TTMaskHasType(&typeMask, i) || !DBIsContact(i))
 	    continue;
 	okPlanes = DBConnPlanes[i] & planes;
 	if (okPlanes != 0)
@@ -783,8 +803,7 @@ DBTechSubsetLayers(src, mask, result)
     TileTypeBitMask *result;		/* Store subset here. */
 {
     TileTypeBitMask tmp,tmp2,clrmask;
-    register int i;
-    bool success = TRUE;
+    int i;
 
     TTMaskZero(result);
     TTMaskZero(&clrmask);
