@@ -26,14 +26,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtechtype.c,v 1.
 #ifdef SYSV
 #include <string.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
@@ -42,12 +43,14 @@ int DBNumTypes;
 char *DBTypeLongNameTbl[NT];
 int DBTypePlaneTbl[NT];		/* Normally accessed as macro "DBPlane(x)" */
 NameList dbTypeNameLists = {NULL, NULL, NULL, (ClientData)0, FALSE};
+HashTable DBTypeAliasTable;
 
     /* Planes and their names */
 int DBNumPlanes;
 char *DBPlaneLongNameTbl[PL_MAXTYPES];
 NameList dbPlaneNameLists = {NULL, NULL, NULL, (ClientData)0, FALSE};
 
+
     /*
      * Sets of types.
      * These are generated after the "types" section of the
@@ -150,6 +153,30 @@ DBTechInitPlane()
     DBNumPlanes = PL_TECHDEPBASE;
 }
 
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBTypeInit --
+ *
+ * Initialization routine for the types database on startup (runs only
+ * once).
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Hash table initialization.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBTypeInit()
+{
+    HashInit(&DBTypeAliasTable, 8, HT_STRINGKEYS);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -207,9 +234,13 @@ DBTechInitType()
 	DBPlane(dtp->dt_type) = dtp->dt_plane;
     }
 
+    /* Hash table of layer aliases */
+    HashKill(&DBTypeAliasTable);
+    HashInit(&DBTypeAliasTable, 8, HT_STRINGKEYS);
+
     DBNumTypes = TT_TECHDEPBASE;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -292,7 +323,8 @@ DBTechAddNameToType(newname, ttype)
  * Define a tile type for the new technology.
  *
  * Results:
- *	TRUE if successful, FALSE on error
+ *	TRUE if successful, FALSE on error.  Returns TRUE on some
+ *	errors that may not necessarily be fatal.
  *
  * Side effects:
  *	Updates the database technology variables.
@@ -324,16 +356,46 @@ DBTechAddType(sectionName, argc, argv)
 	return TRUE;
     }
 
-    cp = dbTechNameAdd(argv[1], (ClientData) DBNumTypes, &dbTypeNameLists);
-    if (cp == NULL)
-	return FALSE;
-    pNum = DBTechNoisyNamePlane(argv[0]);
-    if (pNum < 0)
-	return FALSE;
+    if (!strcmp(argv[0], "alias"))
+    {
+	HashEntry *he;
+	TileTypeBitMask *amask;
 
-    DBTypeLongNameTbl[DBNumTypes] = cp;
-    DBPlane(DBNumTypes) = pNum;
-    DBNumTypes++;
+	/* First check that the alias name does not shadow an existing type */
+	if (DBTechNameType(argv[1]) >= 0)
+	{
+	    TechError("Type alias \"%s\" shadows a defined type\n", argv[1]);
+	    return TRUE;
+	}
+
+	he = HashFind(&DBTypeAliasTable, argv[1]);
+	amask = (TileTypeBitMask *)HashGetValue(he);
+	if (amask == NULL)
+	{
+	    amask = (TileTypeBitMask *)mallocMagic(sizeof(TileTypeBitMask));
+	    DBTechNoisyNameMask(argv[2], amask);
+	    HashSetValue(he, amask);
+	}
+	else
+	{
+	    TechError("Type \"%s\" is already defined and cannot be an alias\n",
+			argv[1]);
+	    return TRUE;
+	}
+    }
+    else
+    {
+	cp = dbTechNameAdd(argv[1], (ClientData) DBNumTypes, &dbTypeNameLists);
+	if (cp == NULL)
+	    return FALSE;
+	pNum = DBTechNoisyNamePlane(argv[0]);
+	if (pNum < 0)
+	    return FALSE;
+
+	DBTypeLongNameTbl[DBNumTypes] = cp;
+	DBPlane(DBNumTypes) = pNum;
+	DBNumTypes++;
+    }
 
     return TRUE;
 }
@@ -628,7 +690,7 @@ dbTechNameAddOne(name, cdata, isPrimary, ptable)
 	    break;
 
     /* Create a new name */
-    MALLOC(NameList *, new, sizeof (NameList));
+    new = (NameList *) mallocMagic((unsigned) (sizeof (NameList)));
     new->sn_name = StrDup((char **) NULL, name);
     new->sn_value = cdata;
     new->sn_primary = isPrimary;
