@@ -23,10 +23,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtiles.c,v 1.3 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
@@ -768,7 +769,7 @@ enumerate:
 	/* Each iteration returns one tile further to the right */
 	while (RIGHT(tp) < rect->r_xtop)
 	{
-	    FREE((char *) tp); 
+	    freeMagic((char *) tp); 
 	    tpnew = RT(tp);
 	    tp = TR(tp);
 	    if (CLIP_TOP(tpnew) <= CLIP_TOP(tp) && BOTTOM(tpnew) < rect->r_ytop)
@@ -778,7 +779,7 @@ enumerate:
 	    }
 	}
 
-	FREE((char *) tp); 
+	freeMagic((char *) tp); 
 	/* At right edge -- walk up to next tile along the right edge */
 	tp = RT(tp);
 	if (BOTTOM(tp) < rect->r_ytop) {
@@ -852,10 +853,10 @@ dbFreeCellFunc(tile)
 	    use->cu_parent = (CellDef *) NULL;
 	    (void) DBCellDeleteUse(use);
 	}
-	FREE((char *) body);
+	freeMagic((char *) body);
     }
 
-    FREE((char *) tile);
+    freeMagic((char *) tile);
     return 0;
 }
 
