@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtimestmp.c,v 1.
 
 #include <stdio.h>
 #include <sys/types.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -31,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtimestmp.c,v 1.
 #include "windows/windows.h"
 #include "textio/textio.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 
 /* Overall comments:
@@ -132,7 +133,7 @@ DBFixMismatch()
 
 	cellDef = mismatch->mm_cellDef;
 	oldArea = mismatch->mm_oldArea;
-	FREE((char *) mismatch);
+	freeMagic((char *) mismatch);
 	mismatch = mismatch->mm_next;
 	if (cellDef->cd_flags & CDPROCESSED) continue;
 
@@ -278,7 +279,7 @@ DBStampMismatch(cellDef, wrongArea)
     Mismatch *mm;
     CellUse *parentUse;
 
-    MALLOC(Mismatch *, mm, sizeof (Mismatch));
+    mm = (Mismatch *) mallocMagic((unsigned) (sizeof (Mismatch)));
     mm->mm_cellDef = cellDef;
     mm->mm_oldArea = *wrongArea;
     mm->mm_next = mismatch;
