@@ -24,14 +24,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtpaint.c,v 1.5
 #include <ctype.h>
 #include <string.h>	/* for memset(), memcpy() */
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 
     /* Painting and erasing tables */
