@@ -23,14 +23,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtpaint2.c,v 1.4
 
 #include <stdio.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 
 #define	SETPAINT(have,paint,plane,get) \
