@@ -23,20 +23,20 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBundo.c,v 1.3 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /***
  *** Identifiers for each of the clients defined here
@@ -690,7 +690,7 @@ dbUndoCellForw(up)
 	case UNDO_CELL_CLRID:
 	    use = findUse(up, TRUE);	/* Find it with current id */
 	    DBUnLinkCell(use, up->cue_parent);
-	    FREE(use->cu_id);
+	    freeMagic(use->cu_id);
 	    use->cu_id = (char *) NULL;
 	    break;
     }
@@ -753,7 +753,7 @@ dbUndoCellBack(up)
 	case UNDO_CELL_SETID:
 	    use = findUse(up, TRUE);	/* Find it with current id */
 	    DBUnLinkCell(use, up->cue_parent);
-	    FREE(use->cu_id);
+	    freeMagic(use->cu_id);
 	    use->cu_id = (char *) NULL;
 	    break;
     }
