@@ -27,7 +27,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWbuttons.c,v 1.2
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -35,7 +35,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWbuttons.c,v 1.2
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
 #include "utils/utils.h"
@@ -348,7 +348,7 @@ DBWBoxHandler(w, cmd)
     if (button == TX_MIDDLE_BUTTON)
     {
 	if (cmd->tx_buttonAction == TX_BUTTON_DOWN)
-	    CmdPaintButton(w, &cmd->tx_p);
+	    CmdPaintEraseButton(w, &cmd->tx_p, TRUE);
 	return;
     }
 
