@@ -23,7 +23,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWdisplay.c,v 1.5
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <stdlib.h>
+#include <string.h>
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -33,10 +37,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWdisplay.c,v 1.5
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
 #include "dbwind/dbwtech.h"
-#include "misc/styles.h"
-#include "main/main.h"
-#include "tech/tech.h"
-#include "signals/signals.h"
+#include "utils/styles.h"
+#include "utils/main.h"
+#include "utils/tech.h"
+#include "utils/signals.h"
 
 /* The following variable is exported to the rest of the world.
  * It is read from the "styletype" line of the technology file,
@@ -145,8 +149,7 @@ extern int dbwWindowFunc(), dbwChangedFunc();
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
-Void
+void
 DBWredisplay(w, rootArea, clipArea)
     MagWindow *w;			/* Window some of whose contents are to be
 				 * redisplayed.
@@ -172,6 +175,11 @@ DBWredisplay(w, rootArea, clipArea)
 	    rootArea->r_xtop, rootArea->r_ytop);
     */
 
+#ifdef MAGIC_WRAPPER
+    /* Honor the display suspend state */
+    if (GrDisplayStatus == DISPLAY_SUSPEND) return;
+#endif
+
     GrLock(w, TRUE);
 
     /* Round up the redisplay area by 1 pixel on all sides.  This
@@ -207,14 +215,14 @@ DBWredisplay(w, rootArea, clipArea)
 	Rect text;
 
 	halfWireWidth = MAX(RtrMetalWidth, RtrPolyWidth);
-	halfWireWidth = (halfWireWidth * w->w_scale)>>13;
-	for (i = GR_TEXT_XLARGE; i >= GR_TEXT_SMALL; i -= 1)
+	halfWireWidth = (halfWireWidth * w->w_scale) >> (SUBPIXELBITS + 1);
+	for (i = GR_TEXT_XLARGE; i >= GR_TEXT_SMALL; i--)
 	{
 	    GrLabelSize("B", GEO_CENTER, i, &text);
 	    if (halfWireWidth > (text.r_ytop - text.r_ybot)) break;
 	}
 	if (i < GR_TEXT_SMALL) i = GR_TEXT_SMALL;
-	if ((3*halfWireWidth) <= (text.r_ytop - text.r_ybot))
+	if ((3 * halfWireWidth) <= (text.r_ytop - text.r_ybot))
 	    crec->dbw_labelSize = -1;
 	else crec->dbw_labelSize = i;
 
@@ -238,8 +246,8 @@ DBWredisplay(w, rootArea, clipArea)
      * in the area to be redisplayed.
      */
 
-    pixelsPerLambda = w->w_scale/4096;
-    lambdasPerPixel = (4096 / w->w_scale) + 1; 
+    pixelsPerLambda = w->w_scale / SUBPIXEL;
+    lambdasPerPixel = (SUBPIXEL / w->w_scale) + 1; 
     labelArea = largerArea;
     (void) GeoInclude(&GrCrossRect, &crec->dbw_expandAmounts);
     if (pixelsPerLambda > 0)
@@ -513,12 +521,13 @@ DBWredisplay(w, rootArea, clipArea)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwPaintFunc(tile, cxp)
-    register Tile *tile;	/* Tile to be redisplayed. */
+    Tile *tile;	/* Tile to be redisplayed. */
     TreeContext *cxp;		/* From DBTreeSrTiles */
 {
-    register SearchContext *scx = cxp->tc_scx;
+    SearchContext *scx = cxp->tc_scx;
 			/* Contains pointer to use containing def
 			 * in which tile appears, and transform to
 			 * screen coordinates.
@@ -707,7 +716,7 @@ DBWDrawLabel(text, rect, pos, style, labelSize, sizeBox)
  *
  * ----------------------------------------------------------------------------
  */
-    /*ARGSUSED*/
+
 int
 dbwLabelFunc(scx, label, tpath)
     SearchContext *scx;		/* Contains pointer to use containing def in
@@ -770,6 +779,7 @@ dbwLabelFunc(scx, label, tpath)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwBBoxFunc(scx)
     SearchContext *scx;		/* Describes context of cell. */
@@ -817,6 +827,7 @@ dbwBBoxFunc(scx)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwTileFunc(tile)
     Tile *tile;				/* A tile to be redisplayed. */
@@ -1262,7 +1273,7 @@ DBWLabelChanged(cellDef, text, area, pos, mask)
     CellDef *cellDef;		/* Cell definition containing label. */
     char *text;			/* The text of the label. */
     Rect *area;			/* The area of the label. */
-    int pos;			/* Relative position of text to area.
+    int pos;			/* Relative position of text to area. */
     int mask;			/* Mask of windows where changes should be
 				 * reflected (DBW_ALLWINDOWS selects all
 				 * windows, and is usually the right value.)
@@ -1379,7 +1390,7 @@ global TileTypeBitMask	*DBWStyleToTypesTbl = NULL;
 void
 DBWTechInitStyles()
 {
-    register int i;
+    int i;
 
     if (DBWNumStyles == 0)
     {
@@ -1452,7 +1463,6 @@ DBWTechParseStyle(stylestr)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
 bool
 DBWTechAddStyle(sectionName, argc, argv)
     char *sectionName;
