@@ -17,7 +17,7 @@
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -26,9 +26,9 @@
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* Types of elements */
 
@@ -117,7 +117,7 @@ AppendString(oldstr, newstr, postfix)
     {
 	strcpy(tmpstr, *oldstr);
 	strcat(tmpstr, newstr);
-	FREE(*oldstr);
+	freeMagic(*oldstr);
     }
     if (postfix != NULL) strcat(tmpstr, postfix);
     *oldstr = tmpstr;
