@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWfdback.c,v 1.3 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -34,9 +34,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWfdback.c,v 1.3 2
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* Each feedback area is stored in a record that looks like this: */
 
@@ -132,7 +132,7 @@ DBWFeedbackRedraw(window, plane)
 	if (fb->fb_scale != curScale)
 	{
 	    curScale = fb->fb_scale;
-	    halfScale = curScale/2;
+	    halfScale = curScale / 2;
 	    worldArea.r_xbot = window->w_surfaceArea.r_xbot * curScale;
 	    worldArea.r_xtop = window->w_surfaceArea.r_xtop * curScale;
 	    worldArea.r_ybot = window->w_surfaceArea.r_ybot * curScale;
@@ -167,13 +167,13 @@ DBWFeedbackRedraw(window, plane)
 	    continue;
 
 	x = ((tmp.r_xbot - worldArea.r_xbot) * window->w_scale) + halfScale;
-	screenArea.r_xbot = (x/curScale + window->w_origin.p_x)>>12;
+	screenArea.r_xbot = (x/curScale + window->w_origin.p_x) >> SUBPIXELBITS;
 	x = ((tmp.r_xtop - worldArea.r_xbot) * window->w_scale) + halfScale;
-	screenArea.r_xtop = (x/curScale + window->w_origin.p_x)>>12;
+	screenArea.r_xtop = (x/curScale + window->w_origin.p_x) >> SUBPIXELBITS;
 	y = ((tmp.r_ybot - worldArea.r_ybot) * window->w_scale) + halfScale;
-	screenArea.r_ybot = (y/curScale + window->w_origin.p_y)>>12;
+	screenArea.r_ybot = (y/curScale + window->w_origin.p_y) >> SUBPIXELBITS;
 	y = ((tmp.r_ytop - worldArea.r_ybot) * window->w_scale) + halfScale;
-	screenArea.r_ytop = (y/curScale + window->w_origin.p_y)>>12;
+	screenArea.r_ytop = (y/curScale + window->w_origin.p_y) >> SUBPIXELBITS;
 
 	/*
 	 * Sanity check on integer bounds
@@ -186,22 +186,25 @@ DBWFeedbackRedraw(window, plane)
 	    continue;
 	}
 
-	/* Another little trick:  when the feedback area is very small ("very 
-	 * small" is a hand-tuned constant), change all stippled styles to
-	 * solid.
-	 */
-	
 #ifdef NONMANHATTAN
 	newStyle = fb->fb_style & (TT_LEFTMASK | TT_RIGHTMASK);
 #else
 	newStyle = fb->fb_style;
 #endif
-	if (((GEO_WIDTH(&screenArea) < 18) || (GEO_HEIGHT(&screenArea) < 18)) &&
-	    ((newStyle == STYLE_MEDIUMHIGHLIGHTS) ||
-	     (newStyle == STYLE_PALEHIGHLIGHTS)))
-	{
+
+	/* Another little trick:  when the feedback area is very small ("very 
+	 * small" is a hand-tuned constant), change all stippled styles to
+	 * solid.
+	 * (The usefulness of this trick is questionable, as it generally
+	 * creates very bothersome output for the "cif see" function and
+	 * other places where the feedback is generated from tiles.)
+	 */
+/*
+	if (((GEO_WIDTH(&screenArea) < 18) || (GEO_HEIGHT(&screenArea) < 18))
+			&& ((newStyle == STYLE_MEDIUMHIGHLIGHTS)
+			|| (newStyle == STYLE_PALEHIGHLIGHTS)))
 	    newStyle = STYLE_SOLIDHIGHLIGHTS;
-	}
+*/
 	if (newStyle != curStyle)
 	{
 	    curStyle = newStyle;
