@@ -24,9 +24,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWhlights.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
