@@ -24,30 +24,30 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWprocs.c,v 1.4 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "dbwind/dbwind.h"
 #include "graphics/graphics.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
 #include "utils/utils.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "graphics/glyphs.h"
 #include "utils/malloc.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 global WindClient DBWclientID;
 static dbwBitMask = 0;
 #define MAX_BITMASK	0177777
 #define MAX_BITS_IN_MASK 16
 
-extern Void DBWredisplay();		/* Defined in DBWdisplay.c */
+extern void DBWredisplay();		/* Defined in DBWdisplay.c */
 
 /* The following variable is used to allow somebody besides ourselves
  * to take over button handling for database windows.  If it is NULL
@@ -55,7 +55,7 @@ extern Void DBWredisplay();		/* Defined in DBWdisplay.c */
  * the address of a procedure to handle buttons.
  */
 
-static Void (*dbwButtonHandler)() = NULL;
+static int (*dbwButtonHandler)() = NULL;
 
 /*
  * ----------------------------------------------------------------------------
@@ -76,6 +76,7 @@ static Void (*dbwButtonHandler)() = NULL;
  * ----------------------------------------------------------------------------
  */
 
+bool
 DBWcreate(window, argc, argv)
     MagWindow *window;
     int argc;
@@ -124,10 +125,10 @@ DBWcreate(window, argc, argv)
 
     window->w_clientData = (ClientData) crec;
     if (argc > 0)
-	DBWloadWindow(window, argv[0]);
+	DBWloadWindow(window, argv[0], TRUE, FALSE);
     else if (ToolGetBox(&boxDef, &box))
     {
-	DBWloadWindow(window, boxDef->cd_name);
+	DBWloadWindow(window, boxDef->cd_name, TRUE, FALSE);
 
 	/* Zoom in on the box, leaving a 10% border or at least 2 units
 	 * on each side.
@@ -145,7 +146,7 @@ DBWcreate(window, argc, argv)
     }
     else
     {
-	DBWloadWindow(window, (char *) NULL);
+	DBWloadWindow(window, (char *) NULL, TRUE, FALSE);
     }
     return TRUE;
 }
@@ -165,6 +166,7 @@ DBWcreate(window, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+bool
 DBWdelete(window)
     MagWindow *window;
 {
@@ -243,7 +245,7 @@ dbwReloadFunc(w, name)
     MagWindow *w;
     char *name;
 {
-    DBWloadWindow(w, name);
+    DBWloadWindow(w, name, TRUE, FALSE);
     return (0);
 }
 
@@ -267,13 +269,19 @@ dbwReloadFunc(w, name)
  *	to the topmost cell in the new window.  Otherwise, the edit
  *	cell doesn't change.
  *
+ *	If "expand" is true, unexpands all subcells of the root cell.
+ *
  * ----------------------------------------------------------------------------
  */
 
 void
-DBWloadWindow(window, name)
+DBWloadWindow(window, name, ignoreTech, expand)
     MagWindow *window;	/* Identifies window to which cell is to be bound */
     char *name;		/* Name of new cell to be bound to this window */
+    bool ignoreTech;	/* If FALSE, indicates that the technology of
+			 * the layout must match the current technology.
+			 */
+    bool expand;	/* Indicates whether or not to expand the cell */
 {
     CellDef *newEditDef;
     CellUse *newEditUse;
@@ -284,6 +292,7 @@ DBWloadWindow(window, name)
 #ifdef FILE_LOCKS
     FILE *dummy = NULL;
 #endif
+   int UnexpandFunc();		/* forward declaration */
 
     loadBox.r_xbot = loadBox.r_ybot = 0;
     loadBox.r_xtop = loadBox.r_ytop = 1;
@@ -324,7 +333,7 @@ DBWloadWindow(window, name)
 	if (newEditDef == (CellDef *) NULL)
 	    newEditDef = DBCellNewDef(name, (char *) NULL);
 
-	if (!DBCellRead(newEditDef, (char *) NULL, TRUE))
+	if (!DBCellRead(newEditDef, (char *) NULL, ignoreTech))
 	{
 	    TxPrintf("Creating new cell\n");
 	    DBCellSetAvail(newEditDef);
@@ -352,6 +361,13 @@ DBWloadWindow(window, name)
     (void) StrDup(&(newEditUse->cu_id), "Topmost cell in the window");
     DBExpand(newEditUse,
 	((DBWclientRec *)window->w_clientData)->dbw_bitmask, TRUE);
+
+    if (expand)
+	DBExpandAll(newEditUse, &(newEditUse->cu_bbox),
+		((DBWclientRec *)window->w_clientData)->dbw_bitmask,
+		FALSE, UnexpandFunc,
+		(ClientData) (((DBWclientRec *)window->w_clientData)->dbw_bitmask));
+
     if (newEdit)
     {
 	if (EditCellUse && EditRootDef)
@@ -370,157 +386,7 @@ DBWloadWindow(window, name)
 	    EditCellUse = newEditUse;
 	    EditRootDef = newEditDef;
 	}
-	EditToRootTransform = GeoIdentityTransform;
-	RootToEditTransform = GeoIdentityTransform;
-    }
 
-    /* enforce a minimum size of 60 and a border of 10% around the sides */
-    xadd = MAX(0, (60 - (loadBox.r_xtop - loadBox.r_xbot)) / 2) + 
-	(loadBox.r_xtop - loadBox.r_xbot + 1) / 10;
-    yadd = MAX(0, (60 - (loadBox.r_ytop - loadBox.r_ybot)) / 2) +
-	(loadBox.r_ytop - loadBox.r_ybot + 1) / 10;
-    loadBox.r_xbot -= xadd;  loadBox.r_xtop += xadd;
-    loadBox.r_ybot -= yadd;  loadBox.r_ytop += yadd;
-
-    window->w_bbox = &(newEditUse->cu_def->cd_bbox);
-    res = WindLoad(window, DBWclientID, (ClientData) newEditUse, &loadBox);
-    ASSERT(res, "DBWcreate");
-
-    /* Update the captions in all windows to reflect the new
-     * edit cell.  Also, if we've got a new edit cell, we need
-     * to explicitly ask for redisplay, because there could be
-     * another window on this cell somewhere else, and it needs
-     * to be redisplayed too (if it's just the new window, that
-     * is taken care of during WindLoad).
-     */
-    CmdSetWindCaption(EditCellUse, EditRootDef);
-    if (newEdit)
-	DBWAreaChanged(newEditDef, &newEditDef->cd_bbox, DBW_ALLWINDOWS,
-	    &DBAllButSpaceBits);
-}
-
-
-/*
- * ----------------------------------------------------------------------------
- *
- * DBWxloadWindow
- *
- *	Replace the root cell of a window by the specified cell.
- *
- *	A cell name of NULL causes the cell with name "(UNNAMED)" to be
- *	created if it does not already exist, or used if it does.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	If there is currently no edit use, or if this is the only
- *	window containing the edit cell, then set the edit cell
- *	to the topmost cell in the new window.  Otherwise, the edit
- *	cell doesn't change.
- *	Unexpands all subcells of the root cell.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-DBWxloadWindow(window, name)
-    MagWindow *window;	/* Identifies window to which cell is to be bound */
-    char *name;		/* Name of new cell to be bound to this window */
-{
-    CellDef *newEditDef;
-    CellUse *newEditUse;
-    void DisplayWindow();
-    int res, newEdit;
-    int xadd, yadd;
-    Rect loadBox;
-    int UnexpandFunc();		/* Forward reference. */
-#ifdef FILE_LOCKS
-    FILE *dummy = NULL;
-#endif
-
-    loadBox.r_xbot = loadBox.r_ybot = 0;
-    loadBox.r_xtop = loadBox.r_ytop = 1;
-
-    /* See if we're to change the edit cell */
-    newEdit = !WindSearch((WindClient) DBWclientID, (ClientData) NULL,
-			    (Rect *) NULL, dbwLoadFunc, (ClientData) window);
-
-    if (name == (char *) NULL)
-    {
-	/*
-	 * If there is an existing unnamed cell, we use it.
-	 * Otherwise, we create one afresh.
-	 */
-	newEditDef = DBCellLookDef(UNNAMED);
-	if (newEditDef == (CellDef *) NULL)
-	{
-	    newEditDef = DBCellNewDef(UNNAMED, (char *) NULL);
-	    DBCellSetAvail(newEditDef);
-	}
-    }
-    else
-    {
-	/*
-	 * Name specified.
-	 * First try to find it in main memory, then try to
-	 * read it from disk.
-	 */
-	newEditDef = DBCellLookDef(name);
-	if (newEditDef == (CellDef *) NULL)
-	    newEditDef = DBCellNewDef(name, (char *) NULL);
-
-	if (!DBCellRead(newEditDef, (char *) NULL, TRUE))
-	{
-	    TxPrintf("Creating new cell\n");
-	    DBCellSetAvail(newEditDef);
-#ifdef FILE_LOCKS
-	    flock_test_set(newEditDef->cd_file, dummy);
-#endif
-	}
-	else
-	{
-	    /* DBCellRead doesn't dare to change bounding boxes, so
-	     * we have to call DBReComputeBbox here (we know that it's
-	     * safe).
-	     */
-	    DBReComputeBbox(newEditDef);
-	    loadBox = newEditDef->cd_bbox;
-	}
-    }
-
-    /*
-     * Attach the new cell to the selected window.
-     */
-
-    newEditUse = DBCellNewUse(newEditDef, (char *) NULL);
-    (void) StrDup(&(newEditUse->cu_id), "Topmost cell in the window");
-    DBExpand(newEditUse,
-	((DBWclientRec *)window->w_clientData)->dbw_bitmask, TRUE);
-    DBExpandAll(newEditUse, &(newEditUse->cu_bbox),
-	((DBWclientRec *)window->w_clientData)->dbw_bitmask, FALSE,
-	UnexpandFunc,
-	(ClientData) (((DBWclientRec *)window->w_clientData)->dbw_bitmask));
-
-    if (newEdit)
-    {
-	if (EditCellUse && EditRootDef)
-	{
-	    DBWUndoOldEdit(EditCellUse, EditRootDef,
-		    &EditToRootTransform, &RootToEditTransform);
-	    DBWUndoNewEdit(newEditUse, newEditDef,
-		    &GeoIdentityTransform, &GeoIdentityTransform);
-	}
-
-	if (newEditUse->cu_def->cd_flags & CDNOEDIT)
-	{
-	    newEdit = FALSE;
-	}
-	else
-	{
-	    EditCellUse = newEditUse;
-	    EditRootDef = newEditDef;
-	}
 	EditToRootTransform = GeoIdentityTransform;
 	RootToEditTransform = GeoIdentityTransform;
     }
@@ -607,7 +473,7 @@ DBWexit()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWcommands(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -652,7 +518,7 @@ DBWcommands(w, cmd)
  *	From now on, all button pushes within database windows are
  *	passed to buttonProc, in the following form:
  *
- *	    Void
+ *	    int 
  *	    buttonProc(w, cmd)
  *		MagWindow *w;
  *		TxCommand *cmd;
@@ -662,10 +528,10 @@ DBWcommands(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void (*(DBWNewButtonHandler(buttonProc)))()
-    Void (*buttonProc)();		/* New button handler. */
+int (*(DBWNewButtonHandler(buttonProc)))()
+    int (*buttonProc)();		/* New button handler. */
 {
-    Void (*result)();
+    int (*result)();
 
     result = dbwButtonHandler;
     dbwButtonHandler = buttonProc;
@@ -688,7 +554,7 @@ Void (*(DBWNewButtonHandler(buttonProc)))()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWupdate()
 {
     DBWFeedbackShow();
@@ -713,25 +579,25 @@ DBWupdate()
 extern bool MakeMainWindow;
 #endif
 
-int
+void
 DBWinit()
 {
     MagWindow *initialWindow;
     int i;
     static char *doc =
-"You are currently using the \"box\" tool.  The button actions are:\n\
-   left    - move the box so its lower-left corner is at cursor position\n\
-   right   - resize box by moving upper-right corner to cursor position\n\
-   middle  - paint box area with material underneath cursor\n\
-You can move or resize the box by different corners by pressing left\n\
-    or right, holding it down, moving the cursor near a different corner\n\
-    and clicking the other (left or right) button down then up without\n\
-    releasing the initial button.\n";
+	"You are currently using the \"box\" tool.  The button actions are:\n"
+	"   left    - move the box so its lower-left corner is at cursor position\n"
+	"   right   - resize box by moving upper-right corner to cursor position\n"
+	"   middle  - paint box area with material underneath cursor\n"
+	"You can move or resize the box by different corners by pressing left\n"
+	"    or right, holding it down, moving the cursor near a different corner\n"
+	"    and clicking the other (left or right) button down then up without\n"
+	"    releasing the initial button.\n";
 
     /* Initialize */
     DBWclientID = WindAddClient("layout", DBWcreate, DBWdelete, 
 	    DBWredisplay, DBWcommands, DBWupdate, DBWexit,
-	    ( Void (*)() ) NULL,
+	    (void (*)()) NULL,
 	    (GrGlyph *) NULL);
 
     /* Add all of the commands for the DBWind interface.  These	*/
