@@ -25,12 +25,12 @@
 
 #ifndef lint
 static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWtools.c,v 1.3 2001/04/13 20:02:58 tim Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -38,7 +38,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWtools.c,v 1.3 20
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
 #include "textio/textio.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/txcommands.h"
 
 #define WINDOW_DEF(w)	(((CellUse *)(w->w_surfaceID))->cu_def)
@@ -62,11 +62,13 @@ static Rect boxRootArea;		/* Root def coords */
  * grid always, instead of snapping to the usual 1x1 grid.  If the value
  * is DBW_SNAP_INTERNAL, the box gets snapped to the internal grid.
  */
-bool DBWSnapToGrid = DBW_SNAP_LAMBDA;
+int DBWSnapToGrid = DBW_SNAP_LAMBDA;
 
 /* Forward reference: */
 
 extern int DBWToolDraw();
+extern void toolSnapToGrid();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -423,7 +425,7 @@ dbwRecordBoxArea(erase)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWDrawBox(window, plane)
     MagWindow *window;		/* Window in which to redraw box. */
     Plane *plane;		/* Non-space tiles on this plane indicate
@@ -432,6 +434,7 @@ DBWDrawBox(window, plane)
 {
     Rect screenArea;
     Rect side;
+    int boxStyle = STYLE_SOLIDHIGHLIGHTS;
     extern int dbwBoxAlways1();	/* Forward reference. */
 
     /* Return if the window is not compatible with the box location
@@ -443,6 +446,19 @@ DBWDrawBox(window, plane)
 	    &DBAllButSpaceBits, dbwBoxAlways1, (ClientData) NULL))
 	return;
 
+    /* Get the box coordinates in the coordinate system of the	*/
+    /* edit cell.  If the box is outside of the edit cell, then	*/
+    /* we draw it with style "medium_highlights" instead of	*/
+    /* "solid_highlights".					*/
+
+    if (EditRootDef == boxRootDef)
+    {
+	Rect editbox;
+        GeoTransRect(&RootToEditTransform, &boxRootArea, &editbox);
+	if (!GEO_OVERLAP(&editbox, &EditCellUse->cu_def->cd_bbox))
+	    boxStyle = STYLE_MEDIUMHIGHLIGHTS;
+    }
+
     /* Transform the box into screen coordinates, then draw it.  If the
      * box is a point, draw it as a cross (GrFastBox does this automatically)
      * and add a slightly solid center.  Otherwise, draw the box several
@@ -475,7 +491,7 @@ DBWDrawBox(window, plane)
 	return;
     }
 
-    GrSetStuff(STYLE_SOLIDHIGHLIGHTS);
+    GrSetStuff(boxStyle);
     if ((screenArea.r_xbot >= window->w_screenArea.r_xbot) &&
 	(screenArea.r_xbot <= window->w_screenArea.r_xtop))
     {
@@ -799,13 +815,14 @@ ToolMoveCorner(corner, point, screenCoords, rootDef)
  * ----------------------------------------------------------------------------
  */
 
+void
 toolSnapToGrid(w, p, rEnclose)
     MagWindow *w;
     Point *p;
     Rect *rEnclose;
 {
     DBWclientRec *crec = (DBWclientRec *) w->w_clientData;
-    register Rect *r;
+    Rect *r;
     Rect lr;
     int xd, yd, xlo, xhi, ylo, yhi, xtmp, ytmp;
 
