@@ -24,15 +24,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWundo.c,v 1.2 200
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/textio.h"
 #include "commands/commands.h"
 
