@@ -172,10 +172,13 @@ extern void DBWBoxHandler();
 extern MagWindow *ToolGetPoint();
 extern MagWindow *ToolGetBoxWindow();
 extern bool ToolGetBox();
+extern bool ToolGetEditBox(Rect *);
 extern void ToolMoveBox(), ToolMoveCorner();
 extern int ToolGetCorner();
 extern void DBWloadWindow(), DBWxloadWindow();
 extern void DBWSetBox();
+extern void DBWUndoOldEdit();
+extern void DBWUndoNewEdit();
 
 /* Exported procedures for managing highlights: */
 
