@@ -24,7 +24,7 @@
 #ifndef _DEBUG_H
 #define _DEBUG_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 struct debugClient
 {
