@@ -21,11 +21,11 @@
 
 #ifndef	lint
 static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCarray.c,v 1.3 2001/04/13 20:02:59 tim Exp $";
-#endif	not lint
+#endif	/* not lint */
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -274,7 +274,7 @@ DRCArrayCheck(def, area, func, cdarg)
     int oldTiles;
     PaintResultType (*savedPaintTable)[NT][NT];
     PaintResultType (*savedEraseTable)[NT][NT];
-    Void (*savedPaintPlane)();
+    void (*savedPaintPlane)();
 
     /* Use DRCDummyUse to fake up a celluse for searching purposes. */
 
@@ -293,11 +293,15 @@ DRCArrayCheck(def, area, func, cdarg)
      * illegal overlaps.
      */
 
+/*
     savedPaintTable = DBNewPaintTable(DRCPaintTable);
     savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
     (void) DBCellSrArea(&scx, drcArrayFunc, (ClientData) area);
+/*
     (void) DBNewPaintTable(savedPaintTable);
     (void) DBNewPaintPlane(savedPaintPlane);
+*/
 
     /* Update count of array tiles processed. */
 
