@@ -25,13 +25,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCbasic.c,v 1.5 2001/
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 int dbDRCDebug = 0;
 
@@ -79,9 +79,13 @@ areaCheck(tile, arg)
 {
     Rect rect;		/* Area where error is to be recorded. */
 
-    /* If the tile has a legal type, then return. */
-
 #ifdef NONMANHATTAN
+
+    /* If the tile has a legal type, then return.  This is where we	*/
+    /* would want to add extra processing to check whether the half of	*/
+    /* the tile that is of an illegal type is inside or outside the	*/
+    /* area of interest.						*/
+
     if (IsSplit(tile))
     {
 	if (TTMaskHasType(&arg->dCD_cptr->drcc_mask, SplitLeftType(tile)) &&
@@ -346,12 +350,23 @@ drcTile (tile, arg)
 	    /*
 	     * Stacked contact types have no rules.  Any stacked contact
 	     * type must have DRC rules applied to each of its constituent
-	     * types.  Start with the first type encountered for each.
+	     * types.  But, if the residue mask for the stacking type
+	     * contains the other type, then this is a "false" edge, and
+	     * we will not process it.  Otherwise, start with the first
+	     * type encountered for each.
 	     */
 	    stackpending = (unsigned char)0x0;
 	    if (tt >= DBNumUserLayers)
 	    {
 		rMask = DBResidueMask(tt);
+		if (to >= DBNumUserLayers)
+		{
+		    TileTypeBitMask combined;
+		    TTMaskAndMask3(&combined, rMask, DBResidueMask(to));
+		    if (!TTMaskIsZero(&combined))
+			continue;
+		}
+		else if (TTMaskHasType(rMask, to)) continue;
 		stackpending |= (unsigned char)0x01;
 		for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
 		    if (TTMaskHasType(rMask, tt))
@@ -360,6 +375,7 @@ drcTile (tile, arg)
 	    if (to >= DBNumUserLayers)
 	    {
 		rMask = DBResidueMask(to);
+		if (TTMaskHasType(rMask, tt)) continue;
 		stackpending |= (unsigned char)0x02;
 		for (to = TT_TECHDEPBASE; to < DBNumUserLayers; to++)
 		    if (TTMaskHasType(rMask, to))
@@ -675,6 +691,14 @@ checkbottom:
 	    if (tt >= DBNumUserLayers)
 	    {
 		rMask = DBResidueMask(tt);
+		if (to >= DBNumUserLayers)
+		{
+		    TileTypeBitMask combined;
+		    TTMaskAndMask3(&combined, rMask, DBResidueMask(to));
+		    if (!TTMaskIsZero(&combined))
+			continue;
+		}
+		else if (TTMaskHasType(rMask, to)) continue;
 		stackpending |= (unsigned char)0x01;
 		for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
 		    if (TTMaskHasType(rMask, tt))
@@ -683,6 +707,7 @@ checkbottom:
 	    if (to >= DBNumUserLayers)
 	    {
 		rMask = DBResidueMask(to);
+		if (TTMaskHasType(rMask, tt)) continue;
 		stackpending |= (unsigned char)0x02;
 		for (to = TT_TECHDEPBASE; to < DBNumUserLayers; to++)
 		    if (TTMaskHasType(rMask, to))
