@@ -32,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCcif.c,v 1.2 2001/01
 #include <string.h>
 #include <sys/types.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -43,7 +43,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCcif.c,v 1.2 2001/01
 #include "drc/drc.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
@@ -153,7 +153,7 @@ drcCifWidth(argc, argv)
 
     scalefactor = drcCifStyle->cs_scaleFactor;
     dpnext = drcCifRules[thislayer][DRC_CIF_SPACE];
-    MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+    dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
     ASSIGN(dpnew,centidistance,dpnext,CIFSolidBits,
     		CIFSolidBits,why,centidistance,DRC_FORWARD,thislayer);
     drcCifRules[thislayer][DRC_CIF_SPACE] = dpnew;
@@ -245,7 +245,7 @@ drcCifSpacing(argc, argv)
     
     scalefactor = drcCifStyle->cs_scaleFactor;
     dpnext = drcCifRules[layer[0]][DRC_CIF_SOLID];
-    MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+    dpnew = (DRCCifCookie *) mallocMagic((unsigned) sizeof (DRCCifCookie));
     ASSIGN(dpnew,centidistance,dpnext,DBSpaceBits,
     		cmask,why,centidistance,DRC_FORWARD,layer[1]);
     drcCifRules[layer[0]][DRC_CIF_SOLID] = dpnew;
@@ -254,7 +254,7 @@ drcCifSpacing(argc, argv)
     {
          dpnew->drcc_flags |= DRC_BOTHCORNERS|DRC_XPLANE;
          dpnext = drcCifRules[layer[1]][DRC_CIF_SOLID];
-         MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+         dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
          ASSIGN(dpnew,centidistance,dpnext,DBSpaceBits,
     		cmask,why,centidistance,
 		DRC_XPLANE|DRC_FORWARD|DRC_BOTHCORNERS,layer[0]);
@@ -263,14 +263,14 @@ drcCifSpacing(argc, argv)
 	 if (layer[0] == layer[1])
 	 {
               dpnext = drcCifRules[layer[1]][DRC_CIF_SPACE];
-              MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+              dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
               ASSIGN(dpnew,centidistance,dpnext,DBSpaceBits,
     		     cmask,why,centidistance,
 		     DRC_XPLANE|DRC_REVERSE|DRC_BOTHCORNERS,layer[0]);
                  drcCifRules[layer[1]][DRC_CIF_SPACE] = dpnew;
 	 
               dpnext = drcCifRules[layer[0]][DRC_CIF_SPACE];
-              MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+              dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
               ASSIGN(dpnew,centidistance,dpnext,DBSpaceBits,
     		     cmask,why,centidistance,
 		     DRC_XPLANE|DRC_REVERSE|DRC_BOTHCORNERS,layer[1]);
@@ -281,14 +281,14 @@ drcCifSpacing(argc, argv)
     if (layer[0] != layer[1]) /* make sure they don't overlap exactly */
     {
          dpnext = drcCifRules[layer[1]][DRC_CIF_SPACE];
-         MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+         dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
          ASSIGN(dpnew,scalefactor,dpnext,DBSpaceBits,
     		DBZeroTypeBits,why,scalefactor,
 		DRC_FORWARD,layer[0]);
          drcCifRules[layer[1]][DRC_CIF_SPACE] = dpnew;
 
          dpnext = drcCifRules[layer[0]][DRC_CIF_SPACE];
-         MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+         dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
          ASSIGN(dpnew,scalefactor,dpnext,DBSpaceBits,
     		DBZeroTypeBits,why,scalefactor,
 		DRC_FORWARD,layer[1]);
@@ -873,7 +873,7 @@ drcCifArea(argc, argv)
 
     scalefactor = drcCifStyle->cs_scaleFactor;
     dpnext = drcCifRules[thislayer][DRC_CIF_SPACE];
-    MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+    dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
     ASSIGN(dpnew,centihorizon,dpnext,CIFSolidBits,
     		CIFSolidBits,why,centidistance,DRC_AREA|DRC_FORWARD,thislayer);
     drcCifRules[thislayer][DRC_CIF_SPACE] = dpnew;
@@ -944,7 +944,7 @@ drcCifMaxwidth(argc, argv)
     
     scalefactor = drcCifStyle->cs_scaleFactor;
     dpnext = drcCifRules[thislayer][DRC_CIF_SPACE];
-    MALLOC(DRCCifCookie *, dpnew, sizeof (DRCCifCookie));
+    dpnew = (DRCCifCookie *) mallocMagic((unsigned) (sizeof (DRCCifCookie)));
     ASSIGN(dpnew,centidistance,dpnext,CIFSolidBits,
     		CIFSolidBits,why,centidistance,DRC_MAXWIDTH|bend,thislayer);
     drcCifRules[thislayer][DRC_CIF_SPACE] = dpnew;
