@@ -27,7 +27,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCcontin.c,v 1.2 2001
 #include <sys/types.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -36,12 +36,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCcontin.c,v 1.2 2001
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "dbwind/dbwtech.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "graphics/graphics.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/malloc.h"
 
 #ifdef MAGIC_WRAPPER
@@ -269,6 +269,49 @@ DRCCheckThis (celldef, operation, area)
     }
 }
 
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DRCRemovePending --
+ *
+ *	Remove a cell def from the DRC pending list.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	DRCPendingRoot linked list modified
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DRCRemovePending(def)
+   CellDef *def;
+{
+    DRCPendingCookie *p, *plast;
+
+    p = DRCPendingRoot;
+    plast = NULL;
+
+    while (p != NULL)
+    {
+	if (p->dpc_def == def)
+	{
+	    if (plast == NULL)
+		DRCPendingRoot = p->dpc_next;
+	    else
+		plast->dpc_next = p->dpc_next;
+
+	    freeMagic(p);
+	    return;
+	}
+	plast = p;
+	p = p->dpc_next;
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
