@@ -24,7 +24,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCmain.c,v 1.2 2001/0
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCmain.c,v 1.2 2001/0
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "drc/drc.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 extern void TxPrintf(char *, ...);
 extern void TxError(char *, ...);
