@@ -21,8 +21,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCprint.c,v 1.2 2001/
 #endif	/* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <sys/types.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -55,7 +57,6 @@ drcGetName(layer, string)
     int layer;
     char *string;		/* Used to hold name.  Must have length >= 8 */
 {
-    extern char *strncpy();
     (void) strncpy(string, DBTypeShortName(layer), 8);
     string[8] = '\0';
     if (layer == TT_SPACE) return "space";
@@ -100,32 +101,32 @@ DRCPrintRulesTable (fp)
 		    gotAny = TRUE;
 		    if (k == 1)
 		    {
-			(void) fprintf(fp,"%-8s %-8s  ",drcGetName(i, buf1),
+			fprintf(fp,"%-8s %-8s  ",drcGetName(i, buf1),
 			    drcGetName(j, buf2));
 			k++;
 		    }
-		    else (void) fprintf(fp,"                   ");
+		    else fprintf(fp,"                   ");
 
-		    (void) fprintf(fp,"%d x %d   %s\n",
+		    fprintf(fp,"%d x %d   %s\n",
 			dp->drcc_dist, dp->drcc_cdist,
 			maskToPrint(&dp->drcc_mask));
-		    (void) fprintf(fp,"                           %s",
+		    fprintf(fp,"                           %s",
 			maskToPrint(&dp->drcc_corner));
 		    if (dp->drcc_flags &
 			    (DRC_REVERSE|DRC_BOTHCORNERS|DRC_XPLANE))
-			(void) fprintf(fp, "\n                          ");
+			fprintf(fp, "\n                          ");
 		    if (dp->drcc_flags & DRC_REVERSE)
-			(void) fprintf(fp," reverse");
+			fprintf(fp," reverse");
 		    if (dp->drcc_flags & DRC_BOTHCORNERS)
-			(void) fprintf(fp," both-corners");
+			fprintf(fp," both-corners");
 		    if (dp->drcc_flags & DRC_XPLANE)
-			(void) fprintf(fp," cross-plane(%s)",
+			fprintf(fp," cross-plane(%s)",
 			    DBPlaneLongName(dp->drcc_plane));
-		    (void) fprintf(fp,"\n");
+		    fprintf(fp,"\n");
 	        }
 	    }
 	}
-	if (gotAny) (void) fprintf(fp,"\n");
+	if (gotAny) fprintf(fp,"\n");
     }
 
     /* Print out overlaps that are illegal between subcells. */
@@ -136,7 +137,7 @@ DRCPrintRulesTable (fp)
 	{
 	    if ((i == TT_ERROR_S) || (j == TT_ERROR_S)) continue;
 	    if (DRCPaintTable[0][i][j] == TT_ERROR_S)
-		(void) fprintf(fp, "Tile type %s can't overlap type %s.\n",
+		fprintf(fp, "Tile type %s can't overlap type %s.\n",
 		    drcGetName(i, buf1), drcGetName(j, buf2));
 	}
     }
@@ -145,7 +146,7 @@ DRCPrintRulesTable (fp)
 
     if (!TTMaskIsZero(&DRCExactOverlapTypes))
     {
-	(void) fprintf(fp, "Types that must overlap exactly: %s\n",
+	fprintf(fp, "Types that must overlap exactly: %s\n",
 	    maskToPrint(&DRCExactOverlapTypes));
     }
 }
