@@ -24,7 +24,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCsubcell.c,v 1.2 200
 
 #include <stdio.h>
 #include <sys/types.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCsubcell.c,v 1.2 200
 #include "drc/drc.h"
 #include "windows/windows.h"
 #include "commands/commands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 /* The variables below are made owns so that they can be used to
  * pass information to the various search functions.
@@ -567,11 +568,15 @@ DRCInteractionCheck(def, area, func, cdarg)
 	    scx.scx_use = DRCDummyUse;
 	    scx.scx_trans = GeoIdentityTransform;
 	    DBCellClearDef(DRCdef);
+/*
 	    savedPaintTable = DBNewPaintTable(DRCPaintTable);
 	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
+/*
 	    (void) DBNewPaintTable(savedPaintTable);
 	    (void) DBNewPaintPlane(savedPaintPlane);
+*/
 
 	    /* Run the basic checker over the interaction area. */
 
@@ -631,11 +636,15 @@ DRCFlatCheck(use, area)
 	    scx.scx_use = use;
 	    scx.scx_trans = GeoIdentityTransform;
 	    DBCellClearDef(DRCdef);
+/*
 	    savedPaintTable = DBNewPaintTable(DRCPaintTable);
 	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
+/*
 	    (void) DBNewPaintTable(savedPaintTable);
 	    (void) DBNewPaintPlane(savedPaintPlane);
+*/
 	    (void) DRCBasicCheck(DRCdef, &scx.scx_area, &chunk,
 		drcIncCount, (ClientData) &drcFlatCount);
 	}
