@@ -24,14 +24,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCtech.c,v 1.4 2001/0
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 #ifdef DRC_CIF_EXTENSIONS
@@ -132,7 +132,7 @@ drcWhyClear()
 	char * old = (char *) drcWhyList;
 	(void) StrDup(&(drcWhyList->dwl_string), (char *) NULL);
 	drcWhyList = drcWhyList->dwl_next;
-	FREE(old);
+	freeMagic(old);
     }
 }
 
@@ -157,7 +157,7 @@ drcWhyDup(why)
 {
     struct drcwhylist * new;
 
-    MALLOC(struct drcwhylist *, new, sizeof *new);
+    new = (struct drcwhylist *) mallocMagic((unsigned) (sizeof *new));
     new->dwl_string = StrDup((char **) NULL, why);
     new->dwl_next = drcWhyList;
     drcWhyList = new;
@@ -253,9 +253,9 @@ DRCTechInit()
 	    {
 		char * old = (char *) dp;
 		dp = dp->drcc_next;
-		FREE(old);
+		freeMagic(old);
 	    }
-	    MALLOC(DRCCookie *, dp, sizeof (DRCCookie));
+	    dp = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 	    dp->drcc_dist = -1;
 	    dp->drcc_next = (DRCCookie *) NULL;
 	    DRCRulesTbl[i][j] = dp;
@@ -522,7 +522,7 @@ drcWidth(argc, argv)
 	    {
 		/* find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic ((unsigned)sizeof (DRCCookie));
 		ASSIGN(dpnew, distance, dp->drcc_next, set, set, why,
 			    distance, DRC_FORWARD, plane);
 
@@ -600,7 +600,7 @@ drcArea(argc, argv)
 	    {
 		/* find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, horizon);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, horizon, dp->drcc_next, set, set, why,
 			    distance, DRC_AREA|DRC_FORWARD, plane);
 
@@ -700,7 +700,7 @@ drcMaxwidth(argc, argv)
 	    {
 		/* find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next, set, set, why,
 			    distance, DRC_MAXWIDTH|bend, plane);
 
@@ -907,7 +907,7 @@ drcSpacing(argc, argv)
 		for (curPlane = PL_TECHDEPBASE; curPlane < DBNumPlanes; curPlane++)
 		{
 		    if (!PlaneMaskHasPlane(planes2, curPlane)) continue;
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set2);
 		    TTMaskAndMask3(&tmp2, &DBPlaneTypes[curPlane], &setR);
 
@@ -926,7 +926,7 @@ drcSpacing(argc, argv)
 		        ASSIGN(dpnew, distance, dp->drcc_next, tmp1, tmp2,
 				why, distance, DRC_FORWARD, curPlane);
 
-			MALLOC(DRCCookie *, dptrig, sizeof (DRCCookie));
+			dptrig = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		        ASSIGN(dptrig, wwidth, dpnew, set1, set1, why,
 				wwidth, DRC_REVERSE | DRC_TRIGGER, curPlane);
 			dp->drcc_next = dptrig;
@@ -964,7 +964,7 @@ drcSpacing(argc, argv)
 			 
 			/* find bucket preceding new one we wish to insert */
 			dp = drcFindBucket(j, i, distance);
-			MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+			dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 			if (widerule)
 			{
 			    DRCCookie *dptrig;
@@ -974,7 +974,7 @@ drcSpacing(argc, argv)
 			    ASSIGN(dpnew, distance, dp->drcc_next,
 				tmp1, tmp2, why, distance,
 				DRC_REVERSE | DRC_BOTHCORNERS, curPlane);
-			    MALLOC(DRCCookie *, dptrig, sizeof (DRCCookie));
+			    dptrig = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 			    ASSIGN(dptrig, wwidth, dpnew, set1, set1, why,
 				wwidth, DRC_FORWARD | DRC_TRIGGER, curPlane);
 			    dp->drcc_next = dptrig;
@@ -1009,7 +1009,7 @@ drcSpacing(argc, argv)
 		{
 		    if (!PlaneMaskHasPlane(planes1, curPlane)) continue;
 
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic ((unsigned) (sizeof (DRCCookie)));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set1);
 		    TTMaskAndMask3(&tmp2, &DBPlaneTypes[curPlane], &setRreverse);
 
@@ -1043,7 +1043,7 @@ drcSpacing(argc, argv)
 			 
 			/* find bucket preceding new one we wish to insert */
 			dp = drcFindBucket(j, i, distance);
-			MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+			dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 			ASSIGN(dpnew, distance, dp->drcc_next,
 				tmp1, tmp2, why, distance, 
 				DRC_REVERSE | DRC_BOTHCORNERS, curPlane);
@@ -1103,7 +1103,7 @@ drcSpacing(argc, argv)
 		    }
 
 		    /* create new check and add it to list */
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set2);
 		    TTMaskZero(&tmp2);
 
@@ -1260,7 +1260,7 @@ drcEdge(argc, argv)
 	    {
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next,
 		    setM, setC, why, cdist, DRC_FORWARD, checkPlane);
 		if (fourway) dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1272,7 +1272,7 @@ drcEdge(argc, argv)
 		{
 		    /* find bucket preceding new one we wish to insert */
 		    dp = drcFindBucket(j, i, distance);
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic ((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew,distance,dp->drcc_next,
 			    setM, setC, why, cdist, DRC_REVERSE, checkPlane);
 		    dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1362,7 +1362,7 @@ drcOverhang(argc, argv)
 	    {
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic ((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next,
 			setM, setC, why, 0, DRC_FORWARD, plane);
 		dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1370,7 +1370,7 @@ drcOverhang(argc, argv)
 
 		/* find bucket preceding new one we wish to insert */
 		dp = drcFindBucket(j, i, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next,
 			setM, setC, why, 0, DRC_REVERSE, plane);
 		dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1450,7 +1450,7 @@ drcRectOnly(argc, argv)
 	    {
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, 1);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, 1, dp->drcc_next,
 		    set2, setC, why, 1, DRC_FORWARD, plane);
 		dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1458,7 +1458,7 @@ drcRectOnly(argc, argv)
 
 		/* find bucket preceding new one we wish to insert */
 		dp = drcFindBucket(j, i, 1);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew,1,dp->drcc_next,
 			    set2, setC, why, 1, DRC_REVERSE, plane);
 		dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1561,7 +1561,7 @@ drcSurround(argc, argv)
 	    {
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next,
 			invM, set2, why, distance, DRC_FORWARD, plane1);
 		if (plane2 != plane1)
@@ -1571,7 +1571,7 @@ drcSurround(argc, argv)
 
 		/* find bucket preceding new one we wish to insert */
 		dp = drcFindBucket(j, i, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next,
 			invM, set2, why, distance, DRC_REVERSE, plane1);
 		if (plane2 != plane1)
@@ -1603,7 +1603,7 @@ drcSurround(argc, argv)
 		{
 		    /* Find bucket preceding the new one we wish to insert */
 		    dp = drcFindBucket(i, j, distance);
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew, distance, dp->drcc_next, set1,
 				invM, why, distance, DRC_FORWARD, plane2);
 		    dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1611,7 +1611,7 @@ drcSurround(argc, argv)
 
 		    /* find bucket preceding new one we wish to insert */
 		    dp = drcFindBucket(j, i, distance);
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew,distance,dp->drcc_next, set1,
 				invM, why, distance, DRC_REVERSE, plane2);
 		    dpnew->drcc_flags |= DRC_BOTHCORNERS;
@@ -1626,7 +1626,7 @@ drcSurround(argc, argv)
 		{
 		    /* Find bucket preceding the new one we wish to insert */
 		    dp = drcFindBucket(i, j, distance);
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew, distance, dp->drcc_next,
 				set2, invM, why, distance, DRC_FORWARD, plane2);
 		    dpnew->drcc_flags |= DRC_BOTHCORNERS | DRC_XPLANE;
@@ -1634,7 +1634,7 @@ drcSurround(argc, argv)
 
 		    /* find bucket preceding new one we wish to insert */
 		    dp = drcFindBucket(j, i, distance);
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew,distance,dp->drcc_next,
 				set2, invM, why, distance, DRC_REVERSE, plane2);
 		    dpnew->drcc_flags |= DRC_BOTHCORNERS | DRC_XPLANE;
@@ -1834,7 +1834,7 @@ drcRectangle(argc, argv)
 
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(i, j, distance);
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next, 
 		    nottypes, DBAllTypeBits, why, distance, 
 		    DRC_FORWARD, plane);
@@ -1842,7 +1842,7 @@ drcRectangle(argc, argv)
 
 		/* Find bucket preceding the new one we wish to insert */
 		dp = drcFindBucket(j, i, distance); /* note: j, i not i, j */
-		MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		dpnew = (DRCCookie *) mallocMagic((unsigned) (sizeof (DRCCookie)));
 		ASSIGN(dpnew, distance, dp->drcc_next, 
 		    nottypes, DBAllTypeBits, why, distance, 
 		    DRC_REVERSE, plane);
@@ -1861,7 +1861,7 @@ drcRectangle(argc, argv)
 			    dp = dp->drcc_next)
 			; /* null body */
 
-		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
+		    dpnew = (DRCCookie *) mallocMagic ((unsigned) (sizeof (DRCCookie)));
 		    ASSIGN(dpnew, distance, dp->drcc_next, 
 			types, DBZeroTypeBits, why, even, 
 			DRC_RECTSIZE, plane);
@@ -2000,7 +2000,7 @@ DRCTechFinal()
 	    dpp = &( DRCRulesTbl [i][j]);
 	    dummy = *dpp;
 	    *dpp = dummy->drcc_next;
-	    FREE ((char *) dummy); 
+	    freeMagic((char *) dummy); 
 	}
     }
 
@@ -2030,6 +2030,14 @@ DRCTechFinal()
 		    if (TTMaskHasType(&dp->drcc_mask, i)) continue;
 		}
 		else if (TTMaskHasType(&dp->drcc_mask, j)) continue;
+
+		/* In magic 7.3, this edge may be legal on planes other	*/
+		/* than drcc_plane if i or j is a contact type or	*/
+		/* TT_SPACE.						*/
+
+		if (DBIsContact(i) || DBIsContact(j) || i == TT_SPACE ||
+			j == TT_SPACE) continue;
+
 		keep = dp;
 		goto illegalEdge;
 	    }
@@ -2044,7 +2052,7 @@ DRCTechFinal()
 	    {
 		if (dp == keep) continue;
 		/* Don't free the shared drcc_why string here! */
-		FREE((char *) dp);
+		freeMagic((char *) dp);
 		drcRulesOptimized += 1;
 	    }
 	    DRCRulesTbl[i][j] = keep;
@@ -2142,14 +2150,14 @@ DRCTechFinal()
 		/* Trigger rules */
 		if (dptrig != NULL)
 		{
-		    FREE((char *)dp->drcc_next);
+		    freeMagic((char *)dp->drcc_next);
 		    *dp2back = dp->drcc_next->drcc_next;
 		}
 		else
 		    *dp2back = dp->drcc_next;
 
 		/* Don't free the shared drcc_why string here! */
-		FREE ((char *) dp);
+		freeMagic((char *) dp);
 		drcRulesOptimized += 1;
 	    }
 	}
