@@ -23,7 +23,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2sim/ext2sim.c,v 1.5 20
 #include <math.h>	/* for sqrt() in bipolar L,W calculation */
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -45,6 +45,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2sim/ext2sim.c,v 1.5 20
 #ifdef MAGIC_WRAPPER
 void CmdExtToSim();
 #endif
+bool simnAP();
+bool simnAPHier();
 int simmainArgs();
 int simdevVisit(), simresistVisit(), simcapVisit(), simnodeVisit();
 int simmergeVisit();
@@ -104,14 +106,14 @@ typedef struct {
 
 #define initNodeClient(node) \
 { \
-	MALLOC(ClientData,(node)->efnode_client,sizeof(nodeClient)); \
+	(node)->efnode_client = (ClientData) mallocMagic((unsigned) (sizeof(nodeClient))); \
 	(( nodeClient *)(node)->efnode_client)->visitMask = (long) 0; \
 }
 
 
 #define initNodeClientHier(node) \
 { \
-	MALLOC(ClientData,(node)->efnode_client,sizeof(nodeClientHier)); \
+	(node)->efnode_client = (ClientData) mallocMagic((unsigned) (sizeof(nodeClientHier))); \
 	((nodeClientHier *) (node)->efnode_client)->visitMask = (long) 0; \
 }
 
@@ -130,13 +132,13 @@ int  esDevsMerged;
 #define addDevMult(f) \
 {  \
         if ( esFMult == NULL ) { \
-          MALLOC(float *, esFMult, esFMSize*sizeof(float));  \
+          esFMult = (float *) mallocMagic((unsigned) (esFMSize*sizeof(float)));  \
         } else if ( esFMIndex >= esFMSize ) {  \
           int i;  \
           float *op = esFMult ;  \
-          MALLOC(float *, esFMult, (esFMSize = esFMSize*2)*sizeof(float)); \
+          esFMult = (float *) mallocMagic((unsigned) ((esFMSize = esFMSize*2)*sizeof(float))); \
           for ( i = 0 ; i < esFMSize/2 ; i++ ) esFMult[i] = op[i]; \
-          if (op) FREE(op); \
+          if (op) freeMagic(op); \
         }  \
         esFMult[esFMIndex++] = (float)(f); \
 }
@@ -426,13 +428,13 @@ CmdExtToSim(w, cmd)
 	    EFScale = 0;
 	    if (EFArgTech)
 	    {
-		FREE(EFArgTech);
+		freeMagic(EFArgTech);
 		EFArgTech = NULL;
 	    }
 	    if (EFSearchPath)
 	    {
-		FREE(EFSearchPath);
-		EFArgTech = NULL;
+		freeMagic(EFSearchPath);
+		EFSearchPath = NULL;
 	    }
 	    break;
 	case EXTTOSIM_RUN:
@@ -451,6 +453,7 @@ usage:
 runexttosim:
 
     esDevsMerged = 0;
+    esFMIndex = 0;
 
     EFInit();
 
@@ -604,7 +607,7 @@ runexttosim:
 	TxPrintf("Devices merged: %d\n", esDevsMerged);
 	esFMIndex = 0;
 	for (p = devMergeList; p != NULL; p = p->next)
-	    FREE(p);
+	    freeMagic(p);
 	devMergeList = NULL;
     }
 
@@ -731,7 +734,7 @@ main(argc, argv)
 	EFVisitDevs(simmergeVisit, (ClientData) NULL);
 	TxPrintf("Devices merged: %d\n", esDevsMerged);
 	esFMIndex = 0;
-	for (p = devMergeList; p != NULL; p = p->next) FREE(p);
+	for (p = devMergeList; p != NULL; p = p->next) freeMagic(p);
     }
 
     EFVisitDevs(simdevVisit, (ClientData) NULL);
@@ -875,7 +878,7 @@ simmainArgs(pargc, pargv)
 	    ndx = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, cp);
 	    fetInfo[ndx].resClassSD = rClass;
 	    fetInfo[ndx].resClassSub = rClassSub;
-	    MALLOC(char *, fetInfo[ndx].defSubs, (strlen(subsNode)+1));
+	    fetInfo[ndx].defSubs = (char *) mallocMagic((unsigned) (strlen(subsNode)+1));
 	    strcpy(fetInfo[ndx].defSubs,subsNode);
 	    TxError("Info: fet %s(%d) sdRclass=%d subRclass=%d dSub=%s\n", 
 	    	cp, ndx, fetInfo[ndx].resClassSD, fetInfo[ndx].resClassSub, 
@@ -1020,8 +1023,11 @@ simdevVisit(dev, hierName, trans)
 	    break;
     }
 
-    /* Output gate, source, and drain node names */
-    simdevOutNode(hierName, gate->dterm_node->efnode_name->efnn_hier, name, esSimF);
+    /* Output gate node name.  Resistor devices don't generate this node. */
+    if (dev->dev_class != DEV_RES)
+       simdevOutNode(hierName, gate->dterm_node->efnode_name->efnn_hier, name, esSimF);
+
+    /* Output source and drain node names */
     if (dev->dev_nterm > 1)
 	simdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier, name, esSimF);
 
@@ -1049,8 +1055,8 @@ simdevVisit(dev, hierName, trans)
     GeoTransRect(trans, &dev->dev_rect, &r);
     scale = GeoScale(trans);
 
-    if (dev->dev_class == DEV_BJT || EFDevTypes[dev->dev_type][0] == 'b') {
-
+    if (dev->dev_class == DEV_BJT || EFDevTypes[dev->dev_type][0] == 'b')
+    {
        /* Bipolar sim format:  We don't have the length and width
 	* of the collector well, but we can get it from the area
 	* and perimeter measurements; hopefully any strict netlist
@@ -1223,7 +1229,7 @@ FILE *outf;
  * ----------------------------------------------------------------------------
  */
  
-int simnAP(node, resClass, scale, outf)
+bool simnAP(node, resClass, scale, outf)
 EFNode *node;
 int  resClass, scale;
 FILE *outf;
@@ -1246,7 +1252,7 @@ FILE *outf;
 	return TRUE;
 }
 
-int simnAPHier(dterm, hierName, resClass, scale, outf)
+bool simnAPHier(dterm, hierName, resClass, scale, outf)
     DevTerm *dterm;
     HierName *hierName;
     int  resClass, scale;
@@ -1515,7 +1521,7 @@ Dev    *dev;
 {
 	   devMerge *fp;
 
-	MALLOC (devMerge *, fp, sizeof(devMerge));
+	fp = (devMerge *) mallocMagic((unsigned) (sizeof(devMerge)));
 	fp->l = l; fp->w = w;
 	fp->g = g; fp->s = s;
 	fp->d = d; fp->b = b;
@@ -1578,9 +1584,9 @@ Dev    *dev;
 		char *t; \
 		int l1 = strlen(a1); \
 		int l2 = strlen(a2); \
-		MALLOC(char *, t, (l1+l2)+1); \
+		t = (char *) mallocMagic((unsigned) (l1+l2)+1); \
 		t = (char *) strcat(a1,a2); \
-		FREE(a1); \
+		freeMagic(a1); \
 		a1 = t ; \
 	} \
 }
@@ -1602,17 +1608,16 @@ Dev    *dev;
  * ----------------------------------------------------------------------------
  */
 int
-simmergeVisit(dev, hierName, trans, l, w)
+simmergeVisit(dev, hierName, trans)
 Dev *dev;		/* Dev to examine */
 HierName *hierName;	/* Hierarchical path down to this dev */
 Transform *trans;	/* Coordinate transform not used */
-int l, w;
 {
 	DevTerm *gate, *source, *drain;
 	Dev     *cf;
 	DevTerm *cg, *cs, *cd;
 	EFNode	*subnode, *snode, *dnode, *gnode;
-	int      scale, pmode;
+	int      scale, pmode, l, w;
     	Rect	 r;
 	float	 m;
 	devMerge *fp, *cfp;
@@ -1634,6 +1639,7 @@ int l, w;
 
     	GeoTransRect(trans, &dev->dev_rect, &r);
     	scale = GeoScale(trans);
+	EFGetLengthAndWidth(dev, &l, &w);
 	fp = simmkDevMerge(l*scale, w*scale, gnode, snode, 
 			dnode, subnode, hierName, dev);
 
@@ -1660,7 +1666,7 @@ int l, w;
 		setDevMult(fp->esFMIndex, DEV_KILLED); 
 		setDevMult(cfp->esFMIndex, m);
 		esDevsMerged++;
-		FREE(fp);
+		freeMagic(fp);
 		return 0;
 	  }
 	}
