@@ -24,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2spice/ext2spice.c,v 1.
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
@@ -60,6 +60,7 @@ char *nodeSpiceName();
 /* Options specific to ext2spice */
 bool esDoExtResis = FALSE;
 bool esDoPorts = TRUE;
+bool esDoResistorTee = FALSE;
 int  esDoSubckt = AUTO;
 bool esDevNodesOnly = FALSE;
 bool esNoAttrs = FALSE;
@@ -78,8 +79,9 @@ float esScale = -1.0 ; /* negative if hspice the EFScale/100 otherwise */
 static unsigned short esFormat = SPICE3 ;
 
 int esCapNum, esDevNum, esResNum, esDiodeNum;
-int esNodeNum; /* just in case we' re extracting spice2 */
-int esSbckNum; /* used in hspice node name shortening   */
+int esNodeNum;  /* just in case we' re extracting spice2 */
+int esSbckNum; 	/* used in hspice node name shortening   */
+int esNoModelType;  /* index for device type "None" (model-less device) */
 
 /*
  * The following hash table and associated functions are used only if 
@@ -142,7 +144,7 @@ unsigned long	initMask = 0;
 
 #define initNodeClient(node) \
 { \
-	MALLOC(ClientData,(node)->efnode_client,sizeof(nodeClient)); \
+	(node)->efnode_client = (ClientData) mallocMagic((unsigned) (sizeof(nodeClient))); \
 	 (( nodeClient *)(node)->efnode_client)->spiceNodeName = NULL; \
 	(( nodeClient *)(node)->efnode_client)->m_w.visitMask = (unsigned long)initMask; \
 }
@@ -150,7 +152,7 @@ unsigned long	initMask = 0;
 
 #define initNodeClientHier(node) \
 { \
-	MALLOC(ClientData,(node)->efnode_client,sizeof(nodeClientHier)); \
+	(node)->efnode_client = (ClientData) mallocMagic((unsigned)(sizeof(nodeClientHier))); \
 	((nodeClientHier *) (node)->efnode_client)->m_w.visitMask = (unsigned long) 0; \
 }
 
@@ -193,13 +195,13 @@ int nodeVisitDebug();
 #define addDevMult(f) \
 {  \
 	if ( esFMult == NULL ) { \
-	  MALLOC(float *, esFMult, esFMSize*sizeof(float));  \
+	  esFMult = (float *) mallocMagic((unsigned) (esFMSize*sizeof(float)));  \
 	} else if ( esFMIndex >= esFMSize ) {  \
 	  int i;  \
 	  float *op = esFMult ;  \
-	  MALLOC(float *, esFMult, (esFMSize = esFMSize*2)*sizeof(float)); \
+	  esFMult = (float *) mallocMagic((unsigned) ((esFMSize = esFMSize*2)*sizeof(float))); \
 	  for ( i = 0 ; i < esFMSize/2 ; i++ ) esFMult[i] = op[i]; \
-	  if (op) FREE(op); \
+	  if (op) freeMagic(op); \
 	}  \
 	esFMult[esFMIndex++] = (float)(f); \
 }
@@ -222,13 +224,14 @@ devMerge *devMergeList = NULL ;
 
 
 
+void topVisit();
+
 #ifdef MAGIC_WRAPPER
 
 #define 	atoCap(s)	((EFCapValue)atof(s))
 
 /* Forward declaration */
 int _ext2spice_start();
-void topVisit();
 
 /*
  * ----------------------------------------------------------------------------
@@ -279,8 +282,9 @@ Exttospice_Init(interp)
 #define EXTTOSPC_CTHRESH	4
 #define EXTTOSPC_MERGE		5
 #define EXTTOSPC_EXTRESIST	6
-#define EXTTOSPC_SUBCIRCUITS	7
-#define EXTTOSPC_HELP		8
+#define EXTTOSPC_RESISTORTEE	7
+#define EXTTOSPC_SUBCIRCUITS	8
+#define EXTTOSPC_HELP		9
 
 void
 CmdExtToSpice(w, cmd)
@@ -317,6 +321,7 @@ CmdExtToSpice(w, cmd)
 	"cthresh [<value>]	set capacitance threshold value",
 	"merge [<type>]		merge parallel transistors",
 	"extresist [on|off]	incorporate information from extresist",
+	"resistor tee [on|off]	model resistor capacitance as a T-network",
 	"subcircuits [on|off]	standard cells become subcircuit calls",
 	"help			print help information",
 	NULL
@@ -354,6 +359,8 @@ CmdExtToSpice(w, cmd)
 	IDX_AUTO, IDX_TOP, IDX_DESCEND
     } yesnoType;  
 
+    esNoModelType = -1;
+
     if (cmd->tx_argc > 1)
     {
 	option = Lookup(cmd->tx_argv[1], cmdExtToSpcOption);
@@ -377,6 +384,20 @@ CmdExtToSpice(w, cmd)
 	    else esDoExtResis = FALSE;
 	    break;
 
+	case EXTTOSPC_RESISTORTEE:
+	    if (cmd->tx_argc == 3)
+	    {
+		Tcl_SetResult(magicinterp, (esDoResistorTee) ? "on" : "off", NULL);
+		return;
+	    }
+	    else if (cmd->tx_argc != 4)
+		goto usage;
+	    idx = Lookup(cmd->tx_argv[3], yesno);
+	    if (idx < 0) goto usage;
+	    else if (idx < 3) esDoResistorTee = TRUE;
+	    else esDoResistorTee = FALSE;
+	    break;
+
 	case EXTTOSPC_SUBCIRCUITS:
 	    if (cmd->tx_argc == 2)
 	    {
@@ -541,13 +562,13 @@ CmdExtToSpice(w, cmd)
 	    EFScale = 0;
 	    if (EFArgTech)
 	    {
-		FREE(EFArgTech);
+		freeMagic(EFArgTech);
 		EFArgTech = NULL;
 	    }
 	    if (EFSearchPath)
 	    {
-		FREE(EFSearchPath);
-		EFArgTech = NULL;
+		freeMagic(EFSearchPath);
+		EFSearchPath = NULL;
 	    }
 	    break;
 
@@ -574,7 +595,7 @@ runexttospice:
     esDiodeNum = 0;
     esSbckNum = 0;
     esNodeNum = 10; /* just in case we're extracting spice2 */
-
+    esFMIndex = 0;
     esDevsMerged = 0;
 
     EFInit();
@@ -666,6 +687,8 @@ runexttospice:
 	    break;
 	}
 	i = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, devname);
+	if (!strcmp(devname, "None"))
+	    esNoModelType = i;
 	if (EFStyle != NULL)
 	{
 	    fetInfo[i].resClassSD = sd_rclass;
@@ -736,7 +759,7 @@ runexttospice:
 	    devMerge *p;
 
 	    for (p = devMergeList; p != NULL; p = p->next)
-		FREE(p);
+		freeMagic(p);
 	    devMergeList = NULL;
 	}
     }
@@ -790,6 +813,7 @@ main(argc, argv)
     int i,flatFlags;
     char *inName;
     FILE *f;
+    bool locDoSubckt;
 
     esDevsMerged = 0;
 
@@ -890,7 +914,7 @@ main(argc, argv)
 	{
 	  devMerge *p;
 
-	  for ( p = devMergeList ; p != NULL ; p=p->next ) FREE(p);
+	  for ( p = devMergeList ; p != NULL ; p=p->next ) freeMagic(p);
 	}
     } else if ( esDistrJunct )
      	EFVisitDevs(devDistJunctVisit, (ClientData) NULL);
@@ -1038,7 +1062,7 @@ spcmainArgs(pargc, pargv)
 	        TxError("DEV_CONNECT_MASK and or nodeClient\n");
 		exit (1);
 	    }
-	    MALLOC(char *, fetInfo[ndx].defSubs, (strlen(subsNode)+1));
+	    fetInfo[ndx].defSubs = (char *) mallocMagic((unsigned) (strlen(subsNode)+1));
 	    strcpy(fetInfo[ndx].defSubs,subsNode);
 	    TxError("info: dev %s(%d) sdRclass=%d subRclass=%d dSub=%s\n", 
 	    cp, ndx, fetInfo[ndx].resClassSD, fetInfo[ndx].resClassSub, 
@@ -1117,20 +1141,22 @@ HierName *suffix;
  *
  * ----------------------------------------------------------------------------
  */
+
 bool extHierSDAttr(term)
-DevTerm *term;
+    DevTerm *term;
 {
     bool r = esHierAP;
 
-    if (term->dterm_attrs) {
-	if  ( Match(ATTR_HIERAP, term->dterm_attrs ) != FALSE ) 
-		r = TRUE ;
-	else if ( Match(ATTR_FLATAP, term->dterm_attrs ) != FALSE )
-		r = FALSE ;
+    if (term->dterm_attrs)
+    {
+	if (Match(ATTR_HIERAP, term->dterm_attrs) != FALSE) 
+	    r = TRUE;
+	else if (Match(ATTR_FLATAP, term->dterm_attrs) != FALSE)
+	    r = FALSE;
     }
     return r;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1378,6 +1404,87 @@ topVisit(def)
     fprintf(esSpiceF, "\n");
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * esOutputResistor ---
+ *
+ * Routine used by spcdevVisit to print a resistor device.  This
+ * is broken out into a separate routine so that each resistor
+ * device may be represented (if the option is selected) by a
+ * "tee" network of two resistors on either side of the central
+ * node, which then has a capacitance to ground.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Output to the SPICE deck.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+esOutputResistor(dev, hierName, trans, term1, term2, has_model, l, w, dscale)
+    Dev *dev;			/* Dev being output */
+    HierName *hierName;		/* Hierarchical path down to this dev */
+    Transform *trans;		/* Coordinate transform for output */
+    DevTerm *term1, *term2;	/* Terminals of the device */
+    bool has_model;		/* Is this a modeled resistor? */
+    int l, w;			/* Device length and width */
+    int dscale;			/* Device scaling (for split resistors) */
+{
+    int scale;
+    Rect r;
+    float sdM ; 
+    char name[12], devchar;
+
+    /* Resistor is "Rnnn term1 term2 value" 		 */
+    /* extraction sets two terminals, which are assigned */
+    /* term1=gate term2=source by the above code.	 */
+    /* extracted units are Ohms; output is in Ohms 	 */
+
+    spcdevOutNode(hierName, term1->dterm_node->efnode_name->efnn_hier,
+			name, esSpiceF);
+    spcdevOutNode(hierName, term2->dterm_node->efnode_name->efnn_hier,
+			name, esSpiceF);
+
+    sdM = getCurDevMult();
+
+    /* SPICE has two resistor types.  If the "name" (EFDevTypes) is */
+    /* "None", the simple resistor type is used, and a value given. */
+    /* If not, the "semiconductor resistor" is used, and L and W    */
+    /* and the device name are output.				    */
+
+    if (!has_model)
+    {
+	fprintf(esSpiceF, " %f", (double)sdM *
+			(double)(dev->dev_values.dev_res)
+			/ (double)(dscale));
+    }
+    else
+    {
+	fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
+
+	GeoTransRect(trans, &dev->dev_rect, &r);
+	scale = GeoScale(trans);
+
+	if (esFormat == HSPICE)
+	{
+	    fprintf(esSpiceF, " w=%d l=%d", w * scale, (l * scale) / dscale);
+	    if (sdM != 1.0)
+		fprintf(esSpiceF, " M=%g", sdM);
+	}
+	else
+	{
+	    fprintf(esSpiceF, " w=%gu l=%gu",
+		(float)w * scale * esScale * sdM,
+		(float)((l * scale * esScale) / dscale));
+	    sdM = 1.0;
+	}
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1424,8 +1531,9 @@ spcdevVisit(dev, hierName, trans)
     int scale, l, w;
     Rect r;
     bool subAP= FALSE, hierS, hierD, extHierSDAttr() ;
-    float sdM ; 
+    float sdM; 
     char name[12], devchar;
+    bool has_model = TRUE;
 
     sprintf(name, "output");
 
@@ -1453,6 +1561,19 @@ spcdevVisit(dev, hierName, trans)
 
     if (!strcmp(EFDevTypes[dev->dev_type], "npn")) dev->dev_class = DEV_BJT;
 
+    /* For resistor and capacitor classes, set a boolean to	*/
+    /* denote whether the device has a model or not, so we	*/
+    /* don't have to keep doing a string compare on EFDevTypes.	*/
+
+    switch(dev->dev_class)
+    {
+	case DEV_RES:
+	case DEV_CAP:
+	    if (dev->dev_type == esNoModelType)
+		has_model = FALSE;
+	    break;
+    }
+
     /* Generate SPICE device name */
     switch(dev->dev_class)
     {
@@ -1473,6 +1594,7 @@ spcdevVisit(dev, hierName, trans)
 	    devchar = 'C';
 	    break;
 	case DEV_SUBCKT:
+	case DEV_RSUBCKT:
 	    devchar = 'X';
 	    break;
     }
@@ -1489,6 +1611,9 @@ spcdevVisit(dev, hierName, trans)
 	{
 	    case DEV_RES:
 		fprintf(esSpiceF, "%d", esResNum++);
+		/* For resistor tee networks, use, e.g.,	*/
+		/* "R1A" and "R1B", for clarity			*/
+		if (esDoResistorTee) fprintf(esSpiceF, "A");
 		break;
 	    case DEV_DIODE:
 		fprintf(esSpiceF, "%d", esDiodeNum++);
@@ -1497,6 +1622,7 @@ spcdevVisit(dev, hierName, trans)
 		fprintf(esSpiceF, "%d", esCapNum++);
 		break;
 	    case DEV_SUBCKT:
+	    case DEV_RSUBCKT:
 		fprintf(esSpiceF, "%d", esSbckNum++);
 		break;
 	    default:
@@ -1504,7 +1630,6 @@ spcdevVisit(dev, hierName, trans)
 		break;
 	}
     }
-
     /* Order and number of nodes in the output depends on the device class */
 
     switch (dev->dev_class)
@@ -1538,6 +1663,14 @@ spcdevVisit(dev, hierName, trans)
 
 	    spcdevOutNode(hierName, gate->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
+
+	    /* Drop through to below (no break statement) */
+
+	case DEV_RSUBCKT:
+	    /* RC-like subcircuits are exactly like other subcircuits	*/
+	    /* except that the "gate" node is treated as an identifier	*/
+	    /* only and is not output.					*/
+
 	    if (dev->dev_nterm > 1)
 		spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
@@ -1553,16 +1686,16 @@ spcdevVisit(dev, hierName, trans)
 	    }
 	    fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
 
-	    /* If this thing looks like a FET (3 or 4 terminals), then	*/
-	    /* write its length and width.				*/
+	    /* Write its length and width and pass them as	*/
+	    /* parameters to the subcircuit call.		*/
 
-	    if (dev->dev_nterm > 2)
+	    GeoTransRect(trans, &dev->dev_rect, &r);
+	    scale = GeoScale(trans);
+
+	    sdM = getCurDevMult();
+
+	    if ((w > 0) && (l > 0))
 	    {
-		GeoTransRect(trans, &dev->dev_rect, &r);
-		scale = GeoScale(trans);
-
-		sdM = getCurDevMult();
-
 		if (esFormat == HSPICE)
 		{
 		    fprintf(esSpiceF, " w=%d l=%d", w*scale, l*scale);
@@ -1580,47 +1713,36 @@ spcdevVisit(dev, hierName, trans)
 	    break;
 
 	case DEV_RES:
-
-	    /* Resistor is "Rnnn term1 term2 value" 		 */
-	    /* extraction sets two terminals, which are assigned */
-	    /* term1=gate term2=source by the above code.	 */
-	    /* extracted units are Ohms; output is in Ohms 	 */
-
-	    spcdevOutNode(hierName, gate->dterm_node->efnode_name->efnn_hier,
-			name, esSpiceF);
-	    spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
-			name, esSpiceF);
-
-	    /* SPICE has two resistor types.  If the "name" (EFDevTypes) is */
-	    /* "None", the simple resistor type is used, and a value given. */
-	    /* If not, the "semiconductor resistor" is used, and L and W    */
-	    /* and the device name are output.				    */
-
-	    if (!strcmp(EFDevTypes[dev->dev_type], "None"))
+	    if (esDoResistorTee)
 	    {
-		fprintf(esSpiceF, " %f", (double)(dev->dev_values.dev_res));
+		/* There are three ways of handling capacitance	*/
+		/* on resistor networks.  One is to ignore it	*/
+		/* (the default; generates "floating" nodes in	*/
+		/* the SPICE output) which is okay for LVS. 	*/
+		/* Another way is the Pi network, in which the	*/
+		/* capacitance is split evenly between the	*/
+		/* terminals.  Again, the resistor node is left	*/
+		/* floating.  The third is the Tee network, in	*/
+		/* which the resistance is split in two parts,	*/
+		/* connecting to a capacitor to ground in the	*/
+		/* middle.  This is the best solution but plays	*/
+		/* havoc with LVS.  So, the choice is a command	*/
+		/* line option.					*/
+
+		esOutputResistor(dev, hierName, trans, gate, source, has_model,
+			l, w, 2);
+		fprintf(esSpiceF, "\n%c", devchar);
+		if (gate->dterm_attrs)
+		    fprintf(esSpiceF, "%sB", gate->dterm_attrs);
+		else
+		    fprintf(esSpiceF, "%dB", esResNum - 1);
+		esOutputResistor(dev, hierName, trans, gate, drain, has_model,
+			l, w, 2);
 	    }
 	    else
 	    {
-		fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
-
-		GeoTransRect(trans, &dev->dev_rect, &r);
-		scale = GeoScale(trans);
-		sdM = getCurDevMult();
-
-		if (esFormat == HSPICE)
-		{
-		    fprintf(esSpiceF, " w=%d l=%d", w*scale, l*scale);
-		    if (sdM != 1.0)
-			fprintf(esSpiceF, " M=%g", sdM);
-		}
-		else
-		{
-		    fprintf(esSpiceF, " w=%gu l=%gu",
-			(float)w * scale * esScale * sdM,
-			(float)l * scale * esScale);
-		    sdM = 1.0;
-		}
+		esOutputResistor(dev, hierName, trans, source, drain, has_model,
+			l, w, 1);
 	    }
 	    break;
 
@@ -1646,14 +1768,17 @@ spcdevVisit(dev, hierName, trans)
 	    spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
 
+	    sdM = getCurDevMult();
+
 	    /* SPICE has two capacitor types.  If the "name" (EFDevTypes) is */
 	    /* "None", the simple capacitor type is used, and a value given. */
 	    /* If not, the "semiconductor capacitor" is used, and L and W    */
 	    /* and the device name are output.				     */
 
-	    if (!strcmp(EFDevTypes[dev->dev_type], "None"))
+	    if (!has_model)
 	    {
-		fprintf(esSpiceF, " %ffF", (double)(dev->dev_values.dev_cap));
+		fprintf(esSpiceF, " %ffF", (double)sdM *
+				(double)(dev->dev_values.dev_cap));
 	    }
 	    else
 	    {
@@ -1661,7 +1786,6 @@ spcdevVisit(dev, hierName, trans)
 
 		GeoTransRect(trans, &dev->dev_rect, &r);
 		scale = GeoScale(trans);
-		sdM = getCurDevMult();
 
 		if (esFormat == HSPICE)
 		{
@@ -2292,61 +2416,69 @@ char *efHNSprintfPrefix(hierName, str)
  *
  * ----------------------------------------------------------------------------
  */
+
 int nodeHspiceName(s)
-char *s;
+    char *s;
 {
-	char *p, *sf;
-	int l, snum=-1 ;
-	HashEntry *he;
-	static char map[MAX_STR_SIZE];
+    char *p, *sf;
+    int l, snum = -1;
+    HashEntry *he;
+    static char map[MAX_STR_SIZE];
 
-	/*
-	 * find the suffix 
-	 */
-	l = strlen(s);
-	for ( p = s+l ; (p > s) && *p != '/'  ; p-- ) ; 
-	if ( p == s ) {
-		sprintf(map, s);
-		goto topLevel;
-	}
-	/* 
-	 * break it into prefix '/0' suffix 
-	 */
-	if ( *p == '/' ) 
-	   *p = 0; 
-	sf = p+1;
+    /*
+     * find the suffix 
+     */
+    l = strlen(s);
+    for (p = s + l; (p > s) && *p != '/'; p--); 
+    if (p == s)
+    {
+	sprintf(map, s);
+	goto topLevel;
+    }
 
-	/* 
-	 * look up prefix in the hash table ad create it if doesnt exist 
-	 */
-	if ( (he = HashLookOnly(&subcktNameTable, s)) == NULL ) {
-	        snum = esSbckNum++;
-		he = HashFind(&subcktNameTable, s);
-		HashSetValue(he, (ClientData) snum);
+    /* 
+     * break it into prefix '/0' suffix 
+     */
+    if (*p == '/') 
+	*p = 0; 
+    sf = p + 1;
+
+    /* 
+     * look up prefix in the hash table ad create it if doesnt exist 
+     */
+    if ((he = HashLookOnly(&subcktNameTable, s)) == NULL)
+    {
+        snum = esSbckNum++;
+	he = HashFind(&subcktNameTable, s);
+	HashSetValue(he, (ClientData) snum);
 #ifndef UNSORTED_SUBCKT
-		DQPushRear(&subcktNameQueue, he);
+	DQPushRear(&subcktNameQueue, he);
 #endif
-	}
-	else 
-		snum = (int) HashGetValue(he);
-	sprintf(map, "x%d/%s", snum, sf);
+    }
+    else 
+	snum = (int) HashGetValue(he);
+    sprintf(map, "x%d/%s", snum, sf);
+
 topLevel:
-	strcpy(s, map);
-	if ( strlen(s) > 15 ) { /* still hspice does not get it */
-		sprintf(s, "z@%d", esNodeNum++);
-		if ( strlen(s) > 15 )
-		{ /* screw it: hspice will not work */
-		    TxError("Error: too many nodes in this circuit to be "
-				"output as names\n");
-		    TxError("       use spice2 format or call and complain "
-				"to Meta software about their stupid parser\n");
+    strcpy(s, map);
+    if (strlen(s) > 15)
+    {
+	/* still hspice does not get it */
+	sprintf(s, "z@%d", esNodeNum++);
+	if (strlen(s) > 15)
+	{
+	    /* screw it: hspice will not work */
+	    TxError("Error: too many nodes in this circuit to be "
+			"output as names\n");
+	    TxError("       use spice2 format or call and complain "
+			"to Meta software about their stupid parser\n");
 #ifdef MAGIC_WRAPPER
-		    return TCL_ERROR;
+	    return TCL_ERROR;
 #else
-		  exit(1);
+	    exit(1);
 #endif
-		}
 	}
+    }
 }
 
 /*
@@ -2366,20 +2498,21 @@ topLevel:
  *
  * ----------------------------------------------------------------------------
  */
+
 int printSubcktDict()
 {
-	HashSearch  hs;
-	HashEntry  *he;
+    HashSearch  hs;
+    HashEntry  *he;
 
-	fprintf(esSpiceF,"\n** hspice subcircuit dictionary\n");
+    fprintf(esSpiceF,"\n** hspice subcircuit dictionary\n");
 
 #ifndef UNSORTED_SUBCKT
-	while (  (he = ( HashEntry *) DQPopFront(&subcktNameQueue) ) != NULL )
+    while ((he = (HashEntry *)DQPopFront(&subcktNameQueue)) != NULL)
 #else
-	HashStartSearch(&hs);
-	while ( (he = HashNext(&subcktNameTable, &hs)) != NULL ) 
+    HashStartSearch(&hs);
+    while ((he = HashNext(&subcktNameTable, &hs)) != NULL) 
 #endif
-	   fprintf(esSpiceF,"* x%d\t%s\n", HashGetValue(he), he->h_key.h_name);
+	fprintf(esSpiceF,"* x%d\t%s\n", HashGetValue(he), he->h_key.h_name);
 }
 
 /*
@@ -2396,64 +2529,132 @@ int printSubcktDict()
  *
  * ----------------------------------------------------------------------------
  */
+
 devMerge *mkDevMerge(l, w, g, s, d, b, hn, dev)
-int     l, w;
-EFNode *g, *s, *d, *b;
-HierName *hn;
-Dev    *dev;
+    int     l, w;
+    EFNode *g, *s, *d, *b;
+    HierName *hn;
+    Dev    *dev;
 {
-	   devMerge *fp;
+    devMerge *fp;
 
-	MALLOC (devMerge *, fp, sizeof(devMerge));
-	fp->l = l; fp->w = w;
-	fp->g = g; fp->s = s;
-	fp->d = d; fp->b = b;
-	fp->dev = dev;
-	fp->esFMIndex = esFMIndex;
-	fp->hierName = hn;
-	fp->next = NULL;
-	addDevMult(1.0);
+    fp = (devMerge *) mallocMagic((unsigned) (sizeof(devMerge)));
+    fp->l = l; fp->w = w;
+    fp->g = g; fp->s = s;
+    fp->d = d; fp->b = b;
+    fp->dev = dev;
+    fp->esFMIndex = esFMIndex;
+    fp->hierName = hn;
+    fp->next = NULL;
+    addDevMult(1.0);
 
-	return fp;
+    return fp;
 }
 
-
-
 /*
  * ----------------------------------------------------------------------------
  *
  * parallelDevs --
- * Macro to look if two devs are in parallel
+ *
+ * Determine if two devs are in parallel
  *
  * Results:
  *    NOT_PARALLEL  if not in parallel
- *    PARALLEL      if s==s d==d and g==g and bulk=bulk
- *    FLIP_PARALLEL if s==d d==s --->>----------------
+ *    PARALLEL      if parallel and an exact match
+ *    ANTIPARALLEL  if parallel but reversed source<->drain nodes
  *
  * Side effects:
  *	None.
  *
  * ----------------------------------------------------------------------------
  */
+
 #define	NOT_PARALLEL	0
 #define	PARALLEL	1
-#define	PARALLEL_R	2
+#define	ANTIPARALLEL	2
 
-#define parallelDevs(f1, f2) \
-( \
-	( (f1)->g == (f2)->g && (f1)->b == (f2)->b && (f1)->l == (f2)->l && \
-	  ( esMergeDevsA || (f1)->w == (f2)->w ) )  ? \
-	   ( ((f1)->d == (f2)->d && (f1)->s == (f2)->s ) ? \
-	       PARALLEL : \
-	      (((f1)->s == (f2)->d && (f1)->d == (f2)->s ) ? PARALLEL_R : NOT_PARALLEL) )\
-	  : NOT_PARALLEL  \
-)
+int
+parallelDevs(f1, f2)
+    devMerge *f1, *f2;
+{
+    /* If the devices are not in the same class, then	*/
+    /* they cannot be parallel.				*/
+
+    if (f1->dev->dev_class != f2->dev->dev_class)
+	return NOT_PARALLEL;
+
+    /* Can't merge devices with different models */
+    if (f1->dev->dev_type != f2->dev->dev_type)
+	return NOT_PARALLEL;
+
+    /* Class-dependent action */
+    switch(f1->dev->dev_class)
+    {
+	case DEV_MOSFET:
+	case DEV_FET:
+
+	    if (f1->b != f2->b) return NOT_PARALLEL;
+	    if ((f1->g == f2->g) && (f1->l == f2->l)
+			&& (esMergeDevsA || (f1->w == f2->w)))
+	    {
+		if ((f1->d == f2->d) && (f1->s == f2->s))
+		    return PARALLEL;
+		else if ((f1->s == f2->d) && (f1->d == f2->s))
+		    return ANTIPARALLEL;
+	    }
+	    break;
+
+	/* Capacitors match if top ("gate") and bottom ("source") are	*/
+	/* the same.  Do not attempt to swap top and bottom, as we do	*/
+	/* not know when it is safe to do so.				*/
+
+	case DEV_CAP:
+	    if ((f1->g != f2->g) || (f1->s != f2->s))
+		return NOT_PARALLEL;
+
+	    else if (f1->dev->dev_type == esNoModelType)
+	    {
+		/* Unmodeled capacitor */
+		if (esMergeDevsA || (f1->dev->dev_values.dev_cap
+				== f2->dev->dev_values.dev_cap))
+		    return PARALLEL;
+	    }
+	    else if (esMergeDevsA || ((f1->l == f2->l) && (f1->w == f2->w)))
+		return PARALLEL;
+	    break;
+
+	/* We can't merge resistors because we accumulate capacitance	*/
+	/* on the central ("gate") node.  Merging the devices would	*/
+	/* cause nodes to disappear.					*/
+
+	case DEV_RES:
+	    break;
+
+	/* For the remaining devices, it might be possible to merge	*/
+	/* if we know that the device model level accepts length and	*/
+	/* width parameters.  However, at this time, no such		*/
+	/* information is passed to the SPICE deck, so we don't try to	*/
+	/* merge these devices.						*/
+
+	case DEV_BJT:
+	case DEV_DIODE:
+	    break;
+
+	/* There is no way to merge subcircuit devices */
+
+	case DEV_SUBCKT:
+	case DEV_RSUBCKT:
+	    break;
+    }
+    return NOT_PARALLEL;
+}
 
 /*
  * ----------------------------------------------------------------------------
  *
  * mergeAttr --
- * Macro to merge two attribute strings
+ *
+ * merge two attribute strings
  *
  * Results:
  *  The merged strings
@@ -2463,20 +2664,25 @@ Dev    *dev;
  *
  * ----------------------------------------------------------------------------
  */
-#define	mergeAttr(a1, a2) { \
-	if ( a1 == NULL ) a1 = a2 ; \
-	else { \
-		char *t; \
-		int l1 = strlen(a1); \
-		int l2 = strlen(a2); \
-		MALLOC(char *, t, (l1+l2)+1); \
-		t = (char *) strcat(a1,a2); \
-		FREE(a1); \
-		a1 = t ; \
-	} \
+
+void
+mergeAttr(a1, a2)
+    char **a1, **a2;
+{
+    if (*a1 == NULL)
+	*a1 = *a2;
+    else
+    {
+	char *t;
+	int l1 = strlen(*a1);
+	int l2 = strlen(*a2);
+	t = (char *) mallocMagic((unsigned int)((l1 + l2) + 1));
+	t = (char *) strcat(*a1, *a2);
+	freeMagic(*a1);
+	*a1 = t;
+    }
 }
 
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2492,109 +2698,149 @@ Dev    *dev;
  *
  * ----------------------------------------------------------------------------
  */
+
 int
-devMergeVisit(dev, hierName, trans, l, w)
-Dev *dev;		/* Dev to examine */
-HierName *hierName;		/* Hierarchical path down to this dev */
-Transform *trans;		/* Coordinate transform not used */
-int l, w;
+devMergeVisit(dev, hierName, trans)
+    Dev *dev;			/* Dev to examine */
+    HierName *hierName;		/* Hierarchical path down to this dev */
+    Transform *trans;		/* Coordinate transform not used */
 {
-	DevTerm *gate, *source, *drain;
-	Dev     *cf;
-	DevTerm *cg, *cs, *cd;
-	EFNode *subnode, *snode, *dnode, *gnode;
-	int      scale, pmode;
-	bool     hS, hD, chS, chD;
-    	Rect r;
-	devMerge *fp, *cfp;
-	float m;
+    DevTerm *gate, *source, *drain;
+    Dev     *cf;
+    DevTerm *cg, *cs, *cd;
+    EFNode *subnode, *snode, *dnode, *gnode;
+    int      scale, pmode, l, w;
+    bool     hS, hD, chS, chD;
+    Rect r;
+    devMerge *fp, *cfp;
+    float m;
 
-	if (esDistrJunct)
-		devDistJunctVisit(dev, hierName, trans, l, w);
+    if (esDistrJunct)
+	devDistJunctVisit(dev, hierName, trans);
 
-	if (dev->dev_nterm < 2) {
-		TxError("outPremature\n");
-		return 0;
-	}
+    if (dev->dev_nterm < 2)
+    {
+	TxError("outPremature\n");
+	return 0;
+    }
 
-	gate = &dev->dev_terms[0];
-	source = drain = &dev->dev_terms[1];
-	if (dev->dev_nterm >= 3)
-		drain = &dev->dev_terms[2];
+    gate = &dev->dev_terms[0];
+    source = drain = &dev->dev_terms[1];
+    if (dev->dev_nterm >= 3)
+	drain = &dev->dev_terms[2];
 
 
-	gnode = GetNode (hierName, gate->dterm_node->efnode_name->efnn_hier);
-	snode = GetNode (hierName, source->dterm_node->efnode_name->efnn_hier);
-	dnode = GetNode (hierName, drain->dterm_node->efnode_name->efnn_hier);
-	if (dev->dev_subsnode)
-	    subnode = spcdevSubstrate(hierName,
+    gnode = GetNode(hierName, gate->dterm_node->efnode_name->efnn_hier);
+    snode = GetNode(hierName, source->dterm_node->efnode_name->efnn_hier);
+    dnode = GetNode(hierName, drain->dterm_node->efnode_name->efnn_hier);
+    if (dev->dev_subsnode)
+	subnode = spcdevSubstrate(hierName,
 			dev->dev_subsnode->efnode_name->efnn_hier, 
 			dev->dev_type, NULL);
-	else
-	    subnode = NULL;
-    	GeoTransRect(trans, &dev->dev_rect, &r);
-    	scale = GeoScale(trans);
-	fp = mkDevMerge(l*scale, w*scale, gnode, snode, 
+    else
+	subnode = NULL;
+
+    GeoTransRect(trans, &dev->dev_rect, &r);
+    scale = GeoScale(trans);
+
+    /* Get length and width of the device */
+    EFGetLengthAndWidth(dev, &l, &w);
+
+    fp = mkDevMerge(l * scale, w * scale, gnode, snode, 
 			dnode, subnode, hierName, dev);
-	hS = extHierSDAttr(source); hD = extHierSDAttr(drain);
-	/*
-	 * run the list of devs. compare the current one with 
-	 * each one in the list. if they fullfill the matching requirements
-	 * merge them only if:
-	 * 1) they have both apf S, D attributes
-	 * or 
-	 * 2) one of them has aph S, D attributes and they have the same 
-	 *    hierarchical prefix
-	 * If one of them has apf and the other aph print a warning.
-	 */
-	for ( cfp = devMergeList ; cfp != NULL ; cfp = cfp->next ) {
-	  if ((pmode = parallelDevs(fp, cfp)) != NOT_PARALLEL) {
+    hS = extHierSDAttr(source);
+    hD = extHierSDAttr(drain);
 
-		cf = cfp->dev;
-		cg = &cfp->dev->dev_terms[0];
-		cs = cd = &cfp->dev->dev_terms[1];
-		if (cfp->dev->dev_nterm >= 3) {
-			if ( pmode == PARALLEL ) 
-				cd = &cfp->dev->dev_terms[2];
-			else if ( pmode == PARALLEL_R ) 
-				cs = &cfp->dev->dev_terms[2];
-		}
-		
+    /*
+     * run the list of devs. compare the current one with 
+     * each one in the list. if they fullfill the matching requirements
+     * merge them only if:
+     * 1) they have both apf S, D attributes
+     * or 
+     * 2) one of them has aph S, D attributes and they have the same 
+     *    hierarchical prefix
+     * If one of them has apf and the other aph print a warning.
+     */
 
-		chS = extHierSDAttr(cs); chD = extHierSDAttr(cd);
-		if ( ! (chS||chD||hS||hD) ) /* all flat S, D */
-			goto mergeThem;
-		if ( cfp->hierName != hierName && 
-		    ( (chS && !hS) || ( chD && !hD ) ||
-		      (!chS && hS) || ( !chD && hD )    ) ) { 
+    for (cfp = devMergeList; cfp != NULL; cfp = cfp->next)
+    {
+	if ((pmode = parallelDevs(fp, cfp)) != NOT_PARALLEL)
+	{
+	    cf = cfp->dev;
+	    cg = &cfp->dev->dev_terms[0];
+	    cs = cd = &cfp->dev->dev_terms[1];
+	    if (cfp->dev->dev_nterm >= 3)
+	    {
+		if (pmode == PARALLEL) 
+		    cd = &cfp->dev->dev_terms[2];
+		    else if (pmode == ANTIPARALLEL) 
+			cs = &cfp->dev->dev_terms[2];
+	    }
 
-		   efHNSprintfPrefix((cfp->hierName)?cfp->hierName:hierName,
+	    chS = extHierSDAttr(cs); chD = extHierSDAttr(cd);
+	    if (!(chS || chD || hS || hD)) /* all flat S, D */
+		goto mergeThem;
+	    if (cfp->hierName != hierName && 
+			((chS && !hS) || (chD && !hD) ||
+			(!chS && hS) || (!chD && hD)))
+	    { 
+
+		efHNSprintfPrefix((cfp->hierName)?cfp->hierName:hierName,
 				     esTempName);
-		   TxError("Warning: conflicting SD attributes of parallel devs in cell: %s\n", esTempName);
-		   break;
-		} else if ( cfp->hierName == hierName ) {
-		   if ( hS && !chS ) {
-			mergeAttr(cs->dterm_attrs, source->dterm_attrs);
-		   }
-		   if ( hD && !chD ) {
-			mergeAttr(cd->dterm_attrs, drain->dterm_attrs);
-		   }
-		} else /* cfp->hierName != hierName */
-			break;
+		TxError("Warning: conflicting SD attributes of parallel"
+			" devs in cell: %s\n", esTempName);
+		break;
+	    }
+	    else if (cfp->hierName == hierName)
+	    {
+		if (hS && !chS)
+		{
+		    mergeAttr(&cs->dterm_attrs, &source->dterm_attrs);
+		}
+		if (hD && !chD)
+		{
+		    mergeAttr(&cd->dterm_attrs, &drain->dterm_attrs);
+		}
+	    }
+	    else /* cfp->hierName != hierName */
+		 break;
 mergeThem:
-		m = esFMult[cfp->esFMIndex] + ((float)fp->w/(float)cfp->w);
-		setDevMult(fp->esFMIndex, DEV_KILLED); 
-		setDevMult(cfp->esFMIndex, m);
-		esDevsMerged++;
-		/* Need to do attribute stuff here */
-		FREE(fp);
-		return 0;
-	  }
+	    switch(dev->dev_class)
+	    {
+		case DEV_MOSFET:
+		case DEV_FET:
+		    m = esFMult[cfp->esFMIndex] + ((float)fp->w / (float)cfp->w);
+		    break;
+		case DEV_RES:
+		    if (fp->dev->dev_type == esNoModelType)
+		        m = esFMult[cfp->esFMIndex] + (fp->dev->dev_values.dev_res
+				/ cfp->dev->dev_values.dev_res);
+		    else
+		        m = esFMult[cfp->esFMIndex] + ((float)fp->l / (float)cfp->l);
+		    break;
+		case DEV_CAP:
+		    if (fp->dev->dev_type == esNoModelType)
+		        m = esFMult[cfp->esFMIndex] + (fp->dev->dev_values.dev_cap
+				/ cfp->dev->dev_values.dev_cap);
+		    else
+		        m = esFMult[cfp->esFMIndex] +
+				(((float)fp->l  * (float)fp->w)
+				/ ((float)cfp->l * (float)cfp->w));
+		    break;
+	    }
+	    setDevMult(fp->esFMIndex, DEV_KILLED); 
+	    setDevMult(cfp->esFMIndex, m);
+	    esDevsMerged++;
+	    /* Need to do attribute stuff here */
+	    freeMagic(fp);
+	    return 0;
 	}
-	/* No parallel devs to it yet */
-	fp->next = devMergeList;
-	devMergeList = fp;
-	return 0;
+    }
+
+    /* No parallel devs to it yet */
+    fp->next = devMergeList;
+    devMergeList = fp;
+    return 0;
 }
 
 /*
@@ -2611,28 +2857,29 @@ mergeThem:
  *
  * ----------------------------------------------------------------------------
  */
+
 int 
 update_w(resClass, w,  n)
-short  resClass;
-int w;
-EFNode *n;
+    short  resClass;
+    int w;
+    EFNode *n;
 {
-	nodeClient *nc;
-	int i;
+    nodeClient *nc;
+    int i;
 
-	if ( n->efnode_client == (ClientData)NULL ) 
-		initNodeClient(n);
-	nc = (nodeClient *) n->efnode_client;
-	if ( nc->m_w.widths == NULL ) {
-		MALLOC(float *, (nc->m_w.widths), sizeof(float)*efNumResistClasses);
-		for ( i=0; i<EFDevNumTypes ; i++ )
-			nc->m_w.widths[i] = 0.0;
-	}
-	nc->m_w.widths[resClass] += (float) w;
+    if (n->efnode_client == (ClientData)NULL) 
+	initNodeClient(n);
+    nc = (nodeClient *) n->efnode_client;
+    if (nc->m_w.widths == NULL)
+    {
+	(nc->m_w.widths) = (float *)mallocMagic((unsigned)sizeof(float)
+		* efNumResistClasses);
+	for (i = 0; i < EFDevNumTypes; i++)
+	    nc->m_w.widths[i] = 0.0;
+    }
+    nc->m_w.widths[resClass] += (float)w;
 }
 
-
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2647,32 +2894,35 @@ EFNode *n;
  *
  * ----------------------------------------------------------------------------
  */
+
 int 
 devDistJunctVisit(dev, hierName, trans)
-Dev *dev;		/* Dev to examine */
-HierName *hierName;		/* Hierarchical path down to this dev */
-Transform *trans;		/* Coordinate transform not used */
+    Dev *dev;			/* Dev to examine */
+    HierName *hierName;		/* Hierarchical path down to this dev */
+    Transform *trans;		/* Coordinate transform not used */
 {
-	EFNode  *n;
-	int      scale, i;
-	int l, w;
-    	Rect r;
+    EFNode  *n;
+    int      scale, i;
+    int l, w;
+    Rect r;
 
-	if (dev->dev_nterm < 2) {
-		TxError("outPremature\n");
-		return 0;
-	}
-
-    	GeoTransRect(trans, &dev->dev_rect, &r);
-    	scale = GeoScale(trans);
-	w = w*scale;
-	EFGetLengthAndWidth(dev, &l, &w);
-
-	for ( i = 1; i<dev->dev_nterm; i++ ) {
-		n = GetNode(hierName,
-			dev->dev_terms[i].dterm_node->efnode_name->efnn_hier);
-		update_w(fetInfo[dev->dev_type].resClassSD, w, n);
-	}
+    if (dev->dev_nterm < 2)
+    {
+	TxError("outPremature\n");
 	return 0;
+    }
+
+    GeoTransRect(trans, &dev->dev_rect, &r);
+    scale = GeoScale(trans);
+    w *= scale;
+    EFGetLengthAndWidth(dev, &l, &w);
+
+    for (i = 1; i<dev->dev_nterm; i++)
+    {
+	n = GetNode(hierName,
+		dev->dev_terms[i].dterm_node->efnode_name->efnn_hier);
+		update_w(fetInfo[dev->dev_type].resClassSD, w, n);
+    }
+    return 0;
 }
 
