@@ -28,9 +28,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extcheck/extcheck.c,v 1.2
 
 #include <stdio.h>
 #include <ctype.h>
-#include <varargs.h>
-#include "misc/magic.h"
-#include "misc/paths.h"
+
+#include "utils/magic.h"
+#include "utils/paths.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -73,7 +73,7 @@ main(argc, argv)
 	exit (1);
 
     /* Read the hierarchical description of the input circuit */
-    EFReadFile(inName, FALSE, FALSE);
+    EFReadFile(inName, FALSE, FALSE, FALSE);
     if (EFArgTech) EFTech = StrDup((char **) NULL, EFArgTech);
     if (EFScale == 0) EFScale = 1;
 
@@ -127,7 +127,7 @@ main(argc, argv)
 
 int
 nodeVisit(node, res, cap)
-    register EFNode *node;
+    EFNode *node;
     int res; 
     double cap;
 {
