@@ -27,8 +27,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFargs.c,v 1.2 200
 #ifdef SYSV
 #include <string.h>
 #endif
-#include "misc/magic.h"
-#include "misc/paths.h"
+#include "utils/magic.h"
+#include "utils/paths.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -57,7 +57,7 @@ char *EFStyle = NULL;		/* Start with no extraction style */
 
 #ifdef MAGIC_WRAPPER
 extern char     *Path;		/* magic's search path---note this should  */
-				/* be done with #include "main/main.h" but */
+				/* be done with #include "utils/main.h" but */
 				/* this is easier.			   */
 #endif
 
@@ -78,7 +78,8 @@ bool efScaleChanged = FALSE;	/* TRUE if .ext scales mismatch */
 
     /* Forward declarations */
 #ifndef MAGIC_WRAPPER
-int efLoadPathFunc();
+extern int  efLoadPathFunc();
+extern void efLoadSearchPath();
 #endif
 
 /*
@@ -164,7 +165,7 @@ EFArgs(argc, argv, err_result, argsProc, cdata)
     /* Hash table of nodes we're going to watch if -N given */
     HashInitClient(&efWatchTable, 32, HT_CLIENTKEYS,
 	efHNCompare, (char *(*)()) NULL,
-	efHNHash, (Void (*)()) NULL);
+	efHNHash, (int (*)()) NULL);
 
     /* Process command line options */
     for (argc--, argv++; argc-- > 0; argv++)
@@ -302,7 +303,7 @@ EFArgs(argc, argv, err_result, argsProc, cdata)
     /* Eliminate trailing .ext from input name */
     if ((cp = rindex(inname, '.')) && strcmp(cp, ".ext") == 0)
     {
-	MALLOC(char *, realIn, cp - inname + 1);
+	realIn = (char *) mallocMagic((unsigned)(cp - inname + 1));
 	(void) strncpy(realIn, inname, cp - inname);
 	realIn[cp - inname] = '\0';
 	inname = realIn;
@@ -347,7 +348,7 @@ usage:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efLoadSearchPath(path)
     char **path;
 {
@@ -356,17 +357,18 @@ efLoadSearchPath(path)
     *path = NULL;
     pv = PaVisitInit();
     PaVisitAddClient(pv, "path", efLoadPathFunc, (ClientData) path);
-    (void) PaVisitFiles(DOT_MAGIC_PATH, ".magic", pv);
+    PaVisitFiles(DOT_MAGIC_PATH, ".magic", pv);
     PaVisitFree(pv);
     if (*path == NULL)
 	*path = ".";
 }
 
+int
 efLoadPathFunc(line, ppath)
     char *line;
     char **ppath;
 {
-    register char *cp, *dp, c;
+    char *cp, *dp, c;
     char path[BUFSIZ];
 
     /* Skip leading blanks */
@@ -387,6 +389,7 @@ efLoadPathFunc(line, ppath)
     }
     *dp = '\0';
     (void) StrDup(ppath, path);
+    return 0;			/* continue search */
 }
 
 #endif
