@@ -26,7 +26,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFbuild.c,v 1.2 20
 #include <string.h>
 #endif
 #include <stdlib.h>		/* for atof() */
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -165,7 +166,7 @@ efBuildNode(def, nodeName, nodeCap, x, y, layerName, av, ac)
     }
 
     /* Allocate a new node with 'nodeName' as its single name */
-    MALLOC(EFNodeName *, newname, sizeof (EFNodeName));
+    newname = (EFNodeName *) mallocMagic((unsigned)(sizeof (EFNodeName)));
     newname->efnn_hier = EFStrToHN((HierName *) NULL, nodeName);
     newname->efnn_port = -1;	/* No port assignment */
     newname->efnn_next = NULL;
@@ -173,7 +174,7 @@ efBuildNode(def, nodeName, nodeCap, x, y, layerName, av, ac)
 
     /* New node itself */
     size = sizeof (EFNode) + (efNumResistClasses - 1) * sizeof (PerimArea);
-    MALLOC(EFNode *, newnode, size);
+    newnode = (EFNode *) mallocMagic((unsigned)(size));
     newnode->efnode_flags = 0;
     newnode->efnode_cap = nodeCap;
     newnode->efnode_attrs = (EFAttr *) NULL;
@@ -245,7 +246,7 @@ efBuildAttr(def, nodeName, r, layerName, text)
     nn = (EFNodeName *) HashGetValue(he);
 
     size = ATTRSIZE(strlen(text));
-    MALLOC(EFAttr *, ap, size);
+    ap = (EFAttr *) mallocMagic((unsigned)(size));
     (void) strcpy(ap->efa_text, text);
     ap->efa_type =
 	efBuildAddStr(EFLayerNames, &EFLayerNumNames, MAXTYPES, layerName);
@@ -361,7 +362,7 @@ efBuildKill(def, name)
 {
     Kill *kill;
 
-    MALLOC(Kill *, kill, sizeof (Kill));
+    kill = (Kill *) mallocMagic((unsigned)(sizeof (Kill)));
     kill->kill_name = EFStrToHN((HierName *) NULL, name);
     kill->kill_next = def->def_kills;
     def->def_kills = kill;
@@ -500,10 +501,13 @@ efBuildDevice(def, class, type, r, argc, argv)
 	    if (hasModel)
 		argstart = 2;
 	    break;
+	case DEV_RSUBCKT:
+	    argstart = 2;
+	    break;
     }
     nterminals = (argc - argstart) / 3;
 
-    MALLOC(Dev *, newdev, (unsigned) DevSize(nterminals));
+    newdev = (Dev *) mallocMagic((unsigned) DevSize(nterminals));
     newdev->dev_nterm = nterminals;
     newdev->dev_rect = *r;
     newdev->dev_type = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, type);
@@ -526,6 +530,10 @@ efBuildDevice(def, class, type, r, argc, argv)
 	    if (strncmp(argv[2], "None", 4) != 0)
 		newdev->dev_subsnode = efBuildDevNode(def, argv[2], TRUE);
 	    break;
+	case DEV_RSUBCKT:
+	    newdev->dev_values.dev_lw.dev_length = atoi(argv[0]);
+	    newdev->dev_values.dev_lw.dev_width = atoi(argv[1]);
+	    break;
 	case DEV_DIODE:		/* do nothing */
 	    break;
 	case DEV_RES:
@@ -693,8 +701,15 @@ efBuildDevNode(def, name, isSubsNode)
 	if (isSubsNode)
 	{
 	    if (!EFHNIsGlob(nn->efnn_hier))
-		efReadError("Default dev substrate node %s is not a global\n",
-		    name);
+	    {
+#ifdef MAGIC_WRAPPER
+		if ((name[0] == '$') && (name[1] != '$'))
+		    efReadError("Substrate node is an undefined Tcl variable.\n");
+		else
+#endif
+		    efReadError("Default device substrate node"
+				" \"%s\" is not a global\n", name);
+	    }
 	    nn->efnn_node->efnode_flags |= EF_DEVTERM;
 	}
     }
@@ -722,8 +737,8 @@ efBuildDevNode(def, name, isSubsNode)
 int
 efBuildAddStr(table, pMax, size, str)
     char *table[];	/* Table to search */
-    int *pMax;			/* Increment this if we add an entry */
-    int size;			/* Maximum size of table */
+    int *pMax;		/* Increment this if we add an entry */
+    int size;		/* Maximum size of table */
     char *str;		/* String to add */
 {
     int n, max;
@@ -787,7 +802,7 @@ efBuildUse(def, subDefName, subUseId, ta, tb, tc, td, te, tf)
     if (newdef == NULL)
 	newdef = efDefNew(subDefName);
 
-    MALLOC(Use *, newuse, sizeof (Use));
+    newuse = (Use *) mallocMagic((unsigned)(sizeof (Use)));
     newuse->use_def = newdef;
     newuse->use_trans.t_a = ta;
     newuse->use_trans.t_b = tb;
@@ -849,7 +864,7 @@ efBuildConnect(def, nodeName1, nodeName2, deltaC, av, ac)
     unsigned size = sizeof (Connection)
 		    + (efNumResistClasses - 1) * sizeof (PerimArea);
 
-    MALLOC(Connection *, conn, size);
+    conn = (Connection *) mallocMagic((unsigned)(size));
     if (efConnInitSubs(conn, nodeName1, nodeName2))
     {
 	conn->conn_cap = (EFCapValue) deltaC;
@@ -893,7 +908,7 @@ efBuildResistor(def, nodeName1, nodeName2, resistance)
 {
     Connection *conn;
 
-    MALLOC(Connection *, conn, sizeof (Connection));
+    conn = (Connection *) mallocMagic((unsigned)(sizeof (Connection)));
     if (efConnInitSubs(conn, nodeName1, nodeName2))
     {
 	conn->conn_res = resistance;
@@ -930,7 +945,7 @@ efBuildCap(def, nodeName1, nodeName2, cap)
 {
     Connection *conn;
 
-    MALLOC(Connection *, conn, sizeof (Connection));
+    conn = (Connection *) mallocMagic((unsigned)(sizeof (Connection)));
     if (efConnInitSubs(conn, nodeName1, nodeName2))
     {
 	conn->conn_cap = (EFCapValue) cap;
@@ -988,9 +1003,9 @@ efConnInitSubs(conn, nodeName1, nodeName2)
     return TRUE;
 
 bad:
-    if (c1->cn_name) FREE((char *) c1->cn_name);
-    if (c2->cn_name) FREE((char *) c2->cn_name);
-    FREE((char *) conn);
+    if (c1->cn_name) freeMagic((char *) c1->cn_name);
+    if (c2->cn_name) freeMagic((char *) c2->cn_name);
+    freeMagic((char *) conn);
     return FALSE;
 }
 
@@ -1131,7 +1146,7 @@ efNodeAddName(node, he, hn)
     EFNodeName *newnn;
     EFNodeName *oldnn;
 
-    MALLOC(EFNodeName *, newnn, sizeof (EFNodeName));
+    newnn = (EFNodeName *) mallocMagic((unsigned)(sizeof (EFNodeName)));
     newnn->efnn_node = node;
     newnn->efnn_hier = hn;
     HashSetValue(he, (char *) newnn);
@@ -1305,7 +1320,7 @@ efNodeMerge(node1, node2)
 	node1->efnode_flags |= EF_PORT;
 
     /* Get rid of node2 */
-    FREE((char *) node2);
+    freeMagic((char *) node2);
 }
 
 /*
@@ -1346,7 +1361,7 @@ efFreeNodeTable(table)
 	{
 	    for (hn = nn->efnn_hier; hn; hn = hn->hn_parent)
 		(void) HashFind(&efFreeHashTable, (char *) hn);
-	    FREE((char *) nn);
+	    freeMagic((char *) nn);
 	}
 }
 
@@ -1379,8 +1394,8 @@ efFreeNodeList(head)
 	    node = (EFNode *) node->efnode_next)
     {
 	for (ap = node->efnode_attrs; ap; ap = ap->efa_next)
-	    FREE((char *) ap);
-	FREE((char *) node);
+	    freeMagic((char *) ap);
+	freeMagic((char *) node);
     }
 }
 
@@ -1404,7 +1419,7 @@ void
 efFreeConn(conn)
     Connection *conn;
 {
-    if (conn->conn_name1) FREE(conn->conn_name1);
-    if (conn->conn_name2) FREE(conn->conn_name2);
-    FREE((char *) conn);
+    if (conn->conn_name1) freeMagic(conn->conn_name1);
+    if (conn->conn_name2) freeMagic(conn->conn_name2);
+    freeMagic((char *) conn);
 }
