@@ -23,7 +23,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFdef.c,v 1.2 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -59,6 +60,7 @@ HashTable efFreeHashTable;
  * ----------------------------------------------------------------------------
  */
 
+void
 EFInit()
 {
     EFLayerNumNames = 1;
@@ -87,6 +89,7 @@ EFInit()
  * ----------------------------------------------------------------------------
  */
 
+void
 EFDone()
 {
     Connection *conn;
@@ -102,15 +105,15 @@ EFDone()
     while (he = HashNext(&efDefHashTable, &hs))
     {
 	def = (Def *) HashGetValue(he);
-	FREE(def->def_name);
+	freeMagic(def->def_name);
 	efFreeNodeTable(&def->def_nodes);
 	efFreeNodeList(&def->def_firstn);
 	HashKill(&def->def_nodes);
 	HashKill(&def->def_dists);
 	for (use = def->def_uses; use; use = use->use_next)
 	{
-	    FREE(use->use_id);
-	    FREE((char *) use);
+	    freeMagic(use->use_id);
+	    freeMagic((char *) use);
 	}
 	for (conn = def->def_conns; conn; conn = conn->conn_next)
 	    efFreeConn(conn);
@@ -122,27 +125,27 @@ EFDone()
 	{
 	    for (n = 0; n < (int)dev->dev_nterm; n++)
 		if (dev->dev_terms[n].dterm_attrs)
-		    FREE((char *) dev->dev_terms[n].dterm_attrs);
-	    FREE((char *) dev);
+		    freeMagic((char *) dev->dev_terms[n].dterm_attrs);
+	    freeMagic((char *) dev);
 	}
 	for (kill = def->def_kills; kill; kill = kill->kill_next)
 	{
-	    FREE(kill->kill_name);
-	    FREE((char *) kill);
+	    freeMagic(kill->kill_name);
+	    freeMagic((char *) kill);
 	}
-	FREE((char *) def);
+	freeMagic((char *) def);
     }
 
     /* Misc cleanup */
-    for (n = 0; n < EFDevNumTypes; n++) FREE(EFDevTypes[n]);
+    for (n = 0; n < EFDevNumTypes; n++) freeMagic(EFDevTypes[n]);
 
     /* Changed from n = 0 to n = 1; First entry "space" is predefined,	*/
     /* not malloc'd.  ---Tim 9/3/02					*/
-    for (n = 1; n < EFLayerNumNames; n++) FREE(EFLayerNames[n]);
+    for (n = 1; n < EFLayerNumNames; n++) freeMagic(EFLayerNames[n]);
 
     if (EFTech)
     {
-	FREE(EFTech);
+	freeMagic(EFTech);
 	EFTech = (char *)NULL;
     }
 
@@ -150,7 +153,7 @@ EFDone()
 /*
     HashStartSearch(&hs);
     while (he = HashNext(&efFreeHashTable, &hs))
-	FREE(he->h_key.h_ptr);
+	freeMagic(he->h_key.h_ptr);
 */
     HashKill(&efFreeHashTable);
 
@@ -214,7 +217,7 @@ efDefNew(name)
     Def *newdef;
 
     he = HashFind(&efDefHashTable, name);
-    MALLOC(Def *, newdef, sizeof (Def));
+    newdef = (Def *) mallocMagic((unsigned) (sizeof (Def)));
     HashSetValue(he, (char *) newdef);
 
     newdef->def_name = StrDup((char **) NULL, name);
