@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFflat.c,v 1.2 200
 #include <string.h>
 #include <math.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -53,8 +53,10 @@ HierContext efFlatContext;
 
 /* Forward declarations */
 int efFlatSingleCap();
-int efFlatGlobHash(), efFlatGlobCmp();
-char *efFlatGlobCopy();
+int efFlatGlobHash(HierName *);
+bool efFlatGlobCmp(HierName *, HierName *);
+char *efFlatGlobCopy(HierName *);
+void efAddNodes(HierContext *, bool);
 
 /*
  * ----------------------------------------------------------------------------
@@ -199,6 +201,7 @@ EFFlatDone()
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatNodes(hc)
     HierContext *hc;
 {
@@ -245,6 +248,7 @@ efFlatNodes(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatNodesStdCell(hc)
     HierContext *hc;
 {
@@ -283,6 +287,7 @@ efFlatNodesStdCell(hc)
  * ----------------------------------------------------------------------------
  */
 
+void
 efAddNodes(hc, stdcell)
     HierContext *hc;
     bool stdcell;
@@ -311,12 +316,12 @@ efAddNodes(hc, stdcell)
  	if (stdcell && is_subcircuit && !(node->efnode_flags & EF_PORT))
 	    continue;
 
-	MALLOC(EFNode *, newnode, size);
+	newnode = (EFNode *) mallocMagic((unsigned)(size));
 	newnode->efnode_attrs = (EFAttr *) NULL;
 	for (ap = node->efnode_attrs; ap; ap = ap->efa_next)
 	{
 	    asize = ATTRSIZE(strlen(ap->efa_text));
-	    MALLOC(EFAttr *, newap, asize);
+	    newap = (EFAttr *) mallocMagic((unsigned)(asize));
 	    (void) strcpy(newap->efa_text, ap->efa_text);
 	    GeoTransRect(&t, &ap->efa_loc, &newap->efa_loc);
 	    newap->efa_type = ap->efa_type;
@@ -373,7 +378,7 @@ efAddNodes(hc, stdcell)
 	     * first (since the first name is the "canonical" name for the
 	     * node).  The order of the remaining names will be reversed.
 	     */
-	    MALLOC(EFNodeName *, newname, sizeof (EFNodeName));
+	    newname = (EFNodeName *) mallocMagic((unsigned)(sizeof (EFNodeName)));
 	    HashSetValue(he, (char *) newname);
 	    newname->efnn_node = newnode;
 	    newname->efnn_hier = hierName;
@@ -400,7 +405,7 @@ efAddNodes(hc, stdcell)
  * distinct nodes in the flat table to merge.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	May merge nodes from the list efNodeList as per the connection
@@ -409,6 +414,7 @@ efAddNodes(hc, stdcell)
  * ----------------------------------------------------------------------------
  */
 
+int
 efAddConns(hc)
     HierContext *hc;
 {
@@ -443,7 +449,7 @@ efAddConns(hc)
  * NULL, we just adjust the R and C of the node 'name1'.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	May merge nodes from the list efNodeList.
@@ -451,6 +457,7 @@ efAddConns(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efAddOneConn(hc, name1, name2, conn)
     HierContext *hc;
     char *name1, *name2;	/* These are strings, not HierNames */
@@ -566,7 +573,7 @@ efFlatGlob()
 	     * Create a new EFNodeName that points to nodeFlat, but
 	     * don't link it in to nodeFlat->efnode_name yet.
 	     */
-	    MALLOC(EFNodeName *, nameGlob, sizeof (EFNodeName));
+	    nameGlob = (EFNodeName *) mallocMagic((unsigned)(sizeof (EFNodeName)));
 	    HashSetValue(heGlob, (ClientData) nameGlob);
 	    nameGlob->efnn_node = nodeFlat;
 	    nameGlob->efnn_hier = (HierName *) heGlob->h_key.h_ptr;
@@ -620,7 +627,7 @@ efFlatGlob()
 	}
 	else
 	{
-	    FREE((char *) nameGlob);
+	    freeMagic((char *) nameGlob);
 	    EFHNFree(hnGlob, (HierName *) NULL, HN_GLOBAL);
 	}
     }
@@ -658,16 +665,17 @@ efFlatGlobError(nameGlob, nameFlat)
     TxPrintf("should be sure eventually to connect them in the layout.\n\n");
 }
 
-int
+bool
 efFlatGlobCmp(hierName1, hierName2)
     HierName *hierName1, *hierName2;
 {
     if (hierName1 == hierName2)
-	return 0;
+	return FALSE;
 
-    return (hierName1 == NULL || hierName2 == NULL
-		|| hierName1->hn_hash != hierName2->hn_hash
-		|| strcmp(hierName1->hn_name, hierName2->hn_name) != 0);
+    return ((bool)(hierName1 == NULL || hierName2 == NULL
+		   || hierName1->hn_hash != hierName2->hn_hash
+		   || strcmp(hierName1->hn_name, hierName2->hn_name) != 0
+		  ));
 }
 
 char *
@@ -678,7 +686,7 @@ efFlatGlobCopy(hierName)
     int size;
 
     size = HIERNAMESIZE(strlen(hierName->hn_name));
-    MALLOC(HierName *, hNew, size);
+    hNew = (HierName *) mallocMagic((unsigned)(size));
     (void) strcpy(hNew->hn_name, hierName->hn_name);
     hNew->hn_parent = (HierName *) NULL;
     hNew->hn_hash = hierName->hn_hash;
@@ -714,6 +722,7 @@ efFlatGlobHash(hierName)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatKills(hc)
     HierContext *hc;
 {
@@ -772,6 +781,7 @@ efFlatKills(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatCaps(hc)
     HierContext *hc;
 {
@@ -803,7 +813,7 @@ efFlatCaps(hc)
  * add the capacitor if either terminal is a killed node.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	Adds an entry to efCapHashTable indexed by the nodes of 'name1'
@@ -815,6 +825,7 @@ efFlatCaps(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatSingleCap(hc, name1, name2, conn)
     HierContext *hc;		/* Contains hierarchical pathname to cell */
     char *name1, *name2;	/* Names of nodes connecting to capacitor */
@@ -876,6 +887,7 @@ efFlatSingleCap(hc, name1, name2, conn)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatDists(hc)
     HierContext *hc;
 {
@@ -953,7 +965,7 @@ double c;
 {
 	EFCapValue *capp = (EFCapValue *)HashGetValue(he);
 	if(capp == NULL) {
-		MALLOC(EFCapValue *, capp, sizeof(EFCapValue));
+		capp = (EFCapValue *) mallocMagic((unsigned)(sizeof(EFCapValue)));
 		HashSetValue(he, capp);
 	}
 	*capp = (EFCapValue) c;
