@@ -23,7 +23,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFhier.c,v 1.2 200
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -66,6 +67,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFhier.c,v 1.2 200
  * ----------------------------------------------------------------------------
  */
 
+int
 efHierSrUses(hc, func, cdata)
     HierContext *hc;
     int (*func)();
@@ -77,7 +79,7 @@ efHierSrUses(hc, func, cdata)
     Use *u;
 
     /* We should not descend into subcircuit "black boxes" */
-    if (hc->hc_use->use_def->def_flags & DEF_SUBCIRCUIT) return 0;
+//  if (hc->hc_use->use_def->def_flags & DEF_SUBCIRCUIT) return 0;
 
     for (u = hc->hc_use->use_def->def_uses; u; u = u->use_next)
     {
