@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFname.c,v 1.4 200
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -161,7 +161,7 @@ EFHNConcat(prefix, suffix)
 	    prev = new, suffix = suffix->hn_parent)
     {
 	size = HIERNAMESIZE(strlen(suffix->hn_name));
-	MALLOC(HierName *, new, size);
+	new = (HierName *) mallocMagic((unsigned)(size));
 	if (efHNStats) efHNRecord(size, HN_CONCAT);
 	new->hn_hash = suffix->hn_hash;
 	(void) strcpy(new->hn_name, suffix->hn_name);
@@ -223,7 +223,7 @@ EFStrToHN(prefix, suffixStr)
 	if (*cp == '/' || *cp == '\0')
 	{
 	    size = HIERNAMESIZE(cp - slashPtr);
-	    MALLOC(HierName *, hierName, size);
+	    hierName = (HierName *) mallocMagic((unsigned)(size));
 	    if (efHNStats) efHNRecord(size, HN_ALLOC);
 	    efHNInit(hierName, slashPtr, cp);
 	    hierName->hn_parent = prefix;
@@ -451,7 +451,7 @@ EFHNFree(hierName, prefix, type)
 	if (hn == prefix)
 	    break;
 
-	FREE((char *) hn);
+	freeMagic((char *) hn);
 	if (efHNStats)
 	{
 	    int len = strlen(hn->hn_name);
@@ -636,7 +636,7 @@ efHNFromUse(hc, prefix)
     }
 
     size = HIERNAMESIZE(strlen(namePtr));
-    MALLOC(HierName *, hierName, size);
+    hierName = (HierName *) mallocMagic ((unsigned)(size));
     if (efHNStats) efHNRecord(size, HN_FROMUSE);
     efHNInit(hierName, namePtr, (char *) NULL);
     hierName->hn_parent = prefix;
@@ -645,7 +645,7 @@ efHNFromUse(hc, prefix)
     he = HashFind(&efHNUseHashTable, (char *) hierName);
     if (HashGetValue(he))
     {
-	FREE((char *) hierName);
+	freeMagic((char *) hierName);
 	return (HierName *) HashGetValue(he);
     }
     HashSetValue(he, (ClientData) hierName);
@@ -682,12 +682,13 @@ efHNFromUse(hc, prefix)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 efHNUseCompare(hierName1, hierName2)
     HierName *hierName1, *hierName2;
 {
-    return (hierName1->hn_parent != hierName2->hn_parent
-	    || strcmp(hierName1->hn_name, hierName2->hn_name));
+    return ((bool)(hierName1->hn_parent != hierName2->hn_parent
+	           || strcmp(hierName1->hn_name, hierName2->hn_name)
+		  ));
 }
 
 int
@@ -833,12 +834,13 @@ efHNHash(hierName)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 efHNDistCompare(dist1, dist2)
     Distance *dist1, *dist2;
 {
-    return efHNCompare(dist1->dist_1, dist2->dist_1)
-	|| efHNCompare(dist1->dist_2, dist2->dist_2);
+    return ((bool)(efHNCompare(dist1->dist_1, dist2->dist_1)
+	           || efHNCompare(dist1->dist_2, dist2->dist_2)
+		  ));
 }
 
 char *
@@ -847,7 +849,7 @@ efHNDistCopy(dist)
 {
     Distance *distNew;
 
-    MALLOC(Distance *, distNew, sizeof (Distance));
+    distNew = (Distance *) mallocMagic ((unsigned)(sizeof (Distance)));
     *distNew = *dist;
     return (char *) distNew;
 }
@@ -871,7 +873,7 @@ efHNDistKill(dist)
     for (hn = dist->dist_2; hn; hn = hn->hn_parent)
 	(void) HashFind(&efFreeHashTable, (char *) hn);
 
-    FREE((char *) dist);
+    freeMagic((char *) dist);
 }
 
 /*
