@@ -27,7 +27,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFread.c,v 1.2 200
 #include <ctype.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -36,12 +37,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFread.c,v 1.2 200
 #include "extflat/extflat.h"
 #include "extflat/EFint.h"
 #include "extract/extract.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 
 #ifndef MAGIC_WRAPPER
 /* This must match the definition for extDevTable in extract/ExtBasic.c */
 char *extDevTable[] = {"fet", "mosfet", "bjt", "devres", "devcap",
-		"diode", "subckt", NULL};
+		"diode", "subckt", "rsubckt", NULL};
 #endif
 
 /*
@@ -264,9 +265,10 @@ readfile:
 		break;
 
 	    /* replaces "fet" (below) */
-	    /* device mosfet|bjt|subckt type xlo ylo xhi yhi area perim */
-	    /*		[substrate] GATE T1 T2 ...			*/
-	    /* device res|cap type xlo ylo xhi yhi value GATE T1 T2 ... */
+	    /* device mosfet|bjt|subckt	type xlo ylo xhi yhi		*/
+	    /*		area perim [substrate] GATE T1 T2 ...		*/
+	    /* device res|cap|rsubckt type xlo ylo xhi yhi value	*/
+	    /*		GATE T1 T2 ...					*/
 	    case DEVICE:
 		r.r_xbot = atoi(argv[3]);
 		r.r_ybot = atoi(argv[4]);
@@ -293,13 +295,16 @@ readfile:
 		    case DEV_DIODE:
 			ac = 7;
 			break;
-		    case DEV_RES:
 		    case DEV_CAP:
+		    case DEV_RES:
 			if (!strcmp(argv[2], "None"))	/* Has device value */
 			   ac = 8;
 			else
 			   ac = 9;	/* Has device L and W */
 			break;
+		    case DEV_RSUBCKT:
+			ac = 9;	/* Similar to RES, with a model */
+			break;
 		}
 		if (((argc - ac) % 3) != 0)
 		{
