@@ -22,8 +22,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -37,6 +40,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 20
 extern Def *efFlatRootDef;
 extern Use efFlatRootUse;
 extern HierContext efFlatContext;
+
+extern void efDevFixLW();
+extern void efHNOutPrefix();
+
+bool efDevKilled();
 
 /*
  * ----------------------------------------------------------------------------
@@ -55,15 +63,16 @@ extern HierContext efFlatContext;
  * call the user-supplied procedure (*subProc)(), which should be of
  * the following form:
  *
- * 	(*subProc)(use, hierName, cdata)
+ * 	(*subProc)(use, hierName, is_top)
  *	    Use *use;
  *	    HierName *hierName;
- *	    ClientData cdata;
+ *	    Boolean is_top;
  *	{
  *	}
  *
- * The procedure should return 0 normally, or 1 to abort the
- * search.
+ * is_top will be TRUE for the top-level cell, and FALSE for all
+ * other cells.  The procedure should return 0 normally, or 1 to abort
+ * the search.
  *
  * Results:
  *	Returns 0 if terminated normally, or 1 if the search
@@ -75,15 +84,32 @@ extern HierContext efFlatContext;
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitSubcircuits(subProc, cdata)
     int (*subProc)();
     ClientData cdata;
 {
     CallArg ca;
+    HierContext *hc;
+    int efVisitSubcircuits();   /* Forward declaration */
+
+    /* If the top-level def is defined as a subcircuit, call topProc */
+
+    hc = &efFlatContext;
+    if (hc->hc_use->use_def->def_flags & DEF_SUBCIRCUIT)
+	if ((*subProc)(hc->hc_use, hc->hc_hierName, TRUE))
+	    return 1;
+
+    /* For each subcell of the top-level def that is defined as */
+    /* a subcircuit, call subProc.				*/
 
     ca.ca_proc = subProc;
     ca.ca_cdata = cdata;
-    return efVisitSubcircuits(&efFlatContext, (ClientData) &ca);
+
+    if (efHierSrUses(hc, efVisitSubcircuits, (ClientData) &ca))
+	return 1;
+
+    return 0;
 }
 
 /*
@@ -99,8 +125,8 @@ EFVisitSubcircuits(subProc, cdata)
 
 int
 efVisitSubcircuits(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     /* Look for children of this def which are defined	*/
     /* as subcircuits via the DEF_SUBCIRCUIT flag.	*/
@@ -128,9 +154,11 @@ efVisitSubcircuits(hc, ca)
  *
  *	Estimate length and width for a device from area and perimeter values.
  *
- * Results: None
+ * Results:
+ *	None
  *
- * Side Effects: values substituted for length and width
+ * Side Effects:
+ *	Values substituted for length and width.
  *
  * ----------------------------------------------------------------------------
  */
@@ -149,6 +177,8 @@ EFGetLengthAndWidth(dev, lptr, wptr)
 	case DEV_MOSFET:
 	case DEV_BJT:
 	case DEV_SUBCKT:
+	case DEV_RES:
+	case DEV_CAP:
 	    l = dev->dev_values.dev_lw.dev_length;
 	    w = dev->dev_values.dev_lw.dev_width;
 	    break;
@@ -181,7 +211,7 @@ EFGetLengthAndWidth(dev, lptr, wptr)
 	    break;
 
 	default:
-	    l = w = 0;	/* RES and CAP devices shouldn't use l & w. */
+	    l = w = 0;	/* DIODE device shouldn't use l & w. */
 	    break;
     }
 
@@ -223,6 +253,7 @@ EFGetLengthAndWidth(dev, lptr, wptr)
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitDevs(devProc, cdata)
     int (*devProc)();
     ClientData cdata;
@@ -247,11 +278,11 @@ EFVisitDevs(devProc, cdata)
 
 int
 efVisitDevs(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     Def *def = hc->hc_use->use_def;
-    register Dev *dev;
+    Dev *dev;
     int scale;
     Transform t;
 
@@ -352,12 +383,12 @@ efDevKilled(dev, prefix)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efDevFixLW(attrs, pL, pW)
     char *attrs;
     int *pL, *pW;
 {
-    register char *cp, *ep;
+    char *cp, *ep;
     char attrName, savec;
     int value;
 
@@ -437,6 +468,7 @@ skip:
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitResists(resProc, cdata)
     int (*resProc)();
     ClientData cdata;
@@ -463,11 +495,11 @@ extern int efVisitSingleResist();
 
 int
 efVisitResists(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     Def *def = hc->hc_use->use_def;
-    register Connection *res;
+    Connection *res;
     Transform t;
     int scale;
 
@@ -505,7 +537,8 @@ efVisitResists(hc, ca)
  * process the resistor if either terminal is a killed node.
  *
  * Results:
- *	Whatever the user-supplied procedure (*ca->ca_proc)() returns.
+ *	Whatever the user-supplied procedure (*ca->ca_proc)() returns
+ *	(type int).
  *
  * Side effects:
  *	Calls the user-supplied procedure.
@@ -513,11 +546,12 @@ efVisitResists(hc, ca)
  * ----------------------------------------------------------------------------
  */
 
+int
 efVisitSingleResist(hc, name1, name2, res, ca)
     HierContext *hc;		/* Contains hierarchical pathname to cell */
     char *name1, *name2;	/* Names of nodes connecting to resistor */
     Connection *res;		/* Contains resistance to add */
-    register CallArg *ca;
+    CallArg *ca;
 {
     EFNode *n1, *n2;
     HashEntry *he;
@@ -571,6 +605,7 @@ efVisitSingleResist(hc, name1, name2, res, ca)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 EFVisitCaps(capProc, cdata)
     int (*capProc)();
@@ -632,8 +667,8 @@ EFVisitNodes(nodeProc, cdata)
     int (*nodeProc)();
     ClientData cdata;
 {
-    register EFNode *node;
-    register EFNodeName *nn;
+    EFNode *node;
+    EFNodeName *nn;
     HierName *hierName;
     EFCapValue cap;
     int res;
@@ -719,9 +754,9 @@ EFVisitNodes(nodeProc, cdata)
 
 int
 EFNodeResist(node)
-    register EFNode *node;
+    EFNode *node;
 {
-    register int n, perim, area;
+    int n, perim, area;
     float s, fperim;
     double v, dresist;
     int resist;
@@ -812,13 +847,13 @@ EFLookDist(hn1, hn2, pMinDist, pMaxDist)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 EFHNOut(hierName, outf)
     HierName *hierName;
-    register FILE *outf;
+    FILE *outf;
 {
     bool trimGlob, trimLocal;
-    register char *cp, c;
+    char *cp, c;
 
     if (hierName->hn_parent) efHNOutPrefix(hierName->hn_parent, outf);
     if (EFTrimFlags)
@@ -840,12 +875,12 @@ EFHNOut(hierName, outf)
     else (void) fputs(hierName->hn_name, outf);
 }
 
-Void
+void
 efHNOutPrefix(hierName, outf)
-    register HierName *hierName;
-    register FILE *outf;
+    HierName *hierName;
+    FILE *outf;
 {
-    register char *cp, c;
+    char *cp, c;
 
     if (hierName->hn_parent)
 	efHNOutPrefix(hierName->hn_parent, outf);
