@@ -22,7 +22,7 @@
 #ifndef _EXTFLAT_H
 #define _EXTFLAT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 typedef unsigned char U_char;
 
