@@ -24,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtArray.c,v 1.3 2
 
 #include <stdio.h>
 #include <string.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -35,8 +35,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtArray.c,v 1.3 2
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
-#include "misc/styles.h"
+#include "utils/signals.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 
@@ -908,7 +908,7 @@ extArrayHardNode(tp, def, ha)
 	LabelList *ll;
 
 	lreg = (LabRegion *) extGetRegion(tp);
-	MALLOC(LabelList *, ll, sizeof (LabelList));
+	ll = (LabelList *) mallocMagic((unsigned) (sizeof (LabelList)));
 	lreg->lreg_labels = ll;
 	ll->ll_next = (LabelList *) NULL;
 	ll->ll_label = arg.hw_label;
