@@ -26,9 +26,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtCell.c,v 1.2 20
 #ifdef SYSV
 #include <string.h>
 #endif
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -37,33 +37,24 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtCell.c,v 1.2 20
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 
 /* --------------------------- Global data ---------------------------- */
 
-/* Used to identify the extractor version that produced a .ext file */
-
-/* NOTE:  I don't know if this was originally intended to track the	*/
-/* magic version number, but I am making it so.  Tim, 2/20/03		*/
-/* (this number is picked up from extract/Makefile and ultimately	*/
-/* derives from the VERSION string in scripts/config)			*/
-
-char *ExtVersionString = MAGIC_VERSION;
-
-    /*
-     * Value normally present in ti_client to indicate tiles that have not
-     * been marked with their associated region.
-     */
+/*
+ * Value normally present in ti_client to indicate tiles that have not
+ * been marked with their associated region.
+ */
 ClientData extUnInit = (ClientData) MINFINITY;
 
 /* ------------------------ Data local to this file ------------------- */
 
-    /* Forward declarations */
+/* Forward declarations */
 int extOutputUsesFunc();
 FILE *extFileOpen();
 
@@ -291,7 +282,7 @@ extHeader(def, f)
     fprintf(f, "timestamp %d\n", def->cd_timestamp);
 
     /* Output our version number */
-    fprintf(f, "version %s\n", ExtVersionString);
+    fprintf(f, "version %s\n", MagicVersion);
 
     /* Output the technology */
     fprintf(f, "tech %s\n", DBTechName);
