@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtCouple.c,v 1.3
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -51,6 +52,7 @@ int extBasicOverlap(), extBasicCouple();
 int extAddOverlap(), extAddCouple();
 int extSideLeft(), extSideRight(), extSideBottom(), extSideTop();
 int extSideOverlap();
+void extSideCommon();
 
 /* Structure to pass on to the coupling and sidewall capacitance	*/
 /* routines to include the current cell definition and the current	*/
@@ -90,7 +92,7 @@ void extNregAdjustCap(nr, c, str)
 {
     char *name;
     name = extNodeName((LabRegion *) nr);
-    TxError("CapDebug: %s += %f (%s)\n", name, c, str);
+    fprintf(stderr, "CapDebug: %s += %f (%s)\n", name, c, str);
 }
 
 void extAdjustCouple(he, c, str)
@@ -104,7 +106,7 @@ void extAdjustCouple(he, c, str)
     ck = (CoupleKey *) he->h_key.h_words;
     name1 = extNodeName((LabRegion *) ck->ck_1);
     name2 = extNodeName((LabRegion *) ck->ck_2);
-    TxError("CapDebug: %s-%s += %f (%s)\n", name1, name2, c, str);
+    fprintf(stderr, "CapDebug: %s-%s += %f (%s)\n", name1, name2, c, str);
 }
 
 
@@ -159,6 +161,7 @@ void extAdjustCouple(he, c, str)
  * ----------------------------------------------------------------------------
  */
 
+void
 extFindCoupling(def, table, clipArea)
     CellDef *def;
     HashTable *table;
@@ -210,12 +213,13 @@ extFindCoupling(def, table, clipArea)
  * ----------------------------------------------------------------------------
  */
 
+void
 extOutputCoupling(table, outFile)
     HashTable *table;	/* Coupling capacitance hash table */
     FILE *outFile;	/* Output file */
 {
-    register HashEntry *he;
-    register CoupleKey *ck;
+    HashEntry *he;
+    CoupleKey *ck;
     HashSearch hs;
     char *text;
     CapValue cap;  /* value of capacitance. */
@@ -229,9 +233,9 @@ extOutputCoupling(table, outFile)
 
 	ck = (CoupleKey *) he->h_key.h_words;
 	text = extNodeName((LabRegion *) ck->ck_1);
-	(void) fprintf(outFile, "cap \"%s\" ", text);
+	fprintf(outFile, "cap \"%s\" ", text);
 	text = extNodeName((LabRegion *) ck->ck_2);
-	(void) fprintf(outFile, "\"%s\" %lg\n", text, cap);
+	fprintf(outFile, "\"%s\" %lg\n", text, cap);
     }
 }
 
@@ -256,22 +260,36 @@ extOutputCoupling(table, outFile)
  * ----------------------------------------------------------------------------
  */
 
+int
 extBasicOverlap(tile, ecs)
     Tile *tile;
     extCapStruct *ecs;
 {
-    int thisType = TiGetType(tile);
-    int pNum, pMask = ExtCurStyle->exts_overlapOtherPlanes[thisType];
-    TileTypeBitMask *tMask = &ExtCurStyle->exts_overlapOtherTypes[thisType];
+    int thisType;
+    int pNum, pMask;
+    TileTypeBitMask *tMask;
     Rect r;
     CellDef *def = ecs->def;
     int thisPlane = ecs->plane;
     extCoupleStruct ecpls;
 
+#ifdef NONMANHATTAN
+    if (IsSplit(tile))
+	thisType = (SplitSide(tile)) ? SplitRightType(tile) :
+		SplitLeftType(tile);
+    else
+#endif
+    thisType = TiGetTypeExact(tile);
+
+    pMask = ExtCurStyle->exts_overlapOtherPlanes[thisType];
+    tMask = &ExtCurStyle->exts_overlapOtherTypes[thisType];
+
     TITORECT(tile, &r);
     extOverlapDef = def;
     if (extCoupleSearchArea)
+    {
 	GEOCLIP(&r, extCoupleSearchArea);
+    }
 
     ecpls.tile = tile;
     ecpls.plane_of_tile = thisPlane;
@@ -327,13 +345,14 @@ struct overlap
     TileTypeBitMask	 o_tmask;
 };
 
+int
 extAddOverlap(tbelow, ecpls)
     Tile *tbelow;
     extCoupleStruct *ecpls;
 {
     int extSubtractOverlap(), extSubtractOverlap2();
-    register NodeRegion *rabove, *rbelow;
-    register HashEntry *he;
+    NodeRegion *rabove, *rbelow;
+    HashEntry *he;
     struct overlap ov;
     TileType ta, tb;
     CoupleKey ck;
@@ -341,11 +360,14 @@ extAddOverlap(tbelow, ecpls)
     CapValue c;
     Tile *tabove = ecpls->tile;
 
-    /* Do nothing if both tiles are connected */
+    /* Check if both tiles are connected.  If they are, we don't need   */
+    /* to check for shielding material, and we don't want to add any    */
+    /* coupling capacitance between them.  However, we *do* want to     */
+    /* subtract off any substrate (area) capacitance previously added   */
+    /* (Correction made 4/29/04 by Tim from a tip by Jeff Sondeen).     */
+
     rabove = (NodeRegion *) extGetRegion(tabove);
     rbelow = (NodeRegion *) extGetRegion(tbelow);
-    if (rabove == rbelow)
-	return (0);
 
     /* Compute the area of overlap */
     ov.o_clip.r_xbot = MAX(LEFT(tbelow), LEFT(tabove));
@@ -353,7 +375,9 @@ extAddOverlap(tbelow, ecpls)
     ov.o_clip.r_ybot = MAX(BOTTOM(tbelow), BOTTOM(tabove));
     ov.o_clip.r_ytop = MIN(TOP(tbelow), TOP(tabove));
     if (extCoupleSearchArea)
+    {
 	GEOCLIP(&ov.o_clip, extCoupleSearchArea);
+    }
     ov.o_area = (ov.o_clip.r_ytop - ov.o_clip.r_ybot)
 	      * (ov.o_clip.r_xtop - ov.o_clip.r_xbot);
     ta = TiGetType(tabove);
@@ -398,10 +422,8 @@ extAddOverlap(tbelow, ecpls)
     /* If any capacitance remains, add this record to the table */
     if (ov.o_area > 0)
     {
-	int oa = 
-	    ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tabove))];
-	int ob = 
-	    ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tbelow))];
+	int oa = ExtCurStyle->exts_planeOrder[ecpls->plane_of_tile];
+	int ob = ExtCurStyle->exts_planeOrder[ecpls->plane_checked];
 	if (oa > ob)
 	{
 	    /*
@@ -421,6 +443,9 @@ extAddOverlap(tbelow, ecpls)
 	    extNregAdjustCap(rabove, 0.0, 
 		"obsolete_overlap (skipped, wrong direction)");
 	    
+        /* If the regions are the same, skip this part */
+        if (rabove == rbelow) return (0);
+
 	/* Find the coupling hash record */
 	if (rabove < rbelow) ck.ck_1 = rabove, ck.ck_2 = rbelow;
 	else ck.ck_1 = rbelow, ck.ck_2 = rabove;
@@ -434,14 +459,13 @@ extAddOverlap(tbelow, ecpls)
 		ov.o_area, "overlap");
 	extSetCapValue(he, c);
     }
-
     return (0);
 }
 
 int
 extSubtractOverlap(tile, ov)
-    register Tile *tile;
-    register struct overlap *ov;
+    Tile *tile;
+    struct overlap *ov;
 {
     Rect r;
     int area;
@@ -457,8 +481,8 @@ extSubtractOverlap(tile, ov)
 
 int
 extSubtractOverlap2(tile, ov)
-    register Tile *tile;
-    register struct overlap *ov;
+    Tile *tile;
+    struct overlap *ov;
 {
     struct overlap ovnew;
     int area, pNum;
@@ -568,6 +592,7 @@ extBasicCouple(tile, ecs)
 
 Rect extSideOverlapSearchArea;
 
+int
 extAddCouple(bp, ecs)
     Boundary *bp;	/* Boundary being considered */
     extCapStruct *ecs;
@@ -629,7 +654,7 @@ extAddCouple(bp, ecs)
     }
 
     if (extCoupleList)
-	(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[DBPlane(tin)],
+	(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[ecs->plane],
 		&r, &ExtCurStyle->exts_sideCoupleOtherEdges[tin][tout],
 		proc, (ClientData) bp);
 
@@ -638,11 +663,13 @@ extAddCouple(bp, ecs)
 	pMask = ExtCurStyle->exts_sideOverlapOtherPlanes[tin][tout];
 	extSideOverlapSearchArea = ovr;
 	extOverlapDef = def;
+
+	esws.bp = bp;
+	esws.plane_of_boundary = ecs->plane;
+
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	    if (PlaneMaskHasPlane(pMask, pNum))
 	    {
-		esws.bp = bp;
-		esws.plane_of_boundary = ecs->plane;
 		esws.plane_checked = pNum;
 		(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 			&ovr, &ExtCurStyle->exts_sideOverlapOtherTypes[tin][tout],
@@ -672,6 +699,7 @@ extAddCouple(bp, ecs)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideOverlap(tp, esws)
     Tile *tp;			/* Overlapped tile */
     extSidewallStruct *esws;	/* Overlapping edge and plane information */
@@ -682,15 +710,12 @@ extSideOverlap(tp, esws)
     TileType ta, tb;
     Rect tpr;
     struct overlap ov;
-    register HashEntry *he;
-    register EdgeCap *e;
+    HashEntry *he;
+    EdgeCap *e;
     int length, areaAccountedFor;
     CapValue cap;
     CoupleKey ck;
 
-    if (rtp == rbp)
-	return (0);
-
     if (bp->b_segment.r_xtop == bp->b_segment.r_xbot)
     {
 	length = MIN(bp->b_segment.r_ytop, TOP(tp))
@@ -711,6 +736,10 @@ extSideOverlap(tp, esws)
     ta = TiGetType(bp->b_inside);
     tb = TiGetType(tp);
 
+    /* Avoid doing the code below if we're just going to return without */
+    /* changing anything.                                               */
+    if ((tb == TT_SPACE) && (rtp == rbp)) return (0);
+
     /* Revert any contacts to their residues */
     if (DBIsContact(ta))
 	ta = DBPlaneToResidue(ta, esws->plane_of_boundary);
@@ -760,13 +789,14 @@ extSideOverlap(tp, esws)
 		    break;
 		}
 	    }
-	    cap += e->ec_cap * ov.o_area;
+	    if (rtp != rbp)
+		cap += e->ec_cap * ov.o_area;
 	    areaAccountedFor += ov.o_area;
 	}
     }
     
     /* Add in the new capacitance. */
-    if (TiGetType(tp) == TT_SPACE)
+    if (tb == TT_SPACE)
     {
 	/* Is tp a space tile?  If so, extGetRegion points to garbage;  	
 	 * make terminal 2 point to ground.
@@ -776,16 +806,8 @@ extSideOverlap(tp, esws)
     }
     else
     {
-	int oa;
-	int ob;
-	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
-	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
-	he = HashFind(extCoupleHashPtr, (char *) &ck);
-	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
-	extSetCapValue(he, cap + extGetCapValue(he));
-
-	oa = ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(bp->b_inside))];
-	ob = ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tp))];
+	int oa = ExtCurStyle->exts_planeOrder[esws->plane_of_boundary];
+	int ob = ExtCurStyle->exts_planeOrder[esws->plane_checked];
 	if (oa > ob)
 	{
 	    /* If the overlapped tile is between the substrate and the boundary
@@ -794,16 +816,15 @@ extSideOverlap(tp, esws)
 	     * we now know it is shielded from the substrate.
 	     */
 	    CapValue subcap;
-	    TileType intype = TiGetType(bp->b_inside);
 	    TileType outtype = TiGetType(bp->b_outside);
 
 	    /* Decompose contacts into their residues */
-	    if (DBIsContact(intype))
-		intype = DBPlaneToResidue(intype, esws->plane_of_boundary);
+	    if (DBIsContact(ta))
+		ta = DBPlaneToResidue(ta, esws->plane_of_boundary);
 	    if (DBIsContact(outtype))
 		outtype = DBPlaneToResidue(outtype, esws->plane_of_boundary);
 
-	    subcap = (ExtCurStyle->exts_perimCap[intype][outtype] *
+	    subcap = (ExtCurStyle->exts_perimCap[ta][outtype] *
 			MIN(areaAccountedFor, length));
 	    rbp->nreg_cap -= subcap;
 	    if (CAP_DEBUG)
@@ -811,8 +832,17 @@ extSideOverlap(tp, esws)
 	} else if (CAP_DEBUG)
 	    extNregAdjustCap(rbp, 0.0, 
 		"obsolete_perimcap (skipped, wrong direction)");
-    }
 
+	/* If the nodes are electrically connected, then we don't add	*/
+	/* any side overlap capacitance to the node.			*/
+	if (rtp == rbp) return (0);
+
+	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
+	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
+	he = HashFind(extCoupleHashPtr, (char *) &ck);
+	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
+	extSetCapValue(he, cap + extGetCapValue(he));
+    }
     return (0);
 }
 
@@ -843,13 +873,14 @@ extSideOverlap(tp, esws)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideLeft(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -891,13 +922,14 @@ extSideLeft(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideRight(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -939,13 +971,14 @@ extSideRight(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideTop(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -987,13 +1020,14 @@ extSideTop(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideBottom(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -1036,6 +1070,7 @@ extSideBottom(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+void
 extSideCommon(rinside, rfar, tpnear, tpfar, overlap, sep)
     NodeRegion *rinside, *rfar;	/* Both must be valid */
     Tile *tpnear, *tpfar;	/* Tiles on near and far side of edge */
@@ -1044,8 +1079,8 @@ extSideCommon(rinside, rfar, tpnear, tpfar, overlap, sep)
 				 */
 {
     TileType near = TiGetType(tpnear), far = TiGetType(tpfar);
-    register HashEntry *he;
-    register EdgeCap *e;
+    HashEntry *he;
+    EdgeCap *e;
     CoupleKey ck;
     CapValue cap;
 
