@@ -27,14 +27,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHard.c,v 1.2 20
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
@@ -240,7 +240,7 @@ extHardSetLabel(scx, reg, arg)
     len = strlen(oldlab->lab_text) + prefixlen;
 
     /* Allocate a Label big enough to hold the complete path */
-    MALLOC(Label *, newlab, (unsigned) (sizeof (Label) + len - 3));
+    newlab = (Label *) mallocMagic((unsigned) (sizeof (Label) + len - 3));
     r=oldlab->lab_rect;
     if (!GEO_SURROUND(&scx->scx_area,&r))
     {
@@ -340,7 +340,7 @@ extHardGenerateLabel(scx, reg, arg)
     extMakeNodeNumPrint(gen, reg->treg_pnum, reg->treg_ll);
     prefixlen = tpath->tp_next - tpath->tp_first;
     len = strlen(gen) + prefixlen;
-    MALLOC(Label *, newlab, (unsigned) (sizeof (Label) + len - 3));
+    newlab = (Label *) mallocMagic((unsigned) (sizeof (Label) + len - 3));
     r.r_ll = reg->treg_tile->ti_ll;
     GEOCLIP(&r,&scx->scx_area);
     r.r_ur.p_x = r.r_ll.p_x+1;
@@ -408,7 +408,7 @@ extHardFreeAll(def, tReg)
 
 	/* Free all LabelLists and then the region */
 	for (ll = reg->treg_labels; ll; ll = ll->ll_next)
-	    FREE((char *) ll);
-	FREE((char *) reg);
+	    freeMagic((char *) ll);
+	freeMagic((char *) reg);
     }
 }
