@@ -25,7 +25,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHier.c,v 1.5 20
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHier.c,v 1.5 20
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "debug/debug.h"
@@ -213,7 +214,7 @@ extHierConnectFunc2(cum, ha)
 	    nn->nn_node = node1;
 	    nn->nn_next = node1->node_names;
 	    node1->node_names = node2->node_names;
-	    FREE((char *) node2);
+	    freeMagic((char *) node2);
 	}
     }
     else if (r.r_xtop > r.r_xbot && r.r_ytop > r.r_ybot)
@@ -405,9 +406,9 @@ extOutputConns(table, outf)
 		}
 	    }
 	    nn->nn_node = (Node *) NULL;
-	    FREE((char *) node);
+	    freeMagic((char *) node);
 	}
-	FREE((char *) nfirst);
+	freeMagic((char *) nfirst);
     }
 }
 
@@ -441,8 +442,8 @@ extHierNewNode(he)
 
     nclasses = ExtCurStyle->exts_numResistClasses;
     n = (nclasses - 1) * sizeof (PerimArea) + sizeof (Node);
-    MALLOC(NodeName *, nn, sizeof (NodeName));
-    MALLOC(Node *, node, (unsigned) n);
+    nn = (NodeName *) mallocMagic((unsigned) (sizeof (NodeName)));
+    node = (Node *) mallocMagic((unsigned) n);
 
     nn->nn_node = node;
     nn->nn_next = (NodeName *) NULL;
@@ -486,7 +487,7 @@ extHierLabFirst(tile, arg)
 {
     LabRegion *new;
 
-    MALLOC(LabRegion *, new, sizeof (LabRegion));
+    new = (LabRegion *) mallocMagic((unsigned) (sizeof (LabRegion)));
     new->lreg_next = (LabRegion *) NULL;
     new->lreg_labels = (LabelList *) NULL;
     new->lreg_pnum = DBNumPlanes;
@@ -551,7 +552,7 @@ extHierNewOne()
     }
     else
     {
-	MALLOC(ExtTree *, et, sizeof (ExtTree));
+	et = (ExtTree *) mallocMagic((unsigned)(sizeof (ExtTree)));
 	(void) sprintf(defname, "__EXTTREE%d__", extHierOneNameSuffix++);
 	DBNewYank(defname, &et->et_use, &dummy);
     }
