@@ -22,10 +22,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtInter.c,v 1.2 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -34,8 +35,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtInter.c,v 1.2 2
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
-#include "misc/styles.h"
+#include "utils/signals.h"
+#include "utils/styles.h"
 
     /* Local data */
 CellUse *extInterUse = (CellUse *) NULL;	/* Subtree being processed */
