@@ -31,7 +31,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtLength.c,v 1.2
 #include <ctype.h>
 #include <math.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -42,12 +42,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtLength.c,v 1.2
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/stack.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 
 /* Temporary cell for holding an entire flattened net */
@@ -90,6 +90,7 @@ static Label *extLengthLabelList;
 struct extPathArg
 {
     int		 epa_min, epa_max;
+    int		 epa_pNum;
     Label	*epa_lab1, *epa_lab2;
 };
 
@@ -301,12 +302,12 @@ extLength(rootUse, f)
 	    }
 
 	    /* Free the driver label */
-	    FREE((char *) dLab);
+	    freeMagic((char *) dLab);
 	}
 
 	/* Free all the receiver labels built up during this iteration */
 	for (rLab = rList; rLab; rLab = rLab->lab_next)
-	    FREE((char *) rLab);
+	    freeMagic((char *) rLab);
 
 	/* For sanity since we've freed the driver label list */
 	HashSetValue(he, (ClientData) NULL);
@@ -502,7 +503,7 @@ extLengthLabelsFunc(scx, label, tpath)
     /* Allocate and fill in a new hierarchical label */
     len = strlen(tpath->tp_first) + sizeof (Label)
 	- sizeof newLab->lab_text + 1;
-    MALLOC(Label *, newLab, (unsigned) len);
+    newLab = (Label *) mallocMagic((unsigned) len);
     newLab->lab_type = label->lab_type;
     GeoTransPos(&scx->scx_trans, label->lab_pos, newLab->lab_pos);
     GeoTransRect(&scx->scx_trans, &label->lab_rect, &newLab->lab_rect);
@@ -579,7 +580,7 @@ extPathLabelFunc(rect, text, childLab, pLabList)
     int len;
 
     len = strlen(text) + sizeof (Label) - sizeof lab->lab_text + 1;
-    MALLOC(Label *, lab, (unsigned) len);
+    lab = (Label *) mallocMagic((unsigned) len);
     lab->lab_type = childLab->lab_type;
     lab->lab_rect = *rect;
     lab->lab_pos = GEO_CENTER;	/* Irrelevant */
@@ -648,9 +649,12 @@ extPathPairDistance(lab1, lab2, pMin, pMax)
     pMask = DBTechTypesToPlanes(&mask);
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	if (PlaneMaskHasPlane(pMask, pNum))
+	{
+	    epa.epa_pNum = pNum;
 	    (void) DBSrPaintClient((Tile *) NULL, extPathDef->cd_planes[pNum],
 		    &r, &mask, (ClientData) MINFINITY,
 		    extPathPairFunc, (ClientData) &epa);
+	}
 
     /* Pass the min and max delay back to our caller */
     *pMin = epa.epa_min;
@@ -765,7 +769,6 @@ extPathFlood(tile, p, distance, epa)
 				 */
 {
     TileType type = TiGetType(tile);
-    int tilePlaneNum = DBPlane(type);
     Label *lab2 = epa->epa_lab2;
     int pMask, pNum, newdistance;
     Tile *tp;
@@ -835,8 +838,11 @@ extPathFlood(tile, p, distance, epa)
     /* Try connections to other planes */
     if (DBIsContact(type))
     {
-	for (pNum = tilePlaneNum - 1; pNum <= tilePlaneNum + 1; pNum += 2)
-	    if (PlaneMaskHasPlane(DBConnPlanes[type], pNum))
+	int pMask = DBConnPlanes[type];
+	pMask &= ~(PlaneNumToMaskBit(epa->epa_pNum));
+
+	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
+	    if (PlaneMaskHasPlane(pMask, pNum))
 	    {
 		Plane *plane = extPathDef->cd_planes[pNum];
 		 
@@ -849,7 +855,9 @@ extPathFlood(tile, p, distance, epa)
 		if (tp->ti_client == (ClientData) MINFINITY
 			&& DBConnectsTo(type, TiGetType(tp)))
 		{
-		    extPathFlood(tp, p, distance, epa);
+		    struct extPathArg newepa = *epa;
+		    newepa.epa_pNum = pNum;
+		    extPathFlood(tp, p, distance, newepa);
 		}
 	    }
     }
@@ -866,20 +874,24 @@ extPathFlood(tile, p, distance, epa)
     if (pMask = DBAllConnPlanes[type])
     {
 	struct extPathFloodArg epfa;
+	struct extPathArg newepa = *epa;
 	Rect biggerArea;
 
 	TITORECT(tile, &epfa.epfa_srcArea);
 	GEO_EXPAND(&epfa.epfa_srcArea, 1, &biggerArea);
 	epfa.epfa_distance = distance;
-	epfa.epfa_epa = epa;
+	epfa.epfa_epa = &newepa;
 	epfa.epfa_srcPoint = p;
 	epfa.epfa_srcTile = tile;
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
-	    if (pNum != tilePlaneNum && PlaneMaskHasPlane(pMask, pNum))
+	    if (pNum != epa->epa_pNum && PlaneMaskHasPlane(pMask, pNum))
+	    {
+		newepa.epa_pNum = pNum;
 		(void) DBSrPaintClient((Tile *) NULL,
 			extPathDef->cd_planes[pNum], &biggerArea,
 			&DBConnectTbl[type], (ClientData) MINFINITY,
 			extPathFloodFunc, (ClientData) &epfa);
+	    }
     }
 }
 
