@@ -23,9 +23,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtMain.c,v 1.2 20
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -34,13 +35,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtMain.c,v 1.2 20
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 
 /* Imports from elsewhere in this module */
 extern FILE *extFileOpen();
