@@ -24,7 +24,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtNghbors.c,v 1.3
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -34,7 +35,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtNghbors.c,v 1.3
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 
 /*
@@ -61,8 +62,11 @@ ClientData extNbrUn;
  * to arg->fra_region.
  *
  * Results:
- *	Returns 0 normally, or 1 if a client decided to abort the
- *	search, or if an interrupt was seen.
+ *	Returns the number of tiles that are found to be connected.
+ *	This is used to find, for example, transistor gates made of
+ *	only one tile, for which a simple calculation suffices for
+ *	computing length and width.  If an error occurred, returns
+ *	the value -1.
  *
  * Side effects:
  *	See comments above.
@@ -81,9 +85,11 @@ ExtFindNeighbors(tile, tilePlaneNum, arg)
     TileType type, t;
     TileTypeBitMask *mask;
     Rect biggerArea;
-    int pNum, pMask;
+    int pNum, pMask, tilesfound;
     PlaneAndArea pla;
 
+    tilesfound = 0;
+
     extNbrUn = arg->fra_uninit;
     if (extNodeStack == (Stack *) NULL)
 	extNodeStack = StackNew(64);
@@ -116,6 +122,7 @@ ExtFindNeighbors(tile, tilePlaneNum, arg)
 	if (tile->ti_client == (ClientData) arg->fra_region)
 	    continue;
 	tile->ti_client = (ClientData) arg->fra_region;
+	tilesfound++;
 	if (DebugIsSet(extDebugID, extDebNeighbor))
 	    extShowTile(tile, "neighbor", 1);
 
@@ -206,6 +213,7 @@ donesides:
 	if (DBIsContact(type))
 	{
 	    pMask = DBConnPlanes[type];
+	    pMask &= ~(PlaneNumToMaskBit(tilePlaneNum));
 	    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 		if (PlaneMaskHasPlane(pMask, pNum))
 		{
@@ -255,7 +263,7 @@ donesides:
 	}
     }
 
-    return (0);
+    return tilesfound;
 
 fail:
     /* Flush the stack */
@@ -264,7 +272,7 @@ fail:
 	POPTILE(tile, tilePlaneNum);
 	tile->ti_client = (ClientData) arg->fra_region;
     }
-    return (1);
+    return -1;
 }
 
 /*
