@@ -23,7 +23,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtRegion.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtRegion.c,v 1.2
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /*
  * ----------------------------------------------------------------------------
@@ -150,9 +151,10 @@ ExtFindRegions(def, area, mask, connectsTo, uninit, first, each)
  * ----------------------------------------------------------------------------
  */
 
+int
 extRegionAreaFunc(tile, arg)
-    register Tile *tile;
-    register FindRegion *arg;
+    Tile *tile;
+    FindRegion *arg;
 {
     /* Allocate a new region */
     if (arg->fra_first)
@@ -191,14 +193,15 @@ extRegionAreaFunc(tile, arg)
  * ----------------------------------------------------------------------------
  */
 
+void
 ExtLabelRegions(def, connTo)
-    register CellDef *def;		/* Cell definition being labelled */
-    register TileTypeBitMask *connTo;	/* Connectivity table (see above) */
+    CellDef *def;		/* Cell definition being labelled */
+    TileTypeBitMask *connTo;	/* Connectivity table (see above) */
 {
     static Point offsets[] = { { 0, 0 }, { 0, -1 }, { -1, -1 }, { -1, 0 } };
-    register LabelList *ll;
-    register Label *lab;
-    register Tile *tp;
+    LabelList *ll;
+    Label *lab;
+    Tile *tp;
     LabRegion *reg;
     int quad, pNum;
     Point p;
@@ -225,7 +228,7 @@ ExtLabelRegions(def, connTo)
 		    && extHasRegion(tp, extUnInit))
 	    {
 		reg = (LabRegion *) extGetRegion(tp);
-		MALLOC(LabelList *, ll, sizeof (LabelList));
+		ll = (LabelList *) mallocMagic((unsigned) (sizeof (LabelList)));
 		ll->ll_label = lab;
 		ll->ll_next = reg->lreg_labels;
 		reg->lreg_labels = ll;
@@ -255,15 +258,17 @@ ExtLabelRegions(def, connTo)
  *
  * ----------------------------------------------------------------------------
  */
+
+void
 ExtLabelOneRegion(def, connTo, reg)
-    register CellDef *def;		/* Cell definition being labelled */
-    register TileTypeBitMask *connTo;	/* Connectivity table (see above) */
+    CellDef *def;		/* Cell definition being labelled */
+    TileTypeBitMask *connTo;	/* Connectivity table (see above) */
     NodeRegion  *reg;			/* The region whose labels we want */
 {
     static Point offsets[] = { { 0, 0 }, { 0, -1 }, { -1, -1 }, { -1, 0 } };
-    register LabelList *ll;
-    register Label *lab;
-    register Tile *tp;
+    LabelList *ll;
+    Label *lab;
+    Tile *tp;
     int quad, pNum;
     Point p;
 
@@ -290,7 +295,7 @@ ExtLabelOneRegion(def, connTo, reg)
 	    if (extConnectsTo(TiGetType(tp), lab->lab_type, connTo)
 		    && (NodeRegion *) extGetRegion(tp) == reg)
 	    {
-		MALLOC(LabelList *, ll, sizeof (LabelList));
+		ll = (LabelList *) mallocMagic((unsigned) (sizeof (LabelList)));
 		ll->ll_label = lab;
 		ll->ll_next = reg->nreg_labels;
 		reg->nreg_labels = ll;
@@ -327,12 +332,12 @@ ExtLabelOneRegion(def, connTo, reg)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtResetTiles(def, resetTo)
-    register CellDef *def;
+    CellDef *def;
     ClientData resetTo;		/* New value for ti_client */
 {
-    register int pNum;
+    int pNum;
 
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	DBResetTilePlane(def->cd_planes[pNum], resetTo);
@@ -361,45 +366,45 @@ ExtResetTiles(def, resetTo)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtFreeRegions(regList)
     Region *regList;	/* List of regions to be freed */
 {
-    register Region *reg;
+    Region *reg;
 
     for (reg = regList; reg; reg = reg->reg_next)
-	FREE((char *) reg);
+	freeMagic((char *) reg);
 }
 
-Void
+void
 ExtFreeLabRegions(regList)
     LabRegion *regList;	/* List of regions to be freed */
 {
-    register LabRegion *lreg;
-    register LabelList *ll;
+    LabRegion *lreg;
+    LabelList *ll;
 
     for (lreg = regList; lreg; lreg = lreg->lreg_next)
     {
 	for (ll = lreg->lreg_labels; ll; ll = ll->ll_next)
-	    FREE((char *) ll);
-	FREE((char *) lreg);
+	    freeMagic((char *) ll);
+	freeMagic((char *) lreg);
     }
 }
 
-Void
+void
 ExtFreeHierLabRegions(regList)
     Region *regList;	/* List of regions to be freed */
 {
-    register Region *reg;
-    register LabelList *ll;
+    Region *reg;
+    LabelList *ll;
 
     for (reg = regList; reg; reg = reg->reg_next)
     {
 	for (ll = ((LabRegion *)reg)->lreg_labels; ll; ll = ll->ll_next)
 	{
-	    FREE((char *) ll->ll_label);
-	    FREE((char *) ll);
+	    freeMagic((char *) ll->ll_label);
+	    freeMagic((char *) ll);
 	}
-	FREE((char *) reg);
+	freeMagic((char *) reg);
     }
 }
