@@ -27,7 +27,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtSubtree.c,v 1.3
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -38,10 +39,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtSubtree.c,v 1.3
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 #ifdef	exactinteractions
 /*
@@ -924,7 +925,7 @@ extSubtreeHardNode(tp, et, ha)
      */
     if (arg.hw_label)
     {
-	MALLOC(LabelList *, ll, sizeof (LabelList));
+	ll = (LabelList *) mallocMagic((unsigned) (sizeof (LabelList)));
 	lreg->lreg_labels = ll;
 	ll->ll_next = (LabelList *) NULL;
 	ll->ll_label = arg.hw_label;
