@@ -25,10 +25,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtTest.c,v 1.2 20
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -36,7 +36,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtTest.c,v 1.2 20
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
