@@ -18,7 +18,7 @@
 
 #ifndef lint
 static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtTimes.c,v 1.4 2001/07/23 17:49:52 tim Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -29,7 +29,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtTimes.c,v 1.4 2
 #include <sys/param.h>
 #include <sys/times.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -94,9 +95,24 @@ struct cumStats cumPercentInteraction;
 struct cumStats cumTotalArea, cumInteractArea, cumClippedArea;
 
 FILE *extDevNull = NULL;
+
+/* Forward declarations */
+
 struct cellStats *extGetStats();
+void extTimesCellFunc();
+void extTimesIncrFunc();
+void extTimesSummaryFunc();
+void extTimesParentFunc();
+void extTimeProc();
+void extCumInit();
+void extCumOutput();
+void extCumAdd();
+void extPaintOnly(CellDef *);
+void extHierCell(CellDef *);
+int  extCountTiles();
 
 extern int extDefInitFunc();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -142,7 +158,7 @@ extern int extDefInitFunc();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtTimes(rootUse, f)
     CellUse *rootUse;
     FILE *f;
@@ -215,8 +231,8 @@ ExtTimes(rootUse, f)
     }
 
     /* Output the summary statistics */
-    (void) fprintf(f, "\n\nSummary statistics:\n\n");
-    (void) fprintf(f, "%s %8s %8s %8s %8s\n",
+    fprintf(f, "\n\nSummary statistics:\n\n");
+    fprintf(f, "%s %8s %8s %8s %8s\n",
 	      "               ", "min", "max", "mean", "std.dev");
     extCumOutput("fets/sec paint ", &cumFetsPerSecPaint, f);
     extCumOutput("fets/sec hier  ", &cumFetsPerSecHier, f);
@@ -235,8 +251,8 @@ ExtTimes(rootUse, f)
 	clip = 100.0 * cumClippedArea.cums_sum / cumTotalArea.cums_sum;
 	inter = 100.0 * cumInteractArea.cums_sum / cumTotalArea.cums_sum;
     }
-    (void) fprintf(f, "Mean %% clipped area = %.2f\n", clip);
-    (void) fprintf(f, "Mean %% interaction area = %.2f\n", inter);
+    fprintf(f, "Mean %% clipped area = %.2f\n", clip);
+    fprintf(f, "Mean %% interaction area = %.2f\n", inter);
 
     /* Free the hash table */
     HashKill(&cellStatsTable);
@@ -316,14 +332,13 @@ extTimesInitFunc(use)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesCellFunc(cs)
     struct cellStats *cs;
 {
     extern long extSubtreeTotalArea;
     extern long extSubtreeInteractionArea;
     extern long extSubtreeClippedArea;
-    int extCountTiles(), extPaintOnly(), extHierCell();
     TransRegion *transList, *tl;
     CellDef *def = cs->cs_def;
     int pNum;
@@ -370,7 +385,7 @@ extTimesCellFunc(cs)
  *	Increments cs->cs_rects.
  */
 
-    /*ARGSUSED*/
+int
 extCountTiles(tile, cs)
     Tile *tile;			/* UNUSED */
     struct cellStats *cs;
@@ -403,7 +418,7 @@ extCountTiles(tile, cs)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesIncrFunc(cs)
     struct cellStats *cs;
 {
@@ -452,7 +467,7 @@ extTimesIncrFunc(cs)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesSummaryFunc(cs, f)
     struct cellStats *cs;
     FILE *f;
@@ -500,30 +515,30 @@ extTimesSummaryFunc(cs, f)
     }
 
     /* Cell name */
-    (void) fprintf(f, "\n%8s %8s %s\n", "", "", cs->cs_def->cd_name);
+    fprintf(f, "\n%8s %8s %s\n", "", "", cs->cs_def->cd_name);
 
     /* Sizes */
-    (void) fprintf(f, "%8d %8d (paint) fets rects\n",
+    fprintf(f, "%8d %8d (paint) fets rects\n",
 			cs->cs_fets, cs->cs_rects);
-    (void) fprintf(f, "%8d %8d (hier) fets rects\n",
+    fprintf(f, "%8d %8d (hier) fets rects\n",
 			cs->cs_hfets, cs->cs_hrects);
-    (void) fprintf(f, "%8d %8d (flat) fets rects\n",
+    fprintf(f, "%8d %8d (flat) fets rects\n",
 			cs->cs_ffets, cs->cs_frects);
 
     /* Times */
-    (void) fprintf(f, "%8.2f %8.2f Tpaint, Tcell\n", tpaint, tcell);
-    (void) fprintf(f, "%8.2f %8.2f Thier, Tincr\n", thier, tincr);
+    fprintf(f, "%8.2f %8.2f Tpaint, Tcell\n", tpaint, tcell);
+    fprintf(f, "%8.2f %8.2f Thier, Tincr\n", thier, tincr);
 
     /* Speeds */
-    (void) fprintf(f, "%8.2f %8.2f (paint) fets/sec rects/sec\n",
+    fprintf(f, "%8.2f %8.2f (paint) fets/sec rects/sec\n",
 			    fetspaint, rectspaint);
-    (void) fprintf(f, "%8.2f %8.2f (hier)  fets/sec rects/sec\n",
+    fprintf(f, "%8.2f %8.2f (hier)  fets/sec rects/sec\n",
 			    fetshier, rectshier);
-    (void) fprintf(f, "%8.2f %8.2f (flat)  fets/sec rects/sec\n",
+    fprintf(f, "%8.2f %8.2f (flat)  fets/sec rects/sec\n",
 			    fetsflat, rectsflat);
 
     /* Fraction of area in subtree processing */
-    (void) fprintf(f, "%8.2f %8.2f         clip %%  inter %%\n",
+    fprintf(f, "%8.2f %8.2f         clip %%  inter %%\n",
 			    pctclip, pctinter);
 
     /* Accumulate statistics */
@@ -561,7 +576,7 @@ extTimesSummaryFunc(cs, f)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesParentFunc(def, cs)
     CellDef *def;
     struct cellStats *cs;
@@ -751,6 +766,7 @@ extTimesFlatUse(use, cs)
  * ----------------------------------------------------------------------------
  */
 
+void
 extTimeProc(proc, def, tv)
     int (*proc)();
     CellDef *def;
@@ -808,7 +824,7 @@ extTimeProc(proc, def, tv)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extPaintOnly(def)
     CellDef *def;
 {
@@ -836,7 +852,7 @@ extPaintOnly(def)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extHierCell(def)
     CellDef *def;
 {
@@ -859,7 +875,7 @@ extHierCell(def)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumInit(cum)
     struct cumStats *cum;
 {
@@ -886,7 +902,7 @@ extCumInit(cum)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumOutput(str, cum, f)
     char *str;			/* Prefix string */
     struct cumStats *cum;
@@ -902,16 +918,16 @@ extCumOutput(str, cum, f)
 	var = (cum->cums_sos / (double) cum->cums_n) - (mean * mean);
     }
 
-    (void) fprintf(f, "%s", str);
+    fprintf(f, "%s", str);
     if (cum->cums_min < INFINITY) 
-	(void) fprintf(f, " %8.2f", cum->cums_min);
+	fprintf(f, " %8.2f", cum->cums_min);
     else
-	(void) fprintf(f, "   <none>");
+	fprintf(f, "   <none>");
     if (cum->cums_max > MINFINITY) 
-	(void) fprintf(f, " %8.2f", cum->cums_max);
+	fprintf(f, " %8.2f", cum->cums_max);
     else
-	(void) fprintf(f, "   <none>");
-    (void) fprintf(f, " %8.2f %8.2f\n", mean, sqrt(var));
+	fprintf(f, "   <none>");
+    fprintf(f, " %8.2f %8.2f\n", mean, sqrt(var));
 }
 
 /*
@@ -931,7 +947,7 @@ extCumOutput(str, cum, f)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumAdd(cum, v)
     struct cumStats *cum;
     double v;
@@ -994,7 +1010,7 @@ extGetStats(def)
 int extInterCountHalo;
 CellDef *extInterCountDef;
 
-int
+void
 ExtInterCount(rootUse, halo, f)
     CellUse *rootUse;
     int halo;
@@ -1024,8 +1040,8 @@ ExtInterCount(rootUse, halo, f)
     (void) DBCellSrDefs(0, extDefInitFunc, (ClientData) 0);
 
     /* Output the summary statistics */
-    (void) fprintf(f, "\n\nSummary statistics:\n\n");
-    (void) fprintf(f, "%s %8s %8s %8s %8s\n",
+    fprintf(f, "\n\nSummary statistics:\n\n");
+    fprintf(f, "%s %8s %8s %8s %8s\n",
 	      "               ", "min", "max", "mean", "std.dev");
     extCumOutput("% cell interact", &cumPercentInteraction, f);
 
@@ -1033,9 +1049,10 @@ ExtInterCount(rootUse, halo, f)
     inter = 0.0;
     if (cumTotalArea.cums_sum > 0)
 	inter = 100.0 * cumInteractArea.cums_sum / cumTotalArea.cums_sum;
-    (void) fprintf(f, "Mean %% interaction area = %.2f\n", inter);
+    fprintf(f, "Mean %% interaction area = %.2f\n", inter);
 }
 
+int
 extInterAreaFunc(use, f)
     CellUse *use;
     FILE *f;
@@ -1073,7 +1090,7 @@ extInterAreaFunc(use, f)
     extCumAdd(&cumTotalArea, (double) area);
     extCumAdd(&cumInteractArea, (double) interarea);
 
-    (void) fprintf(f, "%7.2f%%  %s\n", pctinter, def->cd_name);
+    fprintf(f, "%7.2f%%  %s\n", pctinter, def->cd_name);
 
     /* Visit our children */
     (void) DBCellEnum(def, extInterAreaFunc, (ClientData) f);
