@@ -27,9 +27,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtUnique.c,v 1.3
 #ifdef SYSV
 #include <string.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -38,13 +39,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtUnique.c,v 1.3
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 
 /*
  * ----------------------------------------------------------------------------
