@@ -22,7 +22,7 @@
 #ifndef _EXTRACT_H
 #define _EXTRACT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* Extractor warnings */
 #define	EXTWARN_DUP	0x01	/* Warn if two nodes have the same name */
@@ -45,8 +45,9 @@ extern int ExtDoWarn;		/* Bitmask of above */
 #define DEV_RES         3		/* Resistor */
 #define DEV_CAP         4		/* Capacitor */
 #define DEV_DIODE	5		/* Diode */
-#define DEV_SUBCKT      6		/* Anything else... becomes an "X" */
-					/* record in SPICE.		   */
+#define DEV_SUBCKT      6		/* FET-like (general-purpose)	*/
+					/* subcircuit.			*/
+#define DEV_RSUBCKT    7		/* Resistor-like subcircuit.	*/
 
 /* Device names for .ext file output (new in version 7.2)	*/
 /* (defined in extract/ExtBasic.c *and* extflat/EFread.c)	*/
