@@ -23,23 +23,10 @@
  *
  */
 
-#define _EXTINT
+#ifndef _EXTRACTINT_H
+#define _EXTRACTINT_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_DATABASE
-int err1 = Need_to_include_database/database_header;
-#endif	/* _DATABASE */
-#ifndef	_TILES
-int err2 = Need_to_include_tiles/tile_header;
-#endif	/* _TILES */
-#ifndef	_HASH
-int err3 = Need_to_include_utils/hash_header;
-#endif	/* _HASH */
-#ifndef	_GEOMETRY
-int err4 = Need_to_include_utils/geometry_header;
-#endif	/* _GEOMETRY */
+#include "database/database.h"
 
 #undef	NT
 #define	NT	TT_MAXTYPES
@@ -196,6 +183,12 @@ typedef struct treg
     int		 treg_area;	/* Area of channel */
 } TransRegion;
 
+typedef struct {	/* Maintain plane information when pushing	*/
+    Rect area;		/* tiles on the node stack.  For use with	*/
+    int  plane;		/* function extNbrPushFunc().			*/
+} PlaneAndArea; 
+
+
 /*
  * The following updates reg->lreg_ll and reg->lreg_pnum so that
  * they are always the lowest leftmost coordinate in a cell, on
@@ -903,11 +896,15 @@ extern ClientData extUnInit;
 
 /* For non-recursive flooding algorithm */
 #define	VISITPENDING	((ClientData) NULL)	/* Marks tiles on stack */
-#define	PUSHTILE(tp) \
-    if (1) { \
+
+#define	PUSHTILE(tp, pl) \
 	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData) (tp), extNodeStack); \
-    } else
+	STACKPUSH((ClientData)tp, extNodeStack); \
+	STACKPUSH((ClientData)pl, extNodeStack)
+
+#define POPTILE(tp, pl) \
+	pl = (int) STACKPOP(extNodeStack); \
+	tp = (Tile *) STACKPOP(extNodeStack)
 
 /* ------------------------- Region finding --------------------------- */
 
@@ -951,7 +948,7 @@ extern Region *extHierLabFirst();	extern int extHierLabEach();
  */
 #define	NODETONODE(nold, et, nnew) \
 	if (1) { \
-	    register Tile *tp; \
+	    Tile *tp; \
  \
 	    (nnew) = (NodeRegion *) NULL; \
 	    NODETOTILE((nold), (et), tp); \
@@ -995,3 +992,4 @@ extern struct stack *extNodeStack;
 
 #include "extDebugInt.h"
 
+#endif /* _EXTRACTINT_H */
