@@ -23,7 +23,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/garouter/gaSimple.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -31,17 +32,17 @@ static char rcsid[] = "$Header: /ufs/repository/magic/garouter/gaSimple.c,v 1.2
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "netmenu/netmenu.h"
 #include "gcr/gcr.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "garouter/garouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
 #include "drc/drc.h"
 #include "debug/debug.h"
