@@ -21,26 +21,26 @@ static char rcsid[] = "$Header: /ufs/repository/magic/garouter/gaStem.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "netmenu/netmenu.h"
 #include "gcr/gcr.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "garouter/garouter.h"
 #include "gaInternal.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
 #include "drc/drc.h"
 #include "debug/debug.h"
@@ -84,6 +84,13 @@ int gaNumSimplePaint, gaNumMazePaint, gaNumExtPaint;
 /* Forward declarations */
 int gaStemContainingChannelFunc();
 bool gaStemAssign();
+void gaStemGridRange();
+void gaStemPaint();
+bool gaStemNetClear();
+bool gaStemInternalFunc();
+bool gaStemInternal();
+bool gaStemGrow();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -112,7 +119,7 @@ bool gaStemAssign();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 gaStemAssignAll(routeUse, netList)
     CellUse *routeUse;
     NLNetList *netList;
@@ -378,7 +385,7 @@ gaStemContainingChannelFunc(tile, pCh)
 
 bool
 gaStemGrow(area)
-    register Rect *area;
+    Rect *area;
 {
     Rect r;
     GCRChannel *ch;
@@ -642,7 +649,7 @@ gaStemCheckPin(routeUse, terminalLoc, ch, side, gridPoint, netList)
     NLNetList *netList;		/* Searched for obstructing terminals */
 {
     TileTypeBitMask destMask;
-    register GCRPin *pin;
+    GCRPin *pin;
     SimpleStem simple;
     short code;
     
@@ -680,8 +687,8 @@ gaStemCheckPin(routeUse, terminalLoc, ch, side, gridPoint, netList)
     destMask = DBZeroTypeBits;
     if ((code & GCRBLKM) == 0) TTMaskSetType(&destMask, RtrMetalType);
     if ((code & GCRBLKP) == 0) TTMaskSetType(&destMask, RtrPolyType);
-    if (ASSERT(!TTMaskEqual(&destMask, &DBZeroTypeBits), "gaStemCheckPin"))
-	return ((GCRPin *) NULL);
+
+    ASSERT(!TTMaskEqual(&destMask, &DBZeroTypeBits), "gaStemCheckPin");
 
     /*
      * Try to do things the simple way first, considering routes
@@ -777,15 +784,15 @@ hardway:
 
 bool
 gaStemNetClear(termArea, point, side, netList)
-    register Rect *termArea;	/* Area of the starting terminal */
+    Rect *termArea;	/* Area of the starting terminal */
     Point *point;		/* Crossing point where we want to end up */
     int side;			/* Direction of point relative to termArea */
     NLNetList *netList;		/* Netlist to check for terminals to avoid */
 {
     int min, max, start, type, grid;
-    register NLTermLoc *loc;
-    register NLTerm *term;
-    register NLNet *net;
+    NLTermLoc *loc;
+    NLTerm *term;
+    NLNet *net;
     Rect r;
 
     /* 
@@ -870,11 +877,11 @@ gaStemNetClear(termArea, point, side, netList)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 gaStemGridRange(type, r, pMinGrid, pMaxGrid, pStart)
     int type;
-    register Rect *r;
-    register int *pMinGrid, *pMaxGrid, *pStart;
+    Rect *r;
+    int *pMinGrid, *pMaxGrid, *pStart;
 {
     int min, max, start;
 
@@ -934,13 +941,13 @@ gaStemGridRange(type, r, pMinGrid, pMaxGrid, pStart)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 gaStemPaintAll(routeUse, netList)
     CellUse *routeUse;
     NLNetList *netList;
 {
-    register NLTermLoc *loc;
-    register NLTerm *term;
+    NLTermLoc *loc;
+    NLTerm *term;
     int numInt;
     NLNet *net;
 
@@ -994,7 +1001,7 @@ out:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 gaStemPaint(routeUse, terminalLoc)
     CellUse *routeUse;
     NLTermLoc *terminalLoc;
