@@ -21,14 +21,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/garouter/gaTest.c,v 1.3 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "debug/debug.h"
 #include "gcr/gcr.h"
@@ -39,10 +39,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/garouter/gaTest.c,v 1.3 20
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "textio/txcommands.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "commands/commands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 bool gaInitialized = FALSE;
 
@@ -61,9 +61,14 @@ int gaDebNoClean = 0;
 
 /* Used in the "*garoute split" command */
 int gaSplitPlaneMask;
-int (*gaSplitPaintPlane)();
+void (*gaSplitPaintPlane)();
 Rect gaSplitArea;
 int gaSplitType;
+
+/* Forward declarations */
+
+void GAInit();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -81,8 +86,7 @@ int gaSplitType;
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
-Void
+void
 GATest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -154,13 +158,13 @@ badCmd:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GAGenChans(chanType, area, f)
     int chanType;
     Rect *area;
     FILE *f;
 {
-    extern int DBPaintPlane(), DBPaintPlaneVert();
+    extern void DBPaintPlane(), DBPaintPlaneVert();
     int gaSplitFunc(), gaSplitOut();
     static CellDef *genDef = (CellDef *) NULL;
     static CellUse *genUse = (CellUse *) NULL;
@@ -261,11 +265,11 @@ gaSplitOut(tile, f)
     if (GEO_RECTNULL(&r))
 	return (0);
 
-    (void) fprintf(f, "garoute channel %d %d %d %d",
+    fprintf(f, "garoute channel %d %d %d %d",
 		r.r_xbot, r.r_ybot, r.r_xtop, r.r_ytop);
     if (TiGetType(tile) != TT_SPACE)
-	(void) fprintf(f, " %s", gaSplitType == CHAN_HRIVER ? "h" : "v");
-    (void) fprintf(f, "\n");
+	fprintf(f, " %s", gaSplitType == CHAN_HRIVER ? "h" : "v");
+    fprintf(f, "\n");
     return (0);
 }
 
@@ -375,10 +379,10 @@ gaSplitFunc(scx, plane)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GAInit()
 {
-    register n;
+    int n;
     static struct
     {
 	char	*di_name;
