@@ -22,7 +22,7 @@
 #ifndef _GCR_H
 #define _GCR_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* GCRPin:  One of these for each pin location along each edge of a channel.
  *	All of the pins for a given net are stored on a doubly-linked list
