@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrDebug.c,v 1.2 2001/
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/times.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "textio/textio.h"
 #include "tiles/tile.h"
@@ -79,7 +80,7 @@ GCRRouteFromFile(fname)
 	return ((GCRChannel *) NULL);
     }
 
-    MALLOC(GCRChannel *, ch, sizeof (GCRChannel));
+    ch = (GCRChannel *) mallocMagic((unsigned) (sizeof (GCRChannel)));
     ch->gcr_type = CHAN_NORMAL;
 /*     ch->gcr_area = box; */
     ch->gcr_transform = GeoIdentityTransform;
@@ -92,12 +93,12 @@ GCRRouteFromFile(fname)
     {
 	TxError("Couldn't initialize channel routing problem\n");
 	(void) fclose(fp);
-	FREE((char *) ch);
+	freeMagic((char *) ch);
 	return ((GCRChannel *) NULL);
     }
 
     (void) fclose(fp);
-    MALLOC(GCRColEl *, ch->gcr_lCol, (ch->gcr_width+2) * sizeof (GCRColEl));
+    ch->gcr_lCol = (GCRColEl *) mallocMagic((unsigned) ((ch->gcr_width+2) * sizeof (GCRColEl)));
     times(&tbuf1);
     (void) GCRroute(ch);
     times(&tbuf2);
@@ -150,15 +151,15 @@ gcrMakeChannel(ch, fp)
 
     lenWds = ch->gcr_length + 2;
     widWds = ch->gcr_width + 2;
-    MALLOC(int *, ch->gcr_density, lenWds * sizeof (int));
+    ch->gcr_density = (int *) mallocMagic((unsigned) (lenWds * sizeof (int)));
     ch->gcr_lPins = gcrMakePinLR(fp, 0, ch->gcr_width);
-    MALLOC(GCRPin *, ch->gcr_tPins, lenWds * sizeof (GCRPin));
-    MALLOC(GCRPin *, ch->gcr_bPins, lenWds * sizeof (GCRPin));
-    MALLOC(short **, ch->gcr_result, lenWds * sizeof (short *));
+    ch->gcr_tPins = (GCRPin *) mallocMagic((unsigned) (lenWds * sizeof (GCRPin)));
+    ch->gcr_bPins = (GCRPin *) mallocMagic((unsigned) (lenWds * sizeof (GCRPin)));
+    ch->gcr_result = (short **) mallocMagic((unsigned) (lenWds * sizeof (short *)));
 
     /* Initialize end columns */
-    MALLOC(short *, ch->gcr_result[0], widWds * sizeof (short));
-    MALLOC(short *, ch->gcr_result[ch->gcr_length+1], widWds * sizeof (short));
+    ch->gcr_result[0] = (short *) mallocMagic((unsigned) (widWds * sizeof (short)));
+    ch->gcr_result[ch->gcr_length+1] = (short *) mallocMagic((unsigned) (widWds * sizeof (short)));
     for (i = 0; i < widWds; i++)
     {
 	ch->gcr_result[0][i] = 0;
@@ -169,7 +170,7 @@ gcrMakeChannel(ch, fp)
     for (i = 1; i <= ch->gcr_length; i++)
     {
 	/* Allocate the column */
-	MALLOC(short *, ch->gcr_result[i], widWds * sizeof (short));
+	ch->gcr_result[i] = (short *) mallocMagic((unsigned) (widWds * sizeof (short)));
 
 	/* Initialize the bottom pin */
 	if (fscanf(fp, "%d", &pid) != 1)
@@ -240,7 +241,7 @@ gcrMakePinLR(fp, x, size)
     GCRPin *result;
     int i;
 
-    MALLOC(GCRPin *, result, (unsigned) (size+2) * sizeof (GCRPin));
+    result = (GCRPin *) mallocMagic((unsigned) ((size+2) * sizeof (GCRPin)));
     result[0].gcr_x = result[0].gcr_y = 0;
     result[0].gcr_pId = (GCRNet *) NULL;
     result[size + 1].gcr_x = result[size + 1].gcr_y = 0;
