@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrEdge.c,v 1.2 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "gcr/gcr.h"
