@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrFeas.c,v 1.2 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "gcr/gcr.h"
@@ -32,6 +33,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrFeas.c,v 1.2 2001/0
 
 extern int gcrStandalone;
 extern int gcrRouterErrors;
+
+/* Forward declarations */
+void gcrMakeFeasible();
 
 /*
  * ----------------------------------------------------------------------------
@@ -41,6 +45,7 @@ extern int gcrRouterErrors;
  *	to the first track that is either empty or already assigned to the net.
  *
  * Results:
+ *	None.
  *
  * Side effects:
  *	*failedTop and *failedBot get set true or false, depending on whether
@@ -51,6 +56,7 @@ extern int gcrRouterErrors;
  * ----------------------------------------------------------------------------
  */
 
+void
 gcrFeasible(ch, col)
     GCRChannel * ch;
     int 	 col;		/* Column for feasible connections	*/
@@ -200,6 +206,7 @@ gcrFeasible(ch, col)
  * ----------------------------------------------------------------------------
  */
 
+void
 gcrMakeFeasible(col, net, from, target, width)
     GCRColEl *  col;		/* Describes current column structure. */
     GCRNet   *  net;		/* Net being brought into column. */
