@@ -20,7 +20,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrInit.c,v 1.2 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
@@ -189,7 +190,7 @@ gcrLinkPin(pin, ht, ch)
     if (net == (GCRNet *) NULL)
     {
 	/* New net */
-	MALLOC(GCRNet *, net, sizeof (GCRNet));
+	net = (GCRNet *) mallocMagic((unsigned) (sizeof (GCRNet)));
 	HashSetValue(hEntry, (char *) net);
 	net->gcr_Id = (int) pin->gcr_pId;
 
@@ -286,7 +287,7 @@ gcrDensity(ch)
     lenWds = ch->gcr_length + 2;
     if (ch->gcr_density == (int *) NULL)
     {
-	MALLOC(int *, ch->gcr_density, lenWds * sizeof (int));
+	ch->gcr_density = (int *) mallocMagic((unsigned) (lenWds * sizeof (int)));
     }
     ch->gcr_density[0] = maxVal = density;
 
