@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrLib.c,v 1.2 2001/01
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "gcr/gcr.h"
@@ -399,7 +400,7 @@ gcrCopyCol(col, size)
     GCRColEl *	result;
     int i, limit;
 
-    MALLOC(GCRColEl *, result, (size+2) * sizeof (GCRColEl));
+    result = (GCRColEl *) mallocMagic((unsigned) ((size+2) * sizeof (GCRColEl)));
     limit = size + 2;
     for (i = 0; i < limit; i++)
 	result[i] = col[i];
