@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrRiver.c,v 1.2 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "gcr/gcr.h"
 #include "textio/textio.h"
