@@ -22,7 +22,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrShwFlgs.c,v 1.3 200
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
@@ -32,8 +32,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrShwFlgs.c,v 1.3 200
 #include "gcr/gcr.h"
 #include "utils/heap.h"
 #include "router/router.h"
-#include "main/main.h"
-#include "misc/styles.h"
+#include "utils/main.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 
 #define MAXFLAGS 17
