@@ -22,12 +22,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrUnsplit.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <stdlib.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "gcr/gcr.h"
 #include "utils/malloc.h"
 
+/* Forward declarations */
+
+void gcrMakeRuns();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -49,13 +55,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrUnsplit.c,v 1.2 200
  * ----------------------------------------------------------------------------
  */
 
+void
 gcrVacate(ch, column)
     GCRChannel * ch;
     int		 column;
 {
-    register int        i;
+    int        i;
     int		        to, count, gcrIsGreater();
-    register GCRColEl *	col;
+    GCRColEl *	col;
     GCRNet *		net, ** list;
     bool		nearEnd;
 
@@ -134,6 +141,7 @@ gcrVacate(ch, column)
  * ----------------------------------------------------------------------------
  */
 
+int
 gcrLook(ch, track, canCover)
     GCRChannel * ch;
     int		 track;
@@ -269,7 +277,7 @@ gcrClassify(ch, count)
     GCRChannel * ch;
     int	       * count;
 {
-    register GCRColEl *	col;
+    GCRColEl *	col;
     GCRPin   	      *	pin, * next;
     int			i, dist;
     GCRNet  **	result;
@@ -338,13 +346,15 @@ gcrClassify(ch, count)
  *	wiring occupying a range of tracks.
  *
  * Results:
- *	None.
+ *	Distance value (integer).
  *
  * Side effects:
  *	None.
  *
  * ----------------------------------------------------------------------------
  */
+
+int
 gcrRealDist(col, i, dist)
     GCRColEl * col;
     int i, dist;
@@ -377,6 +387,7 @@ gcrRealDist(col, i, dist)
  * ----------------------------------------------------------------------------
  */
 
+int
 gcrClass(net, track)
     GCRNet    * net;
     int		track;
@@ -434,6 +445,7 @@ gcrClass(net, track)
  * ----------------------------------------------------------------------------
  */
 
+void
 gcrMakeRuns(ch, column, list, count, riseFall)
     GCRChannel * ch;
     int		 column;
@@ -476,6 +488,7 @@ gcrMakeRuns(ch, column, list, count, riseFall)
 	    (abs(from-runTo)>=GCRMinJog) ||
 	    (GCRNearEnd(ch, column) &&
 		   (ch->gcr_rPins[runTo].gcr_pId==net)) )
+	{
 	    if(!riseFall)
 	    {
 		save=col[from].gcr_wanted;
@@ -489,6 +502,7 @@ gcrMakeRuns(ch, column, list, count, riseFall)
 	     */
 	    if(distToTarget>abs(runTo-to))
 		gcrMoveTrack(col, net, from, runTo);
+	}
 	gcrCheckCol(ch, column, "gcrMakeRuns");
     }
     freeMagic((char *) list);
@@ -510,6 +524,8 @@ gcrMakeRuns(ch, column, list, count, riseFall)
  *
  * ----------------------------------------------------------------------------
  */
+
+int
 gcrTryRun(ch, net, from, to, column)
     GCRChannel	* ch;
     GCRNet	* net;
