@@ -24,13 +24,14 @@
 #include <GL/glx.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/undo.h"
 #include "database/database.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "graphics/wind3d.h"
 #include "graphics/graphicsInt.h"
@@ -39,7 +40,7 @@
 #include "textio/textio.h"
 #include "textio/txcommands.h"
 #include "utils/utils.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "dbwind/dbwtech.h"
 #include "dbwind/dbwind.h"
 #include "extract/extract.h"
@@ -69,10 +70,6 @@ global WindClient W3DclientID;
 
 #define glTransYs(n)   (DisplayHeight(grXdpy, grXscrn)-(n))
 
-#ifndef TRUE
-#define TRUE True
-#endif
-
 /* forward declarations */
 
 void W3DCIFredisplay();
@@ -87,7 +84,7 @@ void
 w3dLock(w)
     MagWindow *w;
 {
-    grSimpleLock(w, True);
+    grSimpleLock(w, TRUE);
     w3dSetProjection(w);
 }
 
@@ -275,8 +272,8 @@ w3dFillOps(trans, tile, cliprect, ztop, zbot)
 	
 	if (np > 0)
 	{
-	    w3dFillPolygon(p, np, ztop, True);
-	    w3dFillPolygon(p, np, zbot, False);
+	    w3dFillPolygon(p, np, ztop, TRUE);
+	    w3dFillPolygon(p, np, zbot, FALSE);
 	}
     }
     else
@@ -290,8 +287,8 @@ w3dFillOps(trans, tile, cliprect, ztop, zbot)
     /* draw tile top and bottom */
     if (!GEO_RECTNULL(&r))
     {
-	w3dFillTile(&r, ztop, True);
-	w3dFillTile(&r, zbot, False);
+	w3dFillTile(&r, ztop, TRUE);
+	w3dFillTile(&r, zbot, FALSE);
     }
 
 #ifdef NONMANHATTAN
@@ -588,12 +585,12 @@ w3dPaintFunc(tile, cxp)
     if (!w3dIsLocked)
     {
 	w3dLock(w3dWindow);
-	w3dIsLocked = True;
+	w3dIsLocked = TRUE;
     }
     if (w3dNeedStyle)
     {
 	GrSetStuff(w3dStyle);
-	w3dNeedStyle = False;
+	w3dNeedStyle = FALSE;
     }
 
     w3dRenderVolume(tile, &scx->scx_trans, &scx->scx_area);
@@ -628,7 +625,7 @@ w3dCIFPaintFunc(tile, arg)
     if (!w3dIsLocked)
     {
 	w3dLock(w3dWindow);
-	w3dIsLocked = True;
+	w3dIsLocked = TRUE;
     }
     if (w3dNeedStyle)
     {
@@ -637,7 +634,7 @@ w3dCIFPaintFunc(tile, arg)
 		layer->cl_name,
 		layer->cl_renderStyle); */
 	GrSetStuff(layer->cl_renderStyle + TECHBEGINSTYLES);
-	w3dNeedStyle = False;
+	w3dNeedStyle = FALSE;
     }
 
     w3dRenderCIF(tile, layer, &GeoIdentityTransform);
@@ -692,7 +689,7 @@ w3dCutBox(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    bool hide = False;
+    bool hide = FALSE;
     int lidx = 1, num_layers;
     TileTypeBitMask mask;
     W3DclientRec *crec = (W3DclientRec *) w->w_clientData;
@@ -721,7 +718,7 @@ w3dCutBox(w, cmd)
 	else if (cmd->tx_argc == 2)
 	{
 	    if (!strcmp(cmd->tx_argv[1], "none"))
-		crec->clipped = False;
+		crec->clipped = FALSE;
 	    if (!strcmp(cmd->tx_argv[1], "box"))
 	    {
 		Rect rootBox;
@@ -732,7 +729,7 @@ w3dCutBox(w, cmd)
 		{
 		    if (rootBoxDef == cellDef)
 		    {
-			crec->clipped = True;
+			crec->clipped = TRUE;
 			crec->cutbox = rootBox;
 		    }
 		}
@@ -746,7 +743,7 @@ w3dCutBox(w, cmd)
 			StrIsInt(cmd->tx_argv[3]) &&	
 			StrIsInt(cmd->tx_argv[4]))
 	    {
-		crec->clipped = True;
+		crec->clipped = TRUE;
 		crec->cutbox.r_xbot = atoi(cmd->tx_argv[1]);
 		crec->cutbox.r_ybot = atoi(cmd->tx_argv[2]);
 		crec->cutbox.r_xtop = atoi(cmd->tx_argv[3]);
@@ -774,7 +771,7 @@ w3dSeeLayers(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    bool hide = False;
+    bool hide = FALSE;
     int lidx = 1, num_layers;
     TileTypeBitMask mask;
     W3DclientRec *crec = (W3DclientRec *) w->w_clientData;
@@ -784,7 +781,7 @@ w3dSeeLayers(w, cmd)
 	if (cmd->tx_argc == 3)
 	{
 	    lidx = 2;
-	    if (!strcmp(cmd->tx_argv[1], "no")) hide = True;
+	    if (!strcmp(cmd->tx_argv[1], "no")) hide = TRUE;
 	}
 
 	if (crec->cif)
@@ -876,16 +873,16 @@ w3dToggleCIF(w, cmd)
     if (cmd->tx_argc == 1)
     {
 
-	if ((crec->cif == False) && (CIFCurStyle != NULL))
+	if ((crec->cif == FALSE) && (CIFCurStyle != NULL))
 	{
 	    ((clientRec *)(W3DclientID))->w_redisplay = W3DCIFredisplay;
-	    crec->cif = True;
+	    crec->cif = TRUE;
 	    w3dRescale(crec, (float)CIFCurStyle->cs_scaleFactor);
 	}
-	else if (crec->cif == True)
+	else if (crec->cif == TRUE)
 	{
 	    ((clientRec *)(W3DclientID))->w_redisplay = W3Dredisplay;
-	    crec->cif = False;
+	    crec->cif = FALSE;
 	    w3dRescale(crec, 1.0 / (float)CIFCurStyle->cs_scaleFactor);
 	}
 
@@ -1284,11 +1281,11 @@ Set3DDefaults(mw, crec)
 
     /* Scale all factors appropriately for CIF display */
 
-    if (crec->cif == True)
+    if (crec->cif == TRUE)
 	w3dRescale(crec, (float)CIFCurStyle->cs_scaleFactor);
 
     /* Default is no clipping */
-    crec->clipped = False;	/* no clipping by default */
+    crec->clipped = FALSE;	/* no clipping by default */
 }
 
 /* -----------------------Event Procedures------------------------------ */
@@ -1319,7 +1316,6 @@ W3DEventProc(clientData, xevent)
     switch (xevent->type)
     {
 	case ButtonPress:
-	case ButtonRelease:
 	    break;
 	case KeyPress: {
 	    /* simple stuff, for now */
@@ -1327,7 +1323,7 @@ W3DEventProc(clientData, xevent)
 	    KeySym keysym;
 	    char inChar[10];
 	    int nbytes;
-	    bool action = True;
+	    bool action = TRUE;
 
 	    nbytes = XLookupString(KeyPressedEvent, inChar, sizeof(inChar),
 		&keysym, NULL);
@@ -1341,17 +1337,17 @@ W3DEventProc(clientData, xevent)
 		    if (crec->level > 0) crec->level--;
 		    break;
 		case XK_C:	/* do CIF layers */
-		    if ((crec->cif == False) && (CIFCurStyle != NULL))
+		    if ((crec->cif == FALSE) && (CIFCurStyle != NULL))
 		    {
 			((clientRec *)(W3DclientID))->w_redisplay = W3DCIFredisplay;
-			crec->cif = True;
+			crec->cif = TRUE;
 			w3dRescale(crec, (float)CIFCurStyle->cs_scaleFactor);
 			TTMaskSetMask(&crec->visible, &DBAllTypeBits);
 		    }
-		    else if (crec->cif == True)
+		    else if (crec->cif == TRUE)
 		    {
 			((clientRec *)(W3DclientID))->w_redisplay = W3Dredisplay;
-			crec->cif = False;
+			crec->cif = FALSE;
 			w3dRescale(crec, 1.0 / (float)CIFCurStyle->cs_scaleFactor);
 			TTMaskSetMask(&crec->visible, &DBAllTypeBits);
 		    }
@@ -1432,9 +1428,9 @@ W3DEventProc(clientData, xevent)
 		    TxPrintf("   C		toggle CIF/magic layer view\n");
 		    TxPrintf("   space	reset to view defaults\n");
 		    TxPrintf("   ?,h		print this help information\n");
-		    action = False;
+		    action = FALSE;
 		default:
-		    action = False;
+		    action = FALSE;
 	    }
 	    if (action)
 	    {
@@ -1492,7 +1488,7 @@ W3DEventProc(clientData, xevent)
  *	Replace the root cell of a window by the specified cell.
  *
  * Results:
- *	True if successful, False if not.  The 3D rendering window is
+ *	TRUE if successful, FALSE if not.  The 3D rendering window is
  *	not allowed to create new cells, only to render existing ones.
  *
  * Side effects:
@@ -1512,10 +1508,10 @@ W3DloadWindow(window, name)
 
     newEditDef = DBCellLookDef(name);
     if (newEditDef == (CellDef *)NULL)
-	return False;
+	return FALSE;
 
-    if (!DBCellRead(newEditDef, (char *)NULL, True))
-	return False;
+    if (!DBCellRead(newEditDef, (char *)NULL, TRUE))
+	return FALSE;
 
     DBReComputeBbox(newEditDef);
     loadBox = newEditDef->cd_bbox;
@@ -1538,7 +1534,7 @@ W3DloadWindow(window, name)
  * structures.
  *
  * Results:
- *	False if we have too many windows, True otherwise.
+ *	FALSE if we have too many windows, TRUE otherwise.
  *
  * Side effects:
  *	Initialize the window to be editing the background color.
@@ -1567,7 +1563,7 @@ W3Dcreate(window, argc, argv)
     if (w3dWindow != NULL)
     {
 	TxError("Only one 3D window allowed.\n");
-	return False;
+	return FALSE;
     }
 
     /* The 3D rendering, of course, *only* works with OpenGL, so in an	*/
@@ -1579,7 +1575,7 @@ W3Dcreate(window, argc, argv)
 	TxError("Display type is \"%s\".  OpenGL is required for the 3D display.\n",	
 		MainDisplayType);
 	TxError("Please restart magic with option \"-d OGL\".\n");
-	return False;
+	return FALSE;
     }
  
     crec = (W3DclientRec *) mallocMagic(sizeof(W3DclientRec));
@@ -1603,7 +1599,7 @@ W3Dcreate(window, argc, argv)
     /* Render cif by default.						*/
 
     crec->level = 1;
-    crec->cif = True;
+    crec->cif = TRUE;
 
     window->w_clientData = (ClientData) crec;
     window->w_flags &= ~(WIND_SCROLLABLE | WIND_SCROLLBARS | WIND_CAPTION |
@@ -1628,11 +1624,11 @@ W3Dcreate(window, argc, argv)
 	else
 	{
 	    TxError("Ambiguous directive:  Put cursor box in one of the windows.\n");
-	    return False;
+	    return FALSE;
 	}
     }
 
-    if (result == False)
+    if (result == FALSE)
     {
 	TxError("Cells cannot be created in the 3D window.\n");
 	return result;
@@ -1643,7 +1639,7 @@ W3Dcreate(window, argc, argv)
     colormap = XCreateColormap(grXdpy, RootWindow(grXdpy, DefaultScreen(grXdpy)),
 		grVisualInfo->visual, AllocNone);
 
-    if (!(tktop = Tk_MainWindow(magicinterp))) return False;
+    if (!(tktop = Tk_MainWindow(magicinterp))) return FALSE;
 	
     /* Check for a Tk pathname for the window;  allows window to be	*/
     /* by a Tk GUI script.						*/
@@ -1679,7 +1675,7 @@ W3Dcreate(window, argc, argv)
 	/* set up our own Tk event handler for the 3d window */
 
 	Tk_CreateEventHandler(tkwind, ExposureMask | StructureNotifyMask |
-		ButtonPressMask | ButtonReleaseMask | KeyPressMask,
+		ButtonPressMask | KeyPressMask,
 		(Tk_EventProc *)W3DEventProc, (ClientData)tkwind);
 
 	w3dWindow = window;
@@ -1693,11 +1689,11 @@ W3Dcreate(window, argc, argv)
 
 	Set3DDefaults(window, crec);
 
-	return True;
+	return TRUE;
     }
 
     TxError("Could not create a new Tk window\n");
-    return False;
+    return FALSE;
 }
 
 /*
@@ -1708,7 +1704,7 @@ W3Dcreate(window, argc, argv)
  * Clean up the data structures before deleting a window.
  *
  * Results:
- *	True if we really want to delete the window, False otherwise.
+ *	TRUE if we really want to delete the window, FALSE otherwise.
  *
  * Side effects:
  *	A W3DclientRec is freed.
@@ -1729,7 +1725,7 @@ W3Ddelete(window)
 
     freeMagic((char *) cr);
     Tk_DestroyWindow(xw);
-    return (True);
+    return (TRUE);
 }
 
 
@@ -1761,7 +1757,7 @@ W3Dredisplay(w, rootArea, clipArea)
     int i;
     TileTypeBitMask *mask, layers;
 
-    grSimpleLock(w, True);
+    grSimpleLock(w, TRUE);
 
     crec = (W3DclientRec *) w->w_clientData;
     cellDef = ((CellUse *)w->w_surfaceID)->cu_def;
@@ -1788,7 +1784,7 @@ W3Dredisplay(w, rootArea, clipArea)
 
     /* follow the same locking procedure as DBWredisplay() */
     w3dUnlock(w);
-    w3dIsLocked = False;
+    w3dIsLocked = FALSE;
     for (i = 0; i < DBWNumStyles; i++)
     {
 	/* This should probably be redesigned. . . */
@@ -1797,13 +1793,13 @@ W3Dredisplay(w, rootArea, clipArea)
 	if (!TTMaskIsZero(&layers))
 	{
 	    w3dStyle = i + TECHBEGINSTYLES;
-	    w3dNeedStyle = True;
+	    w3dNeedStyle = TRUE;
 	    (void) DBTreeSrTiles(&scontext, &layers, 0,
 			w3dPaintFunc, (ClientData) NULL);
 	    if (w3dIsLocked)
 	    {
 		w3dUnlock(w);
-		w3dIsLocked = False;
+		w3dIsLocked = FALSE;
 	    }
 	}
     }
@@ -1838,7 +1834,7 @@ W3DCIFredisplay(w, rootArea, clipArea)
     int i;
     TileTypeBitMask *mask;
 
-    grSimpleLock(w, True);
+    grSimpleLock(w, TRUE);
 
     crec = (W3DclientRec *) w->w_clientData;
     cellDef = ((CellUse *)w->w_surfaceID)->cu_def;
@@ -1856,20 +1852,20 @@ W3DCIFredisplay(w, rootArea, clipArea)
     scx.scx_trans = GeoIdentityTransform;
     (void) DBTreeSrTiles(&scx, &DBAllButSpaceAndDRCBits, 0,
 	cifHierCopyFunc, (ClientData) CIFComponentDef);
-    CIFGen(CIFComponentDef, &clipRect, CIFPlanes, &DBAllTypeBits, True, True);
+    CIFGen(CIFComponentDef, &clipRect, CIFPlanes, &DBAllTypeBits, TRUE, TRUE);
     DBCellClearDef(CIFComponentDef);
 
     w3dClear();
 
     /* follow the same locking procedure as DBWredisplay() */
     w3dUnlock(w);
-    w3dIsLocked = False;
+    w3dIsLocked = FALSE;
 
     for (i = 0; i < CIFCurStyle->cs_nLayers; i++)
     {
 	if (TTMaskHasType(&crec->visible, i))
 	{
-	    w3dNeedStyle = True;
+	    w3dNeedStyle = TRUE;
 	    DBSrPaintArea((Tile *) NULL, CIFPlanes[i], &TiPlaneRect,
 			&CIFSolidBits, w3dCIFPaintFunc,
 			(ClientData)(CIFCurStyle->cs_layers[i]));
@@ -1877,7 +1873,7 @@ W3DCIFredisplay(w, rootArea, clipArea)
 	    if (w3dIsLocked)
 	    {
 		w3dUnlock(w);
-		w3dIsLocked = False;
+		w3dIsLocked = FALSE;
 	    }
 	}
     }
@@ -1927,7 +1923,7 @@ W3Dcommand(w, cmd)
 	    WindExecute(w, W3DclientID, cmd);
 	    break;
 	default:
-	    ASSERT(False, "W3Dcommand");
+	    ASSERT(FALSE, "W3Dcommand");
     }
     UndoNext();
 }
