@@ -21,7 +21,10 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grCMap.c,v 1.2 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -32,7 +35,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grCMap.c,v 1.2 2001
 #include "utils/utils.h"
 #include "textio/textio.h"
 
-static char colorMap[256*3];		/* Storage for the color map. */
+static colorEntry *colorMap = NULL;	/* Storage for the color map. */
+static int GrNumColors = 0;		/* Number of colors */
 
 
 /*-----------------------------------------------------------------------------
@@ -54,6 +58,20 @@ static char colorMap[256*3];		/* Storage for the color map. */
 void
 GrResetCMap()
 {
+    int i;
+    colorEntry *ce;
+
+    if (colorMap == NULL || GrNumColors == 0) return;
+
+    for (i = 0; i < GrNumColors; i++)
+    {
+	ce = colorMap + i;
+	if (ce->name != NULL)
+	    freeMagic(ce->name);
+    }
+    freeMagic(colorMap);
+    colorMap = NULL;
+    GrNumColors = 0;
 }
 
 
@@ -105,9 +123,9 @@ char *libPath;			/* a library search path */
 
 {
     FILE *f;
-    int max, red, green, blue, newmax;
-    char *ptr;
-    char fullName[256];
+    int max, red, green, blue, newmax, argc, i;
+    colorEntry *ce;
+    char fullName[256], inputLine[128], colorName[100];
 
     if (dispType == NULL)
     {
@@ -132,34 +150,75 @@ char *libPath;			/* a library search path */
     /* Reset original colormap if necessary */
     GrResetCMap();
 
-    ptr = colorMap;
+    /* Get maximum color entry from file (1st pass) */
+
     max = 0;
-    while (TRUE)
+    while (fgets(inputLine, 128, f) != NULL)
     {
-	if (fscanf(f, "%d %d %d %d", &red, &green, &blue, &newmax) != 4)
+	argc = sscanf(inputLine, "%*d %*d %*d %d", &newmax);
+	if (argc == 0)
 	{
+	    /* Allow comment lines */
+	    if (*inputLine == '#') continue;
+
 	    TxError("Syntax error in color map file \"%s.cmap\"\n", fullName);
+	    TxError("Last color read was index %d\n", max);
 	    return FALSE;
 	}
-	if ((newmax < max) || (newmax > 255))
+	else
 	{
-	    TxError("Colors in map are out of order or too large.\n");
-	    (void) fclose(f);
-	    return FALSE;
-	}
-	for (; max <= newmax; max++)
-	{
-	    *ptr++ = red & 0377;
-	    *ptr++ = green & 0377;
-	    *ptr++ = blue & 0377;
-	}
-	if (max >= 255)
-	{
-	    GrSetCMap(colorMap);
-	    (void) fclose(f);
-	    return TRUE;
+	    if (newmax > max)
+		max = newmax;
 	}
     }
+    rewind(f);
+    colorMap = (colorEntry *)mallocMagic((max + 1) * sizeof(colorEntry));
+    GrNumColors = max + 1;
+
+    /* Read data into colorMap (2nd pass) */
+
+    for (i = 0; i < GrNumColors; )
+    {
+	if (fgets(inputLine, 128, f) == NULL)
+	{
+	    TxError("Premature end-of-file in color map file \"%s.cmap\"\n",
+			fullName);
+	    break;
+	}
+	if ((argc = sscanf(inputLine, "%d %d %d %d %99[^\n]",
+		&red, &green, &blue, &newmax, colorName)) < 4)
+	{
+	    /* Allow comment lines */
+	    if (*inputLine == '#') continue;
+
+	    TxError("Syntax error in color map file \"%s.cmap\"\n", fullName);
+	    TxError("Expecting to read color index %d\n", i);
+	    break;
+	}
+	else if (newmax < i)
+	{
+	    TxError("Colors in map are out of order!\n");
+	    break;
+	}
+
+	for (; i <= newmax; i++)
+	{
+	    ce = colorMap + i;
+	    ce->red = (unsigned char)(red & 0xff);
+	    ce->green = (unsigned char)(green & 0xff);
+	    ce->blue = (unsigned char)(blue & 0xff);
+	    if (argc == 5)
+		ce->name = StrDup(NULL, colorName);
+	    else
+		ce->name = NULL;
+	}
+    }
+
+    fclose(f);
+    if (i < GrNumColors) return FALSE;
+
+    GrSetCMap();
+    return TRUE;
 }
 
 
@@ -199,8 +258,9 @@ char *libPath;			/* a library search path */
 
 {
     FILE *f;
-    char *ptr, *ptr2;
-    int red, green, blue, i;
+    colorEntry *ce, *ce2;
+    int red, green, blue;
+    int i;
     char fullName[256];
 
     if (dispType == NULL) dispType = grCMapType;
@@ -212,94 +272,143 @@ char *libPath;			/* a library search path */
 	TxError("Couldn't write color map file \"%s.cmap\"\n", fullName);
 	return FALSE;
     }
-    ptr = colorMap;
-    red = colorMap[0];
-    green = colorMap[1];
-    blue = colorMap[2];
-    for (i= 0;  i<256;  i++)
+
+    for (i = 0; i < GrNumColors; i++)
     {
-	ptr2 = ptr;
-	if (red == *ptr2++)
-	    if (green == *ptr2++)
-		if (blue == *ptr2++)
-		{
-		    ptr = ptr2;
-		    continue;
-		}
-	(void) fprintf(f, "%d %d %d %d\n", red&0377, green&0377, 
-		blue&0377, i-1);
-	red = *ptr++;
-	green = *ptr++;
-	blue = *ptr++;
+	ce = colorMap + i;
+	red = (int)ce->red;
+	green = (int)ce->green;
+	blue = (int)ce->blue;
+
+	while (i < (GrNumColors - 1))
+	{
+	    ce2 = colorMap + i + 1;
+	    if ((red != (int)ce2->red) || (green != (int)ce2->green)
+			|| (blue != (int)ce2->blue))
+		break;
+	    i++;
+	}
+
+	fprintf(f, "%d %d %d %d", red, green, blue, i);
+	if (ce->name != NULL)
+	    fprintf(f, " %s", ce->name);
+	fprintf(f, "\n");
     }
-    (void) fprintf(f, "%d %d %d 255\n", red, green, blue);
     (void) fclose(f);
     return TRUE;
 }
 
-
-/*-----------------------------------------------------------------------------
- *	GrGetColor reads a color value out of the map.
+/*
+ *-----------------------------------------------------------------------------
+ * GrNameToColor --
  *
- *	Results:	None.
+ *	Get the index of a specific named color, as named in the
+ *	colormap file.
  *
- *	Side Effects:
+ * Results:
+ *	The index of the named color, or -1 if there is no match.
+ *
+ * Side Effects:
+ *	None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+int
+GrNameToColor(colorname)
+    char *colorname;
+{
+    int i;
+    colorEntry *ce;
+
+    for (i = 0; i < GrNumColors; i++)
+    {
+	ce = colorMap + i;
+	if (ce->name == NULL) continue;
+	else if (!strcmp(colorname, ce->name))
+	    return i;
+    }
+    return -1;
+}
+
+/*
+ *-----------------------------------------------------------------------------
+ * GrGetColor --
+ *	reads a color value out of the map.
+ *
+ * Results:
+ *	TRUE on success, FALSE on passing an illegal color index.
+ *
+ * Side Effects:
  *	The values of red, green, and blue are overwritten with the
  *	red, green, and blue intensities for the color indicated by
  *	layer.
  *-----------------------------------------------------------------------------
  */
 
-Void
+bool
 GrGetColor(color, red, green, blue)
-int color;			/* Color to be read. */
-int *red, *green, *blue;	/* Pointers to values of color elements. */
-
+    int color;			/* Color to be read. */
+    int *red, *green, *blue;	/* Pointers to values of color elements. */
 {
-    char *ptr;
-    ptr = &(colorMap[3*color]);
-    *red = *ptr++&0377;
-    *green = *ptr++&0377;
-    *blue = *ptr++&0377;
-}
+    colorEntry *ce;
 
+    if (color >= GrNumColors) return FALSE;
+
+    ce = colorMap + color;
+    *red = (int)ce->red;
+    *green = (int)ce->green;
+    *blue = (int)ce->blue;
+    return TRUE;
+}
 
 
 /*-----------------------------------------------------------------------------
- *	GrPutColor modifies the color map values for a single layer spec.
+ *  GrPutColor --
+ *	 modifies the color map values for a single layer spec.
  *
- *	Results:	None.
+ *  Results:
+ *	TRUE on success, FALSE on passing an illegal color index.
  *
- *	Side Effects:
+ *  Side Effects:
  *	The indicated color is modified to have the given red, green, and
  *	blue intensities.
  *-----------------------------------------------------------------------------
  */
 
-Void
+bool
 GrPutColor(color, red, green, blue)
-int color;			/* Color to be changed. */
-int red, green, blue;		/* New intensities for color. */
-
+    int color;			/* Color to be changed. */
+    int red, green, blue;	/* New intensities for color. */
 {
-    char *ptr;
-    ptr = &(colorMap[3*color]);
-    *ptr++ = red&0377;
-    *ptr++ = green&0377;
-    *ptr = blue&0377;
-    GrSetCMap(colorMap);
+    colorEntry *ce;
+
+    if (color >= GrNumColors) return FALSE;
+
+    ce = colorMap + color;
+    ce->red = (unsigned char)(red & 0xff);
+    ce->green = (unsigned char)(green & 0xff);
+    ce->blue = (unsigned char)(blue & 0xff);
+    if (ce->name != NULL)
+    {
+	freeMagic(ce->name);
+	ce->name = NULL;
+    }
+    GrSetCMap();
+    return TRUE;
 }
 
 
 /*-----------------------------------------------------------------------------
- *	GrPutManyColors --
+ * GrPutManyColors --
  *
  *	Stores a new set of intensities in all portions of the map
  *	which contain a given set of color bits.
  *
- *	Results:	None.
+ * Results:
+ *	None.
  *
- *	Side Effects:
+ * Side Effects:
  *	The color map entries for all layer combinations containing at
  *	least the bits in layers are reset to have the values given by
  *	red, green, and blue.  For example, if layers is 1 then all odd
@@ -311,35 +420,29 @@ int red, green, blue;		/* New intensities for color. */
  *-----------------------------------------------------------------------------
  */
 
-Void
+void
 GrPutManyColors(color, red, green, blue, opaqueBit)
-int color;			/* A specification of colors to be modified. */
-int red, green, blue;		/* New intensity values. */
-int opaqueBit;			/* The opaque/transparent bit.  It is assumed
+   int color;			/* A specification of colors to be modified. */
+   int red, green, blue;	/* New intensity values. */
+   int opaqueBit;		/* The opaque/transparent bit.  It is assumed
 				 * that the opaque layer colors or 
 				 * transparent layer bits lie to the right
 				 * of the opaque/transparent bit.
 				 */
 
 {
-    char *ptr;
-    int i, mask;
-    mask = color;
+    int i;
+    int mask = color;
+
     /* if a transparent layer */
-    if (color&(opaqueBit+opaqueBit-1)) mask |= opaqueBit;
+    if (color & (opaqueBit + opaqueBit - 1)) mask |= opaqueBit;
+
     /* if a opaque layer */
-    if (color&opaqueBit) mask |= (opaqueBit-1);
-    ptr = colorMap;
-    for (i=0;  i<256; i++)
-	if ((i&mask) == color)
-	{
-	    *ptr++ = red&0377;
-	    *ptr++ = green&0377;
-	    *ptr++ = blue&0377;
-	}
-	else
-	{
-	    ptr++;  ptr++; ptr++;
-	}
-    GrSetCMap(colorMap);
+    if (color & opaqueBit) mask |= (opaqueBit - 1);
+
+    for (i = 0; i < GrNumColors; i++)
+	if ((i & mask) == color)
+	    (void) GrPutColor(i, red, green, blue);
+
+    GrSetCMap();
 }
