@@ -23,7 +23,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grClip.c,v 1.8 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -154,7 +155,7 @@ grClipAgainst(startllr, clip)
 	    /* this will modify the list that we are traversing! */
 	    (void) GrDisjoint(&lr->r_r, clip, grClipAddFunc, 
 		    (ClientData) &llr);
-	    FREE( (char *) lr);
+	    freeMagic( (char *) lr);
 	}
 	else
 	    llr = &((*llr)->r_next);
@@ -174,7 +175,7 @@ bool grClipAddFunc(box, cd)
 
     lllr = (LinkedRect ***) cd;
 
-    MALLOC(LinkedRect *, lr, sizeof (LinkedRect));
+    lr = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
     lr->r_r = *box;
     lr->r_next = **lllr;
     **lllr = lr;
@@ -189,7 +190,7 @@ grObsBox(r)
     LinkedRect *ar;
     LinkedRect **areas;
 
-    MALLOC(LinkedRect *, ar, sizeof (LinkedRect));
+    ar = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
     ar->r_r = *r;
     ar->r_next = NULL;
     areas = &ar;
@@ -210,7 +211,7 @@ grObsBox(r)
 	    (*grFillRectPtr)(&((*areas)->r_r));
 	oldarea = *areas;
 	*areas = (*areas)->r_next;
-	FREE( (char *) oldarea );
+	freeMagic( (char *) oldarea );
     }
 }
 
@@ -221,7 +222,7 @@ grObsBox(r)
  *	between a line and a box.
  *
  * Results:
- *	False if the line is completely outside of the box.
+ *	FALSE if the line is completely outside of the box.
  *
  * Side Effects:
  *---------------------------------------------------------
@@ -356,7 +357,7 @@ grClipPoints(line, box, p1, p1OK, p2, p2OK)
 
 
 #define NEWAREA(lr,x1,y1,x2,y2)	{LinkedRect *tmp; \
-    MALLOC(LinkedRect *, tmp, sizeof (LinkedRect)); \
+    tmp = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect))); \
     tmp->r_r.r_xbot = x1; tmp->r_r.r_xtop = x2; \
     tmp->r_r.r_ybot = y1; tmp->r_r.r_ytop = y2; tmp->r_next = lr; lr = tmp;}
 
@@ -387,7 +388,7 @@ GrClipLine(x1, y1, x2, y2)
      * left endpoint of a line, and the ur corner the right endpoint
      * of the line.
      */
-    MALLOC(LinkedRect *, areas, sizeof (LinkedRect));
+    areas = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
     areas->r_next = NULL;
     if (x1 < x2)
     {
@@ -470,7 +471,7 @@ GrClipLine(x1, y1, x2, y2)
 		{
 		    /* clip both sides */
 		    LinkedRect *new;
-		    MALLOC(LinkedRect *, new, sizeof (LinkedRect));
+		    new = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
 		    new->r_r.r_ur = l->r_ur;
 		    new->r_r.r_ll = p2;
 		    new->r_next = (*ar);
@@ -488,7 +489,7 @@ deleteit: {
 	    LinkedRect *reclaim;
 	    reclaim = (*ar);
 	    *ar = reclaim->r_next;
-	    FREE( (char *) reclaim);
+	    freeMagic( (char *) reclaim);
 	}
 
     } /* for ar */
@@ -502,7 +503,7 @@ deleteit: {
 		areas->r_r.r_xtop, areas->r_r.r_ytop);
 	oldarea = areas;
 	areas = areas->r_next;
-	FREE( (char *) oldarea );
+	freeMagic( (char *) oldarea );
     }
 }
 
