@@ -23,9 +23,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grDStyle.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
-#include "misc/styles.h"
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
+#include "utils/styles.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -39,8 +43,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grDStyle.c,v 1.2 20
 #include "dbwind/dbwind.h"
 
 /* imports from other graphics files */
-extern int (*grSetSPatternPtr)();
-extern Void (*grDefineCursorPtr)();
+extern void (*grSetSPatternPtr)();
+extern void (*grDefineCursorPtr)();
 
 /* data structures local to this file only */
 
@@ -142,6 +146,7 @@ GrGetStyleFromName(stylename)
  * ----------------------------------------------------------------------------
  */
 
+void
 GrResetStyles()
 {
     int i;
@@ -172,26 +177,27 @@ GrResetStyles()
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 styleBuildDisplayStyle(line, version)
     char *line;
     int version;
 {
-    int res, argsread;
+    bool res;
+    int argsread;
     int ord = 1, mask, color, outline, nfill, stipple;
     char shortName, longName[52];
-    char fill[42], ordstr[12];
+    char fill[42], ordstr[12], colorName[30];
     dstylelink *newstyle, *sstyle;
 
     char v6scanline[] = "%10s %o %o %o %40s %d %c %50s";
-    char v7scanline[] = "%10s %i %i %i %40s %d %c %50s";
+    char v7scanline[] = "%10s %i %29s %i %40s %d %c %50s";
 
     char *scanline = (version > 6) ? v7scanline : v6scanline;
 
     res = TRUE;
 
     if ((argsread = sscanf(line, scanline,
-		&ordstr, &mask, &color, &outline, fill, &stipple,
+		ordstr, &mask, colorName, &outline, fill, &stipple,
 		&shortName, &longName)) < 7)
     {
 	res = FALSE;
@@ -204,6 +210,10 @@ styleBuildDisplayStyle(line, version)
 					 * in reverse order.
 					 */
 
+	/* Allow colors to be specified by index or by name */
+	if (sscanf(colorName, "%d", &color) == 0)
+	    color = GrNameToColor(colorName);
+
 	newstyle->style.mask = (mask & grBitPlaneMask);
 	newstyle->style.color = (color & grBitPlaneMask);
 	newstyle->style.outline = outline;
@@ -249,12 +259,12 @@ styleBuildDisplayStyle(line, version)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 styleBuildStipplesStyle(line, version)
     char *line;
     int version;
 {
-    int res;
+    bool res;
     int ord;
     int row[8];
 
