@@ -20,15 +20,15 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magsgtty.h"
-#include "misc/magic.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 
 #ifndef lint
