@@ -20,19 +20,19 @@
 #include <unistd.h>
 #include <signal.h>
 
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/magsgtty.h"
 #include "utils/geometry.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "grOGLInt.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 
 GLubyte 	*grOGLStipples[GR_NUM_STIPPLES];
 HashTable	grOGLWindowTable;
@@ -249,7 +249,7 @@ GrOGLInit()
     if (grXdpy == NULL)
     {   
 	TxError("Couldn't open display; check DISPLAY variable\n");
-	return false;
+	return FALSE;
     }
     grXscrn = DefaultScreen(grXdpy);
     grVisualInfo = glXChooseVisual(grXdpy, grXscrn, attributeList);
@@ -274,7 +274,7 @@ GrOGLInit()
 
     glLineWidth(1.0);
     glShadeModel (GL_FLAT);
-    glPixelStorei(GL_PACK_LSB_FIRST, true);
+    glPixelStorei(GL_PACK_LSB_FIRST, TRUE);
 
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
@@ -556,7 +556,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     char	*planecount;
     char 	*fullname;
     FILE* 	f;
-    bool	execFailed = false;
+    bool	execFailed = FALSE;
 
     WindPackageType = WIND_X_WINDOWS;	/* This works okay. */
 
@@ -588,7 +588,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
             X11HELP_PROG, HELPER_PATH);
         error = 0;
         write(fildes[1], &error, 4);
-        return false;
+        return FALSE;
     }
     else {
         fclose(f);
@@ -602,7 +602,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
         sprintf(argv[1], "%d %d", fildes2[0],fildes[1]);
         if (execl(argv[0], argv[0], argv[1], 0) != 0)
         {
-            execFailed = true;
+            execFailed = TRUE;
             TxError("Couldn't execute helper process \"%s\".\n", fullname);
             TxFlush();
             /* we're the child process -- don't muck things up by returning */
@@ -656,20 +656,20 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
 
     if (execFailed) {
         TxError("Execution failed!\n");
-        return false;
+        return FALSE;
     }
 
     TxAdd1InputDevice(fileno(stdin), grOGLWStdin, (ClientData) NULL);
 
     if(!GrOGLInit()){
-	return false;
+	return FALSE;
     }
     GrScreenRect.r_xbot = 0;
     GrScreenRect.r_ybot = 0;
     GrScreenRect.r_xtop = DisplayWidth(grXdpy,grXscrn);
     GrScreenRect.r_ytop = DisplayHeight(grXdpy,grXscrn);
 
-    return true;
+    return TRUE;
 }
 
 /*
@@ -738,7 +738,7 @@ GrOGLCreate(w, name)
    XSizeHints	*xsh;
    char		*windowplace;
    char		*option = (firstWindow)?"window":"newwindow";
-   bool		result = True;
+   bool		result = TRUE;
    int		x     = w->w_frameArea.r_xbot;
    int		y     = glTransYs(w->w_frameArea.r_ytop);
    int		width = w->w_frameArea.r_xtop - w->w_frameArea.r_xbot;
@@ -812,13 +812,13 @@ GrOGLCreate(w, name)
 	xevent.x = xsh->x;
 	xevent.y = xsh->y;
 	xevent.window = wind;
-	XSendEvent(grXdpy, wind, false, StructureNotifyMask, (XEvent *)&xevent);
+	XSendEvent(grXdpy, wind, FALSE, StructureNotifyMask, (XEvent *)&xevent);
 	XFree(xsh);
 	return result;
     }
     else {
 	TxError("Could not open new X window\n");
-	result = False;
+	result = FALSE;
     }
     return result;
 }
