@@ -23,13 +23,13 @@
 #include <GL/gl.h>
 #include <GL/glx.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "grOGLInt.h"
@@ -64,7 +64,7 @@ groglDrawGrid (prect, outline, clip)
 			         * for the grid.  Note:  in order to maintain
 			         * precision for the grid, the rectangle
 			         * coordinates are specified in units of
-			         * screen coordinates multiplied by 4096.
+			         * screen coordinates multiplied by SUBPIXEL.
 			         */
     int outline;		/* the outline style */
     Rect *clip;			/* a clipping rectangle */
@@ -80,9 +80,9 @@ groglDrawGrid (prect, outline, clip)
 	return FALSE;
     
     xstart = prect->r_xbot % xsize;
-    while (xstart < clip->r_xbot<<12) xstart += xsize;
+    while (xstart < clip->r_xbot << SUBPIXELBITS) xstart += xsize;
     ystart = prect->r_ybot % ysize;
-    while (ystart < clip->r_ybot<<12) ystart += ysize;
+    while (ystart < clip->r_ybot << SUBPIXELBITS) ystart += ysize;
     
     groglSetLineStyle(outline);
 
@@ -91,10 +91,10 @@ groglDrawGrid (prect, outline, clip)
     snum = 0;
     low = clip->r_ybot;
     hi = clip->r_ytop;
-    for (x = xstart; x < (clip->r_xtop+1)<<12; x += xsize)
+    for (x = xstart; x < (clip->r_xtop + 1) << SUBPIXELBITS; x += xsize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = x >> 12;
+	shifted = x >> SUBPIXELBITS;
 	glVertex2i(shifted, low);
 	glVertex2i(shifted, hi);
 	snum++;
@@ -103,17 +103,17 @@ groglDrawGrid (prect, outline, clip)
     snum = 0;
     low = clip->r_xbot;
     hi = clip->r_xtop;
-    for (y = ystart; y < (clip->r_ytop+1)<<12; y += ysize)
+    for (y = ystart; y < (clip->r_ytop + 1) << SUBPIXELBITS; y += ysize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = y >> 12;
+	shifted = y >> SUBPIXELBITS;
 	glVertex2i(low, shifted);
 	glVertex2i(hi, shifted);
 	snum++;
     }
 
     glEnd();
-    return true;
+    return TRUE;
 }
 
 
@@ -126,7 +126,7 @@ groglDrawGrid (prect, outline, clip)
  *	draw to) we defer transferring the font bitmaps to
  *	OpenGL display lists until later.
  *
- * Results:	None.
+ * Results:	Success/Fail
  *
  * Side Effects:    None.
  *---------------------------------------------------------
@@ -158,12 +158,12 @@ groglPreLoadFont()
 	      TxError("%s %s\n",unable,fontnames[i]);
               if ((grXFonts[i]= XLoadQueryFont(grXdpy,GR_DEFAULT_FONT))==NULL) {
 	           TxError("%s %s\n",unable,GR_DEFAULT_FONT);
-		   return false;
+		   return FALSE;
 	      }
          }
 	 grXFonts[i] = fontInfo;
     }
-    return true;
+    return TRUE;
 }
 
 
@@ -173,7 +173,7 @@ groglPreLoadFont()
  *	into OpenGL display lists for simple text
  *	rendering.
  *
- * Results:	None.
+ * Results:	Success/Fail.
  *
  * Side Effects:    None.
  *---------------------------------------------------------
@@ -195,11 +195,11 @@ groglLoadFont()
 	grXBases[i] = glGenLists(last+1);
 	if (grXBases[i] == 0) {
 	    TxError("Out of display lists!\n");
-	    return false;
+	    return FALSE;
 	}
 	glXUseXFont(id, first, last-first+1, grXBases[i]+first);
     }
-    return true;
+    return TRUE;
 }
 
 
@@ -214,7 +214,7 @@ groglLoadFont()
  *---------------------------------------------------------
  */
 
-Void
+void
 groglSetCharSize (size)
     int size;		/* Width of characters */
 {
@@ -259,7 +259,7 @@ groglSetCharSize (size)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GrOGLTextSize(text, size, r)
     char *text;
     int size;
@@ -306,6 +306,7 @@ GrOGLTextSize(text, size, r)
  *
  * Results:
  *	An integer containing the pixel's color.
+ *	(Except OpenGL has no such function, so we just return 0)
  *
  * Side effects:
  *	none.
@@ -336,7 +337,7 @@ GrOGLReadPixel (w, x, y)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GrOGLBitBlt(r, p)
     Rect *r;
     Point *p;
@@ -365,7 +366,7 @@ GrOGLBitBlt(r, p)
  *---------------------------------------------------------
  */
 
-Void
+void
 groglPutText (text, pos, clip, obscure)
     char *text;			/* The text to be drawn. */
     Point *pos;			/* A point located at the leftmost point of
@@ -423,8 +424,8 @@ groglPutText (text, pos, clip, obscure)
 
 void
 grOGLGeoSub(r, area)
-register Rect *r;		/* Rectangle to be subtracted from. */
-register Rect *area;		/* Area to be subtracted. */
+Rect *r;		/* Rectangle to be subtracted from. */
+Rect *area;		/* Area to be subtracted. */
 
 {
     if (r->r_xbot == area->r_xbot) r->r_xbot = area->r_xtop;
