@@ -46,8 +46,8 @@
 #include <X11/Xutil.h>
 #include <signal.h>
 
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/magsgtty.h"
 #include "utils/geometry.h"
 #include "graphics/glyphs.h"
 #include "graphics/graphics.h"
@@ -55,11 +55,11 @@
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "grX11Int.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 
 Display *grXdpy;
 int	grXscrn;
@@ -340,7 +340,7 @@ GrX11Init ()
     {
     	 TxError("Couldn't open display %s; check DISPLAY variable\n",
             getenv("DISPLAY"));
-	 return false;
+	 return FALSE;
     }
     grXscrn = XDefaultScreen(grXdpy);
 
@@ -352,7 +352,7 @@ GrX11Init ()
 	 {
 	      TxError("You cannot specify more planes (%d) than the display "
 		"has (%d).\n",grXuserPC,grCurrent.depth);
-	      return false;
+	      return FALSE;
 	 }
 	 grCurrent.depth = (grXuserPC == 1)?0:grXuserPC;
     }
@@ -371,7 +371,7 @@ GrX11Init ()
         window-manager. Same global atom (wm_delete_window) used by
         all windows
     */
-    wm_delete_window = XInternAtom(grXdpy, "WM_DELETE_WINDOW", False);
+    wm_delete_window = XInternAtom(grXdpy, "WM_DELETE_WINDOW", FALSE);
     grDStyleType = grXdepth;
     if (grCurrent.depth) 
     {
@@ -630,7 +630,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     char	*planecount;
     char *fullname;
     FILE* f;
-    bool execFailed = false;
+    bool execFailed = FALSE;
 
     WindPackageType = WIND_X_WINDOWS;
 
@@ -718,18 +718,18 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     
     if (execFailed) {
 	TxError("Execution failed!\n");
-	return false;
+	return FALSE;
     }
 
     TxAdd1InputDevice(fileno(stdin), grXWStdin, (ClientData) NULL);
 
     if(!GrX11Init()){
-	return false;
+	return FALSE;
     };
     GrScreenRect.r_xtop = DisplayWidth(grXdpy,grXscrn);
     GrScreenRect.r_ytop = DisplayHeight(grXdpy,grXscrn);
 
-    return true;
+    return TRUE;
 }
 
 /*
@@ -783,7 +783,7 @@ void _Optlink Input_monitor(void *arg)
     struct     _AVAILDATA BytesAvail;
     ULONG       PipeState;
 
-   while (true) {
+   while (TRUE) {
       DosSleep(8L);   /* time in ms */
       if (_kbhit() ) { sigOnInterrupt(); }
       if(grXdpy != NULL) {
@@ -886,7 +886,7 @@ GrX11Create(w)
         {
 	    XWMHints wmhints;
 	    wmhints.flags = InputHint;
-	    wmhints.input = True;
+	    wmhints.input = TRUE;
 	    XSetWMHints(grXdpy, wind, &wmhints);
         }
 #endif	/* sun */
