@@ -27,23 +27,24 @@
 #include <GL/glx.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
+#include "utils/magsgtty.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "graphics/grTOGLInt.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 #include "graphics/grTkCommon.h"
 
 GLubyte		*grTOGLStipples[GR_NUM_STIPPLES];
@@ -268,7 +269,7 @@ GrTOGLInit ()
     if (toglCurrent.window == NULL)
     {
     	 TxError("No Top-Level Tk window available. . . is Tk running?\n");
-	 return false;
+	 return FALSE;
     }
 
     toglCurrent.windowid = Tk_WindowId(toglCurrent.window);
@@ -291,7 +292,7 @@ GrTOGLInit ()
 	if (!grVisualInfo)
 	{
 	    TxError("No suitable visual!\n");
-	    return false;
+	    return FALSE;
 	}
     }
     grXscrn = grVisualInfo->screen;
@@ -305,7 +306,7 @@ GrTOGLInit ()
 
     glLineWidth(1.0);
     glShadeModel (GL_FLAT);
-    glPixelStorei(GL_PACK_LSB_FIRST, true);
+    glPixelStorei(GL_PACK_LSB_FIRST, TRUE);
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
 
@@ -444,6 +445,10 @@ TOGLEventProc(clientData, xevent)
     Window wind;
     MagWindow *mw;
 
+    XKeyPressedEvent *KeyPressedEvent = (XKeyPressedEvent *) xevent;
+    KeySym keysym;
+    int nbytes;
+
     /* Keys and Buttons:  Determine expansion of macros or redirect
      * keys to the terminal or console.
      */
@@ -451,71 +456,27 @@ TOGLEventProc(clientData, xevent)
     switch (xevent->type) 
     {
 	case ButtonPress:
-	case ButtonRelease:
 	    {
 		XButtonEvent *ButtonEvent = (XButtonEvent *) xevent;
-		int oldButtons = TxCurButtons;
 
 		switch (ButtonEvent->button) {
 		case Button1:
-		    TxCurCommand.tx_button = TX_LEFT_BUTTON;
+		    keysym = XK_Pointer_Button1;
 		    break;
 		case Button2:
-		    TxCurCommand.tx_button = TX_MIDDLE_BUTTON;
+		    keysym = XK_Pointer_Button2;
 		    break;
 		case Button3:
-		    TxCurCommand.tx_button = TX_RIGHT_BUTTON;
+		    keysym = XK_Pointer_Button3;
 		    break;
 		}
-		switch(xevent->type) {
-		case ButtonRelease:
-		    TxCurCommand.tx_buttonAction = TX_BUTTON_UP;
-		    TxCurButtons &= ~(TxCurCommand.tx_button);
-		    break;
-		case ButtonPress:
-		    TxCurCommand.tx_buttonAction = TX_BUTTON_DOWN;
-		    TxCurButtons |= TxCurCommand.tx_button;
-		    break;
-		}
-
-		if (oldButtons != TxCurButtons)
-		{
-		    entry = HashLookOnly(&grTOGLWindowTable, tkwind);
-		    mw = (entry)?(MagWindow *)HashGetValue(entry):0;
-
-		    TxCurCommand.tx_argc = 0;
-		    TxCurCommand.tx_argv[0] = NULL;
-		    TxCurCommand.tx_p.p_x = ButtonEvent->x;
-		    TxCurCommand.tx_p.p_y = glTransY(mw, ButtonEvent->y);
-		    TxCurCommand.tx_wid = mw->w_wid;
-
-		    DRCBreak();
-
-		    SigIOReady = false;
-		    SigInterruptOnSigIO = true;
-		    SigInterruptPending = false;
-
-		    (void) WindSendCommand(mw, &TxCurCommand);
-		    WindUpdate();
-
-		    if (SigInterruptPending)
-			TxPrintf("[Redisplay Interrupted]\n");
-
-		    TxCommandNumber++;	/* for proper "select" behavior */
-		    Tcl_DoWhenIdle(DRCContinuous, NULL);
-
-		    SigInterruptPending = false;
-		    SigInterruptOnSigIO = false;
-		    SigIOReady = false;
-		}
+		nbytes = 0;
+		goto keys_and_buttons;
 	    }
 	    break;
 	case KeyPress:
 	    {
-		XKeyPressedEvent *KeyPressedEvent = (XKeyPressedEvent *) xevent;
-
-		KeySym keysym;
-		int nbytes, keywstate, keymod, idx, idxmax;
+		int keywstate, keymod, idx, idxmax;
 		char inChar[10];
 		Tcl_Channel outChannel = Tcl_GetStdChannel(TCL_STDOUT);
 
@@ -524,6 +485,7 @@ TOGLEventProc(clientData, xevent)
 
 		if (IsModifierKey(keysym)) break;	/* Don't handle modifiers */
 
+keys_and_buttons:
 		entry = HashLookOnly(&grTOGLWindowTable, tkwind);
 		mw = (entry)?(MagWindow *)HashGetValue(entry):0;
 
@@ -581,14 +543,14 @@ TOGLEventProc(clientData, xevent)
 			        TxSetPoint(KeyPressedEvent->x,
 					glTransY(mw, KeyPressedEvent->y),
 					mw->w_wid);
-				TxInputRedirect = False;
+				TxInputRedirect = FALSE;
 				Tcl_EvalEx(consoleinterp, "::tkcon::Eval .text",
 						19, 0);
 				TxSetPrompt('%');
 
 				Tcl_SaveResult(magicinterp, &state);
 				Tcl_EvalEx(magicinterp, "history event 0", 15, 0);
-			        MacroDefine((int)'.',
+			        MacroDefine(mw->w_client, (int)'.',
 					Tcl_GetStringResult(magicinterp),
 					FALSE);
 				Tcl_RestoreResult(magicinterp, &state);
@@ -609,7 +571,7 @@ TOGLEventProc(clientData, xevent)
 				outstr[23] = '\\';
 				outstr[24] = inChar[idx];
 				outstr[25] = '\"';
-				Tcl_EvalEx(consoleinterp, outstr, 25, 0);
+				Tcl_EvalEx(consoleinterp, outstr, 26, 0);
 				outstr[24] = '\"';
 				outstr[25] = '\0';
 			    default:
@@ -648,8 +610,9 @@ TOGLEventProc(clientData, xevent)
 			{
 			    *(TxBuffer + tl) = '\n';
 			    *(TxBuffer + tl + 1) = '\0';
-			    if (tl != 0) MacroDefine(XK_period, TxBuffer, FALSE);
-			    TxInputRedirect = False;
+			    if (tl != 0) MacroDefine(mw->w_client,
+					XK_period, TxBuffer, FALSE);
+			    TxInputRedirect = FALSE;
 			    TxSetPoint(KeyPressedEvent->x,
 					glTransY(mw, KeyPressedEvent->y),
 					mw->w_wid);
@@ -670,7 +633,7 @@ TOGLEventProc(clientData, xevent)
 				|| (keywstate == (int)TX_LONG_CMD2))
 		    {
 			/* Redirect input into the interpreter's terminal window */
-			TxInputRedirect = True;
+			TxInputRedirect = TRUE;
 			if (TxTkConsole)
 			    TxSetPrompt(':');
 			else
@@ -684,7 +647,7 @@ TOGLEventProc(clientData, xevent)
 			bool iMacro;
 			char *macroDef;
 
-			macroDef = MacroRetrieve(keywstate, &iMacro);
+			macroDef = MacroRetrieve(mw->w_client, keywstate, &iMacro);
 
 			if (macroDef == NULL)
 			{
@@ -721,23 +684,18 @@ TOGLEventProc(clientData, xevent)
 				    TxPrintf("%s", macroDef);
 				    TxFlushOut();
 				}
-				TxInputRedirect = True;
+				TxInputRedirect = TRUE;
 			    }
 			    else
 			    {
-				/* TxParseString is defined by magic/magicwrap.i */
-				/* and calls Tcl_Eval()				 */
+				/* TxParseString is defined by tcltk/tclmagic.c
+				 * and calls Tcl_Eval()
+				 */
 
-				char *outstring = Tcl_Alloc(sl +
-					 strlen(Tk_PathName(tkwind)) + 2);
-				sprintf(outstring, "%s %s", 
-					Tk_PathName(tkwind),
-					macroDef);
 				TxSetPoint(KeyPressedEvent->x,
 					glTransY(mw, KeyPressedEvent->y),
 					mw->w_wid);
-				TxParseString(outstring, NULL, NULL);
-				Tcl_Free(outstring);
+				TxParseString(macroDef, NULL, NULL);
 			    }
 			    freeMagic(macroDef);
 			}
@@ -750,7 +708,7 @@ TOGLEventProc(clientData, xevent)
 		XConfigureEvent *ConfigureEvent = (XConfigureEvent*) xevent;
 		Rect	screenRect;
 		int width, height;
-		Bool result;
+		bool result;
 		    
 		width = ConfigureEvent->width;
 		height = ConfigureEvent->height;
@@ -832,11 +790,11 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     char *planecount;
     char *fullname;
     FILE* f;
-    bool execFailed = false;
+    bool execFailed = FALSE;
     int x, y, width, height;
 
     WindPackageType = WIND_X_WINDOWS;  /* to be changed? */
-    TxInputRedirect = False;
+    TxInputRedirect = FALSE;
 
     grCursorType = "color";
     WindScrollBarWidth = 14;
@@ -874,6 +832,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     grSetSPatternPtr = grtoglSetSPattern;
     grPutTextPtr = grtoglPutText;
     grDefineCursorPtr = grTkDefineCursor;
+    grFreeCursorPtr = grTkFreeCursors;
     GrBitBltPtr = GrTOGLBitBlt;
     grDrawGridPtr = grtoglDrawGrid;
     grDrawLinePtr = grtoglDrawLine;
@@ -889,11 +848,11 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     
     if (execFailed) {
 	TxError("Execution failed!\n");
-	return false;
+	return FALSE;
     }
 
     if(!GrTOGLInit()){
-	return false;
+	return FALSE;
     };
 
     Tk_GetVRootGeometry(Tk_MainWindow(magicinterp), &x, &y, &width, &height);
@@ -902,7 +861,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     GrScreenRect.r_xtop = width + x;
     GrScreenRect.r_ytop = height + y;
 
-    return Tk_MainWindow(magicinterp) ? true : false;
+    return Tk_MainWindow(magicinterp) ? TRUE : FALSE;
 }
 
 extern void MakeWindowCommand();
@@ -998,7 +957,7 @@ GrTOGLCreate(w, name)
 
     if (tkwind != 0)
     {
-	Bool result;
+	bool result;
 
 	GrTOGLFlush();
 
@@ -1040,7 +999,7 @@ GrTOGLCreate(w, name)
 	/* set up Tk event handler to start processing */
 
 	Tk_CreateEventHandler(tkwind, ExposureMask | StructureNotifyMask
-		| ButtonPressMask | ButtonReleaseMask | KeyPressMask,
+		| ButtonPressMask | KeyPressMask,
 		 (Tk_EventProc *)TOGLEventProc, (ClientData) tkwind);
 
 	/* set up commands to be passed expressly to this window */  
