@@ -15,13 +15,13 @@
 #include <GL/glx.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "graphics/grTOGLInt.h"
@@ -53,7 +53,7 @@ grtoglDrawGrid (prect, outline, clip)
 			         * for the grid.  Note:  in order to maintain
 			         * precision for the grid, the rectangle
 			         * coordinates are specified in units of
-			         * screen coordinates multiplied by 4096.
+			         * screen coordinates multiplied by SUBPIXEL.
 			         */
     int outline;		/* the outline style */
     Rect *clip;			/* a clipping rectangle */
@@ -69,9 +69,9 @@ grtoglDrawGrid (prect, outline, clip)
 	return FALSE;
     
     xstart = prect->r_xbot % xsize;
-    while (xstart < clip->r_xbot<<12) xstart += xsize;
+    while (xstart < clip->r_xbot << SUBPIXELBITS) xstart += xsize;
     ystart = prect->r_ybot % ysize;
-    while (ystart < clip->r_ybot<<12) ystart += ysize;
+    while (ystart < clip->r_ybot << SUBPIXELBITS) ystart += ysize;
     
     grtoglSetLineStyle(outline);
 
@@ -80,10 +80,10 @@ grtoglDrawGrid (prect, outline, clip)
     snum = 0;
     low = clip->r_ybot;
     hi = clip->r_ytop;
-    for (x = xstart; x < (clip->r_xtop+1)<<12; x += xsize)
+    for (x = xstart; x < (clip->r_xtop+1) << SUBPIXELBITS; x += xsize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = x >> 12;
+	shifted = x >> SUBPIXELBITS;
 	glVertex2i(shifted, low);
 	glVertex2i(shifted, hi);
 	snum++;
@@ -92,16 +92,16 @@ grtoglDrawGrid (prect, outline, clip)
     snum = 0;
     low = clip->r_xbot;
     hi = clip->r_xtop;
-    for (y = ystart; y < (clip->r_ytop+1)<<12; y += ysize)
+    for (y = ystart; y < (clip->r_ytop+1) << SUBPIXELBITS; y += ysize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = y >> 12;
+	shifted = y >> SUBPIXELBITS;
 	glVertex2i(low, shifted);
 	glVertex2i(hi, shifted);
 	snum++;
     }
     glEnd();
-    return true;
+    return TRUE;
 }
 
 
@@ -129,11 +129,11 @@ grtoglLoadFont()
 	grXBases[i] = glGenLists(256);
 	if (grXBases[i] == 0) {
 	    TxError("Out of display lists!\n");
-	    return false;
+	    return FALSE;
 	}
 	glXUseXFont(id, 0, 256, grXBases[i]);
     }
-    return true;
+    return TRUE;
 }
 
 
@@ -259,7 +259,7 @@ GrTOGLReadPixel (w, x, y)
  * ----------------------------------------------------------------------------
  * GrTOGLBitBlt --
  *
- *	Copy information from one part of the screen to the other.
+ *	Copy information in bit block transfers.
  *
  * Results:
  *	None.
@@ -278,7 +278,6 @@ GrTOGLBitBlt(r, p)
 		r->r_ytop - r->r_ybot + 1, GL_COLOR);
 }
 
-
 
 /*---------------------------------------------------------
  * grtoglPutText:
