@@ -12,8 +12,8 @@
 #include <X11/Xlib.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/magsgtty.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -89,5 +89,5 @@ grtoglGetCursorPos (mw, p)
 		  &x, &y, &buttons);
     p->p_x = x;
     p->p_y = glTransY(mw, y);
-    return true;
+    return TRUE;
 }
