@@ -24,23 +24,24 @@
 #include <X11/keysym.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
+#include "utils/magsgtty.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "grTkInt.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 #include "graphics/grTkCommon.h"
 
 GR_CURRENT grCurrent = {
@@ -371,7 +372,7 @@ GrTkInit(dispType)
     if (grCurrent.window == NULL)
     {
     	 TxError("No Top-Level Tk window available. . . is Tk running?\n");
-	 return false;
+	 return FALSE;
     }
 
     grXdpy = Tk_Display(grCurrent.window);
@@ -554,7 +555,7 @@ GrTkInit(dispType)
     {
 	status = 0;
 	if (grClass != 4)
-	    status= XAllocColorCells(grXdpy, grXcmap, True, grDisplay.planes,	
+	    status= XAllocColorCells(grXdpy, grXcmap, TRUE, grDisplay.planes,	
 			grDisplay.planeCount, &grDisplay.basepixel, 1); 
 	if (status == 0) 
 	{
@@ -582,7 +583,7 @@ GrTkInit(dispType)
 		TxPrintf("Unable to allocate %d planes in default colormap; "
 			 "making a new one.\n", grDisplay.planeCount);
 #ifdef MAGIC_WRAPPER
-	    if (grClass == 3) GrTkInstalledCMap = True;
+	    if (grClass == 3) GrTkInstalledCMap = TRUE;
 #endif
 	    if (grDisplay.planeCount <= 8)
 	    {
@@ -727,6 +728,10 @@ MagicEventProc(clientData, xevent)
     Tk_Window wind = (Tk_Window)clientData;
     MagWindow *mw;
 
+    XKeyPressedEvent *KeyPressedEvent = (XKeyPressedEvent *) xevent;
+    KeySym keysym;
+    int nbytes;
+
     /* Keys and Buttons:  Determine expansion of macros or redirect
      * keys to the terminal/console.
      */
@@ -734,73 +739,26 @@ MagicEventProc(clientData, xevent)
     switch (xevent->type) 
     {
 	case ButtonPress:
-	case ButtonRelease:
 	    {
 		XButtonEvent *ButtonEvent = (XButtonEvent *) xevent;
-		int oldButtons = TxCurButtons;
-
 		switch (ButtonEvent->button) {
 		case Button1:
-		    TxCurCommand.tx_button = TX_LEFT_BUTTON;
+		    keysym = XK_Pointer_Button1;
 		    break;
 		case Button2:
-		    TxCurCommand.tx_button = TX_MIDDLE_BUTTON;
+		    keysym = XK_Pointer_Button2;
 		    break;
 		case Button3:
-		    TxCurCommand.tx_button = TX_RIGHT_BUTTON;
+		    keysym = XK_Pointer_Button3;
 		    break;
 		}
-		switch(xevent->type) {
-		case ButtonRelease:
-		    TxCurCommand.tx_buttonAction = TX_BUTTON_UP;
-	 	    TxCurButtons &= ~(TxCurCommand.tx_button);
-		    break;
-		case ButtonPress:
-		    TxCurCommand.tx_buttonAction = TX_BUTTON_DOWN;
-	 	    TxCurButtons |= TxCurCommand.tx_button;
-		    break;
-		}
-
-		if (oldButtons != TxCurButtons)
-		{
-		    entry = HashLookOnly(&grTkWindowTable, wind);
-		    mw = (entry)?(MagWindow *)HashGetValue(entry):0;
-	            grCurrent.window = wind;
-		    grCurrent.windowid = Tk_WindowId(wind);
-	            grCurrent.mw = mw;
-
-		    TxCurCommand.tx_argc = 0;
-		    TxCurCommand.tx_argv[0] = NULL;
-		    TxCurCommand.tx_p.p_x = ButtonEvent->x;
-		    TxCurCommand.tx_p.p_y = grXToMagic(ButtonEvent->y);
-		    TxCurCommand.tx_wid = mw->w_wid;
-
-		    DRCBreak();
-
-		    SigIOReady = false;
-		    SigInterruptOnSigIO = true;
-		    SigInterruptPending = false;
-
-		    (void) WindSendCommand(mw, &TxCurCommand);
-		    WindUpdate();
-
-		    if (SigInterruptPending)
-			TxPrintf("[Redisplay Interrupted]\n");
-
-		    TxCommandNumber++;	/* for proper "select" behavior */
-		    Tcl_DoWhenIdle(DRCContinuous, NULL);
-
-		    SigInterruptPending = false;
-		    SigInterruptOnSigIO = false;
-		    SigIOReady = false;
-		}
+		nbytes = 0;
+		goto keys_and_buttons;
 	    }
 	    break;
 	case KeyPress:
 	    {
-		XKeyPressedEvent *KeyPressedEvent = (XKeyPressedEvent *) xevent;
-		KeySym keysym;
-		int nbytes, keywstate, keymod, idx, idxmax;
+		int keywstate, keymod, idx, idxmax;
 		char inChar[10];
 		Tcl_Channel outChannel = Tcl_GetStdChannel(TCL_STDOUT);
 
@@ -809,6 +767,7 @@ MagicEventProc(clientData, xevent)
 
 		if (IsModifierKey(keysym)) break;	/* Don't handle modifiers */
 
+keys_and_buttons:
 		entry = HashLookOnly(&grTkWindowTable, wind);
 		mw = (entry)?(MagWindow *)HashGetValue(entry):0;
 		grCurrent.window = wind;
@@ -873,7 +832,7 @@ MagicEventProc(clientData, xevent)
 			        TxSetPoint(KeyPressedEvent->x,
 					grXToMagic(KeyPressedEvent->y),
 					grCurrent.mw->w_wid);
-				TxInputRedirect = False;
+				TxInputRedirect = FALSE;
 				Tcl_EvalEx(consoleinterp, "::tkcon::Eval .text",
 						19, 0);
 				TxSetPrompt('%');
@@ -881,7 +840,7 @@ MagicEventProc(clientData, xevent)
 				Tcl_SaveResult(magicinterp, &state);
 				Tcl_EvalEx(magicinterp, "history event 0", 15,
 						0);
-				MacroDefine((int)'.',
+				MacroDefine(mw->w_client, (int)'.',
 					Tcl_GetStringResult(magicinterp),
 					FALSE);
 				Tcl_RestoreResult(magicinterp, &state);
@@ -902,7 +861,7 @@ MagicEventProc(clientData, xevent)
 				outstr[23] = '\\';
 				outstr[24] = inChar[idx];
 				outstr[25] = '\"';
-				Tcl_EvalEx(consoleinterp, outstr, 25, 0);
+				Tcl_EvalEx(consoleinterp, outstr, 26, 0);
 				outstr[24] = '\"';
 				outstr[25] = '\0';
 			    default:
@@ -942,8 +901,9 @@ MagicEventProc(clientData, xevent)
 			{
 			    *(TxBuffer + tl) = '\n';
 			    *(TxBuffer + tl + 1) = '\0';
-			    if (tl != 0) MacroDefine((int)'.', TxBuffer, FALSE);
-			    TxInputRedirect = False;
+			    if (tl != 0) MacroDefine(mw->w_client, (int)'.',
+					TxBuffer, FALSE);
+			    TxInputRedirect = FALSE;
 			    TxSetPoint(KeyPressedEvent->x,
 					grXToMagic(KeyPressedEvent->y),
 					grCurrent.mw->w_wid);
@@ -964,7 +924,7 @@ MagicEventProc(clientData, xevent)
 				|| (keywstate == (int)TX_LONG_CMD2))
 		    {
 			/* Redirect input into the interpreter's terminal window */
-			TxInputRedirect = True;
+			TxInputRedirect = TRUE;
 			if (TxTkConsole)
 			    TxSetPrompt(':');
 			else
@@ -978,7 +938,7 @@ MagicEventProc(clientData, xevent)
 			bool iMacro;
 			char *macroDef;
 
-			macroDef = MacroRetrieve(keywstate, &iMacro);
+			macroDef = MacroRetrieve(mw->w_client, keywstate, &iMacro);
 
 			if (macroDef == NULL)
 			{
@@ -1014,21 +974,18 @@ MagicEventProc(clientData, xevent)
 				    TxPrintf("%s", macroDef);
 				    TxFlushOut();
 				}
-				TxInputRedirect = True;
+				TxInputRedirect = TRUE;
 			    }
 			    else
 			    {
-				/* TxParseString is defined by magic/magicwrap.i */
-				/* and calls Tcl_Eval()				 */
-				char *outstring = Tcl_Alloc(sl +
-					strlen(Tk_PathName(wind)) + 2);
-				sprintf(outstring, "%s %s",
-					Tk_PathName(wind), macroDef);
+				/* TxParseString is defined by tcltk/tclmagic.c
+				 * and calls Tcl_Eval().
+				 */
+
 				TxSetPoint(KeyPressedEvent->x,
 					grXToMagic(KeyPressedEvent->y),
 					grCurrent.mw->w_wid);
-				TxParseString(outstring, NULL, NULL);
-				Tcl_Free(outstring);
+				TxParseString(macroDef, NULL, NULL);
 			    }
 			    freeMagic(macroDef);
 			}
@@ -1121,11 +1078,11 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     char *planecount;
     char *fullname;
     FILE* f;
-    bool execFailed = false;
+    bool execFailed = FALSE;
     int x, y, width, height;
 
     WindPackageType = WIND_X_WINDOWS;
-    TxInputRedirect = False;
+    TxInputRedirect = FALSE;
     grCursorType = "color";
     WindScrollBarWidth = 14;
 
@@ -1160,6 +1117,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     grSetSPatternPtr = grtkSetSPattern;
     grPutTextPtr = grtkPutText;
     grDefineCursorPtr = grTkDefineCursor;
+    grFreeCursorPtr = grTkFreeCursors;
     GrBitBltPtr = GrTkBitBlt;
     grDrawGridPtr = grtkDrawGrid;
     grDrawLinePtr = grtkDrawLine;
@@ -1175,11 +1133,11 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     
     if (execFailed) {
 	TxError("Execution failed!\n");
-	return false;
+	return FALSE;
     }
 
     if (!GrTkInit(dispType)) {
-	return false;
+	return FALSE;
     };
 
     Tk_GetVRootGeometry(Tk_MainWindow(magicinterp), &x, &y, &width, &height);
@@ -1188,7 +1146,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     GrScreenRect.r_xtop = x + width;
     GrScreenRect.r_ytop = y + height;
 
-    return Tk_MainWindow(magicinterp) ? true : false;
+    return Tk_MainWindow(magicinterp) ? TRUE : FALSE;
 }
 
 extern void MakeWindowCommand();
@@ -1364,7 +1322,7 @@ GrTkCreate(w, name)
 	/* set up Tk event handler to start processing */
 
 	Tk_CreateEventHandler(tkwind, ExposureMask | StructureNotifyMask
-		| ButtonPressMask | ButtonReleaseMask | KeyPressMask,
+		| ButtonPressMask | KeyPressMask,
 		(Tk_EventProc *)MagicEventProc, (ClientData) tkwind);
 
 	/* set up commands to be passed expressly to this window */
@@ -1602,7 +1560,7 @@ GrTkUnlock(w)
  *	in the queue.
  *
  * Results:
- *	True if an event is in the event queue.
+ *	TRUE if an event is in the event queue.
  *
  * Side effects:
  *	Hopefully none (put back the event!)
