@@ -23,8 +23,8 @@
 #define TK_FONT_LARGE   "-*-helvetica-medium-r-normal--18-*-75-75-p-*-iso8859-*"
 #define TK_FONT_XLARGE  "-*-helvetica-medium-r-normal--24-*-75-75-p-*-iso8859-*"
 
-extern void GrTkFreeCursor();
-extern Void grTkDefineCursor();
+extern void grTkDefineCursor();
+extern void grTkFreeCursors();
 
 extern Tk_Font grTkFonts[4];
 extern Tk_Cursor grCursors[MAX_CURSORS];
