@@ -10,6 +10,8 @@
  * Copyright 2003 Open Circuit Design, Inc., for MultiGiG Ltd.
  */
 
+#include "utils/magic.h"
+
 /* Constants
  */
 #define M_WIDTH		1023
@@ -17,11 +19,6 @@
 
 #define TK_BATCH_SIZE	10000
 
-#define true		1
-#define false		0
-
-#undef TRUE
-
 #define grMagicToX(y) ( grCurrent.mw->w_allArea.r_ytop - (y))
 #define grXToMagic(y) ( grCurrent.mw->w_allArea.r_ytop - (y))
 
@@ -62,30 +59,30 @@ extern GC grGCFill, grGCText, grGCDraw, grGCCopy, grGCGlyph;
 
 extern bool grtkGetCursorPos();
 extern bool grtkDrawGrid();
-extern Void GrTkEnableTablet();
-extern Void GrTkDisableTablet();
-extern Void GrTkSetCMap();
-extern Void grtkPutText();
-extern Void GrTkSetCursor();
-extern Void GrTkTextSize();
-extern Void GrTkDrawGlyph();
-extern Void GrTkBitBlt();
-extern Void NullBitBlt();
+extern void GrTkEnableTablet();
+extern void GrTkDisableTablet();
+extern void GrTkSetCMap();
+extern void grtkPutText();
+extern void GrTkSetCursor();
+extern void GrTkTextSize();
+extern void GrTkDrawGlyph();
+extern void GrTkBitBlt();
+extern void NullBitBlt();
 extern int  GrTkReadPixel();
-extern Void grtkDrawLine();
-extern Void grtkSetLineStyle();
-extern Void grtkSetCharSize();
-extern Void grtkSetWMandC();
-extern Void grtkFillRect();
-extern Void grtkRectConvert();
+extern void grtkDrawLine();
+extern void grtkSetLineStyle();
+extern void grtkSetCharSize();
+extern void grtkSetWMandC();
+extern void grtkFillRect();
+extern void grtkRectConvert();
 #ifdef NONMANHATTAN
-extern Void grtkFillPolygon();
+extern void grtkFillPolygon();
 #endif
 
-extern Void grtkDrawLines();
+extern void grtkDrawLines();
 extern XSegment grtkLines[];
 extern int grtkNbLines;
-extern Void grtkFillRects();
+extern void grtkFillRects();
 extern XRectangle grtkRects[];
 extern int grtkNbRects;
 
