@@ -36,12 +36,12 @@ char *getenv();
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/magsgtty.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "graphics/glyphs.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
@@ -49,7 +49,7 @@ char *getenv();
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "grX11Int.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 
 extern char  *DBWStyleType;
 
@@ -62,7 +62,6 @@ GR_CURRENT    grCurrent= {0,0,0,0,0,0};
 GR_DISPLAY    grDisplay;
 GC 	      grGCFill, grGCText,grGCDraw;
 GC	      grGCCopy, grGCGlyph, grGCStipple;
-int	      grXWStdin();
 
 unsigned long grPixels[256];
 unsigned long grPlanes[256];
@@ -115,10 +114,12 @@ int Xhelper;
  * of those names, which don't get modified.  Check out the Makefile
  * for details on this.
  */
-extern Void GrX11Close(), GrX11Flush(), GrX11Init();
-extern bool GrX11Create();
-extern Void GrX11Delete(),GrX11Configure(),GrX11Raise(),GrX11Lower();
-extern Void GrX11Lock(),GrX11Unlock(),GrX11IconUpdate();
+
+extern void GrX11Close(), GrX11Flush();
+extern bool GrX11Init(), GrX11Create();
+extern void GrX11Delete(), GrX11Configure(), GrX11Raise(), GrX11Lower();
+extern void GrX11Lock(), GrX11Unlock(), GrX11IconUpdate();
+extern void grXWStdin();
 
 
 /*---------------------------------------------------------
@@ -129,12 +130,10 @@ extern Void GrX11Lock(),GrX11Unlock(),GrX11IconUpdate();
  * Results:	None.
  *
  * Side Effects:    None.
- *
- * Errors:		None.
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetWMandC (mask, c)
     int mask;			/* New value for write mask */
     int c;			/* New value for current color */
@@ -176,7 +175,7 @@ grx11SetWMandC (mask, c)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetLineStyle (style)
     int style;			/* New stipple pattern for lines. */
 {
@@ -271,7 +270,7 @@ grx11SetLineStyle (style)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetSPattern (stipple, pattern)
     int stipple;			/* The stipple number, 1-15. */
     int pattern[8];			/* 8 8-bit patterns integers */
@@ -280,7 +279,7 @@ grx11SetSPattern (stipple, pattern)
     int x,y,pat;
 
     p = XCreatePixmap(grXdpy, XDefaultRootWindow(grXdpy), 8, 8, 1);
-    if (grGCStipple == 0) {
+    if (grGCStipple == NULL) {
 	grGCStipple = XCreateGC(grXdpy, p, 0, 0);
     }
     for (y = 0; y < 8; y++) {
@@ -307,7 +306,7 @@ grx11SetSPattern (stipple, pattern)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetStipple (stipple)
     int stipple;			/* The stipple number to be used. */
 {
@@ -340,7 +339,8 @@ grx11SetStipple (stipple)
  */
 
 bool
-GrX11Init ()
+GrX11Init(dispType)
+    char *dispType;
 {
     int i,j;
     XVisualInfo grvisual_info, *grvisual_get, grtemplate;
@@ -371,7 +371,7 @@ GrX11Init ()
     if (grXdpy == NULL)
     {
     	 TxError("Couldn't open display; check DISPLAY variable\n");
-	 return false;
+	 return FALSE;
     }
     grXscrn = XDefaultScreen(grXdpy);
 
@@ -511,6 +511,9 @@ GrX11Init ()
 	    visual_table[3] = defpsindex;
 	log_color = getenv("MAGIC_COLOR");
 
+	if ((log_color == NULL) && (dispType != NULL) && (dispType[0] != 'X'))
+	    log_color = dispType;
+
 	/* Allow environment variables to override the colormap base and */
 	/* number of reserved colors, as these depend on the terminal X	 */
 	/* server, NOT on the machine running magic.			 */
@@ -530,10 +533,10 @@ GrX11Init ()
         gritems = -1;
         if (log_color != NULL)
 	{
-	    if (strncmp(log_color, "8bit", 4) == 0)  gritems = visual_table[3];
-	    if (strncmp(log_color, "15bit", 5) == 0) gritems = visual_table[4];
-	    if (strncmp(log_color, "16bit", 5) == 0) gritems = visual_table[5];
-	    if (strncmp(log_color, "24bit", 5) == 0) gritems = visual_table[6];
+	    if (strncmp(log_color, "8", 1) == 0)  gritems = visual_table[3];
+	    if (strncmp(log_color, "15", 2) == 0) gritems = visual_table[4];
+	    if (strncmp(log_color, "16", 2) == 0) gritems = visual_table[5];
+	    if (strncmp(log_color, "24", 2) == 0) gritems = visual_table[6];
 	    if (gritems == -1) {
 		printf("The visual mode %s is not available. Sorry.\n", log_color);
 		XFree(grvisual_get);
@@ -589,7 +592,7 @@ GrX11Init ()
     {
 	status = 0;
 	if (grClass != 4)
-	    status= XAllocColorCells(grXdpy, grXcmap, True, grDisplay.planes,
+	    status= XAllocColorCells(grXdpy, grXcmap, TRUE, grDisplay.planes,
 			grDisplay.planeCount, &grDisplay.basepixel, 1); 
 	if (status == 0) 
 	  /*
@@ -657,7 +660,7 @@ GrX11Init ()
 	    /* This must be called here;  because in B/W the colormap	*/
 	    /* is useless, it will not be called by the style file	*/
 	    /* load procedure.						*/
-	    GrX11SetCMap((char *)NULL);
+	    GrX11SetCMap();
 	    break;
 	case 7: case 8:
 	    grDStyleType = "7bit";
@@ -679,15 +682,19 @@ GrX11Init ()
 
 
 /*---------------------------------------------------------
- * GrXClose:
+ * GrXClose --
  *
- * Results:	None.
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	In the non-pthreads version, kills the helper
+ *	process.  In the pthreads version, detaches the
+ *	X11 helper thread.
  *---------------------------------------------------------
  */
 
-Void
+void
 GrX11Close ()
 {
     if (grXdpy == NULL) return;
@@ -697,7 +704,8 @@ GrX11Close ()
     kill(Xhelper, SIGKILL);
     WaitPid (Xhelper, 0);
 #endif
-    grGCStipple = 0;
+    XFreeGC(grXdpy, grGCStipple);
+    grGCStipple = NULL;
     XCloseDisplay(grXdpy);
 #ifdef HAVE_PTHREADS
     xloop_end();
@@ -718,7 +726,7 @@ GrX11Close ()
  *---------------------------------------------------------
  */
 
-Void
+void
 GrX11Flush ()
 {
    XFlush(grXdpy);
@@ -741,8 +749,8 @@ GrX11Flush ()
  * ---------------------------------------------------------------------------
  */
 
-Void
-grX11Stdin ()
+void
+grX11Stdin()
 {
     TxInputEvent *event;
     XEvent	xevent;
@@ -908,11 +916,11 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     int fildes[2],fildes2[2];
     char *fullname;
     FILE* f;
-    bool execFailed = false;
+    bool execFailed = FALSE;
 
     WindPackageType = WIND_X_WINDOWS;
     WindScrollBarWidth = 14;
-    grCursorType = "bw";
+    grCursorType = "color";
 
     /* Set up helper process */
     pipe(fildes);
@@ -939,7 +947,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
 	    X11HELP_PROG, HELPER_PATH);
 	error = 0;
 	write(fildes[1], &error, 4);
-	return false;
+	return FALSE;
     } else {
 	fclose(f);
     }
@@ -952,7 +960,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
 	sprintf(argv[1], "%d %d", fildes2[0],fildes[1]);
 	if (execl(argv[0], argv[0], argv[1], 0) != 0)
 	{
-	    execFailed = true;
+	    execFailed = TRUE;
 	    TxError("Couldn't execute helper process \"%s\".\n", fullname);
 	    TxFlush();
 	    /* we're the child process -- don't muck things up by returning */
@@ -1003,20 +1011,22 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     grFillPolygonPtr = grx11FillPolygon;
 #endif
     
-    if (execFailed) {
+    if (execFailed)
+    {
 	TxError("Execution failed!\n");
-	return false;
+	return FALSE;
     }
 
     TxAdd1InputDevice(fileno(stdin), grXWStdin, (ClientData) NULL);
 
-    if(!GrX11Init()){
-	return false;
-    };
+    if (!GrX11Init(dispType))
+    {
+	return FALSE;
+    }
     GrScreenRect.r_xtop = DisplayWidth(grXdpy,grXscrn);
     GrScreenRect.r_ytop = DisplayHeight(grXdpy,grXscrn);
 
-    return true;
+    return TRUE;
 }
 
 /*
@@ -1033,9 +1043,8 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 grXWStdin(fd, cdata)
     int fd;
     ClientData cdata;
@@ -1065,13 +1074,14 @@ grXWStdin(fd, cdata)
  *	Bind X window to Magic Window w.
  *
  * Results:
- *      Window created, window ID send to Xhelper.
+ *	Success/Failure
  *
  * Side Effects:
- *	None.
+ *      Window created, window ID send to Xhelper.
  *
  * ----------------------------------------------------------------------------
  */
+
 bool
 GrX11Create(w, name)
     MagWindow *w;
@@ -1128,7 +1138,7 @@ GrX11Create(w, name)
         {
 	    XWMHints wmhints;
 	    wmhints.flags = InputHint;
-	    wmhints.input = True;
+	    wmhints.input = TRUE;
 	    XSetWMHints(grXdpy, wind, &wmhints);
         }
 #endif	/* sun */
@@ -1177,7 +1187,7 @@ GrX11Create(w, name)
         write( pipeWrite, (char *) &wind, sizeof(Window));
 	kill( Xhelper, SIGTERM);
 #endif
-	sleep(1); /* wait for Xhelper to register for Expose Events; */
+	sleep(1); /* wait for Xhelper to for Expose Events; */
 		  /* the window new doesn't get painted initially    */
 		  /* otherwise.					     */
 /*        printf("Create call completed.\n");  */
@@ -1196,12 +1206,15 @@ GrX11Create(w, name)
  *      Destroy an X window.
  *
  * Results:
- *      Window destroyed.
+ *	None.
  *
+ * Side Effects:
+ *      Window destroyed.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Delete(w)
     MagWindow *w;
 {
@@ -1222,15 +1235,15 @@ GrX11Delete(w)
  *      Resize/ Move an existing X window.
  *
  * Results:
- *      Window reconfigured to w->w_frameArea.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window reconfigured to w->w_frameArea.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 GrX11Configure(w)
     MagWindow *w;
 {
@@ -1248,14 +1261,15 @@ GrX11Configure(w)
  *	obscures it.
  *
  * Results:
- *      Window raised.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window raised.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Raise(w)
     MagWindow *w;
 {
@@ -1270,19 +1284,21 @@ GrX11Raise(w)
  *	obscures it.
  *
  * Results:
- *      Window lowered.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window lowered.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Lower(w)
     MagWindow *w;
 {
     XLowerWindow(grXdpy, (Window) w->w_grdata );
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1292,14 +1308,15 @@ GrX11Lower(w)
  *	and "grCurrent.mw" to reference the locked window.
  *
  * Results:
- *      Window locked.
+ *	None.
  *
  * Side Effects:
- *	None.
+ *      Window locked.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Lock(w, flag)
     MagWindow *w;
     bool flag;
@@ -1311,6 +1328,7 @@ GrX11Lock(w, flag)
 	grCurrent.window = (Window) w->w_grdata;
     }
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1319,20 +1337,23 @@ GrX11Lock(w, flag)
  *      Unlock a window, flushing stuff out to the display.
  *
  * Results:
- *      Window unlocked.
+ *	None.
  *
  * Side Effects:
+ *      Window unlocked.
  *	Display update.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Unlock(w)
     MagWindow *w;
 {
     GR_X_FLUSH_BATCH();
     grSimpleUnlock(w);
 }
+
 
 /*
  *-------------------------------------------------------------------------
@@ -1345,7 +1366,9 @@ GrX11Unlock(w)
  *
  *-------------------------------------------------------------------------
  */
-Void GrX11IconUpdate(w,text)
+
+void
+GrX11IconUpdate(w,text)
 	MagWindow	*w;
 	char		*text;
 
