@@ -19,15 +19,16 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <X11/Xlib.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
 #include "graphics/graphicsInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "grX11Int.h"
@@ -61,7 +62,7 @@ grx11DrawGrid (prect, outline, clip)
 			         * for the grid.  Note:  in order to maintain
 			         * precision for the grid, the rectangle
 			         * coordinates are specified in units of
-			         * screen coordinates multiplied by 4096.
+			         * screen coordinates multiplied by SUBPIXEL.
 			         */
     int outline;		/* the outline style */
     Rect *clip;			/* a clipping rectangle */
@@ -78,19 +79,19 @@ grx11DrawGrid (prect, outline, clip)
 	return FALSE;
     
     xstart = prect->r_xbot % xsize;
-    while (xstart < clip->r_xbot<<12) xstart += xsize;
+    while (xstart < clip->r_xbot << SUBPIXELBITS) xstart += xsize;
     ystart = prect->r_ybot % ysize;
-    while (ystart < clip->r_ybot<<12) ystart += ysize;
+    while (ystart < clip->r_ybot << SUBPIXELBITS) ystart += ysize;
     
     grx11SetLineStyle(outline);
 
     snum = 0;
     low = grMagicToX(clip->r_ybot);
     hi = grMagicToX(clip->r_ytop);
-    for (x = xstart; x < (clip->r_xtop+1)<<12; x += xsize)
+    for (x = xstart; x < (clip->r_xtop + 1) << SUBPIXELBITS; x += xsize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = x >> 12;
+	shifted = x >> SUBPIXELBITS;
 	seg[snum].x1 = shifted;
 	seg[snum].y1 = low;
 	seg[snum].x2 = shifted;
@@ -102,10 +103,10 @@ grx11DrawGrid (prect, outline, clip)
     snum = 0;
     low = clip->r_xbot;
     hi = clip->r_xtop;
-    for (y = ystart; y < (clip->r_ytop+1)<<12; y += ysize)
+    for (y = ystart; y < (clip->r_ytop + 1) << SUBPIXELBITS; y += ysize)
     {
         if (snum >= GR_NUM_GRIDS) break;
-	shifted = grMagicToX(y >> 12);
+	shifted = grMagicToX(y >> SUBPIXELBITS);
 	seg[snum].x1 = low;
 	seg[snum].y1 = shifted;
 	seg[snum].x2 = hi;
@@ -113,7 +114,7 @@ grx11DrawGrid (prect, outline, clip)
 	snum++;
     }
     XDrawSegments(grXdpy, grCurrent.window, grGCDraw, seg, snum);
-    return true;
+    return TRUE;
 }
 
 
@@ -121,13 +122,13 @@ grx11DrawGrid (prect, outline, clip)
  * grxLoadFont
  *	This local routine loads the X fonts used by Magic.
  *
- * Results:	None.
+ * Results:	Success/failure
  *
  * Side Effects:    None.
  *---------------------------------------------------------
  */
 
-Void
+bool
 grx11LoadFont()
 {
     static char *fontnames[4] = {
@@ -154,11 +155,11 @@ grx11LoadFont()
               if ((grXFonts[i]= XLoadQueryFont(grXdpy,GR_DEFAULT_FONT))==NULL) 
 	      {
 	           TxError("%s %s\n",unable,GR_DEFAULT_FONT);
-		   return false;
+		   return FALSE;
 	      }
          }
     }
-    return true;
+    return TRUE;
 }
 
 
@@ -173,7 +174,7 @@ grx11LoadFont()
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetCharSize (size)
     int size;		/* Width of characters, in pixels (6 or 8). */
 {
@@ -217,7 +218,7 @@ grx11SetCharSize (size)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GrX11TextSize(text, size, r)
     char *text;
     int size;
@@ -280,7 +281,9 @@ GrX11ReadPixel (w, x, y)
     XWindowAttributes	att;
 
     XGetWindowAttributes(grXdpy,grCurrent.window, &att);
-    if ( x < 0 || x >= att.width || grMagicToX(y) < 0 || grMagicToX(y) >= att.height) return(0);
+    if ( x < 0 || x >= att.width || grMagicToX(y) < 0
+		|| grMagicToX(y) >= att.height)
+	return(0);
     image = XGetImage(grXdpy, grCurrent.window, x, grMagicToX(y), 1, 1,
 		      ~0, ZPixmap);
     value = XGetPixel(image, 0, 0);
@@ -292,7 +295,7 @@ GrX11ReadPixel (w, x, y)
  * ----------------------------------------------------------------------------
  * GrXBitBlt --
  *
- *	Copy information from one part of the screen to the other.
+ *	Copy information in bit block transfers.
  *
  * Results:
  *	None.
@@ -302,12 +305,14 @@ GrX11ReadPixel (w, x, y)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 GrX11BitBlt(r, p)
     Rect *r;
     Point *p;
 {
-    XCopyArea(grXdpy, grCurrent.window, grCurrent.window, grGCCopy,
+    Drawable wind = (Drawable)grCurrent.window;
+
+    XCopyArea(grXdpy, wind, wind, grGCCopy,
 	      r->r_xbot, grMagicToX(r->r_ytop),
 	      r->r_xtop - r->r_xbot + 1, r->r_ytop - r->r_ybot + 1,
 	      p->p_x, grMagicToX(p->p_y));
@@ -320,10 +325,16 @@ GrX11BitBlt(r, p)
  * GrX11RectConvert --
  *	Convert a magic rectangle into an X11 rectangle
  *	(Both passed as pointers)
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Converted value returned in xr.
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 grx11RectConvert(mr, xr)
     Rect *mr;
     XRectangle *xr;
@@ -352,7 +363,7 @@ grx11RectConvert(mr, xr)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11PutText (text, pos, clip, obscure)
     char *text;			/* The text to be drawn. */
     Point *pos;			/* A point located at the leftmost point of
@@ -406,16 +417,24 @@ grx11PutText (text, pos, clip, obscure)
 }
 
 
-/* grX11suGeoSub:
+/*
+ *---------------------------------------------------------
+ * grX11suGeoSub --
  *	return the tallest sub-rectangle of r not obscured by area
  *	area must be within r.
+ * 
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Source rectangle "r" is modified.
+ *---------------------------------------------------------
  */
 
 void
 grX11suGeoSub(r, area)
-register Rect *r;		/* Rectangle to be subtracted from. */
-register Rect *area;		/* Area to be subtracted. */
-
+    Rect *r;		/* Rectangle to be subtracted from. */
+    Rect *area;		/* Area to be subtracted. */
 {
     if (r->r_xbot == area->r_xbot) r->r_xbot = area->r_xtop;
     else
