@@ -22,8 +22,8 @@
 #endif  /* OS2 */
 #include <X11/Xlib.h>
 
-#include "misc/magic.h"
-#include "misc/styles.h"
+#include "utils/magic.h"
+#include "utils/styles.h"
 #include "utils/hash.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -69,10 +69,10 @@ GrX11DrawGlyph (gl, p)
     bBox.r_xtop = p->p_x + gl->gr_xsize - 1;
     bBox.r_ytop = p->p_y + gl->gr_ysize - 1;
 
-    anyObscure = false;
+    anyObscure = FALSE;
     for (ob = grCurObscure; ob != NULL; ob = ob->r_next) {
 	if (GEO_TOUCH( &(ob->r_r), &bBox)) {
-	    anyObscure = true;
+	    anyObscure = TRUE;
 	    break;
 	}
     }
