@@ -8,14 +8,14 @@
  */
 
 #include <stdio.h>
+#include <string.h>
+#include <signal.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <signal.h>
-
 #include <X11/keysym.h>
 #include <pthread.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
@@ -34,7 +34,9 @@ pthread_t xloop_thread = 0;
 /*------------------------------------------------------*/
 
 /*
- * ParseEvent(XEvent *event):
+ *--------------------------------------------------------------
+ * ParseEvent(XEvent *event) --
+ *
  *   Pass XEvents on to the magic main process by writing into the
  *   connecting pipe.  Keystrokes must be handled such that magic
  *   can treat untranslated keyboard input from stdin the same way
@@ -46,8 +48,17 @@ pthread_t xloop_thread = 0;
  *   Pass the event and key value back through the I/O pipe so that
  *   the keypress triggers the select() mechanism in magic's textio
  *   routine.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects: 
+ *	pipe I/O
+ *
+ *--------------------------------------------------------------
  */
 
+void
 ParseEvent (event, parentID)
     XEvent *event;
     int parentID;
@@ -137,7 +148,7 @@ ParseEvent (event, parentID)
  *---------------------------------------------------------
  */
 
-int
+void
 xloop_begin(window)
     Window window;
 {
@@ -164,10 +175,17 @@ xloop_begin(window)
     }
 }  
 
-/*----------------------------------------------------------------------*/
-/* xloop_create function creates a thread for the X event loop.         */
-/* Returns 0 on success of pthread_create, non-zero on failure.         */
-/*----------------------------------------------------------------------*/
+/*----------------------------------------------------------------------
+ * xloop_create --
+ *	Function creates a thread for the X event loop.
+ *
+ * Results:
+ *	Returns 0 on success of pthread_create, non-zero on failure.
+ *
+ * Side Effects:
+ *	Thread crated
+ *----------------------------------------------------------------------
+ */
 
 int
 xloop_create(window)
@@ -189,9 +207,18 @@ xloop_create(window)
     return status;
 }
 
-/*----------------------------------------------------------------------*/
-/* Kill the X event loop thread.					*/
-/*----------------------------------------------------------------------*/
+/*
+ *----------------------------------------------------------------------
+ * xloop_end --
+ *	Kill the X event loop thread.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Thread destroyed.
+ *----------------------------------------------------------------------
+ */
 
 void
 xloop_end()
