@@ -22,7 +22,7 @@
 #ifndef _GRAPHICS_H
 #define	_GRAPHICS_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 
 /* data structures */
@@ -127,6 +127,9 @@ extern void (*GrResumePtr)();
 #define GrStop	(*GrStopPtr)
 #define GrResume (*GrResumePtr)
 
+/* Number of colors defined in the colormap */
+extern int GrNumColors;
+
 /* Different graphics (OpenGL vs. X11, for instance) have different 
  * definitions of line and rectangle/polygon coordinates.  Usually
  * this boils down to a single pixel difference on rectangle edges.
