@@ -19,13 +19,10 @@
  * rcsid "$Header: /ufs/repository/magic/graphics/graphicsInt.h,v 1.3 2001/03/29 19:50:10 tim Exp $"
  */
 
-#define _GRAPHINT
-#ifndef	_MAGIC
-    int err = Need_to_include_misc/magic_h
-#endif
-#ifndef	_WINDOWS
-    int err = Need_to_include_windows/windows_h
-#endif
+#ifndef _GRAPHICSINT_H
+#define _GRAPHICSINT_H
+
+#include "windows/windows.h"
 
 
 extern int grNumBitPlanes;
@@ -33,22 +30,23 @@ extern int grBitPlaneMask;
 
 
 /* procedures */
-extern Void (*grPutTextPtr)();
-extern Void (*grSetSPatternPtr)();
-extern Void (*grDefineCursorPtr)();
+extern void (*grPutTextPtr)();
+extern void (*grSetSPatternPtr)();
+extern void (*grDefineCursorPtr)();
+extern void (*grFreeCursorPtr)();
 extern bool (*grDrawGridPtr)();
-extern Void (*grDrawLinePtr)();
-extern Void (*grSetWMandCPtr)();
-extern Void (*grFillRectPtr)();
-extern Void (*grSetStipplePtr)();
-extern Void (*grSetLineStylePtr)();
-extern Void (*grSetCharSizePtr)();
+extern void (*grDrawLinePtr)();
+extern void (*grSetWMandCPtr)();
+extern void (*grFillRectPtr)();
+extern void (*grSetStipplePtr)();
+extern void (*grSetLineStylePtr)();
+extern void (*grSetCharSizePtr)();
 #ifdef NONMANHATTAN
-extern Void (*grFillPolygonPtr)();
+extern void (*grFillPolygonPtr)();
 #endif /* NONMANHATTAN */
 
 extern char *grFgets();
-extern Void grSimpleLock(), grSimpleUnlock();
+extern void grSimpleLock(), grSimpleUnlock();
 extern void grNoLock();
 #define	GR_CHECK_LOCK()	{if (grLockedWindow == NULL) grNoLock();} 
 
@@ -88,11 +86,16 @@ extern bool grDriverInformed;
 extern void grInformDriver();
 
 /* Macro to check for a bogusly small grid. 
- * Turn off grid if there are more than GR_NUMGRIDS gridlines on the
+ * Turn off grid if there are more than GR_NUM_GRIDS gridlines on the
  * screen in either direction, or if they are less than 4 pixels apart.
  */
 #define GR_NUM_GRIDS 160
 #define GRID_TOO_SMALL(x,y,max) ( \
-     ((((GrScreenRect.r_xtop - GrScreenRect.r_xbot) << 12) / (x)) >= (max)) || \
-     ((((GrScreenRect.r_ytop - GrScreenRect.r_ybot) << 12) / (y)) >= (max)) || \
-     (((x) >> 12) < 4) || (((y) >> 12) < 4) )
+     ((((GrScreenRect.r_xtop - GrScreenRect.r_xbot) << SUBPIXELBITS) / (x)) \
+     >= (max)) || \
+     ((((GrScreenRect.r_ytop - GrScreenRect.r_ybot) << SUBPIXELBITS) / (y)) \
+     >= (max)) || \
+     (((x) >> SUBPIXELBITS) < 4) || (((y) >> SUBPIXELBITS) < 4) \
+)
+
+#endif /* _GRAPHICSINT_H */
