@@ -4,7 +4,7 @@
 
 #ifndef lint
 static char rcsid[]="$Header: /ufs/repository/magic/graphics/prcolors.c,v 1.1.1.1 2000/03/29 18:35:03 rajit Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 main()
 {
