@@ -19,14 +19,15 @@
 
 #ifndef lint
 static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteCrss.c,v 1.2 2001/01/12 22:12:51 jsolomon Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "utils/malloc.h"
 #include "debug/debug.h"
@@ -34,14 +35,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteCrss.c,v 1.2
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 /* Passed to glCrossChoose() */
 GlPoint *glCrossLookAhead;
@@ -57,6 +58,8 @@ bool glPenaltiesScaled = FALSE;
 /* Forward declarations */
 GlPoint *glCrossAdjust();
 int glCrossChoose();
+void glCrossTakePin();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -83,14 +86,14 @@ int glCrossChoose();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glCrossMark(rootUse, path, pNetId)
     CellUse *rootUse;	/* For error feedback if non-NULL */
     GlPoint *path;	/* Path linked via gl_path pointers */
     NetId *pNetId;	/* Net and segment identifier; netid_seg is updated */
 {
-    register GCRPin *srcPin, *dstPin;
-    register GlPoint *rp;
+    GCRPin *srcPin, *dstPin;
+    GlPoint *rp;
     bool srcTaken;
     NetId markNetId;
 
@@ -157,7 +160,7 @@ glCrossMark(rootUse, path, pNetId)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glCrossTakePin(rootUse, pin, netid)
     CellUse *rootUse;	/* For error feedback if non-NULL */
     GCRPin *pin;	/* Pin to take */
@@ -232,13 +235,13 @@ glCrossTakePin(rootUse, pin, netid)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glCrossUnreserve(net)
     NLNet *net;
 {
-    register NLTermLoc *loc;
-    register NLTerm *term;
-    register GCRPin *pin;
+    NLTermLoc *loc;
+    NLTerm *term;
+    GCRPin *pin;
  
     /* De-reserve the pins taken by each terminal location in this net */
     for (term = net->nnet_terms; term; term = term->nterm_next)
@@ -287,7 +290,7 @@ glCrossUnreserve(net)
 
 int
 glCrossEnum(inPt, tp, func, cdata)
-    register GlPoint *inPt;	/* Top of heap point being expanded */
+    GlPoint *inPt;	/* Top of heap point being expanded */
     Tile *tp;			/* Tile adjacent to inPt->gl_tile */
     int (*func)();		/* Called for each crossing */
     ClientData cdata;		/* Passed to (*func)() */
@@ -295,7 +298,7 @@ glCrossEnum(inPt, tp, func, cdata)
     int outSide, origin, lo, hi, max, start, n, nhi;
     GCRChannel *ch = inPt->gl_pin->gcr_ch;
     Tile *inTile = inPt->gl_tile;
-    register GCRPin *pins, *pin;
+    GCRPin *pins, *pin;
 
     /* Sanity checks: callers should ensure that these are true */
     ASSERT(tp->ti_client != (ClientData) MINFINITY, "glCrossEnum");
@@ -569,9 +572,9 @@ glCrossAdjust(lookAhead, path)
     /*ARGSUSED*/
 int
 glCrossChoose(newRest, tp, pin, newPath)
-    register GlPoint *newRest;	/* Portion of path already assigned */
-    register Tile *tp;		/* UNUSED */
-    register GCRPin *pin;	/* Pin on boundary of tp being considered */
+    GlPoint *newRest;	/* Portion of path already assigned */
+    Tile *tp;		/* UNUSED */
+    GCRPin *pin;	/* Pin on boundary of tp being considered */
     GlPoint *newPath;		/* Update newPath->gl_pin, newPath->gl_cost */
 {
     GCRPin *savePin;
@@ -631,7 +634,7 @@ glCrossCost(lookAhead, exitPt, entryPt)
     GlPoint *exitPt;
     GlPoint *entryPt;
 {
-    register GCRPin *entryPin, *exitPin, *otherPin;
+    GCRPin *entryPin, *exitPin, *otherPin;
     GCRPin *opposite;
     int count, cost;
 
@@ -775,7 +778,7 @@ glCrossCost(lookAhead, exitPt, entryPt)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 glCrossScalePenalties()
 {
     if (glPenaltiesScaled)
