@@ -22,20 +22,21 @@ static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteDens.c,v 1.2
 
 #include <stdio.h>
 #include <string.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "gcr/gcr.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
 
 /*
@@ -193,7 +194,7 @@ glDMAlloc(dm, top, cap)
     dm->dm_max = 0;
     dm->dm_size = top + 1;
     dm->dm_cap = cap;
-    CALLOC(short *, dm->dm_value, sizeof (short) * dm->dm_size);
+    dm->dm_value = (short *) callocMagic((unsigned) (sizeof (short) * dm->dm_size));
 }
 
 /*
@@ -245,7 +246,7 @@ void
 glDMFree(dm)
     DensMap *dm;
 {
-    FREE((char *) dm->dm_value);
+    freeMagic((char *) dm->dm_value);
 }
 
 /*
