@@ -24,13 +24,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteTest.c,v 1.2
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "debug/debug.h"
 #include "gcr/gcr.h"
@@ -40,12 +40,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteTest.c,v 1.2
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "textio/txcommands.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "commands/commands.h"
 #include "utils/malloc.h"
-#include "misc/styles.h"
-#include "netlist/netlist.h"
+#include "utils/styles.h"
+#include "utils/netlist.h"
 
 bool glInitialized = FALSE;
 
@@ -406,7 +406,7 @@ glHistoAdd(heapPtsBefore, frontierPtsBefore, startPtsBefore)
 {
     GlNetHisto *gh;
 
-    MALLOC(GlNetHisto *, gh, sizeof (GlNetHisto));
+    gh = (GlNetHisto *) mallocMagic((unsigned) (sizeof (GlNetHisto)));
     gh->glh_heap = glCrossingsExpanded - heapPtsBefore;
     gh->glh_frontier = glCrossingsAdded - frontierPtsBefore;
     gh->glh_start = startPtsBefore;
@@ -505,7 +505,7 @@ glHistoDump()
 
     /* Free memory */
     for (gh = glNetHistoList; gh; gh = gh->glh_next)
-	FREE((char *) gh);
+	freeMagic((char *) gh);
     glNetHistoList = NULL;
 
     /* Done */
