@@ -27,26 +27,28 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irCommand.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <stdlib.h>
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "graphics/graphics.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "dbwind/dbwtech.h"
 #include "textio/txcommands.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "commands/commands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
-#include "utils/doubleint.h"
-#include "../mzrouter/mzrouter.h"
+#include "mzrouter/mzrouter.h"
 #include "irouter/irouter.h"
 #include "irouter/irInternal.h"
 
@@ -57,8 +59,7 @@ static MagWindow *irWindow;
 typedef struct
 {
     char	*sC_name;	/* name of iroute subcommand */
-    int    (*sC_proc)();	/* Procedure implementing this 
-				       subcommand */
+    void	(*sC_proc)();	/* Procedure implementing this subcommand */
     char 	*sC_commentString;	/* describes subcommand */
     char 	*sC_usage;		/* command syntax */
 
@@ -90,11 +91,12 @@ extern SubCmdTableE irSubcommands[];
  *	
  * ----------------------------------------------------------------------------
  */
-Void
-irSetNoisyAutoInt(parm,valueS,file)
-int *parm;
-char *valueS;
-FILE *file;
+
+void
+irSetNoisyAutoInt(parm, valueS, file)
+    int *parm;
+    char *valueS;
+    FILE *file;
 {
     int which;
 
@@ -200,7 +202,7 @@ FILE *file;
  */
 
 /* irLSetActive --  */
-Void
+void
 irLSetActive(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -210,7 +212,7 @@ irLSetActive(rL,s,file)
 }
 
 /* irLSetWidth -- */
-Void
+void
 irLSetWidth(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -220,7 +222,7 @@ irLSetWidth(rL,s,file)
 }
 
 /* irLSetHCost -- */
-Void
+void
 irLSetHCost(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -230,7 +232,7 @@ irLSetHCost(rL,s,file)
 }
 	
 /* irLSetVCost -- */
-Void
+void
 irLSetVCost(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -240,7 +242,7 @@ irLSetVCost(rL,s,file)
 }
 
 /* irLSetJogCost -- */
-Void
+void
 irLSetJogCost(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -251,7 +253,7 @@ irLSetJogCost(rL,s,file)
 
  
 /* irLSetHintCost  -- */
-Void
+void
 irLSetHintCost(rL,s,file)
     RouteLayer *rL;
     char *s;
@@ -280,7 +282,7 @@ irLSetHintCost(rL,s,file)
  */
 	
 /* irCSetActive -- */
-Void
+void
 irCSetActive(rC,s, file)
     RouteContact *rC;
     char *s;
@@ -290,7 +292,7 @@ irCSetActive(rC,s, file)
 }
 
 /* irCSetWidth --  */
-Void
+void
 irCSetWidth(rC,s,file)
     RouteContact *rC;
     char *s;
@@ -300,7 +302,7 @@ irCSetWidth(rC,s,file)
 }
 	
 /* irCSetCost -- */
-Void
+void
 irCSetCost(rC,s,file)
     RouteContact *rC;
     char *s;
@@ -330,7 +332,7 @@ irCSetCost(rC,s,file)
 
 
 /* irSrSetRate -- */
-Void
+void
 irSrSetRate(s,file)
     char *s;
     FILE *file;
@@ -339,7 +341,7 @@ irSrSetRate(s,file)
 }
 
 /* irSrSetWidth -- */
-Void
+void
 irSrSetWidth(s,file)
     char *s;
     FILE *file;
@@ -367,7 +369,7 @@ irSrSetWidth(s,file)
  */
 
 /* irWzdSetBloom -- */
-Void
+void
 irWzdSetBloom(s,file)
     char *s;
     FILE *file;
@@ -376,7 +378,7 @@ irWzdSetBloom(s,file)
 }
 
 /* irWzdSetBoundsIncrement -- */
-Void
+void
 irWzdSetBoundsIncrement(s,file)
     char *s;
     FILE *file;
@@ -385,7 +387,7 @@ irWzdSetBoundsIncrement(s,file)
 }
 
 /* irWzdSetEstimate -- */
-Void
+void
 irWzdSetEstimate(s,file)
     char *s;
     FILE *file;
@@ -394,7 +396,7 @@ irWzdSetEstimate(s,file)
 }
 
 /* irWzdSetExpandDests-- */
-Void
+void
 irWzdSetExpandDests(s, file)
 char *s;
 FILE *file;
@@ -403,7 +405,7 @@ FILE *file;
 }
 
 /* irWzdSetPenalty -- */
-Void
+void
 irWzdSetPenalty(s, file)
     char *s;
     FILE *file;
@@ -426,7 +428,7 @@ irWzdSetPenalty(s, file)
     /* print the current penalty factor. */
     if(file)
     {
-	(void) fprintf(file,"%f",
+	fprintf(file,"%f",
 		       (double)irMazeParms->mp_penalty.rf_mantissa /
 		       (double)(1<<irMazeParms->mp_penalty.rf_nExponent));
     }
@@ -441,7 +443,7 @@ irWzdSetPenalty(s, file)
 }
 
 /* irWzdSetPenetration-- */
-Void
+void
 irWzdSetPenetration(s, file)
 char *s;
 FILE *file;
@@ -450,7 +452,7 @@ FILE *file;
 }
 
 /* irWzdSetWindow -- */
-Void
+void
 irWzdSetWindow(s, file)
 char *s;
 FILE *file;
@@ -566,7 +568,7 @@ FILE *file;
 static struct
 {
     char	*cP_name;	/* name of parameter */
-    int    (*cP_proc)();	/* Procedure processing this parameter */
+    void    	(*cP_proc)();	/* Procedure processing this parameter */
 } cParms[] = {
     "active",	irCSetActive,
     "width",	irCSetWidth,
@@ -581,8 +583,7 @@ static struct
     (nV_i >= cmd->tx_argc-1) ? cmd->tx_argv[nV_i=4] : cmd->tx_argv[++nV_i] \
 )
 
-   /*ARGSUSED*/
-Void
+void
 irContactsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -812,7 +813,7 @@ irContactsCmd(w, cmd)
  */
 
     /*ARGSUSED*/
-Void
+void
 irHelpCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -892,7 +893,7 @@ irHelpCmd(w, cmd)
 static struct
 {
     char	*lP_name;	/* name of parameter */
-    int    (*lP_proc)();	/* procedure processing this parameter */
+    void	(*lP_proc)();	/* procedure processing this parameter */
 } lParms[] = {
     "active",	irLSetActive,
     "width",	irLSetWidth,
@@ -911,7 +912,7 @@ static struct
 )
 
     /*ARGSUSED*/	
-Void
+void
 irLayersCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1155,7 +1156,7 @@ static char* rOptions[] = {
     NULL
 };
 
-Void
+void
 irRouteCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1224,7 +1225,9 @@ irRouteCmd(w, cmd)
 		{
 		    if(TTMaskHasType(&layerMask,rL->rl_routeType.rt_tileType) &&
 			    rL->rl_routeType.rt_active)
+		    {
 			LIST_ADD(rL, destLayers);
+		    }
 		}
 		if(destLayers==NULL)
 		{
@@ -1316,7 +1319,9 @@ irRouteCmd(w, cmd)
 		    if(TTMaskHasType(&layerMask,
 				     rL->rl_routeType.rt_tileType) &&
 			    rL->rl_routeType.rt_active)
+		    {
 			LIST_ADD(rL, startLayers);
+		    }
 		}
 		if(startLayers==NULL)
 		{
@@ -1393,15 +1398,14 @@ leaveClean:
 static struct
 {
     char	*srP_name;	/* name of parameter */
-    int    (*srP_proc)();	/* Procedure processing this parameter */
+    void	(*srP_proc)();	/* Procedure processing this parameter */
 } srParms[] = {
     "rate",		irSrSetRate,
     "width",		irSrSetWidth,
     0
 };
 
-    /*ARGSUSED*/
-Void
+void
 irSearchCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1501,8 +1505,7 @@ irSearchCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
-Void
+void
 irSpacingsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1780,7 +1783,8 @@ irSpacingsCmd(w, cmd)
  *	
  * ----------------------------------------------------------------------------
  */
-Void
+
+void
 irVerbosityCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1845,8 +1849,7 @@ irVerbosityCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
-Void
+void
 irVersionCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1886,7 +1889,7 @@ irVersionCmd(w, cmd)
 static struct
 {
     char	*wzdP_name;	/* name of parameter */
-    int    (*wzdP_proc)();	/* Procedure processing this parameter */
+    void	(*wzdP_proc)();	/* Procedure processing this parameter */
 } wzdParms[] = {
     "bloom",		irWzdSetBloom,
     "boundsIncrement",	irWzdSetBoundsIncrement,
@@ -1895,12 +1898,10 @@ static struct
     "penalty",		irWzdSetPenalty,
     "penetration",	irWzdSetPenetration,
     "window",		irWzdSetWindow,
-
     0
 };
 
-    /*ARGSUSED*/
-Void
+void
 irWizardCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -2002,8 +2003,8 @@ irWizardCmd(w, cmd)
  *      such as the search parameter table.
  * ----------------------------------------------------------------------------
  */
-    /*ARGSUSED*/
-Void
+
+void
 irSaveParametersCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -2049,13 +2050,13 @@ irSaveParametersCmd(w, cmd)
     {
 	int n;
 
-	(void) fprintf(saveFile,":iroute contact %s * ",
+	fprintf(saveFile,":iroute contact %s * ",
 		       DBTypeLongNameTbl[rC->rc_routeType.rt_tileType]);
 	for(n=0; cParms[n].cP_name; n++)
 	{
 	    (*cParms[n].cP_proc)(rC,NULL,saveFile);
 	}
-	(void) fprintf(saveFile,"\n");
+	fprintf(saveFile,"\n");
     }
 
     /* save LAYER paramters */
@@ -2063,13 +2064,13 @@ irSaveParametersCmd(w, cmd)
     {
 	int n;
 
-	(void) fprintf(saveFile,":iroute layer %s * ", 
+	fprintf(saveFile,":iroute layer %s * ", 
 	    DBTypeLongNameTbl[rL->rl_routeType.rt_tileType]);
 	for(n=0; lParms[n].lP_name; n++)
 	{
 	    (*lParms[n].lP_proc)(rL,NULL,saveFile);
 	}
-	(void) fprintf(saveFile,"\n");
+	fprintf(saveFile,"\n");
     }
 
     /* save SEARCH parameters */
@@ -2078,10 +2079,10 @@ irSaveParametersCmd(w, cmd)
 
 	for(n=0; srParms[n].srP_name; n++)
 	{
-	    (void) fprintf(saveFile,":iroute search %s ", 
+	    fprintf(saveFile,":iroute search %s ", 
 			   srParms[n].srP_name); 
 	    (*srParms[n].srP_proc)(NULL,saveFile);
-	    (void) fprintf(saveFile,"\n");
+	    fprintf(saveFile,"\n");
 	}
     }
 
@@ -2090,17 +2091,17 @@ irSaveParametersCmd(w, cmd)
 	RouteType *rT;
 	int i;
 
-	(void) fprintf(saveFile,":iroute spacings CLEAR\n");
+	fprintf(saveFile,":iroute spacings CLEAR\n");
 	for (rT=irRouteTypes; rT!= NULL; rT=rT->rt_next)
 	{
 	    for (i=0;i<TT_MAXTYPES;i++)
 		if(rT->rt_spacing[i]>=0)
-		    (void) fprintf(saveFile,":iroute spacings %s %s %d\n", 
+		    fprintf(saveFile,":iroute spacings %s %s %d\n", 
 				   DBTypeLongNameTbl[rT->rt_tileType],
 				   DBTypeLongNameTbl[i],
 				   rT->rt_spacing[i]);
 	    if(rT->rt_spacing[TT_SUBCELL]>=0)
-		(void) fprintf(saveFile,":iroute spacings %s %s %d\n", 
+		fprintf(saveFile,":iroute spacings %s %s %d\n", 
 			       DBTypeLongNameTbl[rT->rt_tileType],
 			       "SUBCELL",
 			       rT->rt_spacing[TT_SUBCELL]);
@@ -2113,10 +2114,10 @@ irSaveParametersCmd(w, cmd)
 
 	for(n=0; wzdParms[n].wzdP_name; n++)
 	{
-	    (void) fprintf(saveFile,":iroute wizard %s ", 
+	    fprintf(saveFile,":iroute wizard %s ", 
 			   wzdParms[n].wzdP_name); 
 	    (*wzdParms[n].wzdP_proc)(NULL,saveFile);
-	    (void) fprintf(saveFile,"\n");
+	    fprintf(saveFile,"\n");
 	}
     }
 
@@ -2148,7 +2149,7 @@ irSaveParametersCmd(w, cmd)
  *	and call it to do the work of implementing the subcommand.  Each
  *	such procedure is of the following form:
  *
- *	Void
+ *	int	
  *	proc(argc, argv)
  *	    int argc;
  *	    char *argv[];
@@ -2220,7 +2221,7 @@ iroute spacings CLEAR\n\
     0
 }, *subCmdP;
 
-Void
+void
 IRCommand(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
