@@ -28,24 +28,24 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irMain.c,v 1.2 200
 /*--- includes --- */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
-#include "utils/doubleint.h"
 #include "../mzrouter/mzrouter.h"
 #include "irouter/irouter.h"
 #include "irouter/irInternal.h"
@@ -90,7 +90,7 @@ RouteType *irRouteTypes;
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 IRInit()
 {
     int n;
