@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irRoute.c,v 1.2 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
@@ -34,11 +34,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irRoute.c,v 1.2 20
 #include "drc/drc.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
 #include "utils/geofast.h"
