@@ -23,13 +23,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irUtils.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "utils/list.h"
-#include "../mzrouter/mzrouter.h"
+#include "mzrouter/mzrouter.h"
 #include "irouter/irouter.h"
 #include "irouter/irInternal.h"
 
