@@ -14,6 +14,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defRead.c,v 1.0 2003/0
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <ctype.h>
 #ifdef SYSV
 #include <string.h>
 #endif
@@ -21,16 +22,17 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defRead.c,v 1.0 2003/0
 #include <stdarg.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/undo.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/malloc.h"
 #include "graphics/graphics.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "cif/cif.h"
 #include "lef/lefInt.h"
 
