@@ -22,13 +22,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defWrite.c,v 1.0 2003/
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/malloc.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "cif/cif.h"
 #include "extflat/extflat.h"
 #include "lef/lefInt.h"
