@@ -19,6 +19,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/0
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <ctype.h>
 #ifdef SYSV
 #include <string.h>
 #endif
@@ -27,10 +28,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/0
 #include <sys/time.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/undo.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
@@ -40,7 +42,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/0
 #include "cif/cif.h"
 #include "lef/lefInt.h"
 
-/* ---------------------------------------------------------------------
+/* ---------------------------------------------------------------------*/
 
 /* Current line number for reading */
 int lefCurrentLine;
