@@ -1,5 +1,5 @@
 /*
- * lef.c --      
+ * lefWrite.c --      
  *
  * This module incorporates the LEF/DEF format for standard-cell place and
  * route.
@@ -13,7 +13,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/lef/lef.c,v 1.0 2003/05/01 10:37:00 tim Exp $";            
+static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefWrite.c,v 1.0 2003/05/01 10:37:00 tim Exp $";            
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -23,26 +23,26 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lef.c,v 1.0 2003/05/01
 #endif
 #include <errno.h>
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/utils.h"
 #include "utils/malloc.h"
 #include "utils/stack.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "graphics/graphics.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 #include "cif/cif.h"
 #include "lef/lefInt.h"
 
-/* ---------------------------------------------------------------------
+/* ---------------------------------------------------------------------*/
 
 /* Stack of cell definitions */
 Stack *lefDefStack;
@@ -68,7 +68,7 @@ Stack *lefDefStack;
  */
 
 FILE *
-lefFileOpen(def, file, mode, prealfile)
+lefFileOpen(def, file, suffix, mode, prealfile)
     CellDef *def;	/* Cell whose .lef file is to be written.  Should
 			 * be NULL if file is being opened for reading.
 			 */
@@ -76,11 +76,12 @@ lefFileOpen(def, file, mode, prealfile)
 			 * derive filename from 'def' as described
 			 * above.
 			 */
-    char *mode;		/* Either "r" or "w", the mode in which the .lef
+    char *suffix;	/* Either ".lef" for LEF files or ".def" for DEF files */
+    char *mode;		/* Either "r" or "w", the mode in which the LEF/DEF
 			 * file is to be opened.
 			 */
     char **prealfile;	/* If this is non-NULL, it gets set to point to
-			 * a string holding the name of the .lef file.
+			 * a string holding the name of the LEF/DEF file.
 			 */
 {
     char namebuf[512], *name, *endp;
@@ -111,14 +112,14 @@ lefFileOpen(def, file, mode, prealfile)
     /* path information in case cell is in a read-only directory (mode	*/
     /* "read" only, and if def is non-NULL).				*/
 
-    if ((rfile = PaOpen(name, mode, ".lef", Path, CellLibPath, prealfile)) != NULL)
+    if ((rfile = PaOpen(name, mode, suffix, Path, CellLibPath, prealfile)) != NULL)
 	return rfile;
 
     if (def) 
     {
 	if (name == def->cd_name) return NULL;
 	name = def->cd_name;
-	return (PaOpen(name, mode, ".lef", Path, CellLibPath, prealfile));
+	return (PaOpen(name, mode, suffix, Path, CellLibPath, prealfile));
     }
     else
 	return NULL;
@@ -552,7 +553,8 @@ lefWriteMacro(def, f, scale)
 
     /* Restrict to routing planes only */
 
-    fprintf(f, "   OBS %s\n", def->cd_name);
+//  fprintf(f, "   OBS %s\n", def->cd_name);	/* Error Fixed; Tim 6/16/04 */
+    fprintf(f, "   OBS\n");
     for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
 	(void) DBSrPaintArea((Tile *)NULL, def->cd_planes[pNum], 
 		&TiPlaneRect, &lc.rmask,
@@ -582,18 +584,19 @@ lefWriteMacro(def, f, scale)
  */
 
 void
-LefWriteAll(rootUse)
+LefWriteAll(rootUse, writeTopCell)
     CellUse *rootUse;
+    bool writeTopCell;
 {
-    CellDef *def;
+    CellDef *def, *rootdef;
     FILE *f;
     char *filename;
     float scale = CIFGetOutputScale(1000);	/* conversion to microns */
 
-    def = rootUse->cu_def;
+    rootdef = rootUse->cu_def;
 
     /* Make sure the entire subtree is read in */
-    DBCellReadArea(rootUse, &def->cd_bbox);
+    DBCellReadArea(rootUse, &rootdef->cd_bbox);
 
     /* Fix up bounding boxes if they've changed */
     DBFixMismatch();
@@ -607,10 +610,10 @@ LefWriteAll(rootUse)
 
     /* Open the file for output */
 
-    f = lefFileOpen(def, (char *)NULL, "w", &filename);
+    f = lefFileOpen(rootdef, (char *)NULL, ".lef", "w", &filename);
 
     TxPrintf("Generating LEF output %s for hierarchy rooted at cell %s:\n",
-		filename, def->cd_name);
+		filename, rootdef->cd_name);
 
     if (f == NULL)
     {
@@ -626,13 +629,14 @@ LefWriteAll(rootUse)
 
     /* Now generate LEF output for all the cells we just found */
 
-    lefWriteHeader(def, f);
+    lefWriteHeader(rootdef, f);
 
     while (def = (CellDef *) StackPop(lefDefStack))
     {
 	def->cd_client = (ClientData) 0;
 	if (!SigInterruptPending)
-	    lefWriteMacro(def, f, scale);
+	    if ((writeTopCell == TRUE) || (def != rootdef))
+		lefWriteMacro(def, f, scale);
     }
 
     fclose(f);
@@ -698,7 +702,7 @@ LefWriteCell(def, outName, isRoot)
     FILE *f;
     float scale = CIFGetOutputScale(1000);
 
-    f = lefFileOpen(def, outName, "w", &filename);
+    f = lefFileOpen(def, outName, ".lef", "w", &filename);
 
     TxPrintf("Generating LEF output %s for cell %s:\n", filename, def->cd_name);
 
