@@ -27,14 +27,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/magic/magicTop.c,v 1.2 2001/
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/malloc.h"
 
-/* dummy definitions */
-YCRVert() {}
-YCRHoriz() {}
-Yacr() {}
-
 /*---------------------------------------------------------------------------
  * main:
  *
@@ -66,4 +61,5 @@ main(argc, argv)
  */
 
 char *MagicVersion = MAGIC_VERSION;
+char *MagicRevision = MAGIC_REVISION;
 char *MagicCompileTime = MAGIC_DATE;
