@@ -57,13 +57,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzBlock.c,v 1.2 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
@@ -970,7 +971,7 @@ mzHWalksFunc(tile, cdarg)
 
 	    if(TiGetType(tLeft)==TT_SAMENODE_BLOCK)
 	    {
-		MALLOC(Walk *, walk, sizeof(Walk));
+		walk = (Walk *) mallocMagic((unsigned) (sizeof(Walk)));
 		walk->w_rT = rT; 
 		walk->w_type = TT_LEFT_WALK;
 		walk->w_rect.r_ybot = MAX(BOTTOM(tile),BOTTOM(tLeft));
@@ -996,7 +997,7 @@ mzHWalksFunc(tile, cdarg)
 	{
 	   if(TiGetType(tRight)==TT_SAMENODE_BLOCK)
 	   {
-	       MALLOC(Walk *, walk, sizeof(Walk));
+	       walk = (Walk *) mallocMagic((unsigned) (sizeof(Walk)));
 	       walk->w_rT = rT; 
 	       walk->w_type = TT_RIGHT_WALK;
 	       walk->w_rect.r_ybot = MAX(BOTTOM(tile),BOTTOM(tRight));
@@ -1058,7 +1059,7 @@ mzVWalksFunc(tile, cdarg)
 	{
 	    if(TiGetType(tBelow)==TT_SAMENODE_BLOCK)
 	    {
-		MALLOC(Walk *, walk, sizeof(Walk));
+		walk = (Walk *) mallocMagic((unsigned) (sizeof(Walk)));
 		walk->w_rT = rT;
 		walk->w_type = TT_BOTTOM_WALK;
 		walk->w_rect.r_xbot = MAX(LEFT(tile),LEFT(tBelow));
@@ -1085,7 +1086,7 @@ mzVWalksFunc(tile, cdarg)
 	{
 	    if(TiGetType(tAbove)==TT_SAMENODE_BLOCK)
 	    {
-		MALLOC(Walk *, walk, sizeof(Walk));
+		walk = (Walk *) mallocMagic((unsigned) (sizeof(Walk)));
 		walk->w_rT = rT;
 		walk->w_type = TT_TOP_WALK;
 		walk->w_rect.r_xbot = MAX(LEFT(tile),LEFT(tAbove));;
