@@ -22,8 +22,9 @@ static char rcsid[] = "$$";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
-#include "signals/signals.h"
+
+#include "utils/magic.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/hash.h"
 #include "utils/geometry.h"
