@@ -30,23 +30,23 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzMain.c,v 1.2 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/geofast.h"
 #include "../utils/list.h"
 #include "utils/heap.h"
@@ -285,7 +285,7 @@ MZCopyParms(oldParms)
 
     /* allocate new structure and copy MazeParameters */
     {
-	MALLOC(MazeParameters *, newParms, sizeof(MazeParameters));
+	newParms = (MazeParameters *) mallocMagic((unsigned)(sizeof(MazeParameters)));
 	*newParms = *oldParms;
     }
 
@@ -301,7 +301,7 @@ MZCopyParms(oldParms)
 	    
 	    /* allocate and equivalence new rL and its rT */
 	    {
-		MALLOC(RouteLayer *, rLNew, sizeof(RouteLayer));
+		rLNew = (RouteLayer *) mallocMagic((unsigned)(sizeof(RouteLayer)));
 		AT_EQUIV(rLOld, rLNew);
 		AT_EQUIV(&(rLOld->rl_routeType),&(rLNew->rl_routeType));
 	    }
@@ -330,7 +330,7 @@ MZCopyParms(oldParms)
 	    
 	    /* allocate and equivalence new rC and its rT */
 	    {
-		MALLOC(RouteContact *, rCNew, sizeof(RouteContact));
+		rCNew = (RouteContact *) mallocMagic((unsigned)(sizeof(RouteContact)));
 		AT_EQUIV(rCOld, rCNew);
 		AT_EQUIV(&(rCOld->rc_routeType),&(rCNew->rc_routeType));
 	    }
@@ -638,7 +638,7 @@ MZAddStart(point, type)
     {
 	ColoredPoint *newTerm;
 
-	MALLOC(ColoredPoint *, newTerm, sizeof(ColoredPoint));
+	newTerm = (ColoredPoint *) mallocMagic((unsigned)(sizeof(ColoredPoint)));
 	newTerm->cp_point = *point;
 	newTerm->cp_type = type;
 	LIST_ADD(newTerm, mzStartTerms);
