@@ -26,13 +26,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzNumLine.c,v 1.2
 /* -- includes -- */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
@@ -73,7 +74,7 @@ mzNLInit(nL, size)
     nL->nl_sizeAlloced = size;
     nL->nl_sizeUsed = 2;
 
-    MALLOC(int *, entries, sizeof(int)*size);
+    entries = (int *) mallocMagic((unsigned)(sizeof(int)*size));
     entries[0] = MINFINITY;
     entries[1] = INFINITY;
 
@@ -143,7 +144,7 @@ mzNLInsert(nL,x)
 
 	/* allocate new entry array */
 	newSize = nL->nl_sizeUsed*2;
-	MALLOC(int *, newEntries, newSize);
+	newEntries = (int *) mallocMagic((unsigned)(newSize));
 
 	/* copy old entries to new */
 	{
@@ -157,7 +158,7 @@ mzNLInsert(nL,x)
 	}
 
 	/* free up old array */
-	FREE(nL->nl_entries);
+	freeMagic(nL->nl_entries);
 
 	/* update numberline */
 	nL->nl_sizeAlloced = newSize;
