@@ -127,19 +127,20 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzSearch.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
-#include "../tiles/tile.h"
+#include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
 #include "debug/debug.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "mzrouter/mzrouter.h"
