@@ -21,25 +21,25 @@
 static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzSubrs.c,v 1.2 2001/01/12 22:13:03 jsolomon Exp $";
 #endif  /* not lint */
 
-/*--- includes --- */
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/geofast.h"
 #include "utils/list.h"
 #include "utils/touchingtypes.h"
@@ -305,7 +305,7 @@ mzMarkConnectedTiles(rect, type, makeDests)
      */
     {
 	ColoredRect *e;
-	MALLOC(ColoredRect *, e,sizeof(ColoredRect));
+	e = (ColoredRect *) mallocMagic((unsigned)(sizeof(ColoredRect)));
 	e->cr_type = type;
 	e->cr_rect = *rect;
 	LIST_ADD(e, expandList);
@@ -356,7 +356,7 @@ mzMarkConnectedTiles(rect, type, makeDests)
 
 	/* Done processing top element of expandList, toss it */ 
 	e = (ColoredRect *) ListPop(&expandList);
-	FREE((char *) e);
+	freeMagic((char *) e);
     }
 
 
@@ -456,7 +456,7 @@ mzConnectedTileFunc(tile, cxp)
 	    ColoredRect *e;
 
 	    /* build colored rect corresponding to tile */
-	    MALLOC(ColoredRect *, e, sizeof(ColoredRect));
+	    e = (ColoredRect *) mallocMagic((unsigned)(sizeof(ColoredRect)));
 	    e->cr_type = TiGetType(tile);
 	    e->cr_rect = r;
 
@@ -743,22 +743,16 @@ mzPaintContact(path, prev)
     /* compute the contact tileType */
     cType = rC->rc_routeType.rt_tileType;
 
-    /* Paint the contact */
-    pNum = DBPlane(cType);
-    DBPaintPlane(mzResultDef->cd_planes[pNum], &r,
-			DBStdPaintTbl(cType, pNum),
-			(PaintUndoInfo *) NULL);
+    /* Paint the contact on all connected mask planes */
+    /* (should just let DBPaint() do this. . . ) */
 
-    /* Paint it on all connected mask planes */
-    if (DBConnPlanes[cType])
+    if (DBIsContact(cType))
     {
-	for (pNumC = PL_TECHDEPBASE; pNumC < DBNumPlanes; pNumC++)
-	    if (PlaneMaskHasPlane(DBConnPlanes[cType], pNumC))
-	    {
-		DBPaintPlane(mzResultDef->cd_planes[pNumC],
-			&r, DBStdPaintTbl(cType, pNumC),
+	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
+	    if (PlaneMaskHasPlane(DBConnPlanes[cType], pNum))
+		DBPaintPlane(mzResultDef->cd_planes[pNum],
+			&r, DBStdPaintTbl(cType, pNum),
 			(PaintUndoInfo *) NULL);
-	    }
     }
 
     return;
@@ -771,7 +765,7 @@ mzPaintContact(path, prev)
  * mzCopyPath --
  *
  * Copy a RoutePath from the temporary arena into permanent storage
- * allocated via MALLOC.
+ * allocated via mallocMagic.
  *
  * Results:
  *	Returns a pointer to a copy of the RoutePath passed to us
@@ -792,7 +786,7 @@ mzCopyPath(path)
     newPrev = newHead = (RoutePath *) NULL;
     for (newPrev = NULL; path; newPrev = new, path = path->rp_back)
     {
-	MALLOC(RoutePath *, new, sizeof (RoutePath));
+	new = (RoutePath *) mallocMagic((unsigned)(sizeof (RoutePath)));
 	*new = *path;
 	if (newPrev) newPrev->rp_back = new;
 	if (newHead == NULL) newHead = new;
@@ -822,7 +816,7 @@ mzFreePath(path)
     RoutePath *path;
 {
     for ( ; path; path = path->rp_back)
-	FREE((char *) path);
+	freeMagic((char *) path);
 }
 
 /*--------------- Static variables only referenced by RPath allocation
@@ -843,7 +837,8 @@ RoutePage *mzCurPage = NULL;
  *
  * Results:
  *	Returns a pointer to a newly allocated RoutePath.
- *	This RoutePath is NOT allocated directly via MALLOC/FREE,
+ *	This RoutePath is NOT allocated directly via
+ *	mallocMagic/freeMagic,
  *	but rather via our own temporary mechanism.  It goes away
  *	once mzFreeAllTemp() gets called, so callers that wish to
  *	retain the "best" RoutePath must call mzCopyPath() to
@@ -865,7 +860,7 @@ mzAllocRPath()
     /* If out of pages, allocate a new one */
     if (mzCurPage == NULL)
     {
-	MALLOC(RoutePage *, mzCurPage, sizeof (RoutePage));
+	mzCurPage = (RoutePage *) mallocMagic((unsigned)(sizeof (RoutePage)));
 	mzCurPage->rpp_next = (RoutePage *) NULL;
 	mzCurPage->rpp_free = 0;
 	if (mzLastPage == NULL)
