@@ -22,15 +22,15 @@ static char rcsid[] = "$Header:";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "../tiles/tile.h"
-#include "utils/doubleint.h"
+#include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/list.h"
 #include "debug/debug.h"
@@ -53,14 +53,14 @@ static char rcsid[] = "$Header:";
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzWalkRight(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
 
@@ -93,11 +93,11 @@ mzWalkRight(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	segCost = DoubleMultII(pNew.p_x - pOrg.p_x,
-			       path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pNew.p_x - pOrg.p_x) *
+			path->rp_rLayer->rl_vCost);
 	else
-	segCost = DoubleMultII(pNew.p_x - pOrg.p_x, 
-			       path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pNew.p_x - pOrg.p_x) *
+			path->rp_rLayer->rl_hCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -106,7 +106,7 @@ mzWalkRight(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaUp, deltaDown, delta;
 	Point lowPt;
 
@@ -141,12 +141,10 @@ mzWalkRight(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-					    MIN(RIGHT(tp),pNew.p_x)
-					            - lowPt.p_x,
-					    path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(RIGHT(tp),pNew.p_x) - lowPt.p_x) *
+				    path->rp_rLayer->rl_hintCost);
+		    hintCost *= delta;
+		    segCost += hintCost;
 		}
 	    }
 	}
@@ -174,14 +172,14 @@ mzWalkRight(path)
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzWalkLeft(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
 
@@ -214,11 +212,11 @@ mzWalkLeft(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x,
-		path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pOrg.p_x - pNew.p_x) *
+ 			path->rp_rLayer->rl_vCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x, 
-		path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pOrg.p_x - pNew.p_x) *
+			path->rp_rLayer->rl_hCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -227,7 +225,7 @@ mzWalkLeft(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaUp, deltaDown, delta;
 	Point lowPt;
 
@@ -262,11 +260,10 @@ mzWalkLeft(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x) *
+					path->rp_rLayer->rl_hintCost);
+		    hintCost *= delta;
+		    segCost  += hintCost;
 		}
 	    }
 	}
@@ -294,14 +291,14 @@ mzWalkLeft(path)
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzWalkUp(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
 
@@ -334,11 +331,11 @@ mzWalkUp(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pNew.p_y - pOrg.p_y,
-		path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pNew.p_y - pOrg.p_y) *
+			path->rp_rLayer->rl_hCost);
 	else
-	    segCost = DoubleMultII(pNew.p_y - pOrg.p_y, 
-		path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pNew.p_y - pOrg.p_y) *
+													path->rp_rLayer->rl_vCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -347,7 +344,7 @@ mzWalkUp(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaRight, deltaLeft, delta;
 	Point lowPt;
 
@@ -362,7 +359,7 @@ mzWalkUp(path)
 		deltaRight = (TiGetType(TR(tp)) == TT_MAGNET) ?
 		    RIGHT(tp) - lowPt.p_x : -1;
 		deltaLeft = (TiGetType(BL(tp)) == TT_MAGNET) ?
-		    lowPt.p_x - LEFT(tp) : -1;
+				lowPt.p_x - LEFT(tp) : -1;
 
 		/* delta = distance to nearest hint */
 		if (deltaRight < 0) 
@@ -382,11 +379,10 @@ mzWalkUp(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(TOP(tp),pNew.p_y) - lowPt.p_y,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(TOP(tp),pNew.p_y) - lowPt.p_y) *
+				path->rp_rLayer->rl_hintCost);
+		    hintCost *= delta;
+		    segCost  += hintCost;
 		}
 	    }
 	}
@@ -414,14 +410,14 @@ mzWalkUp(path)
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzWalkDown(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
 
@@ -454,11 +450,11 @@ mzWalkDown(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y,
-		path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pOrg.p_y - pNew.p_y) *
+			path->rp_rLayer->rl_hCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y, 
-		path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pOrg.p_y - pNew.p_y) *
+			path->rp_rLayer->rl_vCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -467,7 +463,7 @@ mzWalkDown(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaRight, deltaLeft, delta;
 	Point lowPt;
 
@@ -502,11 +498,10 @@ mzWalkDown(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(TOP(tp),pOrg.p_y) - lowPt.p_y,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(TOP(tp),pOrg.p_y) - lowPt.p_y) *
+				path->rp_rLayer->rl_hintCost);
+		    hintCost *= delta;
+		    segCost  += hintCost;
 		}
 	    }
 	}
@@ -534,16 +529,16 @@ mzWalkDown(path)
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzWalkContact(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     int extendCode;	/* Interesting directions to extend in */
     RouteContact *rC;   /* Route contact to make connection with */
     RouteLayer *newRL;	/* Route layer of dest area */ 
-    DoubleInt conCost;	/* Cost of final contact */
+    dlong conCost;	/* Cost of final contact */
 
     /* DEBUG - trace calls to this routine. */
     if (DebugIsSet(mzDebugID, mzDebMaze))
@@ -586,10 +581,7 @@ mzWalkContact(path)
     }
 	
     /* compute contact cost */
-    {
-	int i = rC->rc_cost;
-	DOUBLE_CREATE(conCost, i);
-    }
+    conCost = (dlong) rC->rc_cost;
 
     /* Add final point */
     mzAddPoint(path,&pOrg,newRL,'O',EC_COMPLETE,conCost);
