@@ -21,15 +21,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzXtndLeft.c,v 1.
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "../tiles/tile.h"
-#include "utils/doubleint.h"
+#include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/list.h"
 #include "debug/debug.h"
@@ -52,15 +52,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzXtndLeft.c,v 1.
  *
  * ----------------------------------------------------------------------------
  */
-
-Void
+/* BY NP */
+void
 mzExtendLeft(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
     Point pOrg;		/* point to extend from */
     Point pStep;	/* one unit from pOrg in direction of extension */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     RouteLayer *rL;     /* temp variable for routelayers */
     int reasons;	/* Reasons point is interesting.  Used to
 			 * avoid extensions in uninteresting directions.
@@ -543,11 +543,11 @@ mzExtendLeft(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x,
-		path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pOrg.p_x - pNew.p_x) *
+			path->rp_rLayer->rl_vCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x, 
-		path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pOrg.p_x - pNew.p_x) *
+			path->rp_rLayer->rl_hCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -556,7 +556,7 @@ mzExtendLeft(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaUp, deltaDown, delta;
 	Point lowPt;
 
@@ -591,11 +591,10 @@ mzExtendLeft(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x) *
+				path->rp_rLayer->rl_hintCost);
+		    hintCost *= delta;
+		    segCost += hintCost;
 		}
 	    }
 	}
