@@ -21,7 +21,8 @@
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
@@ -97,7 +98,7 @@ getfirst:
 		label);
 	    continue;
 	}
-	MALLOC(LabInfo *, li, sizeof (LabInfo));
+	li = (LabInfo *) mallocMagic((unsigned) (sizeof (LabInfo)));
 	GEO_EXPAND(&r, -1, &li->li_area);
 	li->li_label = StrDup((char **) NULL, label);
 	li->li_layer = StrDup((char **) NULL, layer);
