@@ -23,7 +23,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMcmdLZ.c,v 1.2 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -33,8 +33,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMcmdLZ.c,v 1.2 20
 #include "netmenu/nmInt.h"
 #include "netmenu/netmenu.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
-#include "main/main.h"
+#include "utils/styles.h"
+#include "utils/main.h"
 #include "textio/textio.h"
 
 
@@ -207,7 +207,65 @@ nmCmdPrintFunc(name, pGotAny)
     TxPrintf("    %s\n", name);
     return 0;
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * NMCmdPushButton --
+ *
+ *	Perform the default button action for the netlist window.
+ *	This allows button actions to be bound to keys or buttons
+ *	arbitrarily, rather than being hardwired into the source.
+ *
+ * Usage:
+ *	pushbutton button
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Invokes the command associated with the button action.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+NMCmdPushButton(w, cmd)
+    MagWindow *w;			/* Netlist window. */
+    TxCommand *cmd;		/* Contains the command's argc and argv. */
+{
+    int button, action;
+    static char *NMButton[] = {"left", "middle", "right", NULL};
+
+    if (cmd->tx_argc != 2)
+    {
+	TxError("Usage: pushbutton <button>\n");
+	return;
+    }
+    button = Lookup(cmd->tx_argv[1], NMButton);
+    if (button < 0)
+    {
+	TxError("Argument \"button\" must be one of "
+		"\"left\", \"middle\", or \"right\".\n");
+	return;
+    }
+    else switch(button)
+    {
+	case 0:
+	    cmd->tx_button = TX_LEFT_BUTTON;
+	    break;
+	case 1:
+	    cmd->tx_button = TX_MIDDLE_BUTTON;
+	    break;
+	case 2:
+	    cmd->tx_button = TX_RIGHT_BUTTON;
+	    break;
+    }
+
+    cmd->tx_buttonAction = TX_BUTTON_DOWN;
+    NMcommand(w, cmd);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -229,7 +287,6 @@ nmCmdPrintFunc(name, pGotAny)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
 void
 NMCmdRipup(w, cmd)
     MagWindow *w;			/* Netlist window. */
@@ -245,7 +302,7 @@ NMCmdRipup(w, cmd)
     }
     else TxError("Usage: ripup [list]\n");
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
