@@ -24,21 +24,23 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMlabel.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
 #include "netmenu/nmInt.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
 #include "commands/commands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
 
 /* The user can enter several labels at once, so he doesn't have
@@ -85,7 +87,7 @@ nmGetNums(string, num1, num2)
     char *string;		/* String to scan. */
     int *num1, *num2;		/* Pointers to places to store numbers. */
 {
-    register char *p;
+    char *p;
     bool gotNum = FALSE;
     bool gotDigit = FALSE;
     int num = 0;
@@ -277,7 +279,7 @@ nmSetCurrentLabel()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 NMGetLabels()
 {
 #define MAXLENGTH 200
@@ -330,7 +332,7 @@ NMGetLabels()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 NMNextLabel()
 {
     if (nmLabelArray[nmCurLabel] == NULL)
@@ -344,7 +346,7 @@ NMNextLabel()
     nmSetCurrentLabel();
 }
 
-Void
+void
 NMPrevLabel()
 {
     if (nmLabelArray[nmCurLabel] == NULL)
@@ -381,7 +383,7 @@ NMPrevLabel()
  */
 
 	/* ARGSUSED */
-Void
+void
 NMChangeNum(window,cmd, nmButton, point)
     MagWindow *window;		/* Window in which button was pushed. */
     NetButton *nmButton;	/* NetButton where button was pushed. */
@@ -492,7 +494,7 @@ nmGetPos(button, point)
  */
 
 	/* ARGSUSED */
-Void
+void
 NMPutLabel(window, cmd, nmButton, point)
     MagWindow *window;		/* Window where mouse button was pushed.
 				 * (ignored) */
@@ -533,7 +535,7 @@ NMPutLabel(window, cmd, nmButton, point)
  */
 
 	/* ARGSUSED */
-Void
+void
 NMReOrientLabel(window, cmd, nmButton, point)
     MagWindow *window;		/* Window that was buttoned. (ignored) */
     NetButton *nmButton;	/* Button that was clicked. */
@@ -567,7 +569,7 @@ NMReOrientLabel(window, cmd, nmButton, point)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 NMFindLabel()
 {
     char *pattern;
