@@ -25,7 +25,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMmain.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
@@ -35,17 +36,17 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMmain.c,v 1.2 200
 #include "database/database.h"
 #include "dbwind/dbwind.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/txcommands.h"
 #include "netmenu/nmInt.h"
 #include "netmenu/netmenu.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 global WindClient NMClientID;
 
 /* Forward declaration: */
 
-extern Void nmNotDefined();
+extern void nmNotDefined();
 
     
 /* The declarations below define the layout of the netlist
@@ -204,7 +205,7 @@ NMdelete(window)
  */
 
 	/* ARGSUSED */
-Void
+int
 NMreposition(window, newScreenArea, final)
     MagWindow *window;			/* Window being repositioned. */
     Rect *newScreenArea;		/* New screen area of window. */
@@ -237,7 +238,7 @@ NMreposition(window, newScreenArea, final)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMredisplay(w, rootArea, clipArea)
     MagWindow *w;			/* The window containing the area. */
     Rect *rootArea;		/* Redisplay area in surface coordinates. */
@@ -355,14 +356,14 @@ NMredisplay(w, rootArea, clipArea)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMcommand(w, cmd)
     MagWindow *w;			/* Net-list menu window. */
     TxCommand *cmd;
 {
     NetButton *nb;
     Point surfacePoint;
-    Void (*proc)();
+    void (*proc)();
     int cmdNum;
 
     if (cmd->tx_button == TX_NO_BUTTON)
@@ -425,7 +426,7 @@ NMcommand(w, cmd)
 		    }
 		    break;
 	    }
-	    if (proc != NULL) (void) (*proc)(w, cmd, nb, &surfacePoint);
+	    if (proc != NULL) (*proc)(w, cmd, nb, &surfacePoint);
 	}
     }
 
@@ -456,17 +457,19 @@ NMcommand(w, cmd)
 void
 NMinit()
 {
-    static char *doc =
-"You are currently using the \"netlist\" tool.  The button actions are:\n\
-   left    - select the net containing the terminal nearest the cursor\n\
-   right   - toggle the terminal nearest the cursor into/out of current net\n\
-   middle  - join current net and net containing terminal nearest the cursor\n\
-";
+    static char *doc = "You are currently using the \"netlist\" tool."
+			"  The button actions are:\n"
+		"   left    - select the net containing the terminal"
+			" nearest the cursor\n"
+		"   right   - toggle the terminal nearest the cursor"
+			" into/out of current net\n"
+		"   middle  - join current net and net containing terminal"
+			" nearest the cursor\n";
 
     NMClientID = WindAddClient("netlist", NMcreate, NMdelete,
-	NMredisplay, NMcommand, (Void (*)()) NULL,
+	NMredisplay, NMcommand, (void(*)())NULL,
 	NMCheckWritten, NMreposition,
-	(GrGlyph *) NULL);
+	(GrGlyph *)NULL);
     DBWHLAddClient(NMRedrawPoints);
     DBWHLAddClient(NMRedrawCell);
     DBWAddButtonHandler("netlist", NMButtonProc, STYLE_CURS_NET, doc);
@@ -508,6 +511,10 @@ NMinit()
 	"netlist [name]          switch current netlist to name.net (default\n\
 			is edit cell name)",
 	NMCmdNetlist, FALSE);
+    WindAddCommand(NMClientID,
+	"nmbutton button action\n\
+			execute the default button action in the netlist window.",
+	NMCmdPushButton, FALSE);
     WindAddCommand(NMClientID,
 	"print [name]            print all terminals in name, or in current net\n\
 			if no name given",
@@ -557,7 +564,7 @@ NMinit()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 nmNotDefined()
 {
     TxError("Sorry, no code has been written for that button yet.\n");
