@@ -22,17 +22,19 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMnetlist.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/textio.h"
 #include "netmenu/nmInt.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/malloc.h"
 #include "netmenu/netmenu.h"
 
@@ -214,7 +216,7 @@ NMAddTerm(new, other)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMDeleteTerm(name)
     char *name;			/* Name of a terminal. */
 {
@@ -254,7 +256,7 @@ NMDeleteTerm(name)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMJoinNets(termA, termB)
     char *termA;		/* Name of a terminal in first net. */
     char *termB;		/* Name of a terminal in second net. */
@@ -325,7 +327,7 @@ NMJoinNets(termA, termB)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMDeleteNet(net)
     char *net;			/* Name of one of the terminals in the net
 				 * to be deleted.
@@ -375,7 +377,7 @@ NMDeleteNet(net)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMNewNetlist(name)
     char *name;			/* Name of the netlist file.  If NULL,
 				 * then the netlist file association
@@ -739,7 +741,7 @@ NMTermInList(name)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMWriteNetlist(fileName)
     char *fileName;		/* If non-NULL, gives name of file in
 				 * which to write current netlist.  If NULL,
@@ -786,7 +788,7 @@ NMWriteNetlist(fileName)
 	TxError("Couldn't write file %s.\n", realName);
 	return;
     }
-    (void) fprintf(file, " Netlist File\n");
+    fprintf(file, " Netlist File\n");
     (void) NMEnumNets(nmWriteNetsFunc, (ClientData) file);
     if (strcmp(realName, nmCurrentNetlist->nl_fileName) == 0)
 	nmCurrentNetlist->nl_flags &= ~NL_MODIFIED;
@@ -800,7 +802,7 @@ nmWriteNetsFunc(name, firstInNet, file)
     FILE *file;			/* File in which to write info. */
 {
     if (firstInNet) fputs("\n", file);
-    (void) fprintf(file, "%s\n", name);
+    fprintf(file, "%s\n", name);
     return 0;
 }
 
@@ -874,7 +876,7 @@ NMCheckWritten()
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMWriteAll()
 {
     Netlist *nl, *saveCurrent;
