@@ -24,18 +24,20 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMwiring.c,v 1.2 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "netmenu/netmenu.h"
 #include "netmenu/nmInt.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "drc/drc.h"
 #include "utils/malloc.h"
 #include "router/router.h"
@@ -118,8 +120,9 @@ static int nmVCount= 0;
  */
 
 int
-nmwRipTileFunc(tile, listHead)
+nmwRipTileFunc(tile, plane, listHead)
     Tile *tile;			/* Tile that is to be deleted. */
+    int plane;			/* Plane index of the tile */
     struct nmwarea **listHead;	/* Pointer to list head pointer. */
 {
     struct nmwarea *new;
@@ -149,7 +152,7 @@ nmwRipTileFunc(tile, listHead)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMRipup()
 {
     struct nmwarea *list;
@@ -296,7 +299,7 @@ nmRipNameFunc(name, firstInNet, area)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMRipupList()
 {
     Rect area;
@@ -399,7 +402,7 @@ nmwNetTermFunc(scx, label, tpath, netPtr)
     TerminalPath *tpath;	/* Gives hierarchical label name. */
     char **netPtr;		/* Pointer to a terminal in current net. */
 {
-    register char *p, *p2;
+    char *p, *p2;
     
     if (index(tpath->tp_first, '/') == 0) return 0;
 
@@ -466,8 +469,9 @@ nmwNetTermFunc(scx, label, tpath, netPtr)
  */
 
 int
-nmwNetTileFunc(tile, netPtr)
+nmwNetTileFunc(tile, plane, netPtr)
     Tile *tile;			/* Tile that is connected to net. */
+    int plane;			/* Plane index of the tile */
     char **netPtr;		/* Pointer to pointer to net name. */
 {
     SearchContext scx;
@@ -527,7 +531,7 @@ nmwNetTileFunc(tile, netPtr)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMExtract()
 {
     Rect area;
@@ -579,7 +583,7 @@ nmwVerifyLabelFunc2(scx, label, tpath, cd)
     TerminalPath *tpath;	/* Gives hierarchical label name. */
     ClientData cd;		/* Used in nmwVerifyTileFunc */
 {
-    register char *p, *p2;
+    char *p, *p2;
     char *name;
     extern int nmwVerifyLabelFunc();	/* Forward reference. */
 
@@ -702,8 +706,9 @@ nmwVerifyLabelFunc2(scx, label, tpath, cd)
  */
 
 int
-nmwVerifyTileFunc(tile, func)
+nmwVerifyTileFunc(tile, plane, func)
     Tile *tile;			/* Tile that is connected to this net. */
+    int plane;			/* Plane index of the tile. */
     int (*func)();		/* Processing function for each tile. */
 {
     SearchContext scx;
@@ -765,7 +770,7 @@ nmwVerifyLabelFunc(rect, name, label, cd)
 
     for (i = 0; i < nmwVerifyCount; i++)
     {
-	register Rect *r;
+	Rect *r;
 
 	r = &nmwVerifyAreas[i];
 	if ((r->r_xbot == rect->r_xbot) && (r->r_ybot == rect->r_ybot)
@@ -1012,10 +1017,10 @@ nmwVerifyNetFunc(name, first)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 NMVerify()
 {
-    register int i;
+    int i;
 
     /* Enumerate all the nets and let the search function do the
      * real work.
@@ -1061,7 +1066,7 @@ NMVerify()
  *
  * ----------------------------------------------------------------------------
  */
-Void
+int
 NMCull()
 {
     int nmwCullNetFunc();
@@ -1282,7 +1287,7 @@ nmAllFunc(name, firstInNet, fp)
 	saveM=nmMArea-saveM;
 	saveP=nmPArea-saveP;
 	saveV=nmVCount-saveV;
-        (void)fprintf(fp,"Net %s total: %d;  Metal: %d;  Poly: %d;  Vias: %d\n",
+        fprintf(fp,"Net %s total: %d;  Metal: %d;  Poly: %d;  Vias: %d\n",
 		name,
 	        saveM/RtrMetalWidth +saveP/RtrPolyWidth +saveV*RtrContactWidth,
 	        saveM/RtrMetalWidth,  saveP/RtrPolyWidth, saveV);
