@@ -22,7 +22,7 @@
 #ifndef _PLOT_H
 #define _PLOT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* Technology-file reading procedures: */
 
@@ -32,11 +32,15 @@ extern void PlotTechFinal();
 
 /* Top-level plot procedures: */
 
-extern void PlotPS();
+#ifdef GREMLIN
 extern void PlotGremlin();
+#endif
+#ifdef VERSATEC
 extern void PlotVersatec();
+#endif
+extern void PlotPS();
+extern void PlotPNM();
 extern void PlotSetParam();
 extern void PlotPrintParams();
-extern void PlotPNM();
 
 #endif /* _PLOT_H */
