@@ -27,14 +27,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/plot/plotCmd.c,v 1.0 2001/
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/utils.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/txcommands.h"
 #include "plow/plow.h"
 #include "select/select.h"
@@ -63,18 +64,20 @@ static char rcsid[] = "$Header: /ufs/repository/magic/plot/plotCmd.c,v 1.0 2001/
 
 /* These definitions must correspond to the ordering in cmdPlotOption[] below */
 
-#define POSTSCRIPT	0
-#define GREMLIN		1
-#define VERSATEC	2
-#define PLOTPNM		3
-#ifdef LLNL
-#define PIXELS		4
-#define PARAMETERS	5
-#define HELP		6
-#else
-#define PARAMETERS	4
-#define HELP		5
+typedef enum {
+	POSTSCRIPT=0,
+	PLOTPNM,
+#ifdef GREMLIN
+	STYLE_GREMLIN,
 #endif
+#ifdef VERSATEC
+	STYLE_VERSATEC,
+#endif
+#ifdef LLNL
+	PIXELS,
+#endif
+	PARAMETERS,
+	HELP } PlotOptions;
 
 void
 CmdPlot(w, cmd)
@@ -97,12 +100,16 @@ CmdPlot(w, cmd)
     {	
 	"postscript file [layers]    generate PostScript file for what's\n\
                                      underneath the box",				
-	"gremlin file [layers]	     generate gremlin file for what's\n\
-		                     underneath the box",
-	"versatec [size [layers]]    generate plot on Versatec printer, size\n\
-		                     inches wide for layers underneath box",
 	"pnm file [scale [layers]]   generate PNM file for what's\n\
 		                     underneath the box",
+#ifdef GREMLIN
+	"gremlin file [layers]	     generate gremlin file for what's\n\
+		                     underneath the box",
+#endif
+#ifdef VERSATEC
+	"versatec [size [layers]]    generate plot on Versatec printer, size\n\
+		                     inches wide for layers underneath box",
+#endif
 #ifdef	LLNL
 	"pixels [width [layers]]     generate plot in pix format, width pixels\n\
 		                     wide, for layers underneath box",
@@ -128,11 +135,17 @@ CmdPlot(w, cmd)
 	}
     }
 
-    if ((option == GREMLIN) || 	(option == VERSATEC) ||	(option == PLOTPNM)
+    if ((option == PLOTPNM) || (option == POSTSCRIPT)
+#ifdef GREMLIN
+		|| (option == STYLE_GREMLIN)
+#endif
+#ifdef VERSATEX
+	        || (option == STYLE_VERSATEC)
+#endif
 #ifdef LLNL
 		|| (option == PIXELS)
 #endif
-		|| (option == POSTSCRIPT))
+		 )
     {
 
 	window = ToolGetPoint((Point *) NULL, (Rect *) NULL);
@@ -181,11 +194,12 @@ CmdPlot(w, cmd)
 	    PlotPS(cmd->tx_argv[2], &scx, &mask, crec->dbw_bitmask);
 	    return;
 	    
-	case GREMLIN:
+#ifdef GREMLIN
+	case STYLE_GREMLIN:
 	    if ((cmd->tx_argc != 3) && (cmd->tx_argc != 4))
 	    {
 		TxError("Wrong number of arguments:\n    plot %s\n",
-			cmdPlotOption[GREMLIN]);
+			cmdPlotOption[STYLE_GREMLIN]);
 		return;
 	    }
 	    if (cmd->tx_argc == 4)
@@ -195,6 +209,7 @@ CmdPlot(w, cmd)
 	    }
 	    PlotGremlin(cmd->tx_argv[2], &scx, &mask, crec->dbw_bitmask);
 	    return;
+#endif /* GREMLIN */
 	    
 	case HELP:
 	    TxPrintf("The \"plot\" commands are:\n");
@@ -216,11 +231,12 @@ CmdPlot(w, cmd)
 	    }
 	    return;
 	
-	case VERSATEC:
+#ifdef VERSATEC
+	case STYLE_VERSATEC:
 	    if (cmd->tx_argc > 4)
 	    {
 		TxError("Too many arguments:\n    plot %s\n",
-			cmdPlotOption[VERSATEC]);
+			cmdPlotOption[STYLE_VERSATEC]);
 		return;
 	    }
 	    if (cmd->tx_argc >= 3)
@@ -233,6 +249,7 @@ CmdPlot(w, cmd)
 	    }
 	    PlotVersatec( &scx, &mask, crec->dbw_bitmask, width);
 	    return;
+#endif
 
 	case PLOTPNM:
 	    if (cmd->tx_argc > 5)
