@@ -25,12 +25,12 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotGremln.c,v 1.2 2001
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
@@ -44,6 +44,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotGremln.c,v 1.2 2001
  * layers.  A single layer may participate in several gremlin styles.
  */
 
+#ifdef GREMLIN
+
 typedef struct gremlinstyle
 {
     TileTypeBitMask grs_layers;		/* Layers to plot in this style. */
@@ -94,6 +96,8 @@ static TileTypeBitMask curMask;	/* Layers currently being searched:  this
 static Rect bbox;		/* Bounding box, in root coordinates, of
 				 * area being plotted.
 				 */
+#endif /* GREMLIN */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -110,6 +114,8 @@ static Rect bbox;		/* Bounding box, in root coordinates, of
  * ----------------------------------------------------------------------------
  */
 
+#ifdef GREMLIN
+
 void
 PlotGremlinTechInit()
 {
@@ -121,6 +127,14 @@ PlotGremlinTechInit()
     }
     plotGremlinStyles = NULL;
 }
+
+#else
+
+void
+PlotGremlinTechInit()
+{}
+
+#endif /* GREMLIN */
 
 /*
  * ----------------------------------------------------------------------------
@@ -139,7 +153,8 @@ PlotGremlinTechInit()
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+#ifdef GREMLIN
+
 bool
 PlotGremlinTechLine(sectionName, argc, argv)
     char *sectionName;		/* Name of this section (unused). */
@@ -187,7 +202,22 @@ PlotGremlinTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
+#else
+
+bool
+PlotGremlinTechLine(sectionName, argc, argv)
+    char *sectionName;		/* Name of this section (unused). */
+    int argc;			/* Number of arguments on line (unused). */
+    char *argv[];		/* Pointers to fields of line (unused). */
+{
+    return TRUE;
+}
+
+#endif /* GREMLIN */
+
+#ifdef GREMLIN
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -800,3 +830,5 @@ PlotGremlin(fileName, scx, layers, xMask)
     fclose(file);
     return;
 }
+
+#endif /* GREMLIN */
