@@ -19,12 +19,11 @@
  * rcsid $Header: /ufs/repository/magic/plot/plotInt.h,v 1.8 2001/08/23 13:48:55 tim Exp $
  */
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_GEOMETRY
-int err1 = Need_to_include_utils/geometry_header;
-#endif	/* _GEOMETRY */
+#ifndef _PLOTINT_H
+#define _PLOTINT_H
+
+#include "utils/magic.h"
+#include "utils/geometry.h"
 
 /* system V machines lack vfont.h, so include the defs below. */
 #if  !defined(SYSV) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(CYGWIN) && !defined(macosx)
@@ -151,18 +150,17 @@ extern void PlotGremlinTechInit();
 extern bool PlotGremlinTechLine();
 
 extern void PlotVersTechInit();
-extern Void PlotVersTechLine();
+extern bool PlotVersTechLine();
+
+extern void PlotColorVersTechInit();
+extern bool PlotColorVersTechLine();
 
 extern void PlotPNMTechInit();
 extern bool PlotPNMTechLine();
-extern bool PlotPNMTechFinal();
-extern Void PlotPNMSetBG();
-
-extern void PlotColorVersTechInit();
-extern Void PlotColorVersTechLine();
+extern void PlotPNMTechFinal();
 
 extern void PlotPixTechInit();
-extern Void PlotPixTechLine();
+extern bool PlotPixTechLine();
 
 /* Raster utilities: */
 
@@ -202,6 +200,7 @@ extern int PlotPSHeight;
 extern int PlotPSMargin;
 
 /* for Versatec (plotVers.c): */
+#ifdef VERSATEC
 extern int PlotVersWidth;
 extern int PlotVersDotsPerInch;
 extern int PlotVersSwathHeight;
@@ -212,16 +211,20 @@ extern char *PlotVersIdFont;
 extern char *PlotVersNameFont;
 extern char *PlotVersLabelFont;
 extern bool PlotVersColor;
+#endif
 
 /* for plotPixels.c: */
+#ifdef LLNL
 extern int PlotPixHeight;
 extern int PlotPixWidth;
+#endif
 
 /* for all: */
 extern bool PlotShowCellNames;
 
 /* for plotPnm.c */
 extern int PlotPNMmaxmem;
-extern int PlotPNMBGr;
-extern int PlotPNMBGg;
-extern int PlotPNMBGb;
+extern int PlotPNMdownsample;
+extern int PlotPNMBG;
+
+#endif /* _PLOTINT_H */
