@@ -25,12 +25,12 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotPS.c,v 1.11 2001/08
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
