@@ -27,7 +27,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotPixels.c,v 1.3 2001
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -40,12 +41,14 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotPixels.c,v 1.3 2001
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
-#include "signals/signals.h"
-#include "misc/styles.h"
+#include "utils/tech.h"
+#include "utils/signals.h"
+#include "utils/styles.h"
 #include "graphics/graphics.h"	
 #include "dbwind/dbwind.h"
     
+#ifdef LLNL
+
 /* forward declarations */
 
 void PlotPixFatLine();
@@ -123,6 +126,9 @@ static int crossSize;		/* Length of each arm of the crosses used
 static Font *labelPixFont;	/* Font to use when rendering labels. */
 static Font *cellNamePixFont;	/* Font to use when rendering cell names. */
 static Font *cellIdPixFont;	/* Font to use when rendering cell ids. */
+
+#endif /* LLNL */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -173,6 +179,9 @@ PlotPixTechLine(sectionName, argc, argv)
 {
     return TRUE;
 }
+
+#ifdef LLNL
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1474,3 +1483,5 @@ PlotPixRasterText(raster, clip, font, string, point, style)
 	xOrig += d->width;
     }
 }
+
+#endif /* LLNL */
