@@ -22,11 +22,13 @@
 
 #ifndef lint
 static char rcsid[]="$Header: /ufs/repository/magic/plot/plotRutils.c,v 1.3 2001/01/12 22:13:10 jsolomon Exp $";
-#endif  not lint
+#endif  /* not lint */
 
-#include <errno.h>
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+#include <errno.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -130,7 +132,7 @@ PlotRastInit()
 	rightBits[i] = PlotSwapBytes(rightBits[i]);
 	singleBit[i] = PlotSwapBytes(singleBit[i]);
     }
-#endif IS_BIG_ENDIAN
+#endif /* IS_BIG_ENDIAN */
 }
 
 /*
@@ -299,10 +301,10 @@ PlotClearRaster(raster, area)
 
 void
 PlotFillRaster(raster, area, stipple)
-    register Raster *raster;		/* Pointer to raster whose bits are
+    Raster *raster;		/* Pointer to raster whose bits are
 					 * to be filled in.
 					 */
-    register Rect *area;		/* Area to be filled in pixel coords.
+    Rect *area;		/* Area to be filled in pixel coords.
 					 * This is an inclusive area:  it
 					 * includes the boundary pixels.  The
 					 * caller must ensure that it is
@@ -312,7 +314,7 @@ PlotFillRaster(raster, area, stipple)
 					 * in the raster area.
 					 */
 {
-    register int *left, *cur, line;
+    int *left, *cur, line;
     int *right;
     int leftMask, rightMask, curStipple;
 
@@ -398,7 +400,7 @@ PlotDumpRaster(raster, file)
     if (count < 0)
     {
 	TxError("I/O error in writing raster file:  %s.\n",
-		STRERROR(errno));
+		strerror(errno));
 	return 1;
     }
     rasFileByteCount += count;
@@ -539,7 +541,7 @@ PlotLoadFont(name)
 	    }
 	    TxError("\n");
 	}
-#endif	DEBUG_FONT
+#endif	/* DEBUG_FONT */
     }
     new->fo_bbox.r_xbot = - new->fo_bbox.r_xbot;
     new->fo_bbox.r_ybot = - new->fo_bbox.r_ybot;
@@ -572,10 +574,10 @@ void
 PlotTextSize(font, string, area)
     Font *font;			/* Font to use in computing text size. */
     char *string;		/* String to compute size of. */
-    register Rect *area;	/* Place to store bounding box. */
+    Rect *area;	/* Place to store bounding box. */
 {
-    register int x;
-    register struct dispatch *d;
+    int x;
+    struct dispatch *d;
 
     area->r_xbot = area->r_xtop = 0;
     area->r_ybot = area->r_ytop = 0;
@@ -620,7 +622,7 @@ PlotTextSize(font, string, area)
 
 void
 PlotRasterText(raster, clip, font, string, point)
-    register Raster *raster;	/* Raster whose bits are to be filled in. */
+    Raster *raster;	/* Raster whose bits are to be filled in. */
     Rect *clip;			/* Area to which to clip the text.  Must be
 				 * entirely within the area of the raster.
 				 */
@@ -643,7 +645,7 @@ PlotRasterText(raster, clip, font, string, point)
     for ( ; *string != 0; string++)
     {
 	int cBytesPerLine, i;
-	register struct dispatch *d;	/* Descriptor for current character. */
+	struct dispatch *d;	/* Descriptor for current character. */
 
 	/* Handle spaces and tabs specially by just spacing over. */
 
@@ -734,7 +736,7 @@ PlotRasterText(raster, clip, font, string, point)
 
 void
 PlotRastPoint(raster, x, y)
-    register Raster *raster;		/* Raster containing pixel to be
+    Raster *raster;		/* Raster containing pixel to be
 					 * filled.
 					 */
     int x, y;				/* Coordinates of pixel. */
