@@ -22,7 +22,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotVers.c,v 1.2 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -34,10 +36,12 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotVers.c,v 1.2 2001/0
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
-#include "signals/signals.h"
+#include "utils/tech.h"
+#include "utils/signals.h"
 #include "dbwind/dbwind.h"
 
+#ifdef VERSATEC
+
 /* Library imports: */
 
 extern int rasFileByteCount; 
@@ -183,6 +187,8 @@ static int crossSize;		/* Length of each arm of the crosses used
 static Font *labelFont;		/* Font to use when rendering labels. */
 static Font *cellNameFont;	/* Font to use when rendering cell names. */
 static Font *cellIdFont;	/* Font to use when rendering cell ids. */
+
+#endif /* VERSATEC */
 
 /*
  * ----------------------------------------------------------------------------
@@ -199,6 +205,8 @@ static Font *cellIdFont;	/* Font to use when rendering cell ids. */
  * ----------------------------------------------------------------------------
  */
 
+#ifdef VERSATEC
+
 void
 PlotVersTechInit()
 {
@@ -223,6 +231,15 @@ PlotVersTechInit()
     if (PlotVersLabelFont == NULL)
 	StrDup(&PlotVersLabelFont, defaultLabelFont);
 }
+
+#else
+
+void
+PlotVersTechInit()
+{}
+
+#endif /* VERSATEC */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -239,6 +256,8 @@ PlotVersTechInit()
  * ----------------------------------------------------------------------------
  */
 
+#ifdef VERSATEC
+
 void
 PlotColorVersTechInit()
 {
@@ -263,6 +282,15 @@ PlotColorVersTechInit()
     if (PlotVersLabelFont == NULL)
 	StrDup(&PlotVersLabelFont, defaultLabelFont);
 }
+
+#else
+
+void
+PlotColorVersTechInit()
+{}
+
+#endif /* VERSATEC */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -281,7 +309,8 @@ PlotColorVersTechInit()
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+#ifdef VERSATEC
+
 bool
 PlotVersTechLine(sectionName, argc, argv)
     char *sectionName;		/* Name of this section (unused). */
@@ -347,7 +376,20 @@ PlotVersTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
+#else
+
+bool
+PlotVersTechLine(sectionName, argc, argv)
+    char *sectionName;		/* Name of this section (unused). */
+    int argc;			/* Number of arguments on line. */
+    char *argv[];		/* Pointers to fields of line. */
+{
+    return TRUE;
+}
+
+#endif /* VERSATEC */
+
 /*
  * ----------------------------------------------------------------------------
  *	PlotColorVersTechLine --
@@ -365,7 +407,8 @@ PlotVersTechLine(sectionName, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+#ifdef VERSATEC
+
 bool
 PlotColorVersTechLine(sectionName, argc, argv)
     char *sectionName;		/* Name of this section (unused). */
@@ -444,7 +487,22 @@ PlotColorVersTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
+#else
+
+bool
+PlotColorVersTechLine(sectionName, argc, argv)
+    char *sectionName;		/* Name of this section (unused). */
+    int argc;			/* Number of arguments on line. */
+    char *argv[];		/* Pointers to fields of line. */
+{
+    return TRUE;
+}
+
+#endif /* VERSATEC */
+
+#ifdef VERSATEC
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -465,8 +523,8 @@ PlotColorVersTechLine(sectionName, argc, argv)
 
 void
 plotTransToSwath(src, dst)
-    register Rect *src;		/* Rectangle in Magic root coords. */
-    register Rect *dst;		/* Rectangle to be filled in with swath
+    Rect *src;		/* Rectangle in Magic root coords. */
+    Rect *dst;		/* Rectangle to be filled in with swath
 				 * corresponding to src.
 				 */
 {
@@ -542,7 +600,7 @@ plotVersLine(area, widen)
 
 void
 plotVersRect(area, widen)
-    register Rect *area;	/* Rectangular area to draw, in root
+    Rect *area;	/* Rectangular area to draw, in root
 				 * coordinates.
 				 */
     int widen;			/* If zero, rectangular outline is drawn
@@ -609,12 +667,12 @@ plotVersRect(area, widen)
 
 int
 plotVersTile(tile, cxp)
-    register Tile *tile;	/* Tile that's of type to be output. */
+    Tile *tile;	/* Tile that's of type to be output. */
     TreeContext *cxp;		/* Describes search in progress. */
 {
     Rect tileArea, rootArea, swathArea, edge;
-    register Tile *neighbor;
-    register Transform *trans = &cxp->tc_scx->scx_trans;
+    Tile *neighbor;
+    Transform *trans = &cxp->tc_scx->scx_trans;
 
     /* Transform tile coords to root coords and then to swath coords. */
     
@@ -659,8 +717,8 @@ plotVersTile(tile, cxp)
     if (tileArea.r_ybot > TiPlaneRect.r_ybot)
     {
 	edge.r_ybot = edge.r_ytop = tileArea.r_ybot;
-	for (neighbor = tile->ti_lb; LEFT(neighbor) < tileArea.r_xtop;
-		neighbor = neighbor->ti_tr)
+	for (neighbor = LB(tile); LEFT(neighbor) < tileArea.r_xtop;
+		neighbor = TR(neighbor))
 	{
 	    if (TTMaskHasType(&curMask, TiGetType(neighbor))) continue;
 	    edge.r_xbot = LEFT(neighbor);
@@ -679,8 +737,8 @@ plotVersTile(tile, cxp)
     if (tileArea.r_xbot > TiPlaneRect.r_xbot)
     {
 	edge.r_xbot = edge.r_xtop = tileArea.r_xbot;
-	for (neighbor = tile->ti_bl; BOTTOM(neighbor) < tileArea.r_ytop;
-		neighbor = neighbor->ti_rt)
+	for (neighbor = BL(tile); BOTTOM(neighbor) < tileArea.r_ytop;
+		neighbor = RT(neighbor))
 	{
 	    if (TTMaskHasType(&curMask, TiGetType(neighbor))) continue;
 	    edge.r_ybot = BOTTOM(neighbor);
@@ -697,8 +755,8 @@ plotVersTile(tile, cxp)
     if (tileArea.r_ytop < TiPlaneRect.r_ytop)
     {
 	edge.r_ybot = edge.r_ytop = tileArea.r_ytop;
-	for (neighbor = tile->ti_rt; RIGHT(neighbor) > tileArea.r_xbot;
-		neighbor = neighbor->ti_bl)
+	for (neighbor = RT(tile); RIGHT(neighbor) > tileArea.r_xbot;
+		neighbor = BL(neighbor))
 	{
 	    if (TTMaskHasType(&curMask, TiGetType(neighbor))) continue;
 	    edge.r_xbot = LEFT(neighbor);
@@ -715,8 +773,8 @@ plotVersTile(tile, cxp)
     if (tileArea.r_xtop < TiPlaneRect.r_xtop)
     {
 	edge.r_xbot = edge.r_xtop = tileArea.r_xtop;
-	for (neighbor = tile->ti_tr; TOP(neighbor) > tileArea.r_ybot;
-		neighbor = neighbor->ti_lb)
+	for (neighbor = TR(tile); TOP(neighbor) > tileArea.r_ybot;
+		neighbor = LB(neighbor))
 	{
 	    if (TTMaskHasType(&curMask, TiGetType(neighbor))) continue;
 	    edge.r_ybot = BOTTOM(neighbor);
@@ -1261,3 +1319,4 @@ PlotVersatec(scx, layers, xMask, width)
     unlink(fileName);
 }
 
+#endif /* VERSATEC */
