@@ -27,15 +27,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #include <string.h>
 #endif
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/txcommands.h"
 #include "plow/plow.h"
 #include "select/select.h"
@@ -77,7 +77,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #define	PLOWNOSTRAIGHTEN	8
 #define	PLOWPLOW		9	/* Implicit when direction specified */
 
-Void
+void
 CmdPlow(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -173,7 +173,8 @@ wrongNumArgs:
 	    PlowSetBound(editDef, &editBox, rootDef, &rootBox);
 	    break;
 	case PLOWHORIZON:
-	    if (cmd->tx_argc == 3) PlowJogHorizon = cmdParseCoord(cmd->tx_argv[2]);
+	    if (cmd->tx_argc == 3) PlowJogHorizon = cmdParseCoord(w,
+			cmd->tx_argv[2], TRUE, TRUE);
 	    else if (cmd->tx_argc != 2) goto wrongNumArgs;
 
 	    if (PlowJogHorizon == INFINITY)
@@ -222,7 +223,17 @@ wrongNumArgs:
 		if (dir < 0)
 		    return;
 		if (cmd->tx_argc == 4)
-		    distance = cmdParseCoord(cmd->tx_argv[3]);
+		{
+		    switch (dir)
+		    {
+			case GEO_EAST: case GEO_WEST:
+			    distance = cmdParseCoord(w, cmd->tx_argv[3], TRUE, TRUE);
+			    break;
+			case GEO_NORTH: case GEO_SOUTH:
+			    distance = cmdParseCoord(w, cmd->tx_argv[3], TRUE, FALSE);
+			    break;
+		    }
+		}
 		else distance = 1;
 
 		switch (dir)
@@ -318,7 +329,7 @@ usage2:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdStraighten(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -378,7 +389,7 @@ usage:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdPlowTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
