@@ -21,12 +21,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowJogs.c,v 1.3 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "plow/plow.h"
 #include "plow/plowInt.h"
 #include "utils/malloc.h"
@@ -392,7 +393,7 @@ plowProcessJogFunc(edge, area)
 
     /* Free the erase list we built in plowJogDragLHS */
     for (lr = plowJogEraseList; lr; lr = lr->r_next)
-	FREE((char *) lr);
+	freeMagic((char *) lr);
     plowJogEraseList = (LinkedRect *) NULL;
     return (ret);
 }
@@ -553,7 +554,7 @@ plowJogDragLHS(edge, newx)
      * Success: nothing else (except perhaps the original RHS edge) moved.
      * Append this edge to the list of linked rectangles.
      */
-    MALLOC(LinkedRect *, lr, sizeof (LinkedRect));
+    lr = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
     lr->r_r = edge->e_rect;
     lr->r_next = plowJogEraseList;
     plowJogEraseList = lr;
