@@ -32,15 +32,16 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowRandom.c,v 1.2 2001
 #ifdef	SYSV
 #include <fcntl.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "plow/plowInt.h"
 #include "textio/textio.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 #include "extract/extract.h"
 
 /* Imports from PlowMain.c */
