@@ -22,12 +22,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowRules1.c,v 1.3 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "plow/plow.h"
 #include "plow/plowInt.h"
 #include "drc/drc.h"
@@ -39,6 +40,7 @@ int plowSliverTopExtent(), plowSliverTopMove();
 int plowSliverBotExtent(), plowSliverBotMove();
 int plowApplyRule();
 int plowPenumbraRule();
+bool plowSliverApplyRules();
 
 /*
  * ----------------------------------------------------------------------------
@@ -74,9 +76,9 @@ int plowPenumbraRule();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prClearUmbra(edge)
-    register Edge *edge;	/* Edge being moved */
+    Edge *edge;	/* Edge being moved */
 {
     TileTypeBitMask rhsTypes;
     struct applyRule ar;
@@ -120,12 +122,12 @@ prClearUmbra(edge)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prUmbra(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* List of rules */
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Rect searchArea;
 
@@ -212,12 +214,12 @@ prUmbra(edge, rules)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prPenumbraTop(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* Rules to apply (must be non-NULL) */
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -235,13 +237,13 @@ prPenumbraTop(edge, rules)
     }
 }
 
-Void
+int
 prPenumbraBot(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* Rules to apply (must be non-NULL) */
 {
     TileTypeBitMask insideTypes;
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -299,11 +301,11 @@ prPenumbraBot(edge, rules)
 
 int
 plowPenumbraTopProc(outline, ar)
-    register Outline *outline;		/* Segment along penumbra border */
-    register struct applyRule *ar;	/* Info needed for shadow search */
+    Outline *outline;		/* Segment along penumbra border */
+    struct applyRule *ar;	/* Info needed for shadow search */
 {
-    register Edge *movingEdge = ar->ar_moving;
-    register PlowRule *pr = ar->ar_rule;
+    Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr = ar->ar_rule;
     Rect searchArea;
     int ret = 0;
 
@@ -353,11 +355,11 @@ plowPenumbraTopProc(outline, ar)
 
 int
 plowPenumbraBotProc(outline, ar)
-    register Outline *outline;		/* Segment along penumbra border */
-    register struct applyRule *ar;	/* Info needed for shadow search */
+    Outline *outline;		/* Segment along penumbra border */
+    struct applyRule *ar;	/* Info needed for shadow search */
 {
-    register Edge *movingEdge = ar->ar_moving;
-    register PlowRule *pr = ar->ar_rule;
+    Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr = ar->ar_rule;
     Rect searchArea;
     int ret = 0;
 
@@ -421,14 +423,15 @@ plowPenumbraBotProc(outline, ar)
  *	May queue the edge.
  */
 
+int
 plowPenumbraRule(impactedEdge, ar)
-    register Edge *impactedEdge;	/* Edge found by shadow search */
-    register struct applyRule *ar;	/* Edge causing the shadow search, and
+    Edge *impactedEdge;	/* Edge found by shadow search */
+    struct applyRule *ar;	/* Edge causing the shadow search, and
 					 * the design rule to apply.
 					 */
 {
-    register PlowRule *pr;
-    register Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr;
+    Edge *movingEdge = ar->ar_moving;
     int newsep, oldsep, newx;
 
     oldsep = impactedEdge->e_x - movingEdge->e_x;
@@ -473,12 +476,12 @@ plowPenumbraRule(impactedEdge, ar)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prSliverTop(edge, rules)
-    register Edge *edge;
+    Edge *edge;
     PlowRule *rules;
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -526,13 +529,13 @@ prSliverTop(edge, rules)
     }
 }
 
-Void
+int
 prSliverBot(edge, rules)
-    register Edge *edge;
+    Edge *edge;
     PlowRule *rules;
 {
     TileTypeBitMask insideTypes;
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -614,8 +617,8 @@ prSliverBot(edge, rules)
 
 int
 plowSliverTopMove(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
     int howfar = ar->ar_moving->e_newx - ar->ar_moving->e_x;
     Edge edge;
@@ -644,12 +647,12 @@ plowSliverTopMove(outline, ar)
 
 int
 plowSliverBotMove(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed.
+    Outline *outline;		/* Segment of outline being followed.
 					 * The sense of "inside" and "outside"
 					 * is reversed from that when handling
 					 * the top half of the penumbra.
 					 */
-    register struct applyRule *ar;
+    struct applyRule *ar;
 {
     int howfar = ar->ar_moving->e_newx - ar->ar_moving->e_x;
     Edge edge;
@@ -707,10 +710,10 @@ plowSliverBotMove(outline, ar)
 
 int
 plowSliverTopExtent(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newx, xmove, ret = 0;
 
     /*
@@ -813,10 +816,10 @@ plowSliverTopExtent(outline, ar)
 
 int
 plowSliverBotExtent(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newx, xmove, ret = 0;
 
     /*
@@ -951,12 +954,12 @@ plowSliverBotExtent(outline, ar)
 
 bool
 plowSliverApplyRules(ar, far, farDist)
-    register struct applyRule *ar;
+    struct applyRule *ar;
     TileType far;
     int farDist;
 {
     TileType near = ar->ar_moving->e_ltype;
-    register PlowRule *pr;
+    PlowRule *pr;
 
     for (pr = plowWidthRulesTbl[near][ar->ar_slivtype]; pr; pr = pr->pr_next)
 	if (pr->pr_dist > farDist && !TTMaskHasType(&pr->pr_oktypes, far))
@@ -997,12 +1000,12 @@ plowSliverApplyRules(ar, far, farDist)
 
 int
 plowApplyRule(impactedEdge, ar)
-    register Edge *impactedEdge;	/* Edge found by shadow search */
-    register struct applyRule *ar;	/* Edge causing the shadow search, and
+    Edge *impactedEdge;	/* Edge found by shadow search */
+    struct applyRule *ar;	/* Edge causing the shadow search, and
 					 * the design rule to apply.
 					 */
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newsep, oldsep, newx;
 
     oldsep = impactedEdge->e_x - movingEdge->e_x;
