@@ -22,12 +22,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowRules2.c,v 1.3 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "plow/plow.h"
 #include "plow/plowInt.h"
 #include "drc/drc.h"
@@ -416,6 +417,7 @@ prContactLHS(edge)
     int pMax;
 
     /* Add the edges of the contact on its other planes */
+    connPlanes &= ~(edge->e_pNum);
     pMax = DBPlane(edge->e_ltype) + 1;
     for (pNum = pMax - 2; pNum <= pMax; pNum++)
 	if (PlaneMaskHasPlane(connPlanes, pNum))
@@ -431,6 +433,7 @@ prContactRHS(edge)
     int pMax;
 
     /* Add the edges of the contact on its other planes */
+    connPlanes &= ~(edge->e_pNum);
     pMax = DBPlane(edge->e_ltype) + 1;
     for (pNum = pMax - 2; pNum <= pMax; pNum++)
 	if (PlaneMaskHasPlane(connPlanes, pNum))
