@@ -26,7 +26,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowTech.c,v 1.2 2001/0
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -100,10 +100,10 @@ PlowDRCInit()
 	for (j = 0; j < TT_MAXTYPES; j++)
 	{
 	    for (pr = plowWidthRulesTbl[i][j]; pr; pr = pr->pr_next)
-		FREE((char *)pr);
+		freeMagic((char *)pr);
 		
 	    for (pr = plowSpacingRulesTbl[i][j]; pr; pr = pr->pr_next)
-		FREE((char *)pr);
+		freeMagic((char *)pr);
 
 	    plowWidthRulesTbl[i][j] = NULL;
 	    plowSpacingRulesTbl[i][j] = NULL;
@@ -233,7 +233,7 @@ plowWidthRule(argc, argv)
 	    {
 		if (DBTypesOnSamePlane(i, j) && TTMaskHasType(&set, j))
 		{
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned)(sizeof (PlowRule)));
 		    pr->pr_dist = distance;
 		    pr->pr_ltypes = setC;
 		    pr->pr_oktypes = set;
@@ -340,7 +340,7 @@ plowSpacingRule(argc, argv)
 		{
 		    if (!PlaneMaskHasPlane(planes2, pNum))
 			continue;
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned) (sizeof (PlowRule)));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[pNum], &set2);
 		    TTMaskCom2(&tmp2, &setRreverse);
 		    TTMaskAndMask3(&pr->pr_ltypes, &DBPlaneTypes[pNum], &tmp2);
@@ -363,7 +363,7 @@ plowSpacingRule(argc, argv)
 		for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 		{
 		    if (!PlaneMaskHasPlane(planes1, pNum)) continue;
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned)(sizeof (PlowRule)));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[pNum], &set1);
 		    TTMaskCom2(&tmp2, &setRreverse);
 		    TTMaskAndMask3(&pr->pr_ltypes, &DBPlaneTypes[pNum], &tmp2);
@@ -477,7 +477,7 @@ plowEdgeRule(argc, argv)
 	    {
 		if (TTMaskHasType(&set2, j))
 		{
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned)(sizeof (PlowRule)));
 		    pr->pr_ltypes = setLeft;
 		    pr->pr_oktypes = setM;
 		    pr->pr_dist = distance;
@@ -489,7 +489,7 @@ plowEdgeRule(argc, argv)
 
 		if (needPenumbraOnly && TTMaskHasType(&setC, j))
 		{
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned)(sizeof (PlowRule)));
 		    pr->pr_ltypes = setRight;
 		    pr->pr_oktypes = setM;
 		    pr->pr_dist = distance;
@@ -552,7 +552,7 @@ plowEdgeRule(argc, argv)
 	    {
 		if (TTMaskHasType(&setRight, j))
 		{
-		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
+		    pr = (PlowRule *) mallocMagic((unsigned)(sizeof (PlowRule)));
 		    TTMaskSetOnlyType(&pr->pr_ltypes, i);
 		    pr->pr_oktypes = setOK;
 		    pr->pr_dist = distance;
@@ -677,7 +677,7 @@ plowTechOptimizeRule(ruleList)
 		     * Delete pCand, and resume outer loop with the
 		     * new values of pCand and pCandLast set below.
 		     */
-		    FREE((char *) pCand);
+		    freeMagic((char *) pCand);
 		    if (pCandLast)
 			pCandLast->pr_next = pCand->pr_next;
 		    else
