@@ -23,17 +23,19 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowTest.c,v 1.3 2001/0
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "misc/magic.h"
-#include "misc/styles.h"
+
+#include "utils/magic.h"
+#include "utils/styles.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/undo.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "commands/commands.h"
 #include "drc/drc.h"
 #include "debug/debug.h"
