@@ -22,7 +22,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowWidth.c,v 1.3 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
