@@ -25,13 +25,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowYank.c,v 1.3 2001/0
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "debug/debug.h"
 #include "plow/plow.h"
 #include "plow/plowInt.h"
