@@ -20,17 +20,10 @@
  * rcsid $Header: /ufs/repository/magic/plow/plowInt.h,v 1.2 2001/01/12 22:13:12 jsolomon Exp $
  */
 
-#define	_PLOWINT
+#ifndef _PLOWINT_H
+#define	_PLOWINT_H
 
-#ifndef	_MAGIC
-	int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_GEOMETRY
-	int err1 = Need_to_include_utils/geometry_header;
-#endif	/* _GEOMETRY */
-#ifndef	_TILES
-	int err2 = Need_to_include_tiles/tile_header;
-#endif	/* _TILES */
+#include "tiles/tile.h"
 
 /*
  * The following is a TileType used by plowing to refer to an
@@ -56,7 +49,7 @@ typedef struct
     TileTypeBitMask	 rte_ltypes;	/* Apply if LHS type is in this set */
     TileTypeBitMask	 rte_rtypes;	/* Apply if RHS type is in this set */
     int			 rte_whichRules;/* See below */
-    Void	       (*rte_proc)();	/* Procedure implementing rule */
+    int		       (*rte_proc)();	/* Procedure implementing rule */
     char		*rte_name;	/* Name of rule (for debugging) */
 } RuleTableEntry;
 
@@ -261,3 +254,5 @@ extern Tile *plowSplitY();
  * recompiled.
  */
 #include "plowDebugInt.h"
+
+#endif	/* _PLOWINT_H */
