@@ -11,7 +11,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResBasic.c,v 1.2 200
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -23,7 +24,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResBasic.c,v 1.2 200
 #include "extract/extractInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "resis/resis.h"
 
@@ -101,7 +102,7 @@ resAllPortNodes(tile, list)
     {
 	x = pl->rp_loc.p_x;
 	y = pl->rp_loc.p_y;
-	MALLOC(resNode *, resptr, sizeof(resNode));
+	resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 	InitializeNode(resptr, x, y, RES_NODE_ORIGIN);
 	resptr->rn_status = TRUE;
 	resptr->rn_noderes = 0;
@@ -128,19 +129,20 @@ resAllPortNodes(tile, list)
  *--------------------------------------------------------------------------
  */
 
-int
+bool
 ResEachTile(tile, startpoint)
-    register Tile 	*tile;
+    Tile 	*tile;
     Point 		*startpoint;
 
 {
-    register Tile 	*tp;
-    resNode		*resptr;
-    cElement		*ce;
-    register TileType	t1, t2;
-    int			xj, yj, merged, i;
-    tElement		*tcell;
-    tileJunk		*tstructs= (tileJunk *)(tile->ti_client);
+    Tile 	*tp;
+    resNode	*resptr;
+    cElement	*ce;
+    TileType	t1, t2;
+    int		xj, yj, i;
+    bool	merged;
+    tElement	*tcell;
+    tileJunk	*tstructs= (tileJunk *)(tile->ti_client);
       
     ResTileCount++;
 
@@ -159,7 +161,7 @@ ResEachTile(tile, startpoint)
     {
 	int x = startpoint->p_x;
 	int y = startpoint->p_y;
-	MALLOC(resNode *, resptr, sizeof(resNode));
+	resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 	InitializeNode(resptr, x, y, RES_NODE_ORIGIN);
 	resptr->rn_status = TRUE;
 	resptr->rn_noderes = 0;
@@ -183,9 +185,9 @@ ResEachTile(tile, startpoint)
 		int x = (LEFT(tile) + RIGHT(tile)) >> 1;
 		int y = (TOP(tile) + BOTTOM(tile)) >> 1;
 
-		MALLOC(resNode *, resptr, sizeof(resNode));
+		resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 		tstructs->transistorList->rt_gate = resptr;
-		MALLOC(tElement *,tcell,sizeof(tElement));
+		tcell = (tElement *) mallocMagic((unsigned)(sizeof(tElement)));
 		tcell->te_thist = tstructs->transistorList;
 		tcell->te_nextt = NULL;
 
@@ -203,7 +205,7 @@ ResEachTile(tile, startpoint)
 #ifdef ARIEL
     if (i = ExtCurStyle->exts_plugSignalNum[t1])
     {
-	MALLOC(tElement *,tcell,sizeof(tElement));
+	tcell = (tElement *) mallocMagic((unsigned)(sizeof(tElement)));
 	   
 	tcell->te_thist= ResImageAddPlug(tile, i, resCurrentNode);
 	tcell->te_nextt = resCurrentNode->rn_te;
@@ -241,7 +243,7 @@ ResEachTile(tile, startpoint)
 	}
 	oldce = ce;
 	ce = ce->ce_nextc;
-	FREE((char *)oldce);
+	freeMagic((char *)oldce);
     }
     tstructs->contactList = NULL;     
 
@@ -357,6 +359,8 @@ ResEachTile(tile, startpoint)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 resSubTranFunc(tile,tp)
 	Tile	*tile,*tp;
 	
@@ -369,10 +373,10 @@ resSubTranFunc(tile,tp)
 
      if (junk->transistorList->rt_subs== NULL)
      {
-          MALLOC(resNode *,resptr,sizeof(resNode));
+          resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 	  junk->transistorList->rt_subs = resptr;
 	  junk->tj_status |= RES_TILE_TRAN;
-          MALLOC(tElement *,tcell,sizeof(tElement));
+          tcell = (tElement *) mallocMagic((unsigned)(sizeof(tElement)));
 	  tcell->te_thist = junk->transistorList;
 	  tcell->te_nextt = NULL;
 	  x = (LEFT(tile)+RIGHT(tile))>>1;
