@@ -15,7 +15,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResConDCS.c,v 1.3 20
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -25,10 +26,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResConDCS.c,v 1.3 20
 #include "textio/textio.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "resis/resis.h"
 
@@ -126,7 +127,7 @@ dbcConnectFuncDCS(tile, cx)
 	     TTMaskHasType(&(ExtCurStyle->exts_transSDTypes[t2]),t1))
 	     {
     	          TiToRect(tp, &tranArea);
-	          MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+	          thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
 		  ResCalcPerimOverlap(thisTran,tp);
 	          GeoTransRect(&scx->scx_trans, &tranArea, &thisTran->area);
 	          thisTran->type = TiGetType(tp);
@@ -142,7 +143,7 @@ dbcConnectFuncDCS(tile, cx)
 	     TTMaskHasType(&(ExtCurStyle->exts_transSDTypes[t2]),t1))
 	     {
     	          TiToRect(tp, &tranArea);
-	          MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+	          thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
 	          GeoTransRect(&scx->scx_trans, &tranArea, &thisTran->area);
 	          thisTran->type = TiGetType(tp);
 	          thisTran->nextTran = TransList;
@@ -158,7 +159,7 @@ dbcConnectFuncDCS(tile, cx)
 	     TTMaskHasType(&(ExtCurStyle->exts_transSDTypes[t2]),t1))
 	     {
     	          TiToRect(tp, &tranArea);
-	          MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+	          thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
 	          GeoTransRect(&scx->scx_trans, &tranArea, &thisTran->area);
 	          thisTran->type = TiGetType(tp);
 	          thisTran->nextTran = TransList;
@@ -174,7 +175,7 @@ dbcConnectFuncDCS(tile, cx)
 	     TTMaskHasType(&(ExtCurStyle->exts_transSDTypes[t2]),t1))
 	     {
     	          TiToRect(tp, &tranArea);
-	          MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+	          thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
 	          GeoTransRect(&scx->scx_trans, &tranArea, &thisTran->area);
 	          thisTran->type = TiGetType(tp);
 	          thisTran->nextTran = TransList;
@@ -186,7 +187,7 @@ dbcConnectFuncDCS(tile, cx)
     else if TTMaskHasType(&(ExtCurStyle->exts_transMask),t1)
     {
     	          TiToRect(tile, &tranArea);
-	          MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+	          thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
 		  ResCalcPerimOverlap(thisTran,tile);
 	          GeoTransRect(&scx->scx_trans, &tranArea, &thisTran->area);
 	          thisTran->type = TiGetType(tile);
@@ -547,7 +548,7 @@ resSubSearchFunc(tile,cx)
      */
      if (ExtCurStyle->exts_transSDCount[t] >1) return 0;
      TiToRect(tile, &tranArea);
-     MALLOC(ResTranTile *, thisTran, sizeof(ResTranTile));
+     thisTran = (ResTranTile *) mallocMagic((unsigned)(sizeof(ResTranTile)));
      GeoTransRect(&cx->tc_scx->scx_trans, &tranArea, &thisTran->area);
      thisTran->type = t;
      thisTran->nextTran = TransList;
