@@ -11,7 +11,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResDebug.c,v 1.2 200
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -24,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResDebug.c,v 1.2 200
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "utils/stack.h"
 #include "resis/resis.h"
