@@ -12,17 +12,18 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResFract.c,v 1.3 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "tiles/tile.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "utils/malloc.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 
 extern Tile *ResSplitX();
 
@@ -31,6 +32,10 @@ Tile	*resSrTile;
 Tile	*resTopTile;
 Plane	*resFracPlane;
 
+/* Forward declarations */
+
+extern void ResCheckConcavity();
+
 
 /*
  * --------------------------------------------------------------------
@@ -150,6 +155,8 @@ enumerate:
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResCheckConcavity(bot,top,tt)
 	Tile	*bot,*top;
 	TileType	tt;
@@ -251,6 +258,7 @@ ResCheckConcavity(bot,top,tt)
  *-------------------------------------------------------------------------
  */
 
+int
 resWalkup(tile,tt,xpos,ypos,func)
 	Tile		*tile;
 	TileType	tt;
@@ -282,6 +290,8 @@ resWalkup(tile,tt,xpos,ypos,func)
      }
      return(BOTTOM(tile));
 }
+
+int
 resWalkdown(tile,tt,xpos,ypos,func)
 	Tile		*tile;
 	TileType	tt;
@@ -321,6 +331,8 @@ resWalkdown(tile,tt,xpos,ypos,func)
      }
      return(TOP(tile));
 }
+
+int
 resWalkright(tile,tt,xpos,ypos,func)
 	Tile		*tile;
 	TileType	tt;
@@ -352,6 +364,8 @@ resWalkright(tile,tt,xpos,ypos,func)
      }
      return(LEFT(tile));
 }
+
+int
 resWalkleft(tile,tt,xpos,ypos,func)
 	Tile		*tile;
 	TileType	tt;
