@@ -11,7 +11,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResJunct.c,v 1.2 200
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -25,9 +26,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResJunct.c,v 1.2 200
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/stack.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
-#include	"resis/resis.h"
+#include "resis/resis.h"
 
 
 
@@ -66,7 +67,7 @@ ResNewSDTransistor(tile,tp,xj,yj,direction,PendingList)
 	{
 	     if (resFet->rt_source == (resNode *) NULL)
 		 {
-		     MALLOC(resNode *,resptr,sizeof(resNode));
+		     resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 		     newnode = TRUE;
 		     resFet->rt_source = resptr;
 		 }
@@ -79,7 +80,7 @@ ResNewSDTransistor(tile,tp,xj,yj,direction,PendingList)
 	{
 	     if (resFet->rt_drain == (resNode *) NULL)
 		 {
-		     MALLOC(resNode *,resptr,sizeof(resNode));
+		     resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 		     newnode = TRUE;
 		     resFet->rt_drain = resptr;
 		 }
@@ -90,7 +91,7 @@ ResNewSDTransistor(tile,tp,xj,yj,direction,PendingList)
 	}
 	if (newnode)
 	{
-	     MALLOC(tElement *,tcell,sizeof(tElement));
+	     tcell = (tElement *) mallocMagic((unsigned)(sizeof(tElement)));
 	     tcell->te_nextt = NULL;
 	     tcell->te_thist = j->transistorList;
 	     InitializeNode(resptr,xj,yj,RES_NODE_TRANSISTOR);
@@ -135,10 +136,10 @@ ResProcessJunction(tile, tp, xj, yj, NodeList)
 #endif
 
 	if (j2->tj_status & RES_TILE_DONE) return;
-	MALLOC(resNode *,resptr,sizeof(resNode));
+	resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 	resptr->rn_te = (tElement *) NULL;
-	MALLOC(ResJunction *,junction,sizeof(ResJunction));
-	MALLOC(jElement *,jcell,sizeof(jElement));
+	junction = (ResJunction *) mallocMagic((unsigned)(sizeof(ResJunction)));
+	jcell = (jElement *) mallocMagic((unsigned)(sizeof(jElement)));
 	InitializeNode(resptr,xj,yj,RES_NODE_JUNCTION);
 	resptr->rn_je = jcell;
 	ResAddToQueue(resptr,NodeList);
