@@ -10,7 +10,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResMain.c,v 1.2 2001
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -22,7 +23,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResMain.c,v 1.2 2001
 #include "extract/extractInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "resis/resis.h"
 
@@ -292,7 +293,7 @@ ResFindNewContactTiles(contacts)
 		       tileJunk	*j = (tileJunk *)tile->ti_client;
 		       cElement *ce;
 		       
-		       MALLOC(cElement *,ce,sizeof(cElement));
+		       ce = (cElement *) mallocMagic((unsigned) (sizeof(cElement)));
 		       contacts->cp_tile[contacts->cp_currentcontact] = tile;
 		       ce->ce_thisc = contacts;
 		       ce->ce_nextc = j->contactList;
@@ -376,7 +377,7 @@ ResProcessTiles(goodies, origin)
 	      {
 	           int x = fix->fp_loc.p_x;
 	           int y = fix->fp_loc.p_y;
-		   MALLOC(resNode *, resptr, sizeof(resNode));
+		   resptr = (resNode *) mallocMagic((unsigned)(sizeof(resNode)));
 		   InitializeNode(resptr, x, y, RES_NODE_ORIGIN);
 	           resptr->rn_status = TRUE;
 	           resptr->rn_noderes = 0;
@@ -564,7 +565,7 @@ ResExtractNet(startlist,goodies,cellname)
 	if (def == (CellDef *) NULL)
 	{
 	    TxError("Error:  No such cell \"%s\"\n", cellname);
-	    return 1;
+	    return TRUE;
 	}
 	scx.scx_use = DBCellNewUse(def, (char *)NULL);
 	DBSetTrans (scx.scx_use, &GeoIdentityTransform);
@@ -576,7 +577,7 @@ ResExtractNet(startlist,goodies,cellname)
 	if (w == (MagWindow *) NULL)
 	{
 	    TxError("Sorry, the box must appear in one of the windows.\n");
-	    return 1;
+	    return TRUE;
 	}
 	scx.scx_use = (CellUse *) w->w_surfaceID;
 	scx.scx_trans = GeoIdentityTransform;   
@@ -684,8 +685,8 @@ ResExtractNet(startlist,goodies,cellname)
 #endif
 
     /* do extraction */
-    if (ResProcessTiles(goodies, &startpoint) != 0) return(1);
-    return(0);
+    if (ResProcessTiles(goodies, &startpoint) != 0) return TRUE;
+    return FALSE;
 }
 
 
@@ -731,13 +732,13 @@ ResCleanUpEverything()
     {
     	 oldCon = ResContactList;
 	 ResContactList = oldCon->cp_nextcontact;
-	 FREE((char *)oldCon);
+	 freeMagic((char *)oldCon);
     }
     while (ResResList != NULL)
     {
     	 oldRes = ResResList;
 	 ResResList = ResResList->rr_nextResistor;
-	 FREE((char *)oldRes);
+	 freeMagic((char *)oldRes);
     }
     while (ResTransList != NULL)
     {
@@ -745,7 +746,7 @@ ResCleanUpEverything()
 	 ResTransList = ResTransList->rt_nextTran;
 	 if ((oldTran->rt_status & RES_TRAN_SAVE) == 0)
 	 {
-	      FREE((char *)oldTran);
+	      freeMagic((char *)oldTran);
 	 }
     }
 
