@@ -12,7 +12,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResMakeRes.c,v 1.2 2
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -24,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResMakeRes.c,v 1.2 2
 #include "extract/extractInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "resis/resis.h"
 
@@ -146,7 +147,7 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
     if   (p1->br_next == NULL) 
     {
 	p1->br_this->rn_float.rn_area += height * (LEFT(tile) - RIGHT(tile));
-	FREE((char *)p1);
+	freeMagic((char *)p1);
 	junk->breakList = NULL;
 	return(merged);
     }
@@ -175,7 +176,7 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
 	    {
 		 currNode = NULL;
 		 p1->br_next = p2->br_next;
-		 FREE((char *)p2);
+		 freeMagic((char *)p2);
 		 p2 = p1;
 	    }
 	    else if (p2->br_this == resCurrentNode)
@@ -183,7 +184,7 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
 		 currNode = p1->br_this;
 	    	 ResMergeNodes(p2->br_this,p1->br_this,pendingList,doneList);
 		 merged = TRUE;
-		 FREE((char *)p1);
+		 freeMagic((char *)p1);
 	    }
 	    else if (p1->br_this == resCurrentNode)
 	    {
@@ -191,14 +192,14 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
 		 p1->br_next = p2->br_next;
 	    	 ResMergeNodes(p1->br_this,p2->br_this,pendingList,doneList);
 		 merged = TRUE;
-		 FREE((char *)p2);
+		 freeMagic((char *)p2);
 		 p2 = p1;
 	    }
 	    else
 	    {
 		 currNode = p1->br_this;
 	    	 ResMergeNodes(p2->br_this,p1->br_this,pendingList,doneList);
-		 FREE((char *)p1);
+		 freeMagic((char *)p1);
 	    }
 
 	    /* 
@@ -223,18 +224,18 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
 
        else
        {
-            MALLOC(resResistor *, resistor, sizeof(resResistor));
+            resistor = (resResistor *) mallocMagic((unsigned) (sizeof(resResistor)));
             resistor->rr_nextResistor = (*resList);
             resistor->rr_lastResistor = NULL;
             if ((*resList) != NULL) (*resList)->rr_lastResistor = resistor;
             (*resList) = resistor;
             resistor->rr_connection1 = p1->br_this;
             resistor->rr_connection2 = p2->br_this;
-            MALLOC(resElement *, element, sizeof(resElement));
+            element = (resElement *) mallocMagic((unsigned) (sizeof(resElement)));
             element->re_nextEl = p1->br_this->rn_re;
             element->re_thisEl = resistor;
             p1->br_this->rn_re = element;
-            MALLOC(resElement *, element, sizeof(resElement));
+            element = (resElement *) mallocMagic((unsigned) (sizeof(resElement)));
             element->re_nextEl = p2->br_this->rn_re;
             element->re_thisEl = resistor;
             p2->br_this->rn_re = element;
@@ -272,11 +273,11 @@ ResCalcEastWest(tile, pendingList, doneList, resList)
 	    resistor->rr_connection2->rn_float.rn_area += rArea;
 	    resistor->rr_float.rr_area = 0;
 		    
-	    FREE((char *)p1);
+	    freeMagic((char *)p1);
 	}
     }
     p2->br_this->rn_float.rn_area += height * (RIGHT(tile) - p2->br_loc.p_x);
-    FREE((char *)p2);
+    freeMagic((char *)p2);
     junk->breakList = NULL;
     return(merged);
 }
@@ -321,7 +322,7 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
     if   (p1->br_next == NULL) 
     {
 	p1->br_this->rn_float.rn_area += width * (TOP(tile) - BOTTOM(tile));
-     	FREE((char *)p1);
+     	freeMagic((char *)p1);
 	junk->breakList = NULL;
 	return(merged);
     }
@@ -349,14 +350,14 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
 	    {
 		 currNode = NULL;
 		 p1->br_next = p2->br_next;
-		 FREE((char *)p2);
+		 freeMagic((char *)p2);
 		 p2 = p1;
 	    }
 	    else if (p2->br_this == resCurrentNode)
 	    {
 		 currNode = p1->br_this;
 	    	 ResMergeNodes(p2->br_this,p1->br_this,pendingList,doneList);
-		 FREE((char *)p1);
+		 freeMagic((char *)p1);
 		 merged = TRUE;
 	    }
 	    else if (p1->br_this == resCurrentNode)
@@ -365,14 +366,14 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
 		 p1->br_next = p2->br_next;
 	    	 ResMergeNodes(p1->br_this,p2->br_this,pendingList,doneList);
 		 merged = TRUE;
-		 FREE((char *)p2);
+		 freeMagic((char *)p2);
 		 p2 = p1;
 	    }
 	    else
 	    {
 		 currNode = p1->br_this;
 	    	 ResMergeNodes(p2->br_this,p1->br_this,pendingList,doneList);
-		 FREE((char *)p1);
+		 freeMagic((char *)p1);
 	    }
 		    
 	    /* 
@@ -397,18 +398,18 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
 
 	else
 	{
-	    MALLOC(resResistor *, resistor, sizeof(resResistor));
+	    resistor = (resResistor *) mallocMagic((unsigned) (sizeof(resResistor)));
 	    resistor->rr_nextResistor = (*resList);
 	    resistor->rr_lastResistor = NULL;
 	    if ((*resList) != NULL) (*resList)->rr_lastResistor = resistor;
 	    (*resList) = resistor;
 	    resistor->rr_connection1 = p1->br_this;
 	    resistor->rr_connection2 = p2->br_this;
-	    MALLOC(resElement *, element, sizeof(resElement));
+	    element = (resElement *) mallocMagic((unsigned) (sizeof(resElement)));
 	    element->re_nextEl = p1->br_this->rn_re;
 	    element->re_thisEl = resistor;
 	    p1->br_this->rn_re = element;
-	    MALLOC(resElement *, element, sizeof(resElement));
+	    element = (resElement *) mallocMagic((unsigned) (sizeof(resElement)));
 	    element->re_nextEl = p2->br_this->rn_re;
 	    element->re_thisEl = resistor;
 	    p2->br_this->rn_re = element;
@@ -443,11 +444,11 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
 	    resistor->rr_connection1->rn_float.rn_area += rArea;
 	    resistor->rr_connection2->rn_float.rn_area += rArea;
 	    resistor->rr_float.rr_area = 0;
-	    FREE((char *)p1);
+	    freeMagic((char *)p1);
 	}
     }
     p2->br_this->rn_float.rn_area += width * (TOP(tile) - p2->br_loc.p_y);
-    FREE((char *)p2);
+    freeMagic((char *)p2);
     junk->breakList = NULL;
     return(merged);
 }
@@ -464,7 +465,7 @@ ResCalcNorthSouth(tile, pendingList, doneList, resList)
  *	breakpoints, and call either ResCalcEastWest or ResCalcNorthSouth
  *
  * Results:
- *	True if merging occurred, False if not.
+ *	TRUE if merging occurred, FALSE if not.
  *
  * Side Effects: Makes resistors. Frees breakpoints
  *
@@ -493,7 +494,7 @@ ResCalcNearTransistor(tile, pendingList, doneList, resList)
      
      if   (junk->breakList->br_next == NULL) 
      {
-     	  FREE((char *)junk->breakList);
+     	  freeMagic((char *)junk->breakList);
 	  junk->breakList = NULL;
 	  return(merged);
      }
@@ -708,13 +709,13 @@ ResCalcNearTransistor(tile, pendingList, doneList, resList)
 			     	  if (p3 == NULL)
 				  {
 				       junk->breakList = p2->br_next;
-				       FREE((char *) p2);
+				       freeMagic((char *) p2);
 				       p2 = junk->breakList;
 				  }
 				  else
 				  {
 				       p3->br_next = p2->br_next;
-				       FREE((char *) p2);
+				       freeMagic((char *) p2);
 				       p2 = p3->br_next;
 				  }
 			     }
@@ -749,13 +750,13 @@ ResCalcNearTransistor(tile, pendingList, doneList, resList)
 			     	  if (p3 == NULL)
 				  {
 				       junk->breakList = p2->br_next;
-				       FREE((char *) p2);
+				       freeMagic((char *) p2);
 				       p2 = junk->breakList;
 				  }
 				  else
 				  {
 				       p3->br_next = p2->br_next;
-				       FREE((char *) p2);
+				       freeMagic((char *) p2);
 				       p2 = p3->br_next;
 				  }
 			     }
@@ -806,11 +807,11 @@ ResDoContacts(contact, nodes, resList)
 	int x = contact->cp_center.p_x;
 	int y = contact->cp_center.p_y;
 
-	MALLOC(resNode *,resptr,sizeof(resNode));
+	resptr = (resNode *) mallocMagic((unsigned) (sizeof(resNode)));
 	InitializeNode(resptr,x,y,RES_NODE_CONTACT);
 	ResAddToQueue(resptr,nodes);
 
- 	MALLOC(cElement *, ccell, sizeof(cElement));
+ 	ccell = (cElement *) mallocMagic((unsigned) (sizeof(cElement)));
 	ccell->ce_nextc = resptr->rn_ce;
 	resptr->rn_ce = ccell;
 	ccell->ce_thisc = contact;
@@ -857,13 +858,13 @@ ResDoContacts(contact, nodes, resList)
       	    int  y = contact->cp_center.p_y;
 	    Tile *tile = contact->cp_tile[tilenum];
 
-	    MALLOC(resNode *,resptr,sizeof(resNode));
+	    resptr = (resNode *) mallocMagic((unsigned) (sizeof(resNode)));
 	    InitializeNode(resptr,x,y,RES_NODE_CONTACT);
 	    ResAddToQueue(resptr,nodes);
 	  
  	    /* add contact pointer to node  */
 
-	    MALLOC(cElement *, ccell, sizeof(cElement));
+	    ccell = (cElement *) mallocMagic((unsigned) (sizeof(cElement)));
 	    ccell->ce_nextc = resptr->rn_ce;
 	    resptr->rn_ce = ccell;
 	    ccell->ce_thisc = contact;
@@ -876,7 +877,7 @@ ResDoContacts(contact, nodes, resList)
 
 	    if (tilenum > 0)
 	    {
-	        MALLOC(resResistor *, resistor, sizeof(resResistor));
+	        resistor = (resResistor *) mallocMagic((unsigned) (sizeof(resResistor)));
 	        resistor->rr_nextResistor = (*resList);
 	        resistor->rr_lastResistor = NULL;
 	        if ((*resList) != NULL) (*resList)->rr_lastResistor = resistor;
@@ -884,11 +885,11 @@ ResDoContacts(contact, nodes, resList)
 	        resistor->rr_connection1 = contact->cp_cnode[tilenum-1];
 	        resistor->rr_connection2 = contact->cp_cnode[tilenum];
 		    
-	        MALLOC(resElement *,element,sizeof(resElement));
+	        element = (resElement *) mallocMagic((unsigned) (sizeof(resElement)));
 	        element->re_nextEl = contact->cp_cnode[tilenum-1]->rn_re;
 	        element->re_thisEl = resistor;
 	        contact->cp_cnode[tilenum-1]->rn_re = element;
-	        MALLOC(resElement *,element,sizeof(resElement));
+	        element = (resElement *) mallocMagic((unsigned)(sizeof(resElement)));
 	        element->re_nextEl = contact->cp_cnode[tilenum]->rn_re;
 	        element->re_thisEl = resistor;
 	        contact->cp_cnode[tilenum]->rn_re = element;
