@@ -4,7 +4,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResMerge.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -538,7 +539,7 @@ ResTriangleCheck(resptr)
 			  rr2->rr_value = 0;
 			  rr3->rr_value = 0;
 	            }
-		    MALLOC(resNode  *, n3, sizeof(resNode));
+		    n3 = (resNode  *) mallocMagic((unsigned) (sizeof(resNode)));
 	      	    /*  Where should the new node be `put'? It */
 	            /* is arbitrarily assigned to the location */
 		    /* occupied by the first node.		 */
@@ -580,15 +581,15 @@ ResTriangleCheck(resptr)
 		     	   ResDeleteResPointer(rr3->rr_connection1,rr3);
 			   rr3->rr_connection1 = n3;
 		    }
-		    MALLOC(resElement *,element, sizeof(resElement));
+		    element = (resElement *) mallocMagic((unsigned)(sizeof(resElement)));
 		    element->re_nextEl = NULL;
 		    element->re_thisEl = rr1;
 		    n3->rn_re = element;
-		    MALLOC(resElement *,element, sizeof(resElement));
+		    element = (resElement *) mallocMagic((unsigned)(sizeof(resElement)));
 		    element->re_nextEl = n3->rn_re;
 		    element->re_thisEl = rr2;
 		    n3->rn_re = element;
-		    MALLOC(resElement *,element, sizeof(resElement));
+		    element = (resElement *) mallocMagic((unsigned)(sizeof(resElement)));
 		    element->re_nextEl = n3->rn_re;
 		    element->re_thisEl = rr3;
 		    n3->rn_re = element;
@@ -790,7 +791,7 @@ ResMergeNodes(node1,node2,pendingList,doneList)
       }
       if (node2->rn_client != (ClientData)NULL)
       {
-	    FREE((char *)node2->rn_client);
+	    freeMagic((char *)node2->rn_client);
 	    node2->rn_client = (ClientData)NULL;
       }
       {
@@ -801,7 +802,7 @@ ResMergeNodes(node1,node2,pendingList,doneList)
 	    node2->rn_more = (resNode   *) MINFINITY;
 	    node2->rn_less = (resNode   *) MINFINITY;
       }
-      FREE((char *)node2);
+      freeMagic((char *)node2);
  }
 
 
@@ -845,7 +846,7 @@ ResDeleteResPointer(node,resistor)
 	       /* pointers to structure.			      */
 	       rcell2->re_thisEl = NULL;
 	       rcell2->re_nextEl = NULL;
-	       FREE((char *)rcell2);
+	       freeMagic((char *)rcell2);
 	       break;
 	  }
 	  rcell1 = rcell2;
@@ -895,7 +896,7 @@ ResEliminateResistor(resistor,homelist)
      resistor->rr_lastResistor = NULL;
      resistor->rr_connection1 = NULL;
      resistor->rr_connection2 = NULL;
-     FREE((char *)resistor);
+     freeMagic((char *)resistor);
 }
 
 
@@ -931,33 +932,33 @@ ResCleanNode(resptr,junk,homelist1,homelist2)
      {
 	     ccell = resptr->rn_ce;
 	     resptr->rn_ce = resptr->rn_ce->ce_nextc;
-	     FREE((char *)ccell);
+	     freeMagic((char *)ccell);
      }
      while (resptr->rn_je != NULL)
      {
 	     jcell = resptr->rn_je;
 	     resptr->rn_je = resptr->rn_je->je_nextj;
-	     FREE((char *)jcell->je_thisj);
-	     FREE((char *)jcell);
+	     freeMagic((char *)jcell->je_thisj);
+	     freeMagic((char *)jcell);
      }
      if (junk == TRUE)
      {
 	  if (resptr->rn_client != (ClientData)NULL)
 	  {
-	       FREE((char *)resptr->rn_client);
+	       freeMagic((char *)resptr->rn_client);
 	       resptr->rn_client = (ClientData)NULL;
 	  }
 	  while (resptr->rn_te != NULL)
           {
 	       tcell = resptr->rn_te;
 	       resptr->rn_te = resptr->rn_te->te_nextt;
-	       FREE((char *)tcell);
+	       freeMagic((char *)tcell);
           }
           while (resptr->rn_re != NULL)
           {
 	       rcell = resptr->rn_re;
 	       resptr->rn_re = resptr->rn_re->re_nextEl;
-	       FREE((char *)rcell);
+	       freeMagic((char *)rcell);
           }
 	  if (resptr->rn_less != NULL)
 	  {
@@ -990,7 +991,7 @@ ResCleanNode(resptr,junk,homelist1,homelist2)
 	       resptr->rn_more = (resNode   *) MINFINITY;
 	       resptr->rn_less = (resNode   *) MINFINITY;
 	  }
-	  FREE((char *)resptr);
+	  freeMagic((char *)resptr);
      }
 }
 
@@ -1049,7 +1050,7 @@ ResFixBreakPoint(sourcelist,origNode,newNode)
 		    {
 			 bp4->br_crect = bp3->br_crect;
 		    }
-		    FREE((char *)bp3);
+		    freeMagic((char *)bp3);
 		    continue;
 	       }else
 	       {
