@@ -12,6 +12,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResReadSim.c,v 1.2 2
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include <math.h>
 #ifdef	SYSV
@@ -19,7 +20,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResReadSim.c,v 1.2 2
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -32,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResReadSim.c,v 1.2 2
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include	"resis/resis.h"
 
@@ -103,6 +105,10 @@ ResFixPoint		*ResFixList;
      (n)->rn_status = TRUE;\
 }
 
+/* Forward declarations */
+
+extern void ResSimProcessDrivePoints();
+
 
 /*
  *-------------------------------------------------------------------------
@@ -115,6 +121,8 @@ ResFixPoint		*ResFixList;
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResReadSim(simfile,fetproc,capproc,resproc,attrproc,mergeproc)
      char	*simfile;
      int	(*fetproc)(),(*capproc)(),(*resproc)();
@@ -166,9 +174,10 @@ ResReadSim(simfile,fetproc,capproc,resproc,attrproc,mergeproc)
 		    case 'A':	if (attrproc) result = 
 		    			(*attrproc)(line[ATTRIBUTENODENAME],
 						    line[ATTRIBUTEVALUE],
-						    simfile,extfile);
+						    simfile, &extfile);
 		    		break;
 		    case 'D':
+		    case 'c':
 		    case 'r':	break;
 		    default:	result = 1;
 		    		(void)fclose(fp);
@@ -209,6 +218,8 @@ ResReadSim(simfile,fetproc,capproc,resproc,attrproc,mergeproc)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResReadNode(nodefile)
 	char	*nodefile;
  
@@ -265,6 +276,7 @@ ResReadNode(nodefile)
  *
  *-------------------------------------------------------------------------
  */
+
 int
 gettokens(line,fp)
 	char line[][MAXTOKEN];
@@ -310,6 +322,8 @@ gettokens(line,fp)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimTransistor(line,rpersquare,ttype)
 	char line[][MAXTOKEN];
 	float	rpersquare;
@@ -321,7 +335,7 @@ ResSimTransistor(line,rpersquare,ttype)
      char		*newattr,tmpattr[MAXTOKEN];
      static int		nowarning = TRUE;
      
-     MALLOC(RTran *, transistor, sizeof(RTran));
+     transistor = (RTran *) mallocMagic((unsigned) (sizeof(RTran)));
      if ((line[RTRAN_WIDTH][0] == '\0') || (line[RTRAN_LENGTH][0] == '\0'))
      {
      	  TxError("error in input file:\n");
@@ -371,7 +385,7 @@ ResSimTransistor(line,rpersquare,ttype)
 	  }
 	  tmpattr[k++]='"';
 	  tmpattr[k++]='\0';
-	  MALLOC(char *,newattr,k);
+	  newattr = (char *) mallocMagic((unsigned) k);
 	  strncpy(newattr,tmpattr,k);
 	  switch (line[i][0])
 	  {
@@ -403,6 +417,7 @@ ResSimTransistor(line,rpersquare,ttype)
  *
  *-------------------------------------------------------------------------
  */
+
 int
 ResSimNewNode(line,type,transistor)
 	char 		line[];
@@ -421,7 +436,7 @@ ResSimNewNode(line,type,transistor)
      }
      entry = HashFind(&ResNodeTable,line);
      node = ResInitializeNode(entry);
-     MALLOC(tranPtr *,tptr, sizeof(tranPtr));
+     tptr = (tranPtr *) mallocMagic((unsigned) (sizeof(tranPtr)));
      tptr->thisTran = transistor;
      tptr->nextTran = node->firstTran;
      node->firstTran = tptr;
@@ -448,12 +463,15 @@ ResSimNewNode(line,type,transistor)
  *	node. Coupling capacitors are added twice, moving the capacitance 
  *	to the substrate.
  *
- *  Results: none
+ *  Results:
+ *	Always return 0
  *
  *  Side Effects: modifies capacitance field  of ResSimNode.
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimCapacitor(line)
 	char line[][MAXTOKEN];
 
@@ -516,12 +534,15 @@ ResSimCapacitor(line)
  *  ResSimResistor-- Adds the capacitance  from a R line to the appropriate
  *	node. 
  *
- *  Results: none
+ *  Results
+ *	Return 0 to keep search going, 1 to abort
  *
  *  Side Effects: modifies resistance field of ResSimNode
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimResistor(line)
 	char line[][MAXTOKEN];
 
@@ -554,12 +575,15 @@ ResSimResistor(line)
  *	attribute. If it is, add it to the correct node's status flag.
  *	Only works with 5.0 1/line attributes
  *
- *  Results: none
+ *  Results:
+ *	Return 0 to keep search going, 1 to abort
  *
  *  Side Effects: modifies resistance field of ResSimNode
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimAttribute(aname,avalue,rootname,readextfile)
 	char *aname,*avalue,*rootname;
 	int	*readextfile;
@@ -660,12 +684,14 @@ ResSimAttribute(aname,avalue,rootname,readextfile)
  *	they are in the root cell.
  *
  * Results:
+ *	None.
  *
  * Side Effects:
  *
  *-------------------------------------------------------------------------
  */
-int
+
+void
 ResSimProcessDrivePoints(filename)
 	char	*filename;
 
@@ -704,13 +730,16 @@ ResSimProcessDrivePoints(filename)
  *	is only done after the first res:fix label is encountered.
  *
  *
- * Results: For each new name, allocate
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	For each new name, allocate memory
  *
  *-------------------------------------------------------------------------
  */
-int
+
+void
 ResSimProcessFixPoints(filename)
 	char	*filename;
 {
@@ -739,7 +768,7 @@ ResSimProcessFixPoints(filename)
 	       			line[RES_EXT_ATTR_TEXT]);
 	       *label ='\0';
 	  }
-	  MALLOC(ResFixPoint *, thisfix, sizeof(ResFixPoint)+strlen(label));
+	  thisfix = (ResFixPoint *) mallocMagic((unsigned) (sizeof(ResFixPoint)+strlen(label)));
 	  thisfix->fp_next = ResFixList;
 	  ResFixList = thisfix;
 	  thisfix->fp_loc.p_x = atoi(line[RES_EXT_ATTR_X]);
@@ -756,7 +785,7 @@ ResSimProcessFixPoints(filename)
  *
  * ResSimMerge-- Processes = line in sim file
  *
- * Results: none
+ * Results: Success/Failure
  *
  * Side Effects: The forward field of one node is set to point to the
  *	other node. All of the junkt from the first node is moved to
@@ -764,6 +793,8 @@ ResSimProcessFixPoints(filename)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimMerge(line)
 	char line[][MAXTOKEN];
 
@@ -803,6 +834,7 @@ ResSimMerge(line)
  *
  *-------------------------------------------------------------------------
  */
+
 ResSimNode *
 ResInitializeNode(entry)
 	HashEntry	*entry;
@@ -811,7 +843,7 @@ ResInitializeNode(entry)
 
      if ((node = (ResSimNode *) HashGetValue(entry)) == NULL)
      {
-	  MALLOC(ResSimNode *, node, sizeof(ResSimNode));
+	  node = (ResSimNode *) mallocMagic((unsigned)(sizeof(ResSimNode)));
 	  HashSetValue(entry,(char *) node);
 	  node->nextnode = ResOriginalNodes;
 	  ResOriginalNodes = node;
