@@ -21,11 +21,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResRex.c,v 1.3 2001/
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
+#include "utils/undo.h"
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
@@ -34,7 +37,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResRex.c,v 1.3 2001/
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include	"resis/resis.h"
 #ifdef LAPLACE
@@ -56,9 +59,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResRex.c,v 1.3 2001/
 HashTable 	ResNodeTable;   /* Hash table of sim file nodes   */
 RTran		*ResTranList;	/* Linked list of Sim transistors */
 ResGlobalParams	gparams;	/* Junk passed between 		  */
-					/* ResCheckSimNodes and 	  */
-					/* ResExtractNet.		  */
-int		Maxtnumber;     	/*maximum transistor number 	  */
+				/* ResCheckSimNodes and 	  */
+				/* ResExtractNet.		  */
+int		Maxtnumber;     /*maximum transistor number 	  */
 extern ResSimNode	*ResOriginalNodes;	/*Linked List of Nodes		  */
 int		resNodeNum;
 
@@ -71,7 +74,7 @@ char	*ResCurrentNode;
 
 FILE	*ResExtFile;
 FILE	*ResLumpFile;
-FILE	*ResGeomFile;
+FILE	*ResFHFile;
 
 int	ResPortIndex;	/* Port ordering to backannotate into magic */
 
@@ -126,7 +129,7 @@ ExtResisForDef(celldef, resisdata)
 	    ResCheckPorts(celldef);
 
 	    /* Extract networks for nets that require it. */
-	    if (!(ResOptionsFlags & ResOpt_Geometry) || 
+	    if (!(ResOptionsFlags & ResOpt_FastHenry) || 
 			DBIsSubcircuit(celldef))
 		ResCheckSimNodes(celldef, resisdata);
 
@@ -149,9 +152,9 @@ ExtResisForDef(celldef, resisdata)
 	{
 	    oldtptr = tptr;
 	    tptr = tptr->nextTran;
-	    FREE((char *)oldtptr);
+	    freeMagic((char *)oldtptr);
 	}
-	FREE((char *) node);
+	freeMagic((char *) node);
     }
     HashKill(&ResNodeTable);
     while (ResTranList != NULL)
@@ -160,10 +163,10 @@ ExtResisForDef(celldef, resisdata)
 	ResTranList = ResTranList->nextTran;
 	if (oldTran->layout != NULL)
 	{
-	    FREE((char *)oldTran->layout);
+	    freeMagic((char *)oldTran->layout);
 	    oldTran->layout = NULL;
 	}
-	FREE((char *)oldTran);
+	freeMagic((char *)oldTran);
     }
 }
 
@@ -188,7 +191,7 @@ CmdExtResis(win, cmd)
 	MagWindow *win;
 	TxCommand *cmd;
 {
-    int		i, j, k, option, value;
+    int		i, j, k, option, value, saveFlags;
     static int	init=1;
     static float tolerance, tdiTolerance, fhFrequency;
     CellDef	*mainDef;
@@ -207,7 +210,7 @@ CmdExtResis(win, cmd)
 
     static char *cmdExtresisCmd[] = 
     {
-	"tolerance value      set ratio between resistor and transistor tol.",
+	"tolerance [value]    set ratio between resistor and transistor tol.",
 	"all 		       extract all the nets",
 	"simplify [on/off]    turn on/off simplification of resistor nets",
 	"extout   [on/off]    turn on/off writing of .res.ext file",
@@ -216,7 +219,8 @@ CmdExtResis(win, cmd)
 	"skip     mask        don't extract these types",
 	"box      type        extract the signal under the box on layer type",
 	"cell	   cellname    extract the network for the cell named cellname",
-	"geometry [freq]      extract subcircuit network geometry into .fh file",
+	"fasthenry [freq]      extract subcircuit network geometry into .fh file",
+	"geometry	      extract network centerline geometry (experimental)",
 	"help                 print this message",
 #ifdef LAPLACE
 	"laplace  [on/off]    solve Laplace's equation using FEM",
@@ -224,25 +228,16 @@ CmdExtResis(win, cmd)
 	NULL
     };
 
-#define RES_AMBIG	-1
-#define RES_BAD		-2
-#define RES_TOL		0
-#define RES_ALL		1
-#define RES_SIMP	2
-#define RES_EXTOUT	3
-#define RES_LUMPED	4
-#define RES_SILENT	5
-#define RES_SKIP	6
-#define RES_BOX		7
-#define RES_CELL	8
-#define RES_GEOMETRY	9
-#define RES_HELP	10
+typedef enum {
+	RES_BAD=-2, RES_AMBIG, RES_TOL,
+	RES_ALL, RES_SIMP, RES_EXTOUT, RES_LUMPED,
+	RES_SILENT, RES_SKIP, RES_BOX, RES_CELL,
+	RES_FASTHENRY, RES_GEOMETRY, RES_HELP,
 #ifdef LAPLACE
-#define RES_LAPLACE	11
-#define RES_RUN		12
-#else
-#define RES_RUN		11
+	RES_LAPLACE,
 #endif
+	RES_RUN
+} ResOptions;
 
     if (init)
     {
@@ -257,12 +252,6 @@ CmdExtResis(win, cmd)
 	init = 0;
     }
 
-    if (ToolGetBoxWindow((Rect *) NULL, (int *) NULL) == NULL)
-    {
-	TxError("Sorry, the box must appear in one of the windows.\n");
-	return;
-    }
-
     option = (cmd->tx_argc > 1) ? Lookup(cmd->tx_argv[1], cmdExtresisCmd)
 		: RES_RUN;
 
@@ -287,25 +276,41 @@ CmdExtResis(win, cmd)
     switch (option)
     {
 	 case RES_TOL:
-	      ResOptionsFlags |=  ResOpt_ExplicitRtol;
-	      if (cmd->tx_argc >2) 
-	      {
-		   tolerance = MagAtof(cmd->tx_argv[2]);
-		   if (tolerance <= 0)
-		   {
-		      TxError("Usage:  %s tolerance [value]\n", cmd->tx_argv[0]);
-			 return;
-		   }
-		   tdiTolerance = tolerance;
-	      }
-	      return;
+	    ResOptionsFlags |=  ResOpt_ExplicitRtol;
+	    if (cmd->tx_argc > 2) 
+	    {
+		tolerance = MagAtof(cmd->tx_argv[2]);
+		if (tolerance <= 0)
+		{
+		    TxError("Usage:  %s tolerance [value]\n", cmd->tx_argv[0]);
+			return;
+		}
+		tdiTolerance = tolerance;
+	    }
+	    else
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewDoubleObj((double)tdiTolerance));
+#else
+		TxPrintf("Tolerance ratio is %g.\n", tdiTolerance);
+#endif
+	    }
+	    return;
+
 	 case RES_ALL:
-	      ResOptionsFlags |= ResOpt_ExtractAll;
-	      break;
+	    ResOptionsFlags |= ResOpt_ExtractAll;
+	    break;
 
 	 case RES_GEOMETRY:
-	      if (cmd->tx_argc == 3)
-	      {
+	    saveFlags = ResOptionsFlags;
+	    ResOptionsFlags |= ResOpt_Geometry | ResOpt_ExtractAll;
+	    ResOptionsFlags &= ~(ResOpt_DoExtFile | ResOpt_DoLumpFile
+			| ResOpt_Simplify | ResOpt_Tdi);
+	    break;
+
+	 case RES_FASTHENRY:
+	    if (cmd->tx_argc == 3)
+	    {
 		  double tmpf = strtod(cmd->tx_argv[2], &endptr);
 		  if (endptr == cmd->tx_argv[2])
 		  {
@@ -314,11 +319,12 @@ CmdExtResis(win, cmd)
 		  }
 		  else
 		      fhFrequency = (float)tmpf;
-	      }
-	      ResOptionsFlags |= ResOpt_Geometry;
-	      ResOptionsFlags &= ~(ResOpt_DoExtFile | ResOpt_DoLumpFile
+	    }
+	    saveFlags = ResOptionsFlags;
+	    ResOptionsFlags |= ResOpt_FastHenry | ResOpt_ExtractAll;
+	    ResOptionsFlags &= ~(ResOpt_DoExtFile | ResOpt_DoLumpFile
 			| ResOpt_Simplify | ResOpt_Tdi);
-	      return;
+	    break;
 
 	case RES_SIMP:
 	    if (cmd->tx_argc == 2)
@@ -395,31 +401,37 @@ CmdExtResis(win, cmd)
 
 	case RES_BOX:
 	    {
-		 TileType	tt;
-		 CellDef	*def;
-		 Rect		rect;
-		 int		oldoptions;
-		 ResFixPoint	fp;
+		TileType	tt;
+		CellDef		*def;
+		Rect		rect;
+		int		oldoptions;
+		ResFixPoint	fp;
 
-	     	 if (cmd->tx_argc != 3) return;
-		 tt = DBTechNoisyNameType(cmd->tx_argv[2]);
-		 if (tt <= 0 || ToolGetBox(&def,&rect)== FALSE) return;
-		 gparams.rg_tranloc = &rect.r_ll;
-		 gparams.rg_ttype = tt;
-		 gparams.rg_status = DRIVEONLY;
-		 oldoptions = ResOptionsFlags;
-		 ResOptionsFlags = ResOpt_DoSubstrate|ResOpt_Signal|ResOpt_Box;
+		if (ToolGetBoxWindow((Rect *) NULL, (int *) NULL) == NULL)
+		{
+		    TxError("Sorry, the box must appear in one of the windows.\n");
+		    return;
+		}
+
+	     	if (cmd->tx_argc != 3) return;
+		tt = DBTechNoisyNameType(cmd->tx_argv[2]);
+		if (tt <= 0 || ToolGetBox(&def, &rect)== FALSE) return;
+		gparams.rg_tranloc = &rect.r_ll;
+		gparams.rg_ttype = tt;
+		gparams.rg_status = DRIVEONLY;
+		oldoptions = ResOptionsFlags;
+		ResOptionsFlags = ResOpt_DoSubstrate|ResOpt_Signal|ResOpt_Box;
 #ifdef LAPLACE
-		 ResOptionsFlags |= (oldoptions & (ResOpt_CacheLaplace|ResOpt_DoLaplace));
-		 LaplaceMatchCount = 0;
-		 LaplaceMissCount = 0;
+		ResOptionsFlags |= (oldoptions & (ResOpt_CacheLaplace|ResOpt_DoLaplace));
+		LaplaceMatchCount = 0;
+		LaplaceMissCount = 0;
 #endif
-		 fp.fp_ttype = tt;
-		 fp.fp_loc = rect.r_ll;
-		 fp.fp_next = NULL;
-		 if (ResExtractNet(&fp, &gparams, NULL) != 0) return;
-		 ResPrintResistorList(stdout,ResResList);
-		 ResPrintTransistorList(stdout,ResTransList);
+		fp.fp_ttype = tt;
+		fp.fp_loc = rect.r_ll;
+		fp.fp_next = NULL;
+		if (ResExtractNet(&fp, &gparams, NULL) != 0) return;
+		ResPrintResistorList(stdout,ResResList);
+		ResPrintTransistorList(stdout,ResTransList);
 #ifdef LAPLACE
 		if (ResOptionsFlags & ResOpt_DoLaplace)
 		{
@@ -471,10 +483,12 @@ CmdExtResis(win, cmd)
 
     if (!ToolGetBox(&mainDef,(Rect *) NULL))
     {
-    	 TxError("Couldn't find def corresponding to box\n");
-	 return;
+    	TxError("Couldn't find def corresponding to box\n");
+	if ((option == RES_FASTHENRY) || (option == RES_GEOMETRY))
+	    ResOptionsFlags = saveFlags;
+	return;
     }
-    ResOptionsFlags |= 	 ResOpt_Signal;
+    ResOptionsFlags |= ResOpt_Signal;
 #ifdef ARIEL
     ResOptionsFlags &= 	~ResOpt_Power;
 #endif
@@ -494,11 +508,17 @@ CmdExtResis(win, cmd)
 #ifdef LAPLACE
     if (ResOptionsFlags & ResOpt_DoLaplace)
     {
-	TxPrintf("Laplace   solved: %d matched %d\n",
-				LaplaceMissCount,LaplaceMatchCount);
+	TxPrintf("Laplace solved: %d matched %d\n",
+				LaplaceMissCount, LaplaceMatchCount);
     }
 #endif
 
+    /* Revert to the original flags in the case of FastHenry or	*/
+    /* geometry centerline extraction.				*/
+
+    if ((option == RES_FASTHENRY) || (option == RES_GEOMETRY))
+	ResOptionsFlags = saveFlags;
+
     return;
 }
 
@@ -661,21 +681,21 @@ ResCheckSimNodes(celldef, resisdata)
     {
      	ResLumpFile = NULL;
     }
-    if (ResOptionsFlags & ResOpt_Geometry)
+    if (ResOptionsFlags & ResOpt_FastHenry)
     {
 	char *geofilename;
-        ResGeomFile = PaOpen(outfile,"w",".fh",".",(char *) NULL, &geofilename);
+        ResFHFile = PaOpen(outfile,"w",".fh",".",(char *) NULL, &geofilename);
 	TxPrintf("Writing FastHenry-format geometry file \"%s\"\n", geofilename);
 	ResPortIndex = 0;
     }
     else
     {
-     	ResGeomFile = NULL;
+     	ResFHFile = NULL;
     }
   
     if (ResExtFile == NULL && (ResOptionsFlags & ResOpt_DoExtFile)
          || (ResOptionsFlags & ResOpt_DoLumpFile) && ResLumpFile == NULL
-         || (ResOptionsFlags & ResOpt_Geometry) && ResGeomFile == NULL)
+         || (ResOptionsFlags & ResOpt_FastHenry) && ResFHFile == NULL)
     {
      	TxError("Couldn't open output file\n");
 	return;
@@ -685,15 +705,15 @@ ResCheckSimNodes(celldef, resisdata)
       *	Write reference plane (substrate) definition and end statement
       * to the FastHenry geometry file.	
       */
-    if (ResOptionsFlags & ResOpt_Geometry)
+    if (ResOptionsFlags & ResOpt_FastHenry)
     {
-	ResPrintReference(ResGeomFile, ResTranList, celldef);
+	ResPrintReference(ResFHFile, ResTranList, celldef);
     }
 
     for (node = ResOriginalNodes; node != NULL; node=node->nextnode)
     {
 	ResCurrentNode = node->name;
-	if (!(ResOptionsFlags & ResOpt_Geometry))
+	if (!(ResOptionsFlags & ResOpt_FastHenry))
 	{
 	    /* Hack!!  Don't extract Vdd or GND lines */
 
@@ -835,7 +855,7 @@ ResCheckSimNodes(celldef, resisdata)
 	    fp.fp_loc = node->location;
 	    fp.fp_ttype = node->type;
 	    fp.fp_next = NULL;
-	    if (ResExtractNet(&fp,&gparams,outfile) != 0)
+	    if (ResExtractNet(&fp, &gparams, outfile) != 0)
 	    {
 	       	TxError("Error in extracting node %s\n",node->name);
 		break;
@@ -878,11 +898,11 @@ ResCheckSimNodes(celldef, resisdata)
      * (Frequency range should be user-specified. . .)
      */
 
-    if (ResOptionsFlags & ResOpt_Geometry)
+    if (ResOptionsFlags & ResOpt_FastHenry)
     {
 	Label *lab;
 
-	fprintf(ResGeomFile, "\n.freq fmin=%2.1g fmax=%2.1g\n",
+	fprintf(ResFHFile, "\n.freq fmin=%2.1g fmax=%2.1g\n",
 			resisdata->frequency, resisdata->frequency);
 
 	/*----------------------------------------------------------------------*/
@@ -893,13 +913,13 @@ ResCheckSimNodes(celldef, resisdata)
 	/* order the arguments in the ".subckt" definition.			*/
 	/*----------------------------------------------------------------------*/
 
-	fprintf(ResGeomFile, "\n* Order of arguments to SPICE subcircuit call:\n");
+	fprintf(ResFHFile, "\n* Order of arguments to SPICE subcircuit call:\n");
 	for (lab = celldef->cd_labels; lab != NULL; lab = lab->lab_next)
 	    if (lab->lab_flags & PORT_DIR_MASK)
-		fprintf(ResGeomFile, "* %d %s\n", lab->lab_flags & PORT_NUM_MASK,
+		fprintf(ResFHFile, "* %d %s\n", lab->lab_flags & PORT_NUM_MASK,
 			lab->lab_text);
 
-	fprintf(ResGeomFile, "\n.end\n");
+	fprintf(ResFHFile, "\n.end\n");
     }
 
     /* Output statistics about extraction */
@@ -926,9 +946,9 @@ ResCheckSimNodes(celldef, resisdata)
     {
      	(void) fclose(ResLumpFile);
     }
-    if (ResGeomFile != NULL)
+    if (ResFHFile != NULL)
     {
-	(void) fclose(ResGeomFile);
+	(void) fclose(ResFHFile);
     }
 }
 
@@ -1163,7 +1183,7 @@ ResFixTranName(line,type,transistor,layoutnode)
         entry = HashFind(&ResNodeTable,line);
         node = ResInitializeNode(entry);
     }
-    MALLOC(tranPtr *,tptr, sizeof(tranPtr));
+    tptr = (tranPtr *) mallocMagic((unsigned) (sizeof(tranPtr)));
     tptr->thisTran = transistor;
     tptr->nextTran = node->firstTran;
     node->firstTran = tptr;
@@ -1461,12 +1481,19 @@ ResWriteExtFile(celldef, node, tol, rctol, nidx, eidx)
 	    ResPrintExtNode(ResExtFile,ResNodeList,node->name);
       	    ResPrintExtRes(ResExtFile,ResResList,newname);
         }
+	if (ResOptionsFlags & ResOpt_FastHenry)
+	{
+	    if (ResResList)
+		ResAlignNodes(ResNodeList, ResResList);
+	    ResPrintFHNodes(ResFHFile, ResNodeList, node->name, nidx, celldef);
+	    ResPrintFHRects(ResFHFile, ResResList, newname, eidx);
+	}
 	if (ResOptionsFlags & ResOpt_Geometry)
 	{
 	    if (ResResList)
 		ResAlignNodes(ResNodeList, ResResList);
-	    ResPrintGeoNodes(ResGeomFile, ResNodeList, node->name, nidx, celldef);
-	    ResPrintGeoRects(ResGeomFile, ResResList, newname, eidx);
+	    if (ResCreateCenterlines(ResResList, nidx, celldef) < 0)
+		return 0;
 	}
 	return 1;
     }
