@@ -19,7 +19,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResSimple.c,v 1.2 20
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResSimple.c,v 1.2 20
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/stack.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include	"resis/resis.h"
 
@@ -293,7 +294,7 @@ ResSimplifyNet(nodelist,biglist,reslist,tolerance)
 	  {
 	       resistor1->rr_connection2 = node2;
 	  }
-          MALLOC(resElement *,resisptr,sizeof(resElement));
+          resisptr = (resElement *) mallocMagic((unsigned)(sizeof(resElement)));
           resisptr->re_thisEl = resistor1;
           resisptr->re_nextEl = node2->rn_re;
           node2->rn_re = resisptr;
@@ -738,7 +739,7 @@ ResCalculateChildCapacitance(me)
      {
 	  return(-1);
      }
-     MALLOC(RCDelayStuff *, myC, sizeof(RCDelayStuff));
+     myC = (RCDelayStuff *) mallocMagic((unsigned) (sizeof(RCDelayStuff)));
      me->rn_client = (ClientData) myC;
 
      /* This following assumes that ResDistributeCapacitance has been run */
