@@ -11,7 +11,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResUtils.c,v 1.2 200
 #else
 #include <strings.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -24,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResUtils.c,v 1.2 200
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/stack.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
 #include "resis/resis.h"
 
@@ -65,9 +66,9 @@ ResFirst(tile, arg)
 #endif
     t = TiGetType(tile);
 
-    if ((DBConnPlanes[t] !=0) && DBIsContact(t))
+    if (DBIsContact(t))
     {
-	    MALLOC(ResContactPoint *, reg, sizeof(ResContactPoint));
+	    reg = (ResContactPoint *) mallocMagic((unsigned) (sizeof(ResContactPoint)));
 	    reg->cp_center.p_x = (LEFT(tile)+RIGHT(tile))>>1;
 	    reg->cp_center.p_y = (TOP(tile)+BOTTOM(tile))>>1;
 	    reg->cp_status = FALSE;
@@ -169,7 +170,7 @@ ResAddPlumbing(tile, arg)
      	  junk2 = resAddField(tile);
 	  if (TTMaskHasType(&(ExtCurStyle->exts_transMask), loctype))
 	  {
-   	       MALLOC(resTransistor *, resFet,sizeof(resTransistor));
+   	       resFet = (resTransistor *) mallocMagic((unsigned)(sizeof(resTransistor)));
 	       {
 	       	    int	   i;
 		    for (i=0; i != RT_TERMCOUNT;i++)
@@ -539,7 +540,7 @@ ResRemovePlumbing(tile, arg)
      
      if (tile->ti_client != (ClientData) MINFINITY)
      {
-          FREE(((char *)(tile->ti_client)));
+          freeMagic(((char *)(tile->ti_client)));
 	  tile->ti_client = (ClientData) MINFINITY;
      }
      return(0);
@@ -625,7 +626,7 @@ ResPreProcessTransistors(TileList, TransistorList, Def)
 	}
 	oldTile = TileList;
 	TileList = TileList->nextTran;
-	FREE((char *)oldTile);
+	freeMagic((char *)oldTile);
     }
 
     for(; TransistorList != NULL;TransistorList = TransistorList->rt_nextTran)
@@ -727,7 +728,7 @@ resAddField(tile)
         tileJunk *Junk;
 	if ((Junk=(tileJunk *)tile->ti_client) == (tileJunk *) MINFINITY)
 	{
-     	      MALLOC(tileJunk *,Junk,sizeof(tileJunk));
+     	      Junk = (tileJunk *) mallocMagic((unsigned) (sizeof(tileJunk)));
 	      ResJunkInit(Junk);
 	      tile->ti_client = (ClientData) Junk;
 	}
