@@ -18,7 +18,8 @@ static char sccsid[] = "@(#)Write.c	4.10 MAGIC (Stanford Addition) 07/86";
 #include <ctype.h>
 #include <math.h>
 #include <strings.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -31,16 +32,17 @@ static char sccsid[] = "@(#)Write.c	4.10 MAGIC (Stanford Addition) 07/86";
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "utils/stack.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/txcommands.h"
-#include	"resis/resis.h"
+#include "resis/resis.h"
 
 #define	RT_SIZE	0xf
 #define MAXTOKEN 256
 #define TRANFLATSIZE 1024
 #define RESGROUPSIZE  256
 
-ResPrintNetwork(filename,reslist)
+void
+ResPrintNetwork(filename, reslist)
     char	*filename;
     resResistor	*reslist;
 
@@ -93,6 +95,7 @@ ResPrintNetwork(filename,reslist)
     fclose(fp);
 }
 
+void
 ResPrintCurrents(filename,extension,node)
 	char	*filename;
 	float	extension;
@@ -126,6 +129,7 @@ ResPrintCurrents(filename,extension,node)
  *-------------------------------------------------------------------------
  */
 
+void
 resCurrentPrintFunc(node,resistor,filename)
 	resNode		*node;
 	resResistor	*resistor;
@@ -158,6 +162,7 @@ resCurrentPrintFunc(node,resistor,filename)
 
 }
 
+void
 ResDeviceCounts()
 {
          int i,j,k;
@@ -173,6 +178,7 @@ ResDeviceCounts()
 }
 
 
+void
 ResWriteECLFile(filename,reslist,nodelist)
 	char	*filename;
 	resResistor	*reslist;
@@ -205,7 +211,7 @@ ResWriteECLFile(filename,reslist,nodelist)
 	            (void)sprintf(newname,"n%d_%d_%d",nodelist->rn_loc.p_x,
 		    	nodelist->rn_loc.p_y,nodenum++);
 	       }
-	       MALLOC(char *,tmpname,strlen(newname)+1);
+	       tmpname = (char *) mallocMagic((unsigned) (strlen(newname)+1));
 	       strcpy(tmpname,newname);
 	       nodelist->rn_name = tmpname;
 	  }
