@@ -20,24 +20,25 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrChannel.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
-#include "main/main.h"
+#include "utils/signals.h"
+#include "utils/main.h"
 #include "router/router.h"
 #include "router/rtrDcmpose.h"
 #include "grouter/grouter.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 /*
  * Maps a tile pointer to a channel structure.
@@ -60,7 +61,9 @@ float RtrEndConst;	/* Sun lint brain death */
 #endif	/* lint */
 
 /* Forward declarations */
-int rtrChannelObstacleMark();
+extern int rtrChannelObstacleMark();
+extern void rtrChannelObstaclePins();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -82,7 +85,7 @@ int rtrChannelObstacleMark();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrChannelRoute(ch, pCount)
     GCRChannel *ch;
     int *pCount;
@@ -206,7 +209,7 @@ bottom:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrChannelBounds(loc, pLength, pWidth, origin)
     Rect *loc;		/* Area the channel is to occupy */
     int *pLength;	/* Filled in with # columns in channel */
@@ -277,7 +280,7 @@ RtrChannelBounds(loc, pLength, pWidth, origin)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrChannelObstacles(use, ch)
     CellUse *use;
     GCRChannel * ch;
@@ -333,12 +336,12 @@ RtrChannelObstacles(use, ch)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 rtrChannelObstaclePins(ch)
-    register GCRChannel *ch;
+    GCRChannel *ch;
 {
-    register short **res;
-    register int row, col, end;
+    short **res;
+    int row, col, end;
 
     res = ch->gcr_result;
     end = ch->gcr_length + 1;
@@ -408,12 +411,12 @@ rtrChannelObstacleMark(tile, cxp)
     Tile *tile;
     TreeContext *cxp;
 {
-    register short **mcol, *mrow, *mrowend, mask;
-    register GCRChannel *ch = (GCRChannel *) cxp->tc_filter->tf_arg;
+    short **mcol, *mrow, *mrowend, mask;
+    GCRChannel *ch = (GCRChannel *) cxp->tc_filter->tf_arg;
     TileType type = TiGetType(tile);
     int loX, numX, loY;
     short **mcolend;
-    register int n;
+    int n;
     Rect r, r2;
 
     mask = 0;
@@ -504,12 +507,12 @@ rtrChannelObstacleMark(tile, cxp)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrChannelDensity(ch)
     GCRChannel *ch;
 {
-    register short *hdens, *vdens, *rptr;
-    register int col, density;
+    short *hdens, *vdens, *rptr;
+    int col, density;
     short *hdend, *vdend;
 
     /*
@@ -577,12 +580,12 @@ RtrChannelDensity(ch)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrChannelCleanObstacles(ch)
-    register GCRChannel *ch;
+    GCRChannel *ch;
 {
-    register short *rptr;
-    register int row, rtop;
+    short *rptr;
+    int row, rtop;
     int col, ctop;
 
     ctop = ch->gcr_length + 1;
