@@ -27,8 +27,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/routeCmd.c,v 1.0 20
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
-#include "misc/styles.h"
+#include "utils/magic.h"
+#include "utils/styles.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -36,13 +36,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/routeCmd.c,v 1.0 20
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/txcommands.h"
 #include "select/select.h"
 #include "commands/commands.h"
 #include "utils/heap.h"
 #include "router/router.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "netmenu/netmenu.h"
 #include "gcr/gcr.h"
 #include "grouter/grouter.h"
