@@ -35,7 +35,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrHazards.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "gcr/gcr.h"
@@ -206,11 +207,11 @@ RtrHazards(ch)
     maxcol = ch->gcr_length + 1;
     for (col = 0; col <= maxcol; col++)
     {
-	FREE((char *) height[col]);
-	FREE((char *) width[col]);
+	freeMagic((char *) height[col]);
+	freeMagic((char *) width[col]);
     }
-    FREE((char *) height);
-    FREE((char *) width);
+    freeMagic((char *) height);
+    freeMagic((char *) width);
 }
 
 /*
@@ -244,10 +245,10 @@ rtrHeights(ch)
      */
     lenWds = ch->gcr_length + 2;
     widWds = ch->gcr_width + 2;
-    MALLOC(short **, heights, lenWds * sizeof (short *));
+    heights = (short **) mallocMagic((unsigned) (lenWds * sizeof (short *)));
     for (col = 0; col < (int) lenWds; col++)
     {
-	MALLOC(short *, heights[col], widWds * sizeof (short));
+	heights[col] = (short *) mallocMagic((unsigned) (widWds * sizeof (short)));
 	for (row = 0; row < (int) widWds; row++)
 	    heights[col][row] = 0;
     }
@@ -316,10 +317,10 @@ rtrWidths(ch)
      */
     lenWds = ch->gcr_length + 2;
     widWds = ch->gcr_width + 2;
-    MALLOC(short **, widths, lenWds * sizeof (short *));
+    widths = (short **) mallocMagic((unsigned) (lenWds * sizeof (short *)));
     for (col = 0; col < (int) lenWds; col++)
     {
-	MALLOC(short *, widths[col], widWds * sizeof (short));
+	widths[col] =  (short *) mallocMagic((unsigned) (widWds * sizeof (short)));
 	for (row = 0; row < (int) widWds; row++)
 	    widths[col][row] = 0;
     }
