@@ -19,29 +19,38 @@
 
 #ifndef lint
 static char rcsid[]="$Header: /ufs/repository/magic/router/rtrPaint.c,v 1.2 2001/01/12 22:13:18 jsolomon Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "gcr/gcr.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 
 int RtrViaLimit		= 2;
 int rtrMetalLength	= 0;
 int rtrPolyLength	= 0;
 int rtrViaCount		= 0;
 bool RtrDoMMax		= TRUE;
+
+/* Forward declarations */
+
+extern void rtrPaintRows();
+extern void rtrPaintColumns();
+extern void rtrMaxMetal();
+
+bool rtrMetalOkay();
+bool rtrDoVia();
 
 /*
  * ----------------------------------------------------------------------------
@@ -58,6 +67,8 @@ bool RtrDoMMax		= TRUE;
  *	paint is added to the edit cell.
  * ----------------------------------------------------------------------------
  */
+
+void
 RtrPaintBack(ch, def)
     GCRChannel * ch;
     CellDef *def;
@@ -87,13 +98,14 @@ RtrPaintBack(ch, def)
  * ----------------------------------------------------------------------------
  */
 
+void
 rtrPaintRows(def, ch)
     CellDef *def;	/* Def into which paint will go */
     GCRChannel *ch;	/* Channel being painted */
 {
     TileType curType, nextType;
-    register short **result, code;
-    register int row, col;
+    short **result, code;
+    int row, col;
     Rect paint, contact;
     PaintUndoInfo ui;
 
@@ -214,6 +226,7 @@ rtrPaintRows(def, ch)
  * ----------------------------------------------------------------------------
  */
 
+void
 rtrPaintColumns(def, ch)
     CellDef * def;
     GCRChannel * ch;
@@ -321,13 +334,15 @@ rtrPaintColumns(def, ch)
  *
  * ----------------------------------------------------------------------------
  */
+
+bool
 rtrDoVia(ch, col, row)
     GCRChannel *ch;	/* The channel undergoing display */
-    register int col;	/* The x coordinate of the location considered */
-    register int row;	/* The y coordinate of the location considered */
+    int col;	/* The x coordinate of the location considered */
+    int row;	/* The y coordinate of the location considered */
 {
     short up, down, left, right, mask;
-    register short **result, code;
+    short **result, code;
 
     result = ch->gcr_result;
     code = result[col][row];
@@ -411,7 +426,7 @@ rtrDoVia(ch, col, row)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 rtrMaxMetal(ch)
     GCRChannel * ch;
 {
@@ -556,9 +571,9 @@ rtrMetalOkay(ch, col, dir)
     int col;		/* The crossing column in the originating channel */
     int dir;		/* Direction of the crossing NORTH or SOUTH */
 {
-    register GCRChannel *newCh;
-    register GCRPin *pin;
-    register short flags;
+    GCRChannel *newCh;
+    GCRPin *pin;
+    short flags;
     int newCol;
 
     switch (dir)
