@@ -22,23 +22,28 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/rtrPin.c,v 1.2 2001
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "debug/debug.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "textio/textio.h"
+
+/* Forward declarations */
+bool rtrPinArrayBlock();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -69,7 +74,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/rtrPin.c,v 1.2 2001
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrPinsInit(ch)
     GCRChannel *ch;
 {
@@ -79,13 +84,13 @@ RtrPinsInit(ch)
     rtrPinArrayInit(ch, GEO_EAST, ch->gcr_rPins, ch->gcr_width);
 }
 
-Void
+int
 rtrPinArrayInit(ch, side, pins, nPins)
     GCRChannel *ch;
     GCRPin *pins;
     int nPins;
 {
-    register GCRPin *pin, *linked;
+    GCRPin *pin, *linked;
     GCRChannel *adjacent;
     GCRPin *lastPin;
     Point point, p;
@@ -202,11 +207,11 @@ rtrPinArrayInit(ch, side, pins, nPins)
 
 GCRPin *
 RtrPointToPin(ch, side, point)
-    register GCRChannel *ch;	/* The channel containing the point */
+    GCRChannel *ch;	/* The channel containing the point */
     int side;			/* Side of ch that point lies on */
-    register Point *point;	/* The point to be converted to a pin */
+    Point *point;	/* The point to be converted to a pin */
 {
-    register int coord;
+    int coord;
 
     switch (side)
     {
@@ -303,7 +308,7 @@ rtrPinArrayBlock(ch, pins, opins, nPins)
     int nPins;		/* Number of internal pins (not counting pins[0]) */
 {
     bool changed, isRiver = (ch->gcr_type != CHAN_NORMAL);
-    register GCRPin *pin, *opin, *linked;
+    GCRPin *pin, *opin, *linked;
     GCRPin *lastPin;
 
     changed = FALSE;
@@ -352,7 +357,7 @@ rtrPinArrayBlock(ch, pins, opins, nPins)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrPinsLink(ch)
     GCRChannel *ch;
 {
@@ -362,12 +367,12 @@ RtrPinsLink(ch)
     rtrPinArrayLink(ch->gcr_rPins, ch->gcr_width);
 }
 
-Void
+int
 rtrPinArrayLink(pins, nPins)
     GCRPin *pins;
     int nPins;
 {
-    register GCRPin *pin, *lastPin, *lastValid;
+    GCRPin *pin, *lastPin, *lastValid;
 
     lastPin = &pins[nPins];
     lastValid = pins;
@@ -452,7 +457,7 @@ rtrPinShow(pin)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrPinsFixStems(ch)
     GCRChannel *ch;
 {
@@ -462,12 +467,12 @@ RtrPinsFixStems(ch)
     rtrPinArrayFixStems(ch->gcr_rPins, ch->gcr_width);
 }
 
-Void
+int
 rtrPinArrayFixStems(pins, nPins)
     GCRPin *pins;
     int nPins;
 {
-    register GCRPin *pin, *lastPin;
+    GCRPin *pin, *lastPin;
 
     lastPin = &pins[nPins];
     for (pin = pins + 1; pin <= lastPin; pin++)
