@@ -23,10 +23,10 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrSide.c,v 1.2 2001/
 
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "utils/malloc.h"
 #include "debug/debug.h"
@@ -37,8 +37,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrSide.c,v 1.2 2001/
 #include "grouter/grouter.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
-#include "main/main.h"
-#include "signals/signals.h"
+#include "utils/main.h"
+#include "utils/signals.h"
 
 /*
  * Local data used for communicating with filter functions.
@@ -313,16 +313,16 @@ rtrSideInitClient(tile, client)
 
 int
 rtrEnumSidesFunc(tile)
-    register Tile *tile;
+    Tile *tile;
 {
     int ybot, ytop, yprev, sep, x, origin;
-    register Tile *tp, *tpB;
+    Tile *tp, *tpB;
     Side side;
 
     /* Skip if already processed, out of the area, or not a cell tile */
     yprev = (int) tile->ti_client;
     ybot = MAX(BOTTOM(tile), rtrSideArea.r_ybot);
-    if (yprev <= ybot || tile->ti_body == NULL
+    if (yprev <= ybot || tile->ti_body == (ClientData) NULL
 	    || RIGHT(tile) >= rtrSideArea.r_xtop)
 	return (0);
 
@@ -401,7 +401,7 @@ rtrEnumSidesFunc(tile)
      */
     ytop = MIN(TOP(tile), TOP(tp));
     ytop = MIN(ytop, yprev);
-    while (tp->ti_body == NULL && TOP(tp) > rtrSideArea.r_ybot
+    while (tp->ti_body == (ClientData) NULL && TOP(tp) > rtrSideArea.r_ybot
 			       && LEFT(tp) == RIGHT(tile)
 			       && RIGHT(tp) >= x)
     {
@@ -428,7 +428,7 @@ rtrEnumSidesFunc(tile)
     {
 	if (TOP(tp) > ybot)
 	{
-	    if (tp->ti_body == NULL)
+	    if (tp->ti_body == (ClientData) NULL)
 	    {
 		if (side.side_line.r_ytop > side.side_line.r_ybot)
 		    if (rtrSidePassToClient(&side))
@@ -472,7 +472,7 @@ rtrEnumSidesFunc(tile)
 
 int
 rtrSidePassToClient(side)
-    register Side *side;
+    Side *side;
 {
     side->side_search.r_ybot = side->side_line.r_ybot;
     side->side_search.r_ytop = side->side_line.r_ytop;
