@@ -25,16 +25,17 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrTravers.c,v 1.2 20
 
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 #include "router/router.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "gcr/gcr.h"
 #include "router/routerInt.h"
 
@@ -59,7 +60,7 @@ int	rtrDelta;			/* Change in layer width		*/
 struct conSrArg
 {
     CellDef *csa_def;			/* Definition being searched. */
-    Plane *csa_plane;			/* Current plane being searched. */
+    int csa_pNum;			/* Index of plane being searched. */
     TileTypeBitMask *csa_connect;	/* Table indicating what connects
 					 * to what.
 					 */
@@ -192,7 +193,7 @@ rtrSrTraverse(def, startArea, mask, connect, bounds, func, clientData)
     csa.csa_clientData = clientData;
     csa.csa_clear = FALSE;
     csa.csa_connect = connect;
-    csa.csa_plane = def->cd_planes[startPlane];
+    csa.csa_pNum = startPlane;
 
     ts.ts_tile = (Tile *) NULL;
     ts.ts_link = (struct rtrTileStack *) NULL;
@@ -208,7 +209,7 @@ rtrSrTraverse(def, startArea, mask, connect, bounds, func, clientData)
     SigDisableInterrupts();
     csa.csa_clientFunc = NULL;
     csa.csa_clear = TRUE;
-    csa.csa_plane = def->cd_planes[startPlane];
+    csa.csa_pNum = startPlane;
     (void) rtrSrTraverseFunc(startTile, &ts);
     SigEnableInterrupts();
 
@@ -265,6 +266,7 @@ rtrSrTraverseFunc(tile, ts)
     Rect tileArea;
     int i;
     TileTypeBitMask *connectMask;
+    TileType ttype;
     unsigned int planes;
     struct conSrArg *csa = ts->ts_csa;
     struct rtrTileStack nts;
@@ -274,6 +276,7 @@ rtrSrTraverseFunc(tile, ts)
     nts.ts_link = ts;
 
     TiToRect(tile, &tileArea);
+    ttype = TiGetType(tile);
 
     /* Make sure this tile overlaps the area we're interested in. */
 
@@ -307,7 +310,7 @@ rtrSrTraverseFunc(tile, ts)
      * recursively.
      */
     
-    connectMask = &csa->csa_connect[TiGetType(tile)];
+    connectMask = &csa->csa_connect[ttype];
 
     /* Left side: */
 
@@ -375,7 +378,8 @@ rtrSrTraverseFunc(tile, ts)
      * other planes.  If so, search those planes.
      */
     
-    planes = DBConnPlanes[TiGetType(tile)];
+    planes = DBConnPlanes[ttype];
+    planes &= ~(csa->csa_pNum);
     if (planes != 0)
     {
         struct conSrArg newcsa;
@@ -384,10 +388,12 @@ rtrSrTraverseFunc(tile, ts)
 	nts.ts_csa = &newcsa;
 	for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
 	{
-	    newcsa.csa_plane = newcsa.csa_def->cd_planes[i];
-	    if (DBSrPaintArea((Tile *) NULL, newcsa.csa_plane,
-		&tileArea, connectMask, rtrSrTraverseFunc,
-		(ClientData) &nts) != 0) return 1;
+	    newcsa.csa_pNum = i;
+	    if (DBSrPaintArea((Tile *) NULL,
+			newcsa.csa_def->cd_planes[i],
+			&tileArea, connectMask, rtrSrTraverseFunc,
+			(ClientData) &nts) != 0)
+		return 1;
 	}
     }
 
@@ -479,9 +485,9 @@ rtrExamineStack(tile, ts)
 	 * Identify pattern  --  *via*   *replacement_material*   *via*
 	 */
 
-	if ( DBConnPlanes[TiGetType(tp[0])] &&
+	if ( DBIsContact(TiGetType(tp[0])) &&
 	     (TiGetType(tp[1]) == rtrReplace) &&
-	     DBConnPlanes[TiGetType(tp[2])] )
+	     DBIsContact(TiGetType(tp[2])))
 	{
 	    int plane;
 	    Rect area;
