@@ -12,7 +12,7 @@
 #include <string.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -21,9 +21,8 @@
 #include "database/database.h"
 #include "windows/windows.h"
 #include "commands/commands.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "dbwind/dbwind.h"
-
 #include "router/router.h"
 #include "gcr/gcr.h"
 #include "grouter/grouter.h"
