@@ -18,22 +18,26 @@
 
 #ifndef lint
 static char rcsid[]="$Header: /ufs/repository/magic/select/selCreate.c,v 1.6 2001/07/30 17:16:22 tim Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "commands/commands.h"
 #include "select/selInt.h"
+#include "select/select.h"
 #include "drc/drc.h"
-#include "main/main.h"
-#include "signals/signals.h"
+#include "utils/main.h"
+#include "utils/signals.h"
 
 /* Two cells worth of information are kept around by the selection
  * module.  SelectDef and SelectUse are for the cells whose contents
@@ -67,10 +71,6 @@ CellDef *SelectRootDef = NULL;
 
 global CellUse *selectLastUse = NULL;
 
-/* The following variable is used by select, so it is defined outside	*/
-/* the plow module, so the plow module can be self-contained.		*/
-
-extern TileTypeBitMask PlowFixedTypes;
 
 /*
  * ----------------------------------------------------------------------------
@@ -131,8 +131,6 @@ SelectInit()
     UndoEnable();
 
     SelUndoInit();
-
-    PlowFixedTypes = DBZeroTypeBits;
 }
 
 /*
@@ -169,45 +167,55 @@ SelectClear()
     if (SelectRootDef == NULL) return;
 
     scx.scx_area = SelectDef->cd_bbox;
-    SelRememberForUndo(TRUE, (CellDef *) NULL, (Rect *) NULL);
 
-    /* Erase all the paint from the select cell. */
-
-    DBEraseMask(SelectDef, &TiPlaneRect, &DBAllButSpaceBits);
-
-    /* Erase all of the labels from the select cell. */
-
-    (void) DBEraseLabel(SelectDef, &TiPlaneRect, &DBAllTypeBits);
-
-    /* Erase all of the subcells from the select cell.  This is a bit tricky,
-     * because we can't erase the subcells while searching for them (it will
-     * cause problems for the database).  The code below first grabs up a
-     * few subcells, then deletes them, then grabs up a few more, then deletes
-     * them, and so on until done.
-     */
-
-    scx.scx_use = SelectUse;
-    scx.scx_trans = GeoIdentityTransform;
-    while (TRUE)
+    if (!strcmp(SelectDef->cd_name, "__SELECT_NET__"))
     {
-	int i;
-
-	selNDelete = 0;
-	(void) DBCellSrArea(&scx, selClearFunc, (ClientData) NULL);
-	for (i = 0; i < selNDelete; i += 1)
-	{
-	    DBUnLinkCell(selDeleteUses[i], SelectDef);
-	    DBDeleteCell(selDeleteUses[i]);
-	    (void) DBCellDeleteUse(selDeleteUses[i]);
-	}
-	if (selNDelete < MAXUSES) break;
+	SelNetRememberForUndo((CellDef *)NULL, (Point *)NULL,
+		TT_SPACE, FALSE, FALSE);
+	DBCellRenameDef(SelectDef, "__SELECT__");
+	DBCellClearDef(SelectDef);
     }
+    else
+    {
+	SelRememberForUndo(TRUE, (CellDef *) NULL, (Rect *) NULL);
 
-    selectLastUse = NULL;
+	/* Erase all the paint from the select cell. */
+
+	DBEraseMask(SelectDef, &TiPlaneRect, &DBAllButSpaceBits);
+
+	/* Erase all of the labels from the select cell. */
+
+	(void) DBEraseLabel(SelectDef, &TiPlaneRect, &DBAllTypeBits);
+
+	/* Erase all of the subcells from the select cell.  This is a bit tricky,
+	 * because we can't erase the subcells while searching for them (it will
+	 * cause problems for the database).  The code below first grabs up a
+	 * few subcells, then deletes them, then grabs up a few more, then deletes
+	 * them, and so on until done.
+	 */
+
+	scx.scx_use = SelectUse;
+	scx.scx_trans = GeoIdentityTransform;
+	while (TRUE)
+	{
+	    int i;
+
+	    selNDelete = 0;
+	    (void) DBCellSrArea(&scx, selClearFunc, (ClientData) NULL);
+	    for (i = 0; i < selNDelete; i += 1)
+	    {
+		DBUnLinkCell(selDeleteUses[i], SelectDef);
+		DBDeleteCell(selDeleteUses[i]);
+		(void) DBCellDeleteUse(selDeleteUses[i]);
+	    }
+	    if (selNDelete < MAXUSES) break;
+	}
+	selectLastUse = NULL;
+	SelRememberForUndo(FALSE, SelectRootDef, &scx.scx_area);
+    }
 
     /* Erase the selection from the screen. */
 
-    SelRememberForUndo(FALSE, SelectRootDef, &scx.scx_area);
     DBWHLRedraw(SelectRootDef, &scx.scx_area, TRUE);
     DBReComputeBbox(SelectDef);
     DBWAreaChanged(SelectDef, &scx.scx_area, DBW_ALLWINDOWS,
@@ -315,136 +323,7 @@ SelectArea(scx, types, xMask)
     DBWAreaChanged(SelectDef, &SelectDef->cd_bbox, DBW_ALLWINDOWS,
 	&DBAllButSpaceBits);
 }
-
-/*
- * ----------------------------------------------------------------------------
- *
- * selGetLabels --
- *
- * 	This is a local procedure used to extract all the labels
- *	associated with the paint in Select2Def.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Labels are added to SelectDef for all labels in the hierarchy
- *	under rootUse that are visible (according to xMask), and
- *	for which there is connected material in Select2Def.
- *
- * ----------------------------------------------------------------------------
- */
 
-void
-selGetLabels(rootUse, xMask)
-    CellUse *rootUse;	/* Hierarchy to search for visible labels. */
-    int xMask;		/* Indicates windows where cells must be expanded
-			 * in order for their labels to be copied.
-			 */
-{
-    SearchContext scx;
-
-    /* This procedure duplicates much of the code of DBTreeSrLabels.
-     * However, it is much more efficient in some cases because it
-     * only checks a subtree if Select2Def contains some paint in
-     * the area of the subtree.  If a very large L-shaped net has
-     * been selected, this could drastically reduce the amount of
-     * searching that must be done to find labels.
-     */
-    
-    scx.scx_use = rootUse;
-    scx.scx_area = Select2Def->cd_bbox;
-    scx.scx_trans = GeoIdentityTransform;
-
-    (void) selLabelCellFunc(&scx, xMask);
-}
-
-/* The procedure below does all the work of getting labels.  It's
- * called from above, and also indirectly by itself, through
- * DBCellSrArea.
- */
-
-int
-selLabelCellFunc(scx, xMask)
-    SearchContext *scx;		/* Area and cell we're currently searching. */
-    int xMask;			/* Indicates window where cell must be
-				 * expanded.
-				 */
-{
-    Label *lab;
-    CellDef *def;
-    int i;
-    Rect rootArea;
-    extern int selLabelPaintFunc();
-
-    /* No point in checking this cell, its children, or its siblings
-     * in an array if it isn't expanded.
-     */
-
-    if (!DBIsExpand(scx->scx_use, xMask)) return 2;
-
-    /* Make sure that there's some material in Select2Def under
-     * the area we're searching.  Otherwise there's no point
-     * in checking for labels.
-     */
-    
-    def = scx->scx_use->cu_def;
-    GeoTransRect(&scx->scx_trans, &def->cd_bbox, &rootArea);
-    for (i = PL_SELECTBASE; i < DBNumPlanes; i += 1)
-    {
-	if (DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[i], &rootArea,
-	    &DBAllButSpaceAndDRCBits, selLabelPaintFunc,
-	    (ClientData) NULL) != 0) goto checkCell;
-    }
-    return 0;
-
-    /* Make sure that the cell is in memory. */
-
-    checkCell:
-    if ((def->cd_flags & CDAVAILABLE) == 0)
-	if (!DBCellRead(def, (char *) NULL, TRUE)) return 2;
-
-    /* For each label in the cell, see if there is connected paint
-     * in Select2Def.  If so, add the label to SelectDef.  Ignore
-     * space labels here, since they can't possibly be connected
-     * to anything.
-     */
-
-    for (lab = def->cd_labels; lab != NULL; lab = lab->lab_next)
-    {
-	Rect area, searchArea;
-	int newPos;
-
-	if (lab->lab_type == TT_SPACE) continue;
-	GeoTransRect(&scx->scx_trans, &lab->lab_rect, &area);
-	newPos = GeoTransPos(&scx->scx_trans, lab->lab_pos);
-	GEO_EXPAND(&area, 1, &searchArea);
-	if (DBSrPaintArea((Tile *) NULL,
-	    Select2Def->cd_planes[DBPlane(lab->lab_type)],
-	    &searchArea, &DBConnectTbl[lab->lab_type], selLabelPaintFunc,
-	    (ClientData) NULL) == 0) continue;
-	DBEraseLabelsByContent(SelectDef, &area, newPos,
-	    -1, lab->lab_text);
-	(void) DBPutLabel(SelectDef, &area, newPos, lab->lab_text,
-	    lab->lab_type);
-    }
-
-    /* Now check subcells of this cell. */
-
-    (void) DBCellSrArea(scx, selLabelCellFunc, (ClientData) xMask);
-
-    return 0;
-}
-
-/* The function below returns 1 whenever called.  It is used to detect
- * when there is paint of particular types under a particular area.
- */
-
-int
-selLabelPaintFunc()
-{
-    return 1;
-}
 
 /*
  * ----------------------------------------------------------------------------
@@ -574,11 +453,11 @@ selFindChunk(plane, wrongTypes, searchArea, containedArea, bestMin,
 
 int
 selSplitFunc(tile, cxp)
-   register Tile *tile;
+   Tile *tile;
    TreeContext *cxp;
 {
-    register SearchContext *scx = cxp->tc_scx;
-    register Rect *area = (Rect *) cxp->tc_filter->tf_arg;
+    SearchContext *scx = cxp->tc_scx;
+    Rect *area = (Rect *) cxp->tc_filter->tf_arg;
     Rect locarea;
 
     if (IsSplit(tile))
@@ -860,17 +739,21 @@ SelectRegion(scx, type, xMask, pArea, less)
 	scx2.scx_area = Select2Def->cd_bbox;
 	scx2.scx_trans = GeoIdentityTransform;
 	DBCellCopyAllPaint(&scx2, &DBAllButSpaceAndDRCBits,
-			   0, SelectUse);
-	
-	/* Grab relevant labels. */
-	
-	selGetLabels(scx->scx_use, xMask);
+			0, SelectUse);
+	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, -1, SelectUse,
+			(Rect *) NULL);
       }
 
     /* Display the new selection. */
 
     SelRememberForUndo(FALSE, SelectRootDef, &Select2Def->cd_bbox);
-    DBReComputeBbox(SelectDef);
+
+    /* SelectDef should not need to recompute the bounding box;	*/
+    /* only to copy it (transformed) from Select2Def.		*/
+    /* DBReComputeBbox(SelectDef); */
+    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
+    DBComputeUseBbox(SelectUse);
+
     DBWHLRedraw(SelectRootDef, &Select2Def->cd_bbox, TRUE);
     DBWAreaChanged(SelectDef, &Select2Def->cd_bbox, DBW_ALLWINDOWS,
 	 &DBAllButSpaceBits);
@@ -913,10 +796,13 @@ SelectNet(scx, type, xMask, pArea, less)
     Rect *pArea;		/* If non-NULL, points to rectangle to be
 				 * filled in with net's bounding box.
 				 */
-    bool less;
+    bool less;			/* Whether to remove material from the
+				 * selection using SelDeleteSel2
+				 */
 {
     TileTypeBitMask mask;
     SearchContext scx2;
+    Point savePoint = scx->scx_area.r_ll;
 
     /* If the source definition is changing, clear the old selection. */
 
@@ -941,32 +827,45 @@ SelectNet(scx, type, xMask, pArea, less)
 	    &TiPlaneRect, Select2Use);
     UndoEnable();
 
+    /* Network undo method added by Nishit and Tim, July 8-10, 2004 */
+    SelNetRememberForUndo(SelectRootDef, &savePoint, type, less, TRUE);
+
     /* Now transfer what we found into the main selection cell.  Pick
      * up all the labels that correspond to the selected material.
      */
     
-    SelRememberForUndo(TRUE, (CellDef *) NULL, (Rect *) NULL);
+    UndoDisable();
     if (less)
-      {
+    {
 	(void) SelRemoveSel2();
-      }
+    }
     else
-      {
+    {
 	scx2.scx_use = Select2Use;
 	scx2.scx_area = Select2Def->cd_bbox;
 	scx2.scx_trans = GeoIdentityTransform;
 	DBCellCopyAllPaint(&scx2, &DBAllButSpaceAndDRCBits,
 			   0, SelectUse);
-	
-	/* Grab relevant labels. */
-	
-	selGetLabels(scx->scx_use, xMask);
-      }
+	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, -1, SelectUse,
+			(Rect *) NULL);
+    }
+
+    /* Rename the cell to "__SELECT_NET__" so that we can treat */
+    /* it differently when it comes time to unselect it.	*/
+
+    DBCellRenameDef(SelectDef, "__SELECT_NET__");
+    UndoEnable(); 
 
     /* Display the newly-selected material. */
+    /* SelectDef should not need to recompute the bounding box;	*/
+    /* only to copy it (transformed) from Select2Def, and then	*/
+    /* transfer this bounding box to the use.			*/
+    /* ---Nishit, 7/6/04					*/
+    /* DBReComputeBbox(SelectDef); */
+
+    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
+    DBComputeUseBbox(SelectUse);
 
-    SelRememberForUndo(FALSE, SelectRootDef, &Select2Def->cd_bbox);
-    DBReComputeBbox(SelectDef);
     DBWHLRedraw(SelectRootDef, &Select2Def->cd_bbox, TRUE);
     DBWAreaChanged(SelectDef, &Select2Def->cd_bbox, DBW_ALLWINDOWS,
 	&DBAllButSpaceBits);
@@ -1145,6 +1044,7 @@ SelectAndCopy2(newSourceDef)
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selACPaintFunc,
 		(ClientData) plane);
     }
+
     (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, -1, SelectUse,
 	    &labelArea);
 
@@ -1174,6 +1074,14 @@ SelectAndCopy2(newSourceDef)
 	(TileTypeBitMask *) NULL);
 }
 
+/* Structure to hold information about an edit area, which may be
+ * a triangular region.
+ */
+typedef struct {
+    Rect *editClip;
+    TileType dinfo;
+} acparg;
+
 /* Utility function: for each tile, copy information over its area from
  * the given edit cell plane to SelectDef.  Always return 0 to keep the
  * search alive.
@@ -1185,88 +1093,164 @@ selACPaintFunc(tile, plane)
     int plane;			/* Index of plane this tile came from. */
 {
     Rect area, editArea;
+    acparg selACarg;
     int selACPaintFunc2();	/* Forward reference. */
 
     TiToRect(tile, &area);
+    /* we want editClip in root coordinates. . . */
+    selACarg.editClip = &area;
     GeoTransRect(&RootToEditTransform, &area, &editArea);
+
+#ifndef NONMANHATTAN
+    selACarg.dinfo = 0;
+#else
+    selACarg.dinfo = TiGetTypeExact(tile);
+
+    if (IsSplit(tile))
+    {
+	DBSrPaintNMArea((Tile *) NULL, EditCellUse->cu_def->cd_planes[plane],
+		selACarg.dinfo, &editArea, &DBAllButSpaceAndDRCBits,
+		selACPaintFunc2, (ClientData) &selACarg);
+    }
+    else
+#endif
     (void) DBSrPaintArea((Tile *) NULL, EditCellUse->cu_def->cd_planes[plane],
 	    &editArea, &DBAllButSpaceAndDRCBits, selACPaintFunc2,
-	    (ClientData) &editArea);
+	    (ClientData) &selACarg);
     return 0;
 }
 
 /* Second-level paint function:  just paint the overlap between
  * tile and editClip into SelectDef.
+ *
+ * This function is like dbCopyAllPaint() but differs just enough
+ * that a separate function is required.  However, much of the code 
+ * could be shared between the two functions if it were properly
+ * broken out into subroutines.
  */
 
 int
-selACPaintFunc2(tile, editClip)
+selACPaintFunc2(tile, selACarg)
     Tile *tile;			/* Tile in edit cell. */
-    Rect *editClip;		/* Edit-cell area to clip to before painting
-				 * into selection.
+    acparg *selACarg;		/* Contains edit-cell area to clip to
+				 * before painting into selection.
 				 */
 {
+    Rect *editClip = selACarg->editClip;
     Rect area, selArea;
-    TileType type;
+    TileType type = TiGetTypeExact(tile);
+
+#ifdef NONMANHATTAN
+    TileType dinfo = selACarg->dinfo & (TT_DIAGONAL | TT_DIRECTION | TT_SIDE);
+#endif
 
     TiToRect(tile, &area);
-    GeoClip(&area, editClip);
     GeoTransRect(&EditToRootTransform, &area, &selArea);
 
 #ifdef NONMANHATTAN
-    if (IsSplit(tile))  
+
+    if (dinfo & TT_DIAGONAL)
     {
-	if (SplitSide(tile))
-	    type = SplitRightType(tile);
+	/* If the select area is triangular, then we need to	*/
+	/* clip in a more complicated manner.			*/
+
+	Point points[5];
+	Rect rrect, orect;
+	int np, i, j;
+	TileType rtype;
+
+	if (type & TT_DIAGONAL)
+	    rtype = (type & TT_SIDE) ? SplitRightType(tile) :
+			SplitLeftType(tile);
 	else
-	    type = SplitLeftType(tile);
+	    rtype = type;
+
+	type = (dinfo & TT_SIDE) ? (rtype << 14) : rtype;
+	type |= dinfo;
+
+	GrClipTriangle(editClip, &selArea, TRUE, dinfo, points, &np);
+
+	if (np == 0)
+	    return 0;
+	if (np >= 3)
+	{
+	    for (i = 0; i < np; i++)
+	    {
+		j = (i + 1) % np;
+		if (points[i].p_x != points[j].p_x && points[i].p_y !=
+				points[j].p_y)
+		{
+		    /* Break out the triangle */
+		    rrect.r_xbot = points[i].p_x;
+		    rrect.r_xtop = points[j].p_x;
+		    rrect.r_ybot = points[i].p_y;
+		    rrect.r_ytop = points[j].p_y;
+		    GeoCanonicalRect(&rrect, &selArea);
+		    break;
+		}
+	    }
+	    if (i == np)  /* Exactly one Manhattan rectangle */
+	    {
+		rrect.r_xbot = points[0].p_x;
+		rrect.r_xtop = points[2].p_x;
+		rrect.r_ybot = points[0].p_y;
+		rrect.r_ytop = points[2].p_y;
+		GeoCanonicalRect(&rrect, &selArea);
+		type = rtype;
+	    }
+	    else if (np >= 4) /* Process extra rectangles in the area */
+	    {
+		/* "orect" is the bounding box of the polygon returned	*/
+		/* by ClipTriangle.					*/
+
+		orect.r_xtop = orect.r_xbot = points[0].p_x;
+		orect.r_ytop = orect.r_ybot = points[0].p_y;
+		for (i = 0; i < np; i++)
+		    GeoIncludePoint(&points[i], &orect);
+
+		/* Rectangle to left or right */
+		rrect.r_ybot = orect.r_ybot;
+		rrect.r_ytop = orect.r_ytop;
+		if (selArea.r_xbot > orect.r_xbot)
+		{
+		    rrect.r_xbot = orect.r_xbot;
+		    rrect.r_xtop = selArea.r_xbot;
+		}
+		else if (selArea.r_xtop < orect.r_xtop)
+		{
+		    rrect.r_xtop = orect.r_xtop;
+		    rrect.r_xbot = selArea.r_xtop;
+		}
+		else
+		    goto topbottom;
+
+		DBPaint(SelectDef, &rrect, rtype);
+topbottom:
+		/* Rectangle to top or bottom */
+		rrect.r_xbot = selArea.r_xbot;
+		rrect.r_xtop = selArea.r_xtop;
+		if (selArea.r_ybot > orect.r_ybot)
+		{
+		    rrect.r_ybot = orect.r_ybot;
+		    rrect.r_ytop = selArea.r_ybot;
+		}
+		else if (selArea.r_ytop < orect.r_ytop)
+		{
+		    rrect.r_ytop = orect.r_ytop;
+		    rrect.r_ybot = selArea.r_ytop;
+		}
+		else
+		    goto splitdone;
+
+		DBPaint(SelectDef, &rrect, rtype);
+	    }
+	}
     }
-    else 
-#endif
-
-    type = TiGetType(tile);
-    if (type >= DBNumUserLayers)
-    {
-        register TileType primary,first;
-        register typecount=0;
-
-        for (primary = TT_SELECTBASE; primary < DBNumUserLayers; primary++)
-        {
-            if (TTMaskHasType(&DBLayerTypeMaskTbl[primary], type))
-            {
-                  typecount++;
-                 first = primary;
-            }
-        }
-        if (typecount == 1)
-        {
-             type = first;
-        }
-        else  /* have to see what's down there  */
-        {
-
-             for (primary = TT_SELECTBASE; primary < DBNumUserLayers; primary++)
-             {
-                  if (TTMaskHasType(&DBLayerTypeMaskTbl[primary], type))
-                  {
-                       int      planenum = DBPlane(primary);
-                       Tile     *tp = EditCellUse->cu_def->cd_planes[planenum]->pl_hint;
-                       GOTOPOINT(tp,&(tile->ti_ll));
-                       if (TiGetType(tp) == primary)
-                       {
-                            type = primary;
-                            break;
-                       }
-                  }
-             }
-        }
-    }
-
-#ifdef NONMANHATTAN
-    if (IsSplit(tile))
-	type = TiGetTypeExact(tile);
+    else
 #endif
+    GeoClip(&selArea, editClip);	/* editClip already in root coords */
 
+splitdone:
     DBPaint(SelectDef, &selArea, type);
     return 0;
 }
