@@ -21,7 +21,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/select/selDisplay.c,v 1.7 20
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -29,9 +30,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/select/selDisplay.c,v 1.7 20
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* The current selection is displayed by displaying the outline of
  * shapes in one cell as an overlay (using the higlight facilities)
@@ -78,7 +79,7 @@ static Plane *selRedisplayPlane;
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 SelRedisplay(window, plane)
     MagWindow *window;		/* Window in which to redisplay. */
     Plane *plane;		/* Non-space tiles on this plane indicate
@@ -176,7 +177,7 @@ selRedisplayFunc(tile, window)
     MagWindow *window;		/* Window in which to redisplay. */
 {
     Rect area, edge, screenEdge;
-    register Tile *neighbor;
+    Tile *neighbor;
     TileType loctype, ntype;
 
     TiToRect(tile, &area);
@@ -198,11 +199,10 @@ selRedisplayFunc(tile, window)
 	/* Use GrDrawTriangleEdge() so that clipping for area select     */
 	/* draws the correct line.					 */
 
-	WindSurfaceToScreen(window, &area, &screenEdge);
+	WindSurfaceToScreenNoClip(window, &area, &screenEdge);
 	if (screenEdge.r_ll.p_x != screenEdge.r_ur.p_x &&
 		screenEdge.r_ll.p_y != screenEdge.r_ur.p_y)
-	    GrDrawTriangleEdge(&screenEdge, (int)SplitDirection(tile),
-		(int)SplitSide(tile));
+	    GrDrawTriangleEdge(&screenEdge, TiGetTypeExact(tile));
 	loctype = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
     }
     else
@@ -217,8 +217,8 @@ selRedisplayFunc(tile, window)
     if (area.r_ybot > TiPlaneRect.r_ybot)
     {
 	edge.r_ybot = edge.r_ytop = area.r_ybot;
-	for (neighbor = tile->ti_lb; LEFT(neighbor) < area.r_xtop;
-		neighbor = neighbor->ti_tr)
+	for (neighbor = LB(tile); LEFT(neighbor) < area.r_xtop;
+		neighbor = TR(neighbor))
 	{
 #ifdef NONMANHATTAN
 	    ntype = TiGetTopType(neighbor);
@@ -248,8 +248,8 @@ searchleft:
     if (area.r_xbot > TiPlaneRect.r_xbot)
     {
 	edge.r_xbot = edge.r_xtop = area.r_xbot;
-	for (neighbor = tile->ti_bl; BOTTOM(neighbor) < area.r_ytop;
-		neighbor = neighbor->ti_rt)
+	for (neighbor = BL(tile); BOTTOM(neighbor) < area.r_ytop;
+		neighbor = RT(neighbor))
 	{
 #ifdef NONMANHATTAN
 	    ntype = TiGetRightType(neighbor);
