@@ -24,13 +24,15 @@ static char rcsid[]="$Header: /ufs/repository/magic/select/selEnum.c,v 1.3 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "select/select.h"
 #include "select/selInt.h"
 #include "utils/malloc.h"
@@ -261,7 +263,7 @@ selEnumPFunc2(tile, arg)
     struct searg *arg;		/* Describes our search. */
 {
     LinkedRect *lr;
-    register ttype;
+    int ttype;
     TileType loctype;
 
 #ifdef NONMANHATTAN
@@ -598,7 +600,7 @@ SelEnumLabels(layers, editOnly, foundNonEdit, func, clientData)
     int (*func)();		/* Function to call for each label found. */
     ClientData clientData;	/* Argument to pass through to func. */
 {
-    register Label *selLabel;
+    Label *selLabel;
     CellUse dummy;
     SearchContext scx;
     struct searg arg;
