@@ -22,18 +22,19 @@ static char rcsid[]="$Header: /ufs/repository/magic/select/selOps.c,v 1.4 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "select/select.h"
 #include "select/selInt.h"
 #include "textio/textio.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "plow/plow.h"
 #include "utils/malloc.h"
 #include "drc/drc.h"
@@ -133,6 +134,24 @@ selDelPaintFunc(rect, type)
 {
     Rect editRect;
 
+#ifdef NONMANHATTAN
+    TileType newtype;
+
+    /* Change diagonal direction according to the transform */
+
+    if (type & TT_DIAGONAL)
+    {
+	TileType dinfo = DBTransformDiagonal(type, &RootToEditTransform);
+
+	if ((type & TT_SIDE) != (dinfo & TT_SIDE))
+	    newtype = dinfo | ((type & TT_LEFTMASK) << 14) |
+                        ((type & TT_RIGHTMASK) >> 14);
+	else
+	    newtype = dinfo | (type & (TT_LEFTMASK | TT_RIGHTMASK));
+	type = newtype;
+    }
+#endif
+
     GeoTransRect(&RootToEditTransform, rect, &editRect);
     DBErase(EditCellUse->cu_def, &editRect, type);
     return 0;
@@ -264,9 +283,10 @@ selTransPaintFunc(rect, type, transform)
     Transform *transform;	/* How to change coords before painting. */
 {
     Rect newarea;
-    TileType newtype = type;
 
 #ifdef NONMANHATTAN
+    TileType newtype;
+
     /* Change diagonal direction according to the transform */
 
     if (type & TT_DIAGONAL)
@@ -278,11 +298,12 @@ selTransPaintFunc(rect, type, transform)
                         ((type & TT_RIGHTMASK) >> 14);
 	else
 	    newtype = dinfo | (type & (TT_LEFTMASK | TT_RIGHTMASK));
+	type = newtype;
     }
 #endif
 
     GeoTransRect(transform, rect, &newarea);
-    DBPaint(Select2Def, &newarea, newtype);
+    DBPaint(Select2Def, &newarea, type);
     return 0;
 }
 
@@ -719,7 +740,7 @@ SelectStretch(x, y)
     {
 	(void) DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[plane],
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selStretchEraseFunc,
-		(ClientData) NULL);
+		(ClientData) &plane);
     }
 
     /* To achieve the stretch affect, fill in material behind the selection
@@ -734,7 +755,7 @@ SelectStretch(x, y)
     {
 	(void) DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[plane],
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selStretchFillFunc,
-		(ClientData) NULL);
+		(ClientData) &plane);
     }
 
     /* Paint back the areas in the list. */
@@ -775,12 +796,21 @@ SelectStretch(x, y)
  */
 
 int
-selStretchEraseFunc(tile)
+selStretchEraseFunc(tile, plane)
     Tile *tile;			/* Tile being moved in a stretch operation. */
+    int *plane;			/* Plane of tiles being searched */
 {
     Rect area, editArea;
-    TileType type;
+    int planeNum;
+    TileType type, t;
+    TileTypeBitMask *typeResidueMask, *connectMask, tmpmask, mask;
 
+#ifdef NONMANHATTAN
+    if (IsSplit(tile))
+	type = (SplitSide(tile)) ? SplitRightType(tile) :
+			SplitLeftType(tile);
+    else
+#endif
     type = TiGetType(tile);
 
     TiToRect(tile, &area);
@@ -801,19 +831,117 @@ selStretchEraseFunc(tile)
      * tile's plane.
      */
 
+    GeoTransRect(&RootToEditTransform, &area, &editArea);
+ 
+    /* Was previously DBEraseMask(), and needs to be again to avoid	*/
+    /* quirky behavior.  However, the DBErase() call is worse.  We need	*/
+    /* to erase all types that interact with "type", *not* all types on	*/
+    /* "plane", due to the way stacked contacts are handled.  But	*/
+    /* contacts on different planes may stretch across one another	*/
+    /* without effect, if the types are stackable.  So, getting the	*/
+    /* correct mask is not so simple.					*/
+
+    /* DBEraseMask(EditCellUse->cu_def, &editArea, &DBPlaneTypes[*plane]); */
+    /* DBErase(EditCellUse->cu_def, &editArea, type); */
+
+    /* Routine modified by Nishit; code below written 9/28/2004, added	*/
+    /* 10/14/04								*/
+
     /*
-     * Stacking contact types do not get erased
+     *   Process mask first
      */
 
-    GeoTransRect(&RootToEditTransform, &area, &editArea);
+    planeNum = *plane;
+    typeResidueMask = DBResidueMask(type);
+    mask = DBPlaneTypes[planeNum];
+    connectMask = &DBConnectTbl[type];
+    for (t = TT_SPACE + 1; t < DBNumTypes; t++)
+    {
+	/* Process all tile types that exist on plane
+	 * "planeNum" (except the current one, as we want
+	 *  to erase that type of tile from the layout).
+	 */
+	if (TTMaskHasType(&mask, t) && (t != type))
+	{
+	    if (DBIsContact(t))
+	    {
+	        /* While stretching non-contact material
+	         * we would not process residue type of "t".
+	         * Because that may remove mask of "type" from
+	         * "mask" which would untouch that material in
+	         * stretching path.
+	         */
+		if (DBIsContact(type))
+	        {
+		     tmpmask = *DBResidueMask(t);
+	             if (!TTMaskIsZero(typeResidueMask) &&
+	                	!TTMaskIsZero(&tmpmask))
+                        TTMaskAndMask3(&tmpmask, typeResidueMask, &tmpmask);
 
-    DBErase(EditCellUse->cu_def, &editArea, type);
+	             /* If t is stacked type then we would not
+	              * remove its residue mask from "mask".
+	              */
+	             if (!TTMaskIsZero(&tmpmask) && (t < DBNumUserLayers))
+	                 TTMaskClearMask(&mask, &tmpmask);
+	         }
+	
+                 /* If tile type "t" connects to tile "type"
+                  * remove that type from mask. We would not
+                  * like to erase that type of tiles.
+                  */
+                 if (TTMaskHasType(connectMask, t))
+                 {
+                     /* In case "type" is a stacked type and both "t" and
+		      * "type" are on same plane, erase that tile (e.g.,
+		      * stack of 3 types selected)
+                      */
+                     if ((type < DBNumUserLayers) &&
+                        	(DBPlane(type) != DBPlane(t)))
+                          TTMaskClearType(&mask, t);
+                 }
+             }
+         }
+      }
 
-    /* Was previously DBEraseMask().  Don't know why.  If you trust the */
-    /* paint/erase tables, it should not be necessary to erase anything	*/
-    /* other than the type itself.					*/
+    /* For stacked type tiles do not erase common residue
+     * type of both contacts from layout.
+     */
 
-    /* DBEraseMask(EditCellUse->cu_def, &editArea, &DBPlaneTypes[DBPlane(type)]); */
+    if (type >= DBNumUserLayers)
+    {
+        t = (DBPlaneToResidue(type, planeNum));
+        TTMaskClearType(&mask, t);
+    }
+
+    /*
+     *   Erase all tile types specified in the processed mask.
+     */
+    	
+    /* New DBEraseMask() routine for stretching. */
+    /* TODO : Placed here just for checking funtionality.
+     * Once works properly shift to DBtcontact.c.
+     */
+    {
+       /* Erase contacts first from mask . Because if you
+        * erase one type of tile from contact first then you
+        * can't remove that contact completely as its residue
+        * type remains on other plane. And that will stay for ever !
+        */
+
+       if (DBIsContact(type))
+       {
+           for (t = TT_SPACE + 1; t < DBNumUserLayers; t++)
+	       if (TTMaskHasType(&mask, t) && DBIsContact(t))
+	           DBErase(EditCellUse->cu_def, &editArea, t);
+       }
+       for (t = TT_SPACE + 1; t < DBNumUserLayers; t++)
+           if (TTMaskHasType(&mask, t) && !DBIsContact(t))
+	        DBErase(EditCellUse->cu_def, &editArea, t);
+    }
+
+    /*
+     *   Completed.
+     */
 
     return 0;
 }
@@ -838,8 +966,9 @@ selStretchEraseFunc(tile)
  */
 
 int
-selStretchFillFunc(tile)
+selStretchFillFunc(tile, plane)
     Tile *tile;			/* Tile in the old selection. */
+    int *plane;			/* Plane of tile being searched */
 {
     Rect area;
     extern int selStretchFillFunc2();
@@ -896,7 +1025,7 @@ selStretchFillFunc(tile)
      */
 
     (void) DBSrPaintArea((Tile *) NULL,
-	    Select2Def->cd_planes[DBPlane(selStretchType)], &area,
+	    Select2Def->cd_planes[*plane], &area,
 	    &DBSpaceBits, selStretchFillFunc2, (ClientData) &area);
     
     return 0;
@@ -937,12 +1066,13 @@ selStretchFillFunc2(tile, area)
     GeoTransRect(&RootToEditTransform, &spaceArea, &editArea);
 
     for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
-	if (DBPaintOnPlane(selStretchType, pNum))
+    {
+	if (DBTypeOnPlane(selStretchType, pNum))
 	    (void) DBSrPaintArea((Tile *) NULL,
 			EditCellUse->cu_def->cd_planes[pNum],
 			&editArea, &DBAllButSpaceAndDRCBits, selStretchFillFunc3,
 			(ClientData) &spaceArea);
-
+    }
     return 0;
 }
 
@@ -958,8 +1088,8 @@ selStretchFillFunc3(tile, area)
     Tile *tile;			/* Tile of edit material that's about to
 				 * be left behind selection.
 				 */
-    Rect *area;			/* Border area we're interested in, in 
-    				 * root coords.
+    Rect *area;			/* The border area we're interested in,
+				 * in root coords.
 				 */
 {
     Rect editArea, rootArea;
