@@ -26,7 +26,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -34,7 +34,7 @@
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 #include "extract/extractInt.h"
 #include "sim/sim.h"
@@ -42,7 +42,7 @@
 #include "dbwind/dbwind.h"
 #include "commands/commands.h"
 #include "textio/txcommands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "graphics/graphics.h"
 
 /* The following structure is used to hold several pieces
@@ -934,7 +934,7 @@ SimPutLabel(cellDef, rect, align, text, type)
     int len, x1, x2, y1, y2, tmp, labx, laby;
 
     len = strlen(text) + sizeof (Label) - sizeof lab->lab_text + 1;
-    MALLOC(Label *, lab, (unsigned) len);
+    lab = (Label *) mallocMagic((unsigned) len);
     strcpy(lab->lab_text, text);
 
     /* Pick a nice alignment if the caller didn't give one.  If the
