@@ -24,7 +24,7 @@
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -35,10 +35,10 @@
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/stack.h"
 #include "sim/sim.h"
 
@@ -127,13 +127,13 @@ SimAddDefList(newdef)
     /* add the cell def to the list */
 
     if (DefList == (DefListElt *) NULL) {
-	MALLOC(DefListElt *, DefList, sizeof(DefListElt));
+	DefList = (DefListElt *) mallocMagic((unsigned) (sizeof(DefListElt)));
 	DefList->dl_def = newdef;
 	DefList->dl_next = (DefListElt *) NULL;
 	return;
     }
     else {
-	MALLOC(DefListElt *, d, sizeof(DefListElt));
+	d = (DefListElt *) mallocMagic((unsigned) (sizeof(DefListElt)));
 	d->dl_next = DefList;
 	d->dl_def = newdef;
 	DefList= d;
@@ -169,7 +169,7 @@ SimInitDefList()
 	q = p;
 	p = p->dl_next;
 	ExtResetTiles(q->dl_def, extUnInit);
-	FREE(q);
+	freeMagic(q);
     }
     DefList = (DefListElt *) NULL;
 }
@@ -512,7 +512,7 @@ SimFindOneNode( sx, tile )
     static NodeSpec	ret;
 
 	/* Allocate a new node */
-    MALLOC(NodeRegion *, reg, sizeof(NodeRegion) );
+    reg = (NodeRegion *) mallocMagic((unsigned) (sizeof(NodeRegion) ));
     reg->nreg_labels = (LabelList *) NULL;
     reg->nreg_cap = 0;
     reg->nreg_resist = 0;
@@ -552,7 +552,7 @@ SimFindOneNode( sx, tile )
 	arg.fra_each = (int (*)()) NULL;
 	(void) ExtFindNeighbors( tile, arg.fra_pNum, &arg );
 
-	FREE( reg );
+	freeMagic( reg );
 
 	ret.nd_name = SimTxtorLabel( -1, &sx->scx_trans, &transistor );
 	ret.nd_what = ND_NAME;
