@@ -30,19 +30,19 @@ static char sccsid[] = "@(#)SimSelect.c	4.14 MAGIC (Berkeley) 10/3/85";
 #endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "commands/commands.h"
 #include "select/selInt.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "sim/sim.h"
 
 /* Two cells worth of information are kept around by the selection
@@ -211,8 +211,8 @@ SimFreeNodeList(List)
     while (temp != NULL) {
 	current = temp;
 	temp = temp->tl_next;
-	FREE(current->tl_nodeName);
-	FREE(current);
+	freeMagic(current->tl_nodeName);
+	freeMagic(current);
     }
     *List = (TileListElt *) NULL;
 }
@@ -228,8 +228,8 @@ simFreeNodeEntry(list, entry)
 	if( curr == entry )
 	{
 	    prev->tl_next = curr->tl_next;
-	    FREE( entry->tl_nodeName );
-	    FREE( entry );
+	    freeMagic( entry->tl_nodeName );
+	    freeMagic( entry );
 	    return( prev );		/* next element in list */
 	}
 
@@ -404,8 +404,8 @@ SimSelectFunc(tile, pHead)
     {
 	if( ! coord )
 	    HashFind(&SimNodeNameTbl, nodeName);
-	MALLOC(TileListElt *, newNodeTile, sizeof (TileListElt));
-	MALLOC(char *, newNodeTile->tl_nodeName, (strlen(nodeName) + 1));
+	newNodeTile = (TileListElt *) mallocMagic((unsigned) (sizeof (TileListElt)));
+	newNodeTile->tl_nodeName = (char *) mallocMagic((unsigned) (strlen(nodeName) + 1));
 	strcpy(newNodeTile->tl_nodeName, nodeName);
 	newNodeTile->tl_nodeTile = tile;
 	newNodeTile->tl_next = *pHead;
@@ -526,8 +526,8 @@ the selection.\n");
 		name = replyLine;
 		if( HashLookOnly(&SimNodeNameTbl, name) == (HashEntry *) NULL)
 		{
-		    FREE(current->tl_nodeName);
-		    MALLOC(char *, current->tl_nodeName, (strlen(name) + 1));
+		    freeMagic(current->tl_nodeName);
+		    current->tl_nodeName = (char *) mallocMagic((unsigned) (strlen(name) + 1));
 		    strcpy(current->tl_nodeName, name);
 		    HashFind(&SimNodeNameTbl, current->tl_nodeName);
 		    *strPtr++ = '=';
@@ -683,14 +683,14 @@ SimRsimMouse(w)
     if (!sawcell) {
 	/* add the cell def to the list */
 	if (SimCellLabList == (SimDefListElt *) NULL) {
-	    MALLOC(SimDefListElt *, SimCellLabList, sizeof(SimDefListElt));
+	    SimCellLabList = (SimDefListElt *) mallocMagic((unsigned) (sizeof(SimDefListElt)));
 	    SimCellLabList->dl_isMarked = FALSE;
 	    SimCellLabList->dl_def = cu->cu_def;
 	    SimCellLabList->dl_next = (SimDefListElt *) NULL;
 	    dummy = SimCellLabList;
 	}
 	else {
-	    MALLOC(SimDefListElt *, dummy, sizeof(SimDefListElt));
+	    dummy = (SimDefListElt *) mallocMagic((unsigned) (sizeof(SimDefListElt)));
 	    dummy->dl_isMarked = FALSE;
 	    dummy->dl_next = SimCellLabList;
 	    dummy->dl_def = cu->cu_def;
