@@ -27,7 +27,7 @@
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"   
+#include "utils/magic.h"   
 #include "utils/geometry.h"
 #include "tiles/tile.h"  
 #include "utils/hash.h"  
@@ -38,7 +38,7 @@
 #include "utils/utils.h"
 #include "textio/textio.h"
 #include "textio/txcommands.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "graphics/graphics.h"
 #include "utils/malloc.h" 
 #include "dbwind/dbwind.h"
@@ -49,6 +49,7 @@
  */
 
 char *MagicVersion = MAGIC_VERSION;
+char *MagicRevision = MAGIC_REVISION;
 char *MagicCompileTime = MAGIC_DATE;
 
 Tcl_Interp *magicinterp;
@@ -275,7 +276,7 @@ AddCommandTag(ClientData clientData,
 	return TCL_OK;
     }
 
-    if (hstring != NULL) FREE(hstring);
+    if (hstring != NULL) freeMagic(hstring);
 
     if (strlen(argv[2]) == 0)
     {
@@ -377,7 +378,7 @@ _tcl_dispatch(ClientData clientData,
     }
     Tcl_ResetResult(interp);
 
-    TxInputRedirect = False;
+    TxInputRedirect = FALSE;
     TxTclDispatch(clientData, argc, argv);
     return TagCallback(interp, NULL, argc, argv);
 }
@@ -460,7 +461,8 @@ static int
 _magic_initialize(ClientData clientData,
         Tcl_Interp *interp, int argc, char *argv[])
 {
-    int n;
+    WindClient client;
+    int n, i;
     char keyword[100];
     char *kwptr = keyword + 7;
     char **commandTable;
@@ -494,23 +496,23 @@ _magic_initialize(ClientData clientData,
     /* Registration of commands is performed after calling the	*/
     /* start function, not after initialization, as the command */
     /* modularization requires magic initialization to get a	*/
-    /* valid DBWclientID and windClientID.			*/
+    /* valid DBWclientID, windClientID, etc.			*/
 
     sprintf(keyword, "magic::");
-    commandTable = WindGetCommandTable(DBWclientID);
-    for (n = 0; commandTable[n] != NULL; n++)
-    {
-	sscanf(commandTable[n], "%s ", kwptr); /* get first word */
-	Tcl_CreateCommand(interp, keyword, (Tcl_CmdProc *)_tcl_dispatch,
-			(ClientData)NULL, (Tcl_CmdDeleteProc *) NULL);
-    }
 
-    commandTable = WindGetCommandTable(windClientID);
-    for (n = 0; commandTable[n] != NULL; n++)
+    /* Work through all the known clients, and register the	*/
+    /* commands of all of them.					*/
+
+    client = (WindClient)NULL;
+    while ((client = WindNextClient(client)) != NULL)
     {
-	sscanf(commandTable[n], "%s ", kwptr); /* get first word */
-	Tcl_CreateCommand(interp, keyword, (Tcl_CmdProc *)_tcl_dispatch,
+	commandTable = WindGetCommandTable(client);
+	for (n = 0; commandTable[n] != NULL; n++)
+	{
+	    sscanf(commandTable[n], "%s ", kwptr); /* get first word */
+	    Tcl_CreateCommand(interp, keyword, (Tcl_CmdProc *)_tcl_dispatch,
 			(ClientData)NULL, (Tcl_CmdDeleteProc *) NULL);
+	}
     }
 
     /* Extra commands provided by the Tk graphics routines	*/
@@ -591,14 +593,14 @@ TxDialog(prompt, responses, defresp)
     newstr = StrDup(NULL, prompt);
     evalstr = TxPrintString("tk_dialog .dialog \"Dialog\""
 	" \"%s\" {} %d ", newstr, defresp);
-    FREE(newstr);
+    freeMagic(newstr);
 
     for (pos = 0; responses[pos] != 0; pos++)
     {
 	newstr = StrDup(NULL, evalstr);
 	evalstr = TxPrintString("%s \"%s\" ", newstr,
 		responses[pos]);
-	FREE(newstr);
+	freeMagic(newstr);
     }
 
     Tcl_EvalEx(magicinterp, evalstr, -1, 0);
@@ -674,7 +676,7 @@ TxGetLinePfix(dest, maxChars, prefix)
 	    Tcl_Free(string);
 	}
 	else
-	    Tcl_EvalEx(magicinterp, "magic::dialog", 12, 0);
+	    Tcl_EvalEx(magicinterp, "magic::dialog", 13, 0);
     }
     else
     {
@@ -834,7 +836,8 @@ Tcl_printf(FILE *f, char *fmt, va_list args_in)
 
     if (escapes > 0)
     {
-	finalstr = Tcl_Alloc(nchars + escapes + 26);
+	/* "+ 4" required to process "$$...$$"; haven't figured out why. */ 
+	finalstr = Tcl_Alloc(nchars + escapes + 26 + 4);
 	strncpy(finalstr, outptr, 24);
 	escapes = 0;
 	for (i = 24; *(outptr + i) != '\0'; i++)
@@ -948,7 +951,7 @@ TerminalInputProc(instanceData, buf, toRead, errorCodePtr)
 
     *errorCodePtr = 0;
 
-    TxInputRedirect = False;
+    TxInputRedirect = FALSE;
     if (TxBuffer != NULL) {
        tlen = strlen(TxBuffer);
        if (tlen < toRead) {
@@ -991,14 +994,6 @@ Tclmagic_Init(interp)
 
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
-    /* Set initial command structure, so that magic doesn't	 */
-    /* fault when running commands before magic::start is called */
-
-    TxCurCommand.tx_p.p_x = 20;
-    TxCurCommand.tx_p.p_y = 20;
-    TxCurCommand.tx_wid = WIND_UNKNOWN_WINDOW;
-
-
     /* Initialization and Startup commands */
     Tcl_CreateCommand(interp, "magic::initialize", (Tcl_CmdProc *)_magic_initialize,
 			(ClientData)NULL, (Tcl_CmdDeleteProc *) NULL);
