@@ -42,24 +42,6 @@ set Glyph(zoom) [image create bitmap \
 	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/zoom.xbm \
 	-background gray -foreground steelblue]
 
-# Handle the kludgy macros-call-Tcl-procedures setup by creating
-# a command "gmacro" (general-purpose macro).  The idea is that
-# macros only call magic (not Tcl) commands, but that tag callbacks
-# can call anything.  So "gmacro" sets up a dummy keyword that
-# is not a command, and attaches a tag callback function to it.
-# The tag callback implements the actual macro.
-
-proc magic::gmacro {key value} {
-   global Opts
-   if {[catch {set Opts(gmacrokeys)}]} {
-      set Opts(gmacrokeys) 0
-   } else {
-      incr Opts(gmacrokeys)
-   }
-   magic::macro $key gmkey$Opts(gmacrokeys)
-   magic::tag gmkey$Opts(gmacrokeys) $value
-}
-
 # Menu button callback functions
 
 proc magic::promptload {type} {
@@ -67,15 +49,33 @@ proc magic::promptload {type} {
       cif { set Layoutfilename [ tk_getOpenFile -filetypes \
 		{{CIF {.cif {.cif}}} {"All files" {*}}}]
 	    if {$Layoutfilename != ""} {
-		magic::load [file root $Layoutfilename]
+		set cifname [file tail [file root $Layoutfilename]]
+		magic::cellname create $cifname
+		magic::load $cifname
 		magic::cif read [file root $Layoutfilename]
 	    }
 	  }
       gds { set Layoutfilename [ tk_getOpenFile -filetypes \
 		{{GDS {.gds .strm .cal {.gds .strm .cal}}} {"All files" {*}}}]
 	    if {$Layoutfilename != ""} {
-		magic::load [file root $Layoutfilename]
+		set origlist [magic::cellname list top]
 		magic::gds read [file root $Layoutfilename]
+		set newlist [magic::cellname list top]
+
+		# Find entries in newlist that are not in origlist.
+		# If there's only one, load it into the window.
+
+		set newtopcells {}
+		foreach n $newlist {
+		   if {[lsearch $origlist $n] < 0} {
+		      lappend newtopcells $n
+		   }
+		}
+		if {[llength $newtopcells] == 1} {
+		   magic::load [lindex $newtopcells 0]
+		} elseif {[llength $newtopcells] != 0} {
+		   puts stdout "Top-level cells read from GDS file: $newtopcells"
+		}
 	    }
 	  }
       magic { set Layoutfilename [ tk_getOpenFile -filetypes \
@@ -497,7 +497,7 @@ magic::tag load "magic::cellmanager; magic::caption %W"
 magic::tag getcell "magic::cellmanager"
 magic::tag edit "magic::caption %W"
 magic::tag save "magic::caption %W"
-magic::tag box "magic::boxview %W"
+magic::tag box "magic::boxview %W %1"
 magic::tag move "magic::boxview %W"
 magic::tag scroll "magic::scrollupdate %W"
 magic::tag view "magic::scrollupdate %W"
@@ -556,9 +556,10 @@ proc magic::repaintwrapper { win } {
 # Because "box" calls "box", use the "info level" command to avoid
 # infinite recursion.
 
-proc magic::boxview {win} {
-   if {[info level] <= 1} {
-
+proc magic::boxview {win {cmdstr ""}} {
+   if {${cmdstr} == "exists" || ${cmdstr} == "help" || ${cmdstr} == ""} {
+      # do nothing. . . informational only, no change to the box
+   } elseif {[info level] <= 1} {
       # For NULL window, find all layout windows and apply update to each.
       if {$win == {}} {
          set winlist [magic::windownames layout]
@@ -1066,10 +1067,11 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 
    bind $winname <Enter> {focus %W}
 
-   # Button press events bypass the normal command mechanism, so any tag features
-   # required on button presses/releases need to be duplicated.
+   # Note: Tk binding bypasses the event proc, so it is important to
+   # set the current point;  otherwise, the cursor will report the
+   # wrong position and/or the wrong window.
 
-   bind ${winname} <Motion> "::magic::cursorview ${winname}"
+   bind ${winname} <Motion> "setpoint %x %y ; magic::cursorview ${winname}"
 
    # Resize the window
    if {[catch {wm geometry ${framename} $Winopts(${framename},geometry)}]} {
@@ -1149,10 +1151,9 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 
    magic::caption ${winname}
 
-   # Rename "open" macro by rebinding using the "gmacro" procedure
-   # (see above for the gmacro definition)
-   magic::gmacro o {magic::openwrapper}
-   magic::gmacro O {magic::closewrapper}
+   # Rename "open" macro
+   magic::macro o {magic::openwrapper}
+   magic::macro O {magic::closewrapper}
 
    return ${winname}
 }
@@ -1196,20 +1197,6 @@ proc magic::addcommandentry { framename } {
    bind ${framename}.eval.text <Enter> {focus %W}
 }
 
-# Check for presence of padlist manager script and include it
-
-if {[file exists ${CAD_HOME}/lib/magic/tcl/padlist.tcl]} {
-   source ${CAD_HOME}/lib/magic/tcl/padlist.tcl
-   set Opts(padlist) 0
-}
-
-# Check for presence of the miscellaneous tools script and include it
-
-if {[file exists ${CAD_HOME}/lib/magic/tcl/tools.tcl]} {
-   source ${CAD_HOME}/lib/magic/tcl/tools.tcl
-   set Opts(tools) 0
-}
-
 # Remove the command entry window from the bottom of a frame.
 
 proc magic::deletecommandentry { framename } {
@@ -1221,8 +1208,6 @@ puts "Use openwrapper to create a new GUI-based layout window"
 namespace import magic::closewrapper
 puts "Use closewrapper to remove a new GUI-based layout window"
 
-namespace import magic::gmacro
-
 # Create a simple wrapper for the 3D window. . . this can be
 # greatly expanded upon.
 
