@@ -25,7 +25,7 @@
 #ifndef _TEXTIO_H
 #define _TEXTIO_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 #ifdef MAGIC_WRAPPER
 extern char *TxBuffer;
