@@ -19,17 +19,11 @@
  * rcsid $Header: /ufs/repository/magic/textio/textioInt.h,v 1.3 2001/08/23 13:48:57 tim Exp $
  */
 
-#define _TEXTIOINT
+#ifndef _TEXTIOINT_H
+#define _TEXTIOINT_H
 
-#ifndef _MAGIC
-	err = Need_to_include_misc/magic_header
-#endif
-#ifndef _TEXTIO
-	err = Need_to_include_textio/textio_header
-#endif
-#ifndef _TXCOMMANDS
-	err = Need_to_include_textio/txcommands_header
-#endif
+#include "textio/textio.h"
+#include "textio/txcommands.h"
 
 extern bool txHavePrompt;
 
@@ -37,7 +31,7 @@ typedef struct {
     fd_set tx_fdmask;		/* A mask of the file descriptors for this 
 				 * device.
 				 */
-    Void (*tx_inputProc)(); 	/* A procedure that fetches events and stores
+    void (*tx_inputProc)(); 	/* A procedure that fetches events and stores
 				 * them in the input queue via TxAddEvent().
 				 */
     ClientData tx_cdata;	/* Data to be passed back to caller. */
@@ -52,7 +46,12 @@ typedef struct {
     struct sgttyb tx_i_sgtty;
     struct tchars tx_i_tchars;
 } txTermState;
-#endif SYSV
+#endif /* SYSV */
 
-extern int TxGetInputEvent();
-extern void txFprintfBasic();
+extern bool TxGetInputEvent();
+
+/* Routines with variable argument lists */
+
+extern void txFprintfBasic(FILE *, ...);
+
+#endif /* _TEXTIOINT_H */
