@@ -32,20 +32,21 @@ static char rcsid[]="$Header: /ufs/repository/magic/textio/txCommands.c,v 1.7 20
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
-#include "misc/magsgtty.h"
 
-#include "misc/magic.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "textio/textioInt.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
+#include "dbwind/dbwind.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "graphics/graphics.h"
 #include "utils/dqueue.h"
 #include "utils/malloc.h"
@@ -69,7 +70,6 @@ static txLastInputEntry = -1;
 
 /* The current point -- reset by the 'setpoint' command and for each
  * interactive command.  Calls to TxClearPoint clear previous setpoints,
- * as do interactive commands.
  *
  * Each input point is associated with a window, as windows may use 
  * different coordinate systems.
@@ -92,7 +92,6 @@ extern void send_interpreter(char *);
 
 char *TxBuffer;		/* For use with special stdin processing */
 bool TxInputRedirect;	/* For redirecting Tk events to the terminal */
-TxCommand TxCurCommand;
 #endif
 
 DQueue txInputEvents;
@@ -415,7 +414,7 @@ TxFreeCommand(command)
     ASSERT(command != NULL, "TxFreeCommand");
 #ifdef MAGIC_WRAPPER
     /* No Tx Queue in MAGIC_WRAPPER; call is just to free memory */
-    FREE((char *)command);
+    freeMagic((char *)command);
 #else
     DQPushRear(&txFreeCommands, (ClientData) command);
 #endif
@@ -548,7 +547,7 @@ TxDelete1InputDevice(fd)
  *	None.
  *
  * Side effects:
- *	None.
+ *	Changes global set point variables.
  * ----------------------------------------------------------------------------
  */
 
@@ -571,7 +570,7 @@ TxSetPoint(x, y, wid)
  *
  * Results:
  *	integer ID of the current window, or -1 if txHaveCurrentPoint is
- *	FALSE.
+ *	TX_POINT_CLEAR
  *
  * Side effects:
  *	Current point goes into
@@ -583,7 +582,7 @@ int
 TxGetPoint(tx_p)
     Point *tx_p;
 {
-    if (txHaveCurrentPoint == TRUE)
+    if (txHaveCurrentPoint)
     {
 	if (tx_p != (Point *)NULL)
 	    *tx_p = txCurrentPoint;
@@ -971,7 +970,8 @@ txGetInteractiveCommand(block, queue)
 	if ((ch == (int)TX_LONG_CMD) || (ch == (int)TX_LONG_CMD2))
 	{
 	    (void) TxGetLinePrompt(inputLine, TX_MAX_CMDLEN, TX_CMD_PROMPT);
-	    if (inputLine[0] != '\0') MacroDefine((int)'.', inputLine, FALSE);
+	    if (inputLine[0] != '\0') MacroDefine(DBWclientID, (int)'.',
+			inputLine, FALSE);
 	    TxParseString(inputLine, queue, (TxInputEvent* ) NULL);
 	}
 	else
@@ -979,7 +979,7 @@ txGetInteractiveCommand(block, queue)
 	    int iMacro; /* Interactive macro */
 	    char *macroDef;
 
-	    macroDef = MacroRetrieve(ch, &iMacro);
+	    macroDef = MacroRetrieve(DBWclientID, ch, &iMacro);
 	    if (macroDef == NULL)
 	    {
 		/* Cases macroDef may be NULL:			*/
@@ -1003,7 +1003,8 @@ txGetInteractiveCommand(block, queue)
 		{
 		    (void) TxGetLineWPrompt(inputLine,
 					TX_MAX_CMDLEN, TX_CMD_PROMPT, macroDef);
-		    if (inputLine[0] != '\0') MacroDefine((int)'.', inputLine, FALSE);
+		    if (inputLine[0] != '\0') MacroDefine(DBWclientID, (int)'.',
+				inputLine, FALSE);
 		    TxParseString(inputLine, queue, (TxInputEvent *) NULL);
 		}
 		else
@@ -1157,15 +1158,11 @@ TxTclDispatch(clientData, argc, argv)
 	tclcmd->tx_argv[n] = &tclcmd->tx_argstring[asize];
 	asize += (1 + strlen(argv[n]));
     }
-    if (txHaveCurrentPoint) {
-	tclcmd->tx_p = txCurrentPoint;
+    tclcmd->tx_p = txCurrentPoint;
+    if (txHaveCurrentPoint)
 	tclcmd->tx_wid = txCurrentWindowID;
-	txHaveCurrentPoint = FALSE;
-    }
-    else {
-	tclcmd->tx_p = TxCurCommand.tx_p;
-	tclcmd->tx_wid = TxCurCommand.tx_wid;
-    }
+    else
+	tclcmd->tx_wid = WIND_UNKNOWN_WINDOW;
 
     result = WindSendCommand((MagWindow *)clientData, tclcmd);
     TxFreeCommand(tclcmd);
