@@ -18,7 +18,7 @@
 
 #ifndef lint
 static char rcsid[]="$Header: /ufs/repository/magic/textio/txInput.c,v 1.11 2001/08/23 13:48:57 tim Exp $";
-#endif  not lint
+#endif  /* not lint */
 
 #include <stdio.h>
 #include <sys/time.h>
@@ -31,15 +31,15 @@ static char rcsid[]="$Header: /ufs/repository/magic/textio/txInput.c,v 1.11 2001
 #endif
 
 
-#include "misc/magsgtty.h"
-#include "misc/magic.h"
-#include "misc/magsgtty.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
+#include "utils/magsgtty.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "textio/textioInt.h"
 #include "utils/dqueue.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
 #include "database/database.h"
@@ -54,8 +54,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/textio/txInput.c,v 1.11 2001
 #include <readline/readline.h>
 #include <readline/history.h>
 #else
-#include "readline/readline.h"
-#include "readline/history.h"
+#include "readline/readline/readline.h"
+#include "readline/readline/history.h"
 #endif
 
 int    TxPrefix(void);
@@ -236,7 +236,11 @@ static struct cmd_spec {
   { "select more box", LAYER_COMPL, { (char *)NULL } },
   { "select less box", LAYER_COMPL, { (char *)NULL } },
 
-  { "send", ARGS_COMPL, {"netlist", "color", "layout", (char *)NULL} },
+  { "send", ARGS_COMPL, {"netlist", "color", "layout", 
+#ifdef THREE_D
+	"wind3d",
+#endif
+		 (char *)NULL} },
   { "snap", ARGS_COMPL, {"on", "off", (char *)NULL} },
   { "tool", ARGS_COMPL, {"box", "wiring", "netlist", "rsim", (char *)NULL} },
   { "wire", ARGS_COMPL, {"help", "horizontal", "leg", "switch", "type", 
@@ -271,6 +275,10 @@ bool txHavePrompt = FALSE;	/* is a prompt on the screen? */
 char *txReprint1 = NULL;
 char *txReprint2 = NULL;
 
+#ifdef MAGIC_WRAPPER
+extern bool TxTkConsole;
+#endif
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -963,6 +971,7 @@ make_techtype_list(void)
  *
  * ----------------------------------------------------------------------------
  */
+
 char *
 TxGetLineWPrompt(dest, maxChars, prompt, prefix)
     char *dest;
@@ -1190,6 +1199,7 @@ TxGetLine(dest, maxChars)
  */
 
 #if defined(SYSV) || defined(CYGWIN)
+
 void
 txGetTermState(buf)
     struct termio *buf;
@@ -1209,7 +1219,7 @@ txGetTermState(buf)
     (void) ioctl(fileno(stdin), TIOCGETP, (char *) &(buf->tx_i_sgtty) );
     (void) ioctl(fileno(stdin), TIOCGETC, (char *) &(buf->tx_i_tchars) );
 }
-#endif SYSV
+#endif /* SYSV */
 
 
 /*
@@ -1232,7 +1242,7 @@ txSetTermState(buf)
     struct termio *buf;
 #else
     txTermState *buf;
-#endif SYSV
+#endif /* SYSV */
 {
 #if defined(SYSV) || defined(CYGWIN)
     ioctl( fileno(stdin), TCSETAF, buf );
@@ -1240,7 +1250,7 @@ txSetTermState(buf)
     /* set the current terminal characteristics */
     (void) ioctl(fileno(stdin), TIOCSETN, (char *) &(buf->tx_i_sgtty) );
     (void) ioctl(fileno(stdin), TIOCSETC, (char *) &(buf->tx_i_tchars) );
-#endif SYSV
+#endif /* SYSV */
 }
 
 
@@ -1253,9 +1263,10 @@ txSetTermState(buf)
  *	cbreak on, and no EOFs the way we like it.
  *
  * Results:
- *	The passed terminal record is modified.
+ *	None.
  *
  * Side effects:
+ *	The passed terminal record is modified.
  *	No terminal modes are actually changed.
  * ----------------------------------------------------------------------------
  */
@@ -1266,7 +1277,7 @@ txInitTermRec(buf)
     struct termio *buf;
 #else
     txTermState *buf;
-#endif SYSV
+#endif /* SYSV */
 {
 #if defined(SYSV) || defined(CYGWIN)
     buf->c_lflag = ISIG;    /* raw: no echo and no processing, allow signals */
@@ -1278,10 +1289,7 @@ txInitTermRec(buf)
     buf->tx_i_sgtty.sg_flags &= ~ECHO;
     buf->tx_i_tchars.t_eofc = -1;
 
-    /* Give the graphics module a chance to override this. */
-    if (GrTermStatePtr) 
-	(*GrTermStatePtr)(&buf->tx_i_sgtty, &buf->tx_i_tchars);
-#endif SYSV
+#endif /* SYSV */
 }
 
 
@@ -1290,7 +1298,7 @@ txInitTermRec(buf)
 struct termio closeTermState;
 #else
 static txTermState closeTermState;
-#endif SYSV
+#endif /* SYSV */
 
 static bool haveCloseState = FALSE;
 
@@ -1333,7 +1341,7 @@ txSaveTerm()
     TxEOFChar = closeTermState.tx_i_tchars.t_eofc;
     TxInterruptChar = closeTermState.tx_i_tchars.t_intrc;
     haveCloseState = TRUE;
-#endif SYSV
+#endif /* SYSV */
 }
 
 
@@ -1358,7 +1366,13 @@ TxSetTerminal()
     struct termio buf;
 #else
     txTermState buf;
-#endif SYSV
+#endif /* SYSV */
+
+#ifdef MAGIC_WRAPPER
+    /* If using Tk console, don't mess with the terminal settings;	  */
+    /* Otherwise, this prevents running magic in the terminal background. */
+    if (TxTkConsole) return;
+#endif
 
     if (TxStdinIsatty)
     {
@@ -1387,5 +1401,12 @@ TxSetTerminal()
 void
 TxResetTerminal()
 {
+
+#ifdef MAGIC_WRAPPER
+    /* If using Tk console, don't mess with the terminal settings;	  */
+    /* Otherwise, this prevents running magic in the terminal background. */
+    if (TxTkConsole) return;
+#endif
+
     if (TxStdinIsatty && haveCloseState) txSetTermState(&closeTermState);
 }
