@@ -19,7 +19,7 @@
 static char rcsid[]  =  "$Header: /ufs/repository/magic/textio/txMore.c,v 1.2 2001/01/12 22:13:26 jsolomon Exp $";
 #endif  /* not lint */
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 
 /*
