@@ -31,16 +31,16 @@ static char rcsid[] = "$Header: /ufs/repository/magic/textio/txOutput.c,v 1.4 20
 #endif /* SYSV */
 #include <sys/stat.h>
 #include <unistd.h>
-#include "misc/magsgtty.h"
 
-#include "misc/magic.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "textio/textioInt.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 #include "utils/utils.h"
 #include "utils/malloc.h"
 
@@ -173,7 +173,7 @@ TxPrintString(char *fmt, ...)
     if (outstr == NULL)
     {
 	outlen = 100;
-	MALLOC(char *, outstr, outlen + 1);
+	outstr = (char *) mallocMagic((unsigned) (outlen + 1));
     }
 
     va_start(args, fmt);
@@ -183,8 +183,8 @@ TxPrintString(char *fmt, ...)
     if (nchars >= outlen)
     {
 	outlen = nchars + 1;
-	FREE(outstr);
-	MALLOC(char *, outstr, outlen + 1);
+	freeMagic(outstr);
+	outstr = (char *) mallocMagic((unsigned) (outlen + 1));
 	va_start(args, fmt);
 	vsnprintf(outstr, outlen, fmt, args);
 	va_end(args);
@@ -364,11 +364,11 @@ TxUseMore()
     /* Determine if "more" executable exists and is world executable */
     /* before attempting a fork.  Check environment variable PAGER   */
     /* first before defaulting to the built-in value PAGERDIR	     */
-    /* (see misc/paths.h).					     */
+    /* (see utils/paths.h).					     */
 
     if ((useenv = getenv("PAGER")) == NULL)
     {
-	MALLOC(char *, pagerpath, strlen(PAGERDIR) + 1);
+	pagerpath = (char *) mallocMagic((unsigned) (strlen(PAGERDIR) + 1));
 	strcpy(pagerpath, PAGERDIR);
     }
     else
@@ -417,7 +417,7 @@ TxUseMore()
     TxMoreFile = fdopen(pipeEnds[1], "w");
 
 done:
-    if (useenv == NULL) FREE(pagerpath);
+    if (useenv == NULL) freeMagic(pagerpath);
     return;
 }
 
