@@ -21,7 +21,7 @@
 #ifndef _TXCOMMANDS_H
 #define _TXCOMMANDS_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 
 /* Structure of one Magic command.  All commands are in the same format. 
