@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/tiles/search.c,v 1.2 2001/
 #endif	/* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 
@@ -52,9 +53,9 @@ TiSrPoint(hintTile, plane, point)
 				 * with the plane instead.
 				 */
     Plane * plane;		/* Plane (containing hint tile pointer) */
-    register Point * point;	/* Point for which to search */
+    Point * point;	/* Point for which to search */
 {
-    register Tile *tp = (hintTile) ? hintTile : plane->pl_hint;
+    Tile *tp = (hintTile) ? hintTile : plane->pl_hint;
 
     GOTOPOINT(tp, point);
     plane->pl_hint = tp;
