@@ -21,10 +21,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/tiles/search2.c,v 1.2 2001
 #endif	/* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* -------------------- Local function headers ------------------------ */
 
