@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/tiles/tile.c,v 1.2 2001/01
 #endif	/* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -62,7 +63,7 @@ TiNewPlane(tile)
     Plane *newplane;
     static Tile *infinityTile = (Tile *) NULL;
 
-    MALLOC(Plane *, newplane, sizeof (Plane));
+    newplane = (Plane *) mallocMagic((unsigned) (sizeof (Plane)));
     newplane->pl_top = TiAlloc();
     newplane->pl_right = TiAlloc();
     newplane->pl_bottom = TiAlloc();
@@ -148,11 +149,11 @@ void
 TiFreePlane(plane)
     Plane *plane;	/* Plane to be freed */
 {
-    FREE((char *) plane->pl_left);
-    FREE((char *) plane->pl_right);
-    FREE((char *) plane->pl_top);
-    FREE((char *) plane->pl_bottom);
-    FREE((char *) plane);
+    freeMagic((char *) plane->pl_left);
+    freeMagic((char *) plane->pl_right);
+    freeMagic((char *) plane->pl_top);
+    freeMagic((char *) plane->pl_bottom);
+    freeMagic((char *) plane);
 }
 
 /*
@@ -212,7 +213,7 @@ TiSplitX(tile, x)
 
     ASSERT(x > LEFT(tile) && x < RIGHT(tile), "TiSplitX");
 
-    MALLOC(Tile *, newtile, sizeof (Tile));
+    newtile = (Tile *) mallocMagic((unsigned) (sizeof (Tile)));
     newtile->ti_client = (ClientData) MINFINITY;
     newtile->ti_body = (ClientData) 0;
 
@@ -284,7 +285,7 @@ TiSplitY(tile, y)
 
     ASSERT(y > BOTTOM(tile) && y < TOP(tile), "TiSplitY");
 
-    MALLOC(Tile *, newtile, sizeof (Tile));
+    newtile = (Tile *) mallocMagic((unsigned) (sizeof (Tile)));
     newtile->ti_client = (ClientData) MINFINITY;
     newtile->ti_body = (ClientData) 0;
 
@@ -357,7 +358,7 @@ TiSplitX_Left(tile, x)
 
     ASSERT(x > LEFT(tile) && x < RIGHT(tile), "TiSplitX");
 
-    MALLOC(Tile *, newtile, sizeof (Tile));
+    newtile = (Tile *) mallocMagic((unsigned) (sizeof (Tile)));
     newtile->ti_client = (ClientData) MINFINITY;
     newtile->ti_body = (ClientData) 0;
 
@@ -420,7 +421,7 @@ TiSplitY_Bottom(tile, y)
 
     ASSERT(y > BOTTOM(tile) && y < TOP(tile), "TiSplitY");
 
-    MALLOC(Tile *, newtile, sizeof (Tile));
+    newtile = (Tile *) mallocMagic((unsigned) (sizeof (Tile)));
     newtile->ti_client = (ClientData) MINFINITY;
     newtile->ti_body = (ClientData) 0;
 
@@ -534,7 +535,7 @@ TiJoinX(tile1, tile2, plane)
 
     if (plane->pl_hint == tile2)
 	plane->pl_hint = tile1;
-    FREE((char *) tile2);
+    freeMagic((char *) tile2);
 }
 
 /*
@@ -619,7 +620,7 @@ TiJoinY(tile1, tile2, plane)
 
     if (plane->pl_hint == tile2)
 	plane->pl_hint = tile1;
-    FREE((char *) tile2);
+    freeMagic((char *) tile2);
 }
 
 Tile *
@@ -627,7 +628,7 @@ TiAlloc()
 {
     Tile *newtile;
 
-    MALLOC(Tile *, newtile, sizeof (Tile));
+    newtile = (Tile *) mallocMagic((unsigned) (sizeof (Tile)));
     newtile->ti_client = (ClientData) MINFINITY;
     newtile->ti_body = (ClientData) 0;
     return (newtile);
@@ -637,7 +638,7 @@ void
 TiFree(tp)
     Tile *tp;
 {
-    FREE((char *) tp);
+    freeMagic((char *) tp);
 }
 
 /* ==================================================================== */
