@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/args.c,v 1.2 2001/01
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 
 /*
