@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/dqueue.c,v 1.2 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/dqueue.h"
 #include "utils/malloc.h"
 
@@ -47,7 +48,7 @@ DQInit(q, capacity)
     int capacity;
 {
     if (capacity < 1) capacity = 1;
-    MALLOC(ClientData *, q->dq_data, (capacity+1) * sizeof (ClientData));
+    q->dq_data = (ClientData *) mallocMagic((unsigned)((capacity+1) * sizeof (ClientData)));
     q->dq_size = 0;
     q->dq_maxSize = capacity;
     q->dq_front = 0;	/* next slot in front is loc 0 */
@@ -75,7 +76,7 @@ void
 DQFree(q)
     DQueue *q;
 {
-    FREE((char *) q->dq_data); 
+    freeMagic((char *) q->dq_data); 
 }
 
 /*
@@ -138,7 +139,7 @@ ClientData
 DQPopFront(q)
     DQueue *q;
 {
-    if (q->dq_size == 0) return NULL;
+    if (q->dq_size == 0) return (ClientData) NULL;
     q->dq_size--;
     q->dq_front++;
     if (q->dq_front > q->dq_maxSize) q->dq_front = 0;
@@ -149,7 +150,7 @@ ClientData
 DQPopRear(q)
     DQueue *q;
 {
-    if (q->dq_size == 0) return NULL;
+    if (q->dq_size == 0) return (ClientData) NULL;
     q->dq_size--;
     q->dq_rear--;
     if (q->dq_rear < 0) q->dq_rear = q->dq_maxSize;
@@ -183,7 +184,7 @@ DQChangeSize(q, newSize)
     if (newSize < q->dq_size) newSize = q->dq_size;
     DQInit(&newq, newSize);
     DQCopy(&newq, q);
-    FREE((char *) q->dq_data); 
+    freeMagic((char *) q->dq_data); 
     q->dq_data = newq.dq_data;
     q->dq_maxSize = newq.dq_maxSize;
     q->dq_front = newq.dq_front;
