@@ -25,7 +25,7 @@
 #ifndef	_DQUEUE_H
 #define	_DQUEUE_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* The dqueue structure, to be manipulated only by the 
  * procedures declared in this file.
