@@ -27,7 +27,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/finddisp.c,v 1.2 200
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/utils.h"
 
 /* Import from library routines: */
