@@ -27,6 +27,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/flock.c,v 1.10 2001/
 #include <unistd.h>
 #endif
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <sys/file.h>
 #include <sys/stat.h>
@@ -34,9 +35,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/flock.c,v 1.10 2001/
 #include <sys/time.h>
 
 #ifdef FILE_LOCKS
-#define FLOCK_DEBUG
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -225,7 +225,7 @@ flock_init()
 
     upid = getpid();
     hst = gethostname(hstname, 100);
-    MALLOC(flock_list *, f_list_ptr, sizeof(flock_list));
+    f_list_ptr = (flock_list *) mallocMagic((unsigned) (sizeof(flock_list)));
     f_list_head = f_list_ptr;
     f_list_head->ptr = 0;
     f_list_head->upid = upid;
@@ -379,7 +379,7 @@ flock_list_add(realname)
     }
     if (!dup)
     {
-	MALLOC(flock_list *, fptr->ptr, sizeof(flock_list));
+	fptr->ptr = (flock_list *) mallocMagic((unsigned) (sizeof(flock_list)));
 	fptr = fptr->ptr;
 	fptr->ptr = 0;
 	fptr->filename = realname;
@@ -423,8 +423,8 @@ flock_test_set(lfilename, f)
 
     if (strpbrk(lfilename, "/\\") == 0)
     {
-	MALLOC(char *, locfile, strlen(LOCK_DIR) + strlen(lfilename) +
-			strlen("lock") + 4);
+	locfile = (char *) mallocMagic((unsigned) (strlen(LOCK_DIR) + strlen(lfilename) +
+			strlen("lock") + 4));
 	sprintf(locfile, "%s/%s.%s", LOCK_DIR, lfilename, "lock" );
 	/* TxPrintf("Lock file created: %s\n", locfile); */
 
@@ -529,7 +529,7 @@ flock_test_set(lfilename, f)
 		atbuf = asctime(&mtime);
 		TxPrintf("File <%s> last modified on: %s", lfilename, atbuf);
 		buflen = strlen(atbuf);
-		MALLOC(char *, atbuf2, buflen+1);
+		atbuf2 = (char *) mallocMagic((unsigned) buflen+1);
 		strncpy(atbuf2, atbuf, buflen-1);
 		atbuf2[buflen-1] = '\0';
 		fprintf(flck, "host:     %s pid: %d \nUSER:     %s"
@@ -539,7 +539,7 @@ flock_test_set(lfilename, f)
 				fptr->hostname, fptr->upid, getenv("USER"),
 				getenv("MAGICID"), cw_buff,
 				asctime(&ctimeptr), filestat.st_mtime, atbuf2);
-		FREE(atbuf2);
+		freeMagic(atbuf2);
 	    }
 	    fclose(flck);
 	}
@@ -568,7 +568,7 @@ flock_open(filename, ext, mode)
     FILE *f;
     int ptr, n=0, dup=0;
     char *locfile, *recname;
-    char lfilename[1024], tempfilename[1024];
+    char lfilename[MAXPATHLEN], tempfilename[MAXPATHLEN];
     int readlen;
     struct stat filestat;
     flock_list *fptr = f_list_ptr, *fnul =  NULL;
@@ -613,7 +613,7 @@ flock_open(filename, ext, mode)
        }
     }
     if(strpbrk(filename, "/\\") == 0) {
-       MALLOC(char *, recname, strlen(LOCK_DIR)+strlen(filename)+strlen("lock")+4);
+       recname = (char *) mallocMagic((unsigned) (strlen(LOCK_DIR)+strlen(filename)+strlen("lock")+4));
        sprintf(recname, "%s/%s.%s", LOCK_DIR, filename, "lock" );
 
        /* Test for "rb" is the other half of the kludge found in DBio.c */
