@@ -26,8 +26,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/fractions.c,v 1.0 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 
 /*
@@ -52,7 +54,7 @@ int
 FindGCF(a, b)
     int a, b;
 {
-    register int a_mod_b, bp;
+    int a_mod_b, bp;
 
     bp = abs(b);
     if ((a_mod_b = (abs(a)) % bp) == 0) return (bp);
