@@ -21,7 +21,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/utils/geometry.c,v 1.2 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
@@ -490,7 +491,7 @@ GeoInvertTrans(t, inverse)
  *-------------------------------------------------------------------
  */
 
-int
+bool
 GeoInclude(src, dst)
     Rect *src, *dst;
 {
@@ -546,11 +547,11 @@ GeoInclude(src, dst)
  *-------------------------------------------------------------------
  */
 
-int
+bool
 GeoIncludeAll(src, dst)
     Rect *src, *dst;
 {
-    int value;
+    bool value;
 
     if ((dst->r_xbot > dst->r_xtop) || (dst->r_ybot > dst->r_ytop))
     {
