@@ -223,7 +223,8 @@ extern void GeoTransRect(), GeoTransTrans();
 extern void GeoTransPoint(), GeoInvertTrans();
 extern void GeoTranslateTrans();
 extern void GeoTransTranslate();
-extern int GeoInclude(), GeoTransPos(), GeoIncludeAll();
+extern int GeoTransPos();
+extern bool GeoInclude(), GeoIncludeAll();
 extern void GeoClip();
 extern void GeoClipPoint();
 extern int GeoRectPointSide();
