@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/hash.c,v 1.2 2001/01
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
 
@@ -187,7 +187,7 @@ HashInitClient(table, nBuckets, ptrKeys, compareFn, copyFn, hashFn, killFn)
     }
 
     /* Allocate and initialize the buckets */
-    MALLOC(HashEntry **, table->ht_table,
+    table->ht_table = (HashEntry **) mallocMagic(
 		(unsigned) (sizeof (HashEntry *)  * table->ht_size));
     ptr = table->ht_table;
     for (i = 0; i < table->ht_size; i++)
@@ -417,23 +417,23 @@ next:
     switch (table->ht_ptrKeys)
     {
 	case HT_STRINGKEYS:
-	    MALLOC(HashEntry *, h, (unsigned) sizeof(HashEntry)+strlen(key)-3);
+	    h = (HashEntry *) mallocMagic((unsigned) (sizeof(HashEntry)+strlen(key)-3));
 	    (void) strcpy(h->h_key.h_name, key);
 	    break;
 	case HT_CLIENTKEYS:
 	    if (table->ht_copyFn)
 	    {
-		MALLOC(HashEntry *, h, (unsigned) sizeof (HashEntry));
+		h = (HashEntry *) mallocMagic((unsigned) (sizeof (HashEntry)));
 		h->h_key.h_ptr = (*table->ht_copyFn)(key);
 		break;
 	    }
 	    /* Fall through to ... */
 	case HT_WORDKEYS:
-	    MALLOC(HashEntry *, h, (unsigned) sizeof (HashEntry));
+	    h = (HashEntry *) mallocMagic((unsigned) (sizeof (HashEntry)));
 	    h->h_key.h_ptr = key;
 	    break;
 	case HT_STRUCTKEYS:
-	    MALLOC(HashEntry *, h,
+	    h = (HashEntry *) mallocMagic(
 		    (unsigned) (sizeof (HashEntry) + sizeof (unsigned)));
 	    up = h->h_key.h_words;
 	    kp = (unsigned *) key;
@@ -442,7 +442,7 @@ next:
 	    break;
 	default:
 	    n = table->ht_ptrKeys;
-	    MALLOC(HashEntry *, h,
+	    h = (HashEntry *) mallocMagic(
 		    (unsigned) (sizeof(HashEntry) + (n-1) * sizeof (unsigned)));
 	    up = h->h_key.h_words;
 	    kp = (unsigned *) key;
@@ -514,7 +514,7 @@ rebuild(table)
 	}
     }
 
-    FREE((char *) oldTable);
+    freeMagic((char *) oldTable);
 }
 
 /*---------------------------------------------------------
@@ -646,11 +646,11 @@ HashKill(table)
     for (hp = table->ht_table, hend = &hp[table->ht_size]; hp < hend; hp++)
 	for (h = *hp; h != NIL; h = h->h_next)
 	{
-	    FREE((char *) h);
+	    freeMagic((char *) h);
 	    if (killFn)
 		(*killFn)(h->h_key.h_ptr);
 	}
-    FREE((char *) table->ht_table);
+    freeMagic((char *) table->ht_table);
 
     /*
      * Set up the hash table to cause memory faults on any future
@@ -685,7 +685,7 @@ HashTable *table;
 	HashStartSearch(&hs);
 	while (he = HashNext(table, &hs)) {
 		p = HashGetValue(he);
-		FREE(p);
+		freeMagic(p);
 	}
 	HashKill(table);
 }
