@@ -22,7 +22,8 @@ static char rcsid[]  =  "$Header: /ufs/repository/magic/utils/heap.c,v 1.2 2001/
 
 #include <stdio.h>
 #include <string.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/heap.h"
 #include "utils/utils.h"
@@ -152,7 +153,7 @@ HeapInitType(heap, size, descending, stringIds, keyType)
 	    break;
     }
 
-    MALLOC(HeapEntry *, heap->he_list, (heap->he_size+2) * sizeof (HeapEntry));
+    heap->he_list = (HeapEntry *) mallocMagic((unsigned) ((heap->he_size+2) * sizeof (HeapEntry)));
     ASSERT(heap->he_list != NULL, "Malloc failed in HeapInit");
 }
 
@@ -188,7 +189,7 @@ HeapKill(heap, func)
     if (func)
         for (i = 1; i <= heap->he_used; i++)
 	   (*func) (heap, i);
-    FREE((char *) heap->he_list);
+    freeMagic((char *) heap->he_list);
     heap->he_list = NULL;
 }
 
@@ -215,7 +216,7 @@ HeapFreeIdFunc(heap, i)
     int i;			/* The index of the entry whose id gets freed */
 {
     if (heap->he_stringId)
-	FREE(heap->he_list[i].he_id);
+	freeMagic(heap->he_list[i].he_id);
 }
 
 /*
@@ -395,10 +396,10 @@ HeapAdd(heap, pKey, id)
 	HeapEntry *new;
 
 	/* Need to recopy to a larger area */
-	MALLOC(HeapEntry *, new, (2 * heap->he_size + 2) * sizeof (HeapEntry));
+	new = (HeapEntry *) mallocMagic((unsigned) ((2 * heap->he_size + 2) * sizeof (HeapEntry)));
 	bcopy((char *) list, (char *) new,
 		(heap->he_size + 2) * sizeof (HeapEntry));
-	FREE((char *) heap->he_list);
+	freeMagic((char *) heap->he_list);
 	heap->he_list = list = new;
 	heap->he_size *= 2;
     }
