@@ -22,7 +22,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/lookup.c,v 1.2 2001/
 
 #include <stdio.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 
 
