@@ -11,8 +11,7 @@
  *   run through linked lists and process and free them at the same time.
  *
  *   ALWAYS use mallocMagic() with freeMagic() and NEVER mix them with
- *   malloc() and free().  Note that MALLOC() and FREE() are macro calls
- *   to mallocMagic() and freeMagic(), respectively.
+ *   malloc() and free().
  *
  *   Malloc trace routines have been removed.  There are standard methods
  *   to trace memory allocation and magic doesn't need its own built-in
@@ -42,8 +41,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/malloc.c,v 1.6 2001/
 #include <errno.h>
 #include <string.h>
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/malloc.h"
 
 /* Normally we're supposed to warn against the use of standard malloc()	*/
