@@ -28,7 +28,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/path.c,v 1.5 2001/01
 #include <sys/param.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
@@ -166,7 +166,7 @@ PaExpand(psource, pdest, size)
 	}
 	if (string != NULL)
 	{
-	    MALLOC(char *, newEntry, strlen(string) + 1);
+	    newEntry = (char *) mallocMagic((unsigned) (strlen(string) + 1));
 	    (void) strcpy(newEntry, string);
 	    HashSetValue(h, newEntry);
 	}
@@ -234,7 +234,7 @@ PaExpand(psource, pdest, size)
 	    }
 	}
 
-	MALLOC(char *, newEntry, strlen(string) + 1);
+	newEntry = (char *) mallocMagic((unsigned) (strlen(string) + 1));
 	(void) strcpy(newEntry, string);
 	HashSetValue(h, newEntry);
 
