@@ -22,14 +22,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/port.c,v 1.2 2001/01
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
 
 /*-------------------------------------------------------------------
  * MagAtof --
  *	Magic's own atof function.
- *	Convert a string to a double floating point number.
+ *	Convert a string to a single-precision floating point number.
  *
  * Results:
  *	A floating point number.
@@ -39,15 +40,15 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/port.c,v 1.2 2001/01
  *-------------------------------------------------------------------
  */
 
-double
+float
 MagAtof(s)
     char *s;
 {
 #ifdef linux
     float flt;
-    if (sscanf (s, "%f", &flt) == 1) return flt;
-    else return -1.0;
+    if (sscanf(s, "%f", &flt) == 1) return flt;
+    else return (float)(-1.0);
 #else
-    return atof(s);
+    return (float)atof(s);
 #endif
 }
