@@ -2,19 +2,21 @@
 static char rcsid[] = "$Header: /ufs/repository/magic/utils/printstuff.c,v 1.2 2001/01/12 22:13:32 jsolomon Exp $";
 #endif /* not lint */
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 
+void
 PrintTrans(t)
-Transform *t;
+    Transform *t;
 {
     printf("Translate: (%d, %d)\n", t->t_c, t->t_f);
     printf("%d\t%d\n", t->t_a, t->t_d);
     printf("%d\t%d\n", t->t_b, t->t_e);
 }
 
+void
 PrintRect(r)
-Rect *r;
+    Rect *r;
 {
     printf("(%d,%d) :: (%d,%d)\n", r->r_xbot, r->r_ybot, r->r_xtop, r->r_ytop);
 }
