@@ -24,7 +24,7 @@ static char rcsid[]  =  "$Header: /ufs/repository/magic/utils/set.c,v 1.2 2001/0
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
