@@ -21,7 +21,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/stack.c,v 1.2 2001/0
 #endif	/* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/stack.h"
 #include "utils/malloc.h"
@@ -50,9 +51,9 @@ StackNew(sincr)
 {
     Stack *stack;
 
-    MALLOC(Stack *, stack, sizeof (Stack));
+    stack = (Stack *) mallocMagic((unsigned) (sizeof (Stack)));
     stack->st_incr = sincr;
-    MALLOC(struct stackBody *, stack->st_body, stackSize(sincr));
+    stack->st_body = (struct stackBody *) mallocMagic((unsigned) (stackSize(sincr)));
     stack->st_ptr = stack->st_body->sb_data;
     stack->st_body->sb_next = NULL;
 
@@ -83,10 +84,10 @@ StackFree(stack)
     for (stackp = stack->st_body; stackp != NULL; stackp = stacknext)
     {
 	stacknext = stackp->sb_next;
-	FREE((char *) stackp);
+	freeMagic((char *) stackp);
     }
 
-    FREE((char *) stack);
+    freeMagic((char *) stack);
 }
 
 /*
@@ -113,7 +114,7 @@ StackPush(arg, stack)
 
     if (stack->st_ptr >= &stack->st_body->sb_data[stack->st_incr])
     {
-	MALLOC(struct stackBody *, bodyNew, stackSize(stack->st_incr));
+	bodyNew = (struct stackBody *) mallocMagic((unsigned) (stackSize(stack->st_incr)));
 	bodyNew->sb_next = stack->st_body;
 	stack->st_ptr = bodyNew->sb_data;
 	stack->st_body = bodyNew;
@@ -153,7 +154,7 @@ StackPop(stack)
 	    return ((ClientData) NULL);
 	stack->st_body = bodyOld->sb_next;
 	stack->st_ptr = &stack->st_body->sb_data[stack->st_incr];
-	FREE((char *) bodyOld);
+	freeMagic((char *) bodyOld);
     }
 
     return (*--(stack->st_ptr));
