@@ -22,8 +22,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/strdup.c,v 1.2 2001/
 
 #include <stdio.h>
 #include <stdlib.h>		/* for strtod */
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 
 
@@ -39,9 +41,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/strdup.c,v 1.2 2001/
  *	null byte, which contains a copy of the supplied string.
  *
  * Side effects:
- *	MALLOC's a character array large enough to hold str, and
+ *	malloc's a character array large enough to hold str, and
  *	copies str into it, unless str is NULL.  If str is NULL, no
- *	MALLOC is done.  Also, if oldstr is non-NULL, then a) if
+ *	malloc is done.  Also, if oldstr is non-NULL, then a) if
  *	*oldstr is not NULL, frees the storage allocated to oldstr,
  *	and b) sets *oldstr to the new string allocated, or to
  *	NULL if str is NULL.
@@ -57,14 +59,14 @@ StrDup(oldstr, str)
 
     if (str != NULL)
     {
-	MALLOC(char *, newstr, strlen(str) + 1);
+	newstr = (char *) mallocMagic((unsigned) (strlen(str) + 1));
 	(void) strcpy(newstr, str);
     }
     else newstr = NULL;
     if (oldstr != (char **) NULL)
     {
 	if (*oldstr != NULL)
-	    FREE(*oldstr);
+	    freeMagic(*oldstr);
 	*oldstr = newstr;
     }
 
