@@ -23,7 +23,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/touchtypes.c,v 1.3 2
 
 #include <stdio.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -136,8 +136,10 @@ TouchingTypes(cellUse, expansionMask, point)
  *
  * ---------------------------------------------------------------------
  */
+
+int
 touchingTypesFunc(tile, cxp)
-    register Tile *tile;
+    Tile *tile;
     TreeContext *cxp;
 {
     SearchContext *scx = cxp->tc_scx;
@@ -174,6 +176,7 @@ touchingTypesFunc(tile, cxp)
  *
  * ---------------------------------------------------------------------
  */
+
 int
 touchingSubcellsFunc(scx, cdarg)
     SearchContext *scx;
