@@ -21,7 +21,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windClient.c,v 1.3 2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -30,14 +31,14 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windClient.c,v 1.3 2
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "main/main.h"
-#include "macros/macros.h"
+#include "utils/main.h"
+#include "utils/macros.h"
 #include "utils/utils.h"
 #include "utils/malloc.h"
 #include "graphics/graphics.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/txcommands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 /* The following defines are used to indicate corner positions
  * of the box:
@@ -59,12 +60,13 @@ extern int windQuitCmd(), windRedrawCmd();
 extern int windResetCmd(), windSpecialOpenCmd();
 extern int windOverCmd(), windUnderCmd(), windDebugCmd();
 extern int windDumpCmd(), windHelpCmd();
+extern int windMacroCmd(), windIntMacroCmd();
 extern int windLogCommandsCmd(), windUpdateCmd(), windSleepCmd();
 extern int windSourceCmd();
 extern int windSetpointCmd();
 extern int windPushbuttonCmd(), windSendCmd();
 extern int windPauseCmd(), windGrstatsCmd();
-extern int windEchoCmd(), windGrowCmd(), windMacroCmd(), windIntMacroCmd();
+extern int windEchoCmd(), windGrowCmd();
 extern int windUndoCmd(), windRedoCmd();
 extern int windCenterCmd(), windScrollCmd();
 extern int windVersionCmd(), windViewCmd(), windXviewCmd(), windZoomCmd();
@@ -98,10 +100,10 @@ static int windCorner = WIND_ILG;	/* Nearest corner when button went
  * ----------------------------------------------------------------------------
  */
 
+void
 windButtonSetCursor(button, corner)
-int button;			/* Button that is down. */
-int corner;			/* Corner to be displayed in cursor. */
-
+    int button;			/* Button that is down. */
+    int corner;			/* Corner to be displayed in cursor. */
 {
     switch (corner)
     {
@@ -306,6 +308,7 @@ windMoveRect(wholeRect, corner, p, rect)
  * ----------------------------------------------------------------------------
  */
 
+void
 windFrameDown(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -512,12 +515,6 @@ windClientButtons(w, cmd)
 	case WIND_X_WINDOWS:
 	    break;
 	
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunHandleCaptionInput(w, cmd);
-#endif	/* SUNVIEW */
-	    break;
-	
 	default:
 	    /* Magic Windows */
 	    if (cmd->tx_button == TX_MIDDLE_BUTTON) 
@@ -562,7 +559,7 @@ windClientButtons(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 windCmdInterp(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -604,9 +601,9 @@ windCmdInterp(w, cmd)
 void
 windClientInit()
 {
-    windClientID = WindAddClient(WINDOW_CLIENT, ( Void (*)() ) NULL,
-	( Void (*)() ) NULL, ( Void (*)() ) NULL, windCmdInterp, 
-	( Void (*)() ) NULL, ( Void (*)() ) NULL, ( Void (*)() ) NULL,
+    windClientID = WindAddClient(WINDOW_CLIENT, ( bool (*)() ) NULL,
+	( bool (*)() ) NULL, ( void (*)() ) NULL, windCmdInterp, 
+	( void (*)() ) NULL, ( bool (*)() ) NULL, ( void (*)() ) NULL,
 	(GrGlyph *) NULL);
 
     /* Set up all of the window commands */
@@ -634,7 +631,7 @@ windClientInit()
 	"center [x y]		center window on the cursor or indicated coordinate",
 	windCenterCmd, FALSE);
     WindAddCommand(windClientID,
-	"closewindow		close a window",
+	"closewindow [name]	close a window",
 	windCloseCmd, FALSE);
     WindAddCommand(windClientID,
 	"cursor			return magic coordinates of the cursor",
@@ -648,15 +645,15 @@ windClientInit()
 			containing pattern)",
 	windHelpCmd, FALSE);
     WindAddCommand(windClientID,
-	"imacro [char [string]]	define or print an interactive macro called char",
-	windIntMacroCmd, FALSE);
+        "imacro [char [string]] define or print an interactive macro called char",
+        windIntMacroCmd, FALSE);
     WindAddCommand(windClientID,
 	"logcommands [file [update]]\n\
 			log all commands into a file",
 	windLogCommandsCmd, FALSE);
     WindAddCommand(windClientID,
-	"macro [char [string]]	define or print a macro called char",
-	windMacroCmd, FALSE);
+        "macro [char [string]]  define or print a macro called char",
+        windMacroCmd, FALSE);
     WindAddCommand(windClientID,
 	"openwindow [cell][name]\n\
 			open a new window with indicated name, bound to indicated cell",
@@ -699,7 +696,12 @@ windClientInit()
 	"undo [count]		undo commands",
 	windUndoCmd, FALSE);
     WindAddCommand(windClientID,
+#ifdef MAGIC_WRAPPER
+	"updatedisplay [suspend|resume]\n\
+			force display update, or suspend/resume updates",
+#else
 	"updatedisplay		force the display to be updated",
+#endif
 	windUpdateCmd, FALSE);
     WindAddCommand(windClientID,
 	"version			print out version info",
