@@ -30,16 +30,16 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdAM.c,v 1.7 20
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "utils/malloc.h"
 #include "utils/runstats.h"
-#include "macros/macros.h"
-#include "signals/signals.h"
+#include "utils/macros.h"
+#include "utils/signals.h"
 #include "graphics/graphics.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/txcommands.h"
 #include "graphics/glyphs.h"
 #include "windows/windInt.h"
@@ -49,6 +49,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdAM.c,v 1.7 20
 #include "dbwind/dbwind.h"
 #include "utils/utils.h"
 
+/* Forward declarations */
+void windDoMacro();
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -738,131 +741,6 @@ windHelpCmd(w, cmd)
     ASSERT(FALSE, windHelpCmd);
 }
 
-
-/*
- * ----------------------------------------------------------------------------
- *
- * windDoMacro --
- *
- *	Working function for windIntMacroCmd and windMacroCmd
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Causes the macro package to define a new macro.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-windDoMacro(cmd, interactive)
-    TxCommand *cmd;
-    bool interactive;
-{
-    macrodef *cmacro;
-    char *cp, *cn;
-    char ch;
-    int ct, iReturn;
-    bool any;
-
-    if (cmd->tx_argc == 1)
-    {
-	any = FALSE;
-	ch = 0;
-	for (cmacro = mactable; cmacro != NULL; cmacro = cmacro->nextmacro)
-	{
-	    cp = cmacro->macrodef;
-	    cn = MacroName(cmacro->keyvalue);
-
-	    if (cmacro->interactive)
-	    {
-		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
-			     cn, cp);
-	    }
-	    else
-	    {
-		TxPrintf("Macro '%s' contains \"%s\"\n",
-			     cn, cp);
-	    }
-	    freeMagic(cn);
-	    any = TRUE;
-	}
-	if (!any)
-	    TxPrintf("No macros are defined.\n");
-	return;
-    }
-    else if (cmd->tx_argc == 2)
-    {
-	int verbose;
-	ct = MacroKey(cmd->tx_argv[1], &verbose);
-	if (ct == 0)
-	{
-        if( verbose ) TxError("Unrecognized macro name %s\n", cmd->tx_argv[1]);
-	    return;
-	}
-	cp = MacroRetrieve(ct, &iReturn);
-	if (cp != NULL)
-	{
-	    cn = MacroName(ct);
-	    if (iReturn)
-	    {
-		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
-			 cn, cp);
-	    }
-	    else
-	    {
-		TxPrintf("Macro '%s' contains \"%s\"\n",
-			 cn, cp);
-	    }
-	    freeMagic(cp);
-	    freeMagic(cn);
-	}
-	return;
-    }
-    else if (cmd->tx_argc == 3)
-    {
-	int verbose;
-	ct = MacroKey(cmd->tx_argv[1], &verbose);
-	if (ct == 0)
-	{
-        if( verbose ) TxError("Unrecognized macro name %s\n", cmd->tx_argv[1]);
-	    return;
-	}
-	if (cmd->tx_argv[2][0] == '\0') MacroDelete(ct);
-	else if (interactive) MacroDefine(ct, cmd->tx_argv[2], TRUE);
-	else MacroDefine(ct, cmd->tx_argv[2], FALSE);
-	return;
-    }
-
-    TxError("Usage: %s [macro_name [string]]\n", cmd->tx_argv[0]);
-}
-
-/*
- * ----------------------------------------------------------------------------
- *
- * windIntMacroCmd --
- *
- *	Define a new interactive macro.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Calls windDoMacro.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-windIntMacroCmd(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    windDoMacro(cmd, TRUE);
-}
-
-
 static char *logKeywords[] =
     {
 	"update",
@@ -914,7 +792,30 @@ usage:
     TxError("Usage: %s [filename [update]]\n", cmd->tx_argv[0]);
 }
 
-
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * windIntMacroCmd --
+ *
+ *	Define a new interactive macro.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Calls windDoMacro.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+windIntMacroCmd(w, cmd)
+    MagWindow *w;
+    TxCommand *cmd;
+{
+    windDoMacro(w, cmd, TRUE);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -936,7 +837,148 @@ windMacroCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    windDoMacro(cmd, FALSE);
+    windDoMacro(w, cmd, FALSE);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * windDoMacro --
+ *
+ *	Working function for CmdIntMacro and CmdMacro
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Causes the macro package to define a new macro.
+ *
+ * ----------------------------------------------------------------------------
+ */
 
+void
+windDoMacro(w, cmd, interactive)
+    MagWindow *w;
+    TxCommand *cmd;
+    bool interactive;
+{
+    char *cp, *cn;
+    char ch;
+    int ct, iReturn, argstart;
+    bool any;
+    macrodef *cMacro;
+    HashTable *clienttable;
+    HashEntry *h;
+    HashSearch hs;
+    WindClient wc;
+
+    /* If the second argument is a window name, we attempt to	*/
+    /* retrieve a client ID from it.  This overrides the actual	*/
+    /* window the command was called from, so technically we	*/
+    /* can define macros for clients from inside other clients.	*/
+    /* The main use, though, is to define macros for a client	*/
+    /* from a script, rc file, or command-line.			*/
+    /* Default to the layout window if the command has no	*/
+    /* associated window.					*/
+
+    argstart = 1;
+    if (cmd->tx_argc > 1)
+    {
+	wc = WindGetClient(cmd->tx_argv[1], TRUE);
+	if (wc == NULL)
+	    wc = (w == NULL) ? DBWclientID : w->w_client;
+	else
+	    argstart = 2;
+    }
+
+    if (cmd->tx_argc == argstart)
+    {
+	h = HashLookOnly(&MacroClients, wc);
+	if (h == NULL)
+	    return;
+	else
+	{
+	    clienttable = (HashTable *)HashGetValue(h);
+	    if (clienttable == (HashTable *)NULL)
+	    {
+		TxError("No such client.\n");
+		return;
+	    }
+	}
+
+	any = FALSE;
+	ch = 0;
+	HashStartSearch(&hs);
+	while (TRUE)
+	{
+	    h = HashNext(clienttable, &hs);
+	    if (h == NULL) break;
+	    cMacro = (macrodef *) HashGetValue(h);
+	    cp = cMacro->macrotext;
+	    cn = MacroName((int)h->h_key.h_ptr);
+
+	    if (cMacro->interactive)
+	    {
+		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
+			     cn, cp);
+	    }
+	    else
+	    {
+		TxPrintf("Macro '%s' contains \"%s\"\n",
+			     cn, cp);
+	    }
+	    freeMagic(cn);
+	    any = TRUE;
+	}
+	if (!any)
+	    TxPrintf("No macros are defined for this client.\n");
+	return;
+    }
+    else if (cmd->tx_argc == (argstart + 1))
+    {
+	int verbose;
+	ct = MacroKey(cmd->tx_argv[argstart], &verbose);
+	if (ct == 0)
+	{
+	    if (verbose)
+		TxError("Unrecognized macro name %s\n", cmd->tx_argv[argstart]);
+	    return;
+	}
+	cp = MacroRetrieve(wc, ct, &iReturn);
+	if (cp != NULL)
+	{
+	    cn = MacroName(ct);
+	    if (iReturn)
+	    {
+		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
+			 cn, cp);
+	    }
+	    else
+	    {
+		TxPrintf("Macro '%s' contains \"%s\"\n",
+			 cn, cp);
+	    }
+	    freeMagic(cp);
+	    freeMagic(cn);
+	}
+	return;
+    }
+    else if (cmd->tx_argc == (argstart + 2))
+    {
+	int verbose;
+	ct = MacroKey(cmd->tx_argv[argstart], &verbose);
+	if (ct == 0)
+	{
+	    if (verbose)
+		TxError("Unrecognized macro name %s\n", cmd->tx_argv[argstart]);
+	    return;
+	}
+	argstart++;
+	if (cmd->tx_argv[argstart][0] == '\0') MacroDelete(wc, ct);
+	else if (interactive) MacroDefine(wc, ct, cmd->tx_argv[argstart], TRUE);
+	else MacroDefine(wc, ct, cmd->tx_argv[argstart], FALSE);
+	return;
+    }
+
+    TxError("Usage: %s [macro_name [string]]\n", cmd->tx_argv[0]);
+}
