@@ -27,7 +27,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdNR.c,v 1.3 20
 #include <sys/types.h>
 #include <sys/times.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -36,10 +36,10 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdNR.c,v 1.3 20
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "main/main.h"
-#include "tech/tech.h"
+#include "utils/main.h"
+#include "utils/tech.h"
 #include "utils/runstats.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/utils.h"
 #include "graphics/graphics.h"
 #include "textio/txcommands.h"
@@ -83,7 +83,7 @@ windOpenCmd(w, cmd)
     area.r_ybot = frame.p_y - CREATE_HEIGHT/2;
     area.r_ytop = frame.p_y + CREATE_HEIGHT/2;
 
-    wc = WindGetClient(DEFAULT_CLIENT);
+    wc = WindGetClient(DEFAULT_CLIENT, TRUE);
     ASSERT(wc != (WindClient) NULL, "windOpenCmd");
 
     if (WindCreate(wc, &area, TRUE, cmd->tx_argc - 1, cmd->tx_argv + 1) == 
