@@ -26,22 +26,21 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdSZ.c,v 1.3 20
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "windows/windows.h"
 #include "graphics/glyphs.h"
 #include "windows/windInt.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/utils.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/txcommands.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "dbwind/dbwind.h"
 #include "graphics/graphics.h"
-#include "misc/patchlevel.h"
 
 
 /*
@@ -228,6 +227,8 @@ windSetpointCmd(w, cmd)
 
     if (cmd->tx_argc == 4) 
 	wid = atoi(cmd->tx_argv[3]);
+    else if (w != NULL)
+	wid = w->w_wid;
     else
 	wid = WIND_UNKNOWN_WINDOW;
 
@@ -396,7 +397,7 @@ windSpecialOpenCmd(w, cmd)
     else
 	client = cmd->tx_argv[1];
 
-    wc = WindGetClient(client);
+    wc = WindGetClient(client, FALSE);
     /* clients whose names begin with '*' are hidden */
     if ((wc == (WindClient) NULL) || (client[0] == '*')) goto usage;
 
@@ -452,7 +453,7 @@ windNamesCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    bool doforall = False;
+    bool doforall = FALSE;
     WindClient wc = NULL;
     MagWindow *sw;
 
@@ -464,10 +465,10 @@ windNamesCmd(w, cmd)
     if (cmd->tx_argc == 2)
     {
 	if (!strncmp(cmd->tx_argv[1], "all", 3))
-	    doforall = True;
+	    doforall = TRUE;
 	else
 	{
-	    wc = WindGetClient(cmd->tx_argv[1]);
+	    wc = WindGetClient(cmd->tx_argv[1], FALSE);
 	    if (wc == (WindClient) NULL)
 	    {
 		TxError("Usage:  windownames [all | client_type]\n");
@@ -475,7 +476,7 @@ windNamesCmd(w, cmd)
 		WindPrintClientList(FALSE);
 		return;
 	    }
-	    doforall = True;
+	    doforall = TRUE;
 	}
     }
 
@@ -484,10 +485,10 @@ windNamesCmd(w, cmd)
 	wc = DBWclientID;
 	windCheckOnlyWindow(&w, wc);
 	if (w == (MagWindow *)NULL)
-	    doforall = True;
+	    doforall = TRUE;
     }
 
-    if (doforall == True)
+    if (doforall == TRUE)
     {
 	for (sw = windTopWindow; sw != NULL; sw = sw->w_nextWindow)
 	    if ((wc == NULL) || (sw->w_client == wc))
@@ -686,8 +687,8 @@ windVersionCmd(w, cmd)
 	return;
     }
 
-    TxPrintf("Version %s.  Compiled on %s.\n", MagicVersion, MagicCompileTime);
-    TxPrintf("Patch level %d.\nPatch history: %s\n", PATCHLEVEL, PatchNames());
+    TxPrintf("Version %s revision %s.  Compiled on %s.\n",
+		MagicVersion, MagicRevision, MagicCompileTime);
 }
 
 /*
@@ -942,7 +943,7 @@ windSendCmd(w, cmd)
     if (cmd->tx_argc < 3) goto usage;
     if (cmd->tx_argv[1][0] == '*') goto usage; /* hidden window client */
 
-    client = WindGetClient(cmd->tx_argv[1]);
+    client = WindGetClient(cmd->tx_argv[1], FALSE);
     if (client == (WindClient) NULL) goto usage;
     toWindow = (MagWindow *) NULL;
     (void) WindSearch(client, (ClientData) NULL, (Rect *) NULL, 
