@@ -22,7 +22,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windDisp.c,v 1.3 200
 #include <stdio.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -30,12 +30,12 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windDisp.c,v 1.3 200
 #include "windows/windows.h"
 #include "windows/windInt.h"
 #include "graphics/graphics.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 
 /* The following Plane is used to keep track of areas of the
@@ -123,7 +123,7 @@ windFreeList(llr)
     {
 	freelr = lr;
 	lr = lr->r_next;
-	FREE( (char *) freelr);
+	freeMagic( (char *) freelr);
     }
 
     *llr = (LinkedRect *) NULL;
@@ -159,7 +159,7 @@ windReClip()
 	LinkedRect *tmp;
 
 	/* add window onto windCoveredAreas */
-	MALLOC(LinkedRect *, tmp, sizeof (LinkedRect));
+	tmp = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
 	tmp->r_next = windCoveredAreas;
 	tmp->r_r = w1->w_frameArea;
 	windCoveredAreas = tmp;
@@ -178,7 +178,7 @@ windReClip()
 	    {
 		if ( GEO_TOUCH( &(w1->w_frameArea), &(w2->w_frameArea) ))
 		{
-		    MALLOC(LinkedRect *, tmp, sizeof (LinkedRect));
+		    tmp = (LinkedRect *) mallocMagic((unsigned) (sizeof (LinkedRect)));
 		    tmp->r_next = w1->w_clipAgainst;
 		    tmp->r_r = w2->w_frameArea;
 		    w1->w_clipAgainst = tmp;
