@@ -48,7 +48,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windMain.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "graphics/glyphs.h"
 #include "windows/windows.h"
@@ -217,19 +219,19 @@ WindInit()
 
 WindClient
 WindAddClient(clientName, create, delete, redisplay, command, update, 
-exitproc, reposition, icon)
+		exitproc, reposition, icon)
     char *clientName;		/* A textual name for the client.  This
 				 * name will be visable in the user
 				 * interface as the name to use to switch
 				 * a window over to a new client
 				 */
-    Void (*create)();
+    bool (*create)();
     bool (*delete)();
-    Void (*redisplay)();
-    Void (*command)();
-    Void (*update)();
-    Void (*exitproc)();
-    Void (*reposition)();
+    void (*redisplay)();
+    void (*command)();
+    void (*update)();
+    bool (*exitproc)();
+    void (*reposition)();
     GrGlyph *icon;		/* An icon to draw when the window is closed.
 				 * (currently for Sun Windows only).
 				 */
@@ -238,7 +240,6 @@ exitproc, reposition, icon)
 
     ASSERT( (clientName != NULL), "WindAddClient");
     ASSERT( (command != NULL), "WindAddClient");
-    ASSERT( (table != NULL), "WindAddClient");
 
     res = (clientRec *) mallocMagic(sizeof(clientRec));
     res->w_clientName = clientName;
@@ -258,7 +259,7 @@ exitproc, reposition, icon)
 
     res->w_commandTable = (char **)mallocMagic(sizeof(char *));
     *(res->w_commandTable) = NULL;
-    res->w_functionTable = (Void (**)())mallocMagic(sizeof(Void (*)()));
+    res->w_functionTable = (void (**)())mallocMagic(sizeof(void (*)()));
     *(res->w_functionTable) = NULL;
 
     windFirstClientRec = res;
@@ -283,29 +284,72 @@ exitproc, reposition, icon)
  */
 
 WindClient
-WindGetClient(clientName)
+WindGetClient(clientName, exact)
     char *clientName;	/* the textual name of the client */
+    bool exact;		/* must the name be exact, or are abbreviations allowed */
 {
     clientRec *cr, *found;
     int length;
 
-    /* Accept any unique abbreviation. */
+    /* Accept only an exact match */
+
+    if (exact)
+    {
+	for (cr = windFirstClientRec; cr != (clientRec *) NULL; 
+		cr = cr->w_nextClient)
+	    if (!strcmp(clientName, cr->w_clientName))
+		return (WindClient)cr;
+	return (WindClient) NULL;
+    }
+
+    /* Accept any unique abbreviation */
 
     found = NULL;
     length = strlen(clientName);
     for (cr = windFirstClientRec; cr != (clientRec *) NULL; 
 	    cr = cr->w_nextClient)
     {
-	if (strncmp(clientName, cr->w_clientName, length) == 0)
+	if (!strncmp(clientName, cr->w_clientName, length))
 	{
-	    if (found != NULL) return NULL;
+	    if (found != NULL) return (WindClient) NULL;
 	    found = cr;
 	}
     }
 
     return (WindClient) found;
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ * WindNextClient --
+ *
+ *	Return the w_nextClient record to the caller as a WindClient
+ *	variable.  If "client" is 0, pass the first client record.
+ *	This allows the calling routine to enumerate all the known
+ *	clients.
+ *
+ * Results:
+ *	Type WindClient is returned.  If the end of the list is
+ *	reached, (WindClient)NULL (0) is returned.
+ *
+ * Side effects:
+ *	None.
+ * ----------------------------------------------------------------------------
+ */
+
+WindClient
+WindNextClient(client)
+    WindClient client;
+{
+    clientRec *cr = (clientRec *)client;
+    int length;
+
+    if (cr == NULL)
+	return (WindClient)windFirstClientRec;
+    else
+	return (WindClient)(cr->w_nextClient);
+}
+
 /*
  * ----------------------------------------------------------------------------
  * WindPrintClientList --
@@ -320,6 +364,7 @@ WindGetClient(clientName)
  * ----------------------------------------------------------------------------
  */
 
+void
 WindPrintClientList(wizard)
     bool wizard;	/* If true print the names of ALL clients, even those
 			 * that don't have user-visable windows */
@@ -359,7 +404,7 @@ WindExecute(w, rc, cmd)
     int cmdNum;
     clientRec *client = (clientRec *) rc;
     char **commandTable = client->w_commandTable;
-    Void (**functionTable)() = client->w_functionTable;
+    void (**functionTable)() = client->w_functionTable;
 
     if (cmd->tx_argc > 0)
     {
@@ -367,7 +412,7 @@ WindExecute(w, rc, cmd)
 
 	if (cmdNum >= 0)
 	{
-	    (void) (*functionTable[cmdNum])(w, cmd);
+	    (*functionTable[cmdNum])(w, cmd);
 	    return cmdNum;
 	}
 	return -1;
@@ -399,15 +444,15 @@ void
 WindAddCommand(rc, text, func, dynamic)
     WindClient rc;
     char *text;
-    Void (*func)();
+    void (*func)();
     bool dynamic;
 {
     int cidx, numCommands = 0;
     clientRec *client = (clientRec *) rc;
     char **commandTable = client->w_commandTable;
-    Void (**functionTable)() = client->w_functionTable;
+    void (**functionTable)() = client->w_functionTable;
     char **newcmdTable;
-    Void (**newfnTable)();
+    void (**newfnTable)();
 
     /* Find the number of commands and functions, increment by one, and */
     /* Allocate a new array of pointers.				*/
@@ -416,7 +461,7 @@ WindAddCommand(rc, text, func, dynamic)
     numCommands++;
 
     newcmdTable = (char **)mallocMagic((numCommands + 1) * sizeof(char *));
-    newfnTable = (Void (**)())mallocMagic((numCommands + 1) * sizeof(Void (*)()));
+    newfnTable = (void (**)())mallocMagic((numCommands + 1) * sizeof(void (*)()));
 
     /* Copy the old values, inserting the new command in alphabetical	*/
     /* order.								*/
@@ -482,12 +527,12 @@ int
 WindReplaceCommand(rc, command, newfunc)
     WindClient rc;
     char *command;
-    Void (*newfunc)();
+    void (*newfunc)();
 {
     int cidx, clen;
     clientRec *client = (clientRec *) rc;
     char **commandTable = client->w_commandTable;
-    Void (**functionTable)() = client->w_functionTable;
+    void (**functionTable)() = client->w_functionTable;
 
     clen = strlen(command);
 
