@@ -22,7 +22,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windMove.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -72,6 +74,7 @@ int windCurNumWindows = 0;
  * ----------------------------------------------------------------------------
  */
 
+void
 windUnlink(w)
     MagWindow *w;
 {
@@ -131,7 +134,7 @@ windFree(w)
     windCurNumWindows--;
     if (w->w_caption != (char *) NULL) freeMagic(w->w_caption);
     if (w->w_iconname != (char *) NULL) freeMagic(w->w_iconname);
-    if (w->w_redrawAreas != NULL) {
+    if (w->w_redrawAreas != (ClientData) NULL) {
 	DBFreePaintPlane( (Plane *) w->w_redrawAreas);
 	TiFreePlane( (Plane *) w->w_redrawAreas);
     }
@@ -160,7 +163,6 @@ WindSetWindowAreas(w)
     switch ( WindPackageType )
     {
 	case WIND_X_WINDOWS:
-	case WIND_SUN_WINDOWS:
 	    /* Windows have origin at lower-left corner */
 	    w->w_allArea.r_xbot = w->w_allArea.r_ybot = 0;
 	    w->w_allArea.r_xtop = w->w_frameArea.r_xtop - w->w_frameArea.r_xbot;
@@ -179,10 +181,7 @@ WindSetWindowAreas(w)
  * ----------------------------------------------------------------------------
  * windSetWindowPosition --
  *
- *	Make sure that the window system knows that the window is located
- *	at w->w_frameArea.  Called when w->w_frame area is changed.
- *	This is a no-op if Magic is managing it's own windows, since it
- *	runs directly off of w->w_frameArea.
+ *	(deprecated function)
  *
  * Results:
  *	None.
@@ -191,19 +190,11 @@ WindSetWindowAreas(w)
  *	None.
  * ----------------------------------------------------------------------------
  */
-	/* ARGSUSED */
+
 void
 windSetWindowPosition(w)
     MagWindow *w;
 {
-    switch ( WindPackageType )
-    {
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunSetWindowPosition(w);
-#endif	/* SUNVIEW */
-	    break;
-    }
 }
 
 /*
@@ -259,7 +250,6 @@ WindDelete(w)
  *	windows.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
 MagWindow *
 WindCreate(client, frameArea, isHint, argc, argv)
@@ -295,8 +285,8 @@ WindCreate(client, frameArea, isHint, argc, argv)
     w->w_stippleOrigin.p_x = 0;
     w->w_stippleOrigin.p_y = 0;
     w->w_bbox = NULL;
-    w->w_grdata = NULL;
-    w->w_redrawAreas = NULL;
+    w->w_grdata = (ClientData) NULL;
+    w->w_redrawAreas = (ClientData) NULL;
     w->w_iconname = NULL;
     for (id = 0; ((1 << id) & windWindowMask) != 0; id++) /* advance id */ ;
     windWindowMask |= (1 << id);
@@ -326,11 +316,7 @@ WindCreate(client, frameArea, isHint, argc, argv)
     }
     else
 	w->w_frameArea = *frameArea;
-#ifdef	SUNVIEW
-    /* Don't set window positions ourselves. */
-    if ((WindPackageType == WIND_SUN_WINDOWS) && isHint)
-	GrSunFigureLocation(&w->w_frameArea);
-#endif	/* SUNVIEW */
+
     WindSetWindowAreas(w);
 
     /* now link the window in on top */
@@ -343,7 +329,7 @@ WindCreate(client, frameArea, isHint, argc, argv)
     windTopWindow = w;
 
     /* notify the client */
-    OK = ( (cr->w_create == NULL) || (*(cr->w_create))(w, argc, argv) );
+    OK = ((cr->w_create == NULL) || (*(cr->w_create))(w, argc, argv));
 
 #ifdef THREE_D
     if (strcmp(cr->w_clientName, "wind3d"))
@@ -454,11 +440,6 @@ WindUnder(w)
 	    if ( GrUnderWindowPtr )
 		(*GrUnderWindowPtr)(w);
 	    break;
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunUnder(w);
-#endif	/* SUNVIEW */
-	    break;
 	default:
 	    /* Mark for redisplay all the areas that this window
 	     * currently obscures.
@@ -517,12 +498,6 @@ WindOver(w)
 		(*GrOverWindowPtr)(w);
 	    break;
 	
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunOver(w);
-#endif	/* SUNVIEW */
-	    break;
-	
 	default:
 	    /* Mark for redisplay all of the areas of the screen that
 	     * currently obscure this window.
@@ -660,9 +635,9 @@ WindReframe(w, r, inside, move)
     if (move)
     {
 	xmove = newFrameArea.r_xbot - w->w_frameArea.r_xbot;
-	w->w_origin.p_x += xmove << 12;
+	w->w_origin.p_x += xmove << SUBPIXELBITS;
 	ymove = newFrameArea.r_ybot - w->w_frameArea.r_ybot;
-	w->w_origin.p_y += ymove << 12;
+	w->w_origin.p_y += ymove << SUBPIXELBITS;
 	w->w_stippleOrigin.p_x += xmove;
 	w->w_stippleOrigin.p_y += ymove;
     }
@@ -670,7 +645,6 @@ WindReframe(w, r, inside, move)
     switch ( WindPackageType )
     {
 	case WIND_X_WINDOWS:
-	case WIND_SUN_WINDOWS:
 	    break;
 	
 	default:
@@ -717,7 +691,6 @@ WindReframe(w, r, inside, move)
 
     switch ( WindPackageType )
     {
-	case WIND_SUN_WINDOWS:
 	case WIND_X_WINDOWS:
 	    break;
 	
@@ -864,9 +837,6 @@ WindFullScreen(w)
 	    if ( GrConfigureWindowPtr )
 		(*GrConfigureWindowPtr)(w);
 	    break;
-	case WIND_SUN_WINDOWS:
-	    WindAreaChanged(w, (Rect *) NULL);
-	    break;
 	default:
 	    WindAreaChanged((MagWindow *) NULL, (Rect *) NULL);
     }
