@@ -21,8 +21,11 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windSend.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
-#include "misc/magic.h"
+
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -30,13 +33,10 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windSend.c,v 1.2 200
 #include "windows/windInt.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/txcommands.h"
 
 clientRec *windClient = NULL;
-#ifdef THREE_D
-clientRec *threeDClient = NULL;
-#endif
 
 bool windPrintCommands = FALSE;	/* debugging flag */
 
@@ -56,6 +56,12 @@ static WindClient windGrabber =  (WindClient) NULL;
 
 Stack *windGrabberStack = NULL;
 
+/* Forward declarations */
+
+extern void WindGrabInput();
+extern void WindReleaseInput();
+extern void windHelp();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -97,7 +103,7 @@ WindSendCommand(w, cmd)
     /* itself.							*/
 
     if (windClient == (clientRec *) NULL)
-	windClient = (clientRec *) WindGetClient(WINDOW_CLIENT);
+	windClient = (clientRec *) WindGetClient(WINDOW_CLIENT, TRUE);
 
     /* ignore no-op commands */
     if ( (cmd->tx_button == TX_NO_BUTTON) && (cmd->tx_argc == 0) )
@@ -155,9 +161,9 @@ WindSendCommand(w, cmd)
     }
     else
 	/* Can't determine a window---assume a windowless layout client */
-	rc = (clientRec *) WindGetClient(DEFAULT_CLIENT);
+	rc = (clientRec *) WindGetClient(DEFAULT_CLIENT, TRUE);
 
-    if (windGrabber != NULL)
+    if (windGrabber != (WindClient) NULL)
     {
 	/* this client wants to hog all commands */
 	rc = (clientRec *) windGrabber;
@@ -201,7 +207,7 @@ WindSendCommand(w, cmd)
 		TxError( "'%s' window is waiting for %s button to be released.\n",
 		    rc->w_clientName, bname);
 	    }
-	    else if (windGrabber != NULL)
+	    else if (windGrabber != (WindClient) NULL)
 	    {
 		TxError( "'%s' window is grabbing all input.\n", rc->w_clientName);
 	    }
@@ -274,7 +280,7 @@ WindSendCommand(w, cmd)
     /* A client may modify WindNewButtons & WindOldButtons in rare cases,
      * so we better check again.
      */
-    if ((WindNewButtons == 0) && (windGrabber != NULL))
+    if ((WindNewButtons == 0) && (windGrabber != (WindClient) NULL))
 	WindReleaseInput((WindClient) rc);
 
     return TRUE;
@@ -298,6 +304,7 @@ WindSendCommand(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 WindGrabInput(client)
     WindClient client;
 {
@@ -322,6 +329,7 @@ WindGrabInput(client)
  * ----------------------------------------------------------------------------
  */
 
+void
 WindReleaseInput(client)
     WindClient client;
 {
@@ -343,8 +351,8 @@ WindReleaseInput(client)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windHelp(cmd, name, table)
     TxCommand *cmd;		/* Information about command options. */
     char *name;			/* Name of client for whom help is being
