@@ -20,17 +20,22 @@
  *
  */
 
-#define _WINDOWS
+#ifndef _WINDOWS_H
+#define _WINDOWS_H
 
-#ifndef _MAGIC
-    err = Need_to_include_misc/magic_header
-#endif
-#ifndef _GEOMETRY
-    err = Need_to_include_utils/geometry_header
-#endif
+#include "utils/magic.h"
+#include "utils/geometry.h"
 
+/* SUBPIXELBITS represents a fixed-point shift for representing the	*/
+/* scale factor between the screen and the layout.  It is only		*/
+/* necessary that the screen resolution * SUBPIXEL does not overflow	*/
+/* type (int).  The original value of 12 has become too small for	*/
+/* large chips on nanometer grids, so it has been upped to 16.		*/
+
+#define SUBPIXELBITS		16
+#define SUBPIXEL		(1 << SUBPIXELBITS)
+#define HSUBPIXEL		(1 << (SUBPIXELBITS - 1))
 
-
 typedef ClientData WindClient;	/* A unique ID of a client of the
 				 * window package.  The value 'NULL' is
 				 * indicates an invalid value.
@@ -118,12 +123,12 @@ typedef struct WIND_S1 {
 				 * are modified by procedures that move and
 				 * scroll windows, e.g. WindMove and WindScroll.
 				 */
-    Point w_origin;		/* This screen point, in 1/4096 pixels,
+    Point w_origin;		/* This screen point, in 1/SUBPIXEL pixels,
 				 * corresponds to w_surfaceArea.r_ll.
 				 * Used to transform between surface and screen
 				 * coordinates. (R)
 				 */
-    int w_scale;		/* Defines how many 1/4096ths of a pixel
+    int w_scale;		/* Defines how many 1/SUBPIXEL of a pixel
 				 * correspond to 1 world unit.  Used to
 				 * transform between surface and screen
 				 * coordinates. (R)
@@ -222,6 +227,7 @@ typedef struct WIND_S1 {
 /* utility procs & special stuff */
 extern MagWindow *WindCreate();
 extern WindClient WindGetClient();
+extern WindClient WindNextClient();
 extern WindClient WindAddClient();
 extern void WindInit();
 extern void WindUpdate();
@@ -233,6 +239,7 @@ extern int WindExecute();
 extern void WindAddCommand();
 extern int WindReplaceCommand();
 extern char **WindGetCommandTable();
+extern int windCheckOnlyWindow(MagWindow **, WindClient);
 
 
 /* searching procs */
@@ -261,7 +268,7 @@ extern void WindScreenToSurface();
 extern void WindSurfaceToScreen();
 extern void WindPointToSurface();
 extern void WindPointToScreen();
-
+extern void WindSurfaceToScreenNoClip();
 
 /* procs to change things or inform the window manager about changes */
 extern void WindCaption();
@@ -296,8 +303,7 @@ extern int windMaxWindows;  	/* Use above macro, never increase this! */
  */
 extern int WindPackageType;
 #define WIND_MAGIC_WINDOWS	0
-#define WIND_SUN_WINDOWS	1
-#define	WIND_X_WINDOWS		2
+#define	WIND_X_WINDOWS		1
 
 /* Scroll bar width.
  * May be set by the graphics package before WindInit() is called.
@@ -310,3 +316,5 @@ extern int WindScrollBarWidth;
 
 /* Global identifier for the window client structure */
 extern WindClient windClientID;
+
+#endif /* _WINDOWS_H */
