@@ -22,7 +22,7 @@
 #ifndef _WIREINT_H
 #define _WIREINT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "database/database.h"
 
 /* Undo-able wiring parameters: */
