@@ -23,7 +23,8 @@ static char rcsid[]="$Header: /ufs/repository/magic/wiring/wireOps.c,v 1.2 2001/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -33,11 +34,11 @@ static char rcsid[]="$Header: /ufs/repository/magic/wiring/wireOps.c,v 1.2 2001/
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "drc/drc.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "wiring/wiring.h"
 #include "wiring/wireInt.h"
 #include "textio/txcommands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 /* The following variables define the state of the wiring interface. */
 
