@@ -25,13 +25,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/wiring/wireTech.c,v 1.2 2001
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "wiring/wiring.h"
 #include "utils/malloc.h"
 
