@@ -19,14 +19,11 @@
  * rcsid $Header: /ufs/repository/magic/wiring/wiring.h,v 1.2 2001/01/12 22:13:37 jsolomon Exp $
  */
 
-#define _WIRING
+#ifndef _WIRING_H
+#define _WIRING_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_DATABASE
-int err0 = Need_to_include_database/database_header;
-#endif	/* _DATABASE */
+#include "utils/magic.h"
+#include "database/database.h"
 
 /* Table that defines the shape of contacts and the layers that they
  * connect.  This definition allows some layers to extend around the
@@ -34,7 +31,9 @@ int err0 = Need_to_include_database/database_header;
  * sizes for the different layers that the contact connects.
  */
 
-typedef struct
+typedef struct _Contact *ContactPtr;
+
+typedef struct _Contact
 {
     TileType con_type;		/* Type of material that forms core of
 				 * contact.
@@ -53,12 +52,12 @@ typedef struct
 				 * the contact connects.
 				 */
     int con_surround2;
+
+    ContactPtr con_next;	/* Pointer to next contact record */
 } Contact;
 
-extern Contact *WireContacts[];	/* Points to all the contacts that are
-				 * defined.
-				 */
-extern int WireNumContacts;	/* Number of valid entries in WireContacts. */
+extern Contact *WireContacts;	/* Points to all the contacts that are
+				 * defined. */
 
 /* Procedures for placing wires: */
 
@@ -77,7 +76,10 @@ extern void WireAddContact();
 extern void WireTechInit();
 extern bool WireTechLine();
 extern void WireTechFinal();
+extern void WireTechScale();
 
 /* Initialization: */
 
 extern void WireInit();
+
+#endif /* _WIRING_H */
